```py
namespace azure.mgmt.web

    class azure.mgmt.web.WebSiteManagementClient(_WebSiteManagementClientOperationsMixin): implements ContextManager 
        app_service_environments: AppServiceEnvironmentsOperations
        app_service_plans: AppServicePlansOperations
        certificates: CertificatesOperations
        deleted_web_apps: DeletedWebAppsOperations
        diagnostics: DiagnosticsOperations
        get_usages_in_location: GetUsagesInLocationOperations
        global_operations: GlobalOperations
        kube_environments: KubeEnvironmentsOperations
        provider: ProviderOperations
        recommendations: RecommendationsOperations
        resource_health_metadata: ResourceHealthMetadataOperations
        site_certificates: SiteCertificatesOperations
        static_sites: StaticSitesOperations
        web_apps: WebAppsOperations
        workflow_run_action_repetitions: WorkflowRunActionRepetitionsOperations
        workflow_run_action_repetitions_request_histories: WorkflowRunActionRepetitionsRequestHistoriesOperations
        workflow_run_action_scope_repetitions: WorkflowRunActionScopeRepetitionsOperations
        workflow_run_actions: WorkflowRunActionsOperations
        workflow_runs: WorkflowRunsOperations
        workflow_trigger_histories: WorkflowTriggerHistoriesOperations
        workflow_triggers: WorkflowTriggersOperations
        workflow_versions: WorkflowVersionsOperations
        workflows: WorkflowsOperations

        def __init__(
                self, 
                credential: TokenCredential, 
                subscription_id: str, 
                base_url: Optional[str] = None, 
                *, 
                api_version: str = ..., 
                cloud_setting: Optional[AzureClouds] = ..., 
                polling_interval: Optional[int] = ..., 
                **kwargs: Any
            ) -> None: ...

        @overload
        def check_name_availability(
                self, 
                request: ResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ResourceNameAvailability: ...

        @overload
        def check_name_availability(
                self, 
                request: ResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ResourceNameAvailability: ...

        @overload
        def check_name_availability(
                self, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ResourceNameAvailability: ...

        def close(self) -> None: ...

        @distributed_trace
        def get_publishing_user(self, **kwargs: Any) -> User: ...

        @distributed_trace
        def get_source_control(
                self, 
                source_control_type: str, 
                **kwargs: Any
            ) -> SourceControl: ...

        @distributed_trace
        def get_subscription_deployment_locations(self, **kwargs: Any) -> DeploymentLocations: ...

        @distributed_trace
        def list_ase_regions(self, **kwargs: Any) -> ItemPaged[AseRegion]: ...

        @distributed_trace
        def list_billing_meters(
                self, 
                *, 
                billing_location: Optional[str] = ..., 
                os_type: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[BillingMeter]: ...

        @distributed_trace
        def list_custom_host_name_sites(
                self, 
                *, 
                hostname: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[CustomHostnameSites]: ...

        @distributed_trace
        def list_geo_regions(
                self, 
                *, 
                custom_mode_workers_enabled: Optional[bool] = ..., 
                linux_dynamic_workers_enabled: Optional[bool] = ..., 
                linux_workers_enabled: Optional[bool] = ..., 
                sku: Optional[Union[str, SkuName]] = ..., 
                xenon_workers_enabled: Optional[bool] = ..., 
                **kwargs: Any
            ) -> ItemPaged[GeoRegion]: ...

        @distributed_trace
        def list_premier_add_on_offers(self, **kwargs: Any) -> ItemPaged[PremierAddOnOffer]: ...

        @overload
        def list_site_identifiers_assigned_to_host_name(
                self, 
                name_identifier: NameIdentifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[Identifier]: ...

        @overload
        def list_site_identifiers_assigned_to_host_name(
                self, 
                name_identifier: NameIdentifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[Identifier]: ...

        @overload
        def list_site_identifiers_assigned_to_host_name(
                self, 
                name_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[Identifier]: ...

        @distributed_trace
        def list_skus(self, **kwargs: Any) -> SkuInfos: ...

        @distributed_trace
        def list_source_controls(self, **kwargs: Any) -> ItemPaged[SourceControl]: ...

        @overload
        def move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def regional_check_name_availability(
                self, 
                location: str, 
                request: DnlResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DnlResourceNameAvailability: ...

        @overload
        def regional_check_name_availability(
                self, 
                location: str, 
                request: DnlResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DnlResourceNameAvailability: ...

        @overload
        def regional_check_name_availability(
                self, 
                location: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DnlResourceNameAvailability: ...

        def send_request(
                self, 
                request: HttpRequest, 
                *, 
                stream: bool = False, 
                **kwargs: Any
            ) -> HttpResponse: ...

        @overload
        def update_publishing_user(
                self, 
                user_details: User, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> User: ...

        @overload
        def update_publishing_user(
                self, 
                user_details: User, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> User: ...

        @overload
        def update_publishing_user(
                self, 
                user_details: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> User: ...

        @overload
        def update_source_control(
                self, 
                source_control_type: str, 
                request_message: SourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SourceControl: ...

        @overload
        def update_source_control(
                self, 
                source_control_type: str, 
                request_message: SourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SourceControl: ...

        @overload
        def update_source_control(
                self, 
                source_control_type: str, 
                request_message: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SourceControl: ...

        @overload
        def validate(
                self, 
                resource_group_name: str, 
                validate_request: ValidateRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ValidateResponse: ...

        @overload
        def validate(
                self, 
                resource_group_name: str, 
                validate_request: ValidateRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ValidateResponse: ...

        @overload
        def validate(
                self, 
                resource_group_name: str, 
                validate_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ValidateResponse: ...

        @overload
        def validate_move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def validate_move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def validate_move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def verify_hosting_environment_vnet(
                self, 
                parameters: VnetParameters, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetValidationFailureDetails: ...

        @overload
        def verify_hosting_environment_vnet(
                self, 
                parameters: VnetParameters, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetValidationFailureDetails: ...

        @overload
        def verify_hosting_environment_vnet(
                self, 
                parameters: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetValidationFailureDetails: ...


namespace azure.mgmt.web.aio

    class azure.mgmt.web.aio.WebSiteManagementClient(_WebSiteManagementClientOperationsMixin): implements AsyncContextManager 
        app_service_environments: AppServiceEnvironmentsOperations
        app_service_plans: AppServicePlansOperations
        certificates: CertificatesOperations
        deleted_web_apps: DeletedWebAppsOperations
        diagnostics: DiagnosticsOperations
        get_usages_in_location: GetUsagesInLocationOperations
        global_operations: GlobalOperations
        kube_environments: KubeEnvironmentsOperations
        provider: ProviderOperations
        recommendations: RecommendationsOperations
        resource_health_metadata: ResourceHealthMetadataOperations
        site_certificates: SiteCertificatesOperations
        static_sites: StaticSitesOperations
        web_apps: WebAppsOperations
        workflow_run_action_repetitions: WorkflowRunActionRepetitionsOperations
        workflow_run_action_repetitions_request_histories: WorkflowRunActionRepetitionsRequestHistoriesOperations
        workflow_run_action_scope_repetitions: WorkflowRunActionScopeRepetitionsOperations
        workflow_run_actions: WorkflowRunActionsOperations
        workflow_runs: WorkflowRunsOperations
        workflow_trigger_histories: WorkflowTriggerHistoriesOperations
        workflow_triggers: WorkflowTriggersOperations
        workflow_versions: WorkflowVersionsOperations
        workflows: WorkflowsOperations

        def __init__(
                self, 
                credential: AsyncTokenCredential, 
                subscription_id: str, 
                base_url: Optional[str] = None, 
                *, 
                api_version: str = ..., 
                cloud_setting: Optional[AzureClouds] = ..., 
                polling_interval: Optional[int] = ..., 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def check_name_availability(
                self, 
                request: ResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ResourceNameAvailability: ...

        @overload
        async def check_name_availability(
                self, 
                request: ResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ResourceNameAvailability: ...

        @overload
        async def check_name_availability(
                self, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ResourceNameAvailability: ...

        async def close(self) -> None: ...

        @distributed_trace_async
        async def get_publishing_user(self, **kwargs: Any) -> User: ...

        @distributed_trace_async
        async def get_source_control(
                self, 
                source_control_type: str, 
                **kwargs: Any
            ) -> SourceControl: ...

        @distributed_trace_async
        async def get_subscription_deployment_locations(self, **kwargs: Any) -> DeploymentLocations: ...

        @distributed_trace
        def list_ase_regions(self, **kwargs: Any) -> AsyncItemPaged[AseRegion]: ...

        @distributed_trace
        def list_billing_meters(
                self, 
                *, 
                billing_location: Optional[str] = ..., 
                os_type: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[BillingMeter]: ...

        @distributed_trace
        def list_custom_host_name_sites(
                self, 
                *, 
                hostname: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[CustomHostnameSites]: ...

        @distributed_trace
        def list_geo_regions(
                self, 
                *, 
                custom_mode_workers_enabled: Optional[bool] = ..., 
                linux_dynamic_workers_enabled: Optional[bool] = ..., 
                linux_workers_enabled: Optional[bool] = ..., 
                sku: Optional[Union[str, SkuName]] = ..., 
                xenon_workers_enabled: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[GeoRegion]: ...

        @distributed_trace
        def list_premier_add_on_offers(self, **kwargs: Any) -> AsyncItemPaged[PremierAddOnOffer]: ...

        @overload
        def list_site_identifiers_assigned_to_host_name(
                self, 
                name_identifier: NameIdentifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[Identifier]: ...

        @overload
        def list_site_identifiers_assigned_to_host_name(
                self, 
                name_identifier: NameIdentifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[Identifier]: ...

        @overload
        def list_site_identifiers_assigned_to_host_name(
                self, 
                name_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[Identifier]: ...

        @distributed_trace_async
        async def list_skus(self, **kwargs: Any) -> SkuInfos: ...

        @distributed_trace
        def list_source_controls(self, **kwargs: Any) -> AsyncItemPaged[SourceControl]: ...

        @overload
        async def move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def regional_check_name_availability(
                self, 
                location: str, 
                request: DnlResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DnlResourceNameAvailability: ...

        @overload
        async def regional_check_name_availability(
                self, 
                location: str, 
                request: DnlResourceNameAvailabilityRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DnlResourceNameAvailability: ...

        @overload
        async def regional_check_name_availability(
                self, 
                location: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DnlResourceNameAvailability: ...

        def send_request(
                self, 
                request: HttpRequest, 
                *, 
                stream: bool = False, 
                **kwargs: Any
            ) -> Awaitable[AsyncHttpResponse]: ...

        @overload
        async def update_publishing_user(
                self, 
                user_details: User, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> User: ...

        @overload
        async def update_publishing_user(
                self, 
                user_details: User, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> User: ...

        @overload
        async def update_publishing_user(
                self, 
                user_details: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> User: ...

        @overload
        async def update_source_control(
                self, 
                source_control_type: str, 
                request_message: SourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SourceControl: ...

        @overload
        async def update_source_control(
                self, 
                source_control_type: str, 
                request_message: SourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SourceControl: ...

        @overload
        async def update_source_control(
                self, 
                source_control_type: str, 
                request_message: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SourceControl: ...

        @overload
        async def validate(
                self, 
                resource_group_name: str, 
                validate_request: ValidateRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ValidateResponse: ...

        @overload
        async def validate(
                self, 
                resource_group_name: str, 
                validate_request: ValidateRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ValidateResponse: ...

        @overload
        async def validate(
                self, 
                resource_group_name: str, 
                validate_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ValidateResponse: ...

        @overload
        async def validate_move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def validate_move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: CsmMoveResourceEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def validate_move(
                self, 
                resource_group_name: str, 
                move_resource_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def verify_hosting_environment_vnet(
                self, 
                parameters: VnetParameters, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetValidationFailureDetails: ...

        @overload
        async def verify_hosting_environment_vnet(
                self, 
                parameters: VnetParameters, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetValidationFailureDetails: ...

        @overload
        async def verify_hosting_environment_vnet(
                self, 
                parameters: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetValidationFailureDetails: ...


namespace azure.mgmt.web.aio.operations

    class azure.mgmt.web.aio.operations.AppServiceEnvironmentsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_change_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_info: VirtualNetworkProfile, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AsyncItemPaged[Site]]: ...

        @overload
        async def begin_change_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_info: VirtualNetworkProfile, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AsyncItemPaged[Site]]: ...

        @overload
        async def begin_change_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_info: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AsyncItemPaged[Site]]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AppServiceEnvironmentResource]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AppServiceEnvironmentResource]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AppServiceEnvironmentResource]: ...

        @overload
        async def begin_create_or_update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[WorkerPoolResource]: ...

        @overload
        async def begin_create_or_update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[WorkerPoolResource]: ...

        @overload
        async def begin_create_or_update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[WorkerPoolResource]: ...

        @overload
        async def begin_create_or_update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[WorkerPoolResource]: ...

        @overload
        async def begin_create_or_update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[WorkerPoolResource]: ...

        @overload
        async def begin_create_or_update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[WorkerPoolResource]: ...

        @distributed_trace_async
        async def begin_delete(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                force_delete: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def begin_delete_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[Any]: ...

        @distributed_trace_async
        async def begin_resume(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[AsyncItemPaged[Site]]: ...

        @distributed_trace_async
        async def begin_suspend(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[AsyncItemPaged[Site]]: ...

        @distributed_trace_async
        async def begin_upgrade(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def delete_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @distributed_trace_async
        async def get_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @distributed_trace_async
        async def get_ase_v3_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @distributed_trace_async
        async def get_diagnostics_item(
                self, 
                resource_group_name: str, 
                name: str, 
                diagnostics_name: str, 
                **kwargs: Any
            ) -> HostingEnvironmentDiagnostics: ...

        @distributed_trace
        def get_inbound_network_dependencies_endpoints(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[InboundEnvironmentEndpoint]: ...

        @distributed_trace_async
        async def get_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @distributed_trace
        def get_outbound_network_dependencies_endpoints(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[OutboundEnvironmentEndpoint]: ...

        @distributed_trace_async
        async def get_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_endpoint_connection_list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace_async
        async def get_private_link_resources(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace_async
        async def get_vip_info(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AddressResponse: ...

        @distributed_trace_async
        async def get_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> AsyncItemPaged[AppServiceEnvironmentResource]: ...

        @distributed_trace
        def list_app_service_plans(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[AppServicePlan]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[AppServiceEnvironmentResource]: ...

        @distributed_trace
        def list_capacities(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StampCapacity]: ...

        @distributed_trace_async
        async def list_diagnostics(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[HostingEnvironmentDiagnostics]: ...

        @distributed_trace
        def list_multi_role_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_multi_role_pool_instance_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                instance: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_multi_role_pool_skus(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SkuInfo]: ...

        @distributed_trace
        def list_multi_role_pools(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkerPoolResource]: ...

        @distributed_trace
        def list_multi_role_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Usage]: ...

        @distributed_trace_async
        async def list_operations(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[Operation]: ...

        @distributed_trace
        def list_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmUsageQuota]: ...

        @distributed_trace
        def list_web_apps(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                properties_to_include: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Site]: ...

        @distributed_trace
        def list_web_worker_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_web_worker_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Usage]: ...

        @distributed_trace
        def list_worker_pool_instance_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                instance: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_worker_pool_skus(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SkuInfo]: ...

        @distributed_trace
        def list_worker_pools(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkerPoolResource]: ...

        @distributed_trace_async
        async def reboot(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def test_upgrade_available_notification(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @overload
        async def update_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                custom_dns_suffix_configuration: CustomDnsSuffixConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @overload
        async def update_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                custom_dns_suffix_configuration: CustomDnsSuffixConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @overload
        async def update_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                custom_dns_suffix_configuration: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @overload
        async def update_ase_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                ase_networking_configuration: AseV3NetworkingConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @overload
        async def update_ase_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                ase_networking_configuration: AseV3NetworkingConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @overload
        async def update_ase_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                ase_networking_configuration: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @overload
        async def update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        async def update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        async def update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        async def update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        async def update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        async def update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...


    class azure.mgmt.web.aio.operations.AppServicePlansOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlan, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AppServicePlan]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlan, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AppServicePlan]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[AppServicePlan]: ...

        @overload
        async def create_or_update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        async def create_or_update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        async def create_or_update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @distributed_trace_async
        async def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @distributed_trace_async
        async def get_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace_async
        async def get_hybrid_connection_plan_limit(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> HybridConnectionLimits: ...

        @distributed_trace_async
        async def get_route_for_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                **kwargs: Any
            ) -> List[VnetRoute]: ...

        @distributed_trace_async
        async def get_server_farm_instance_details(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ServerFarmInstanceDetails: ...

        @distributed_trace_async
        async def get_server_farm_rdp_password(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ServerFarmRdpDetails: ...

        @distributed_trace_async
        async def get_server_farm_skus(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @distributed_trace_async
        async def get_vnet_from_server_farm(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace_async
        async def get_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                **kwargs: Any
            ) -> VnetGateway: ...

        @distributed_trace
        def list(
                self, 
                *, 
                detailed: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[AppServicePlan]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[AppServicePlan]: ...

        @distributed_trace_async
        async def list_capabilities(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[Capability]: ...

        @distributed_trace_async
        async def list_hybrid_connection_keys(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> HybridConnectionKey: ...

        @distributed_trace
        def list_hybrid_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[HybridConnection]: ...

        @distributed_trace_async
        async def list_routes_for_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> List[VnetRoute]: ...

        @distributed_trace
        def list_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmUsageQuota]: ...

        @distributed_trace_async
        async def list_vnets(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[VnetInfoResource]: ...

        @distributed_trace
        def list_web_apps(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                skip_token: Optional[str] = ..., 
                top: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Site]: ...

        @distributed_trace
        def list_web_apps_by_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[str]: ...

        @distributed_trace_async
        async def reboot_worker(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def recycle_managed_instance_worker(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_name: str, 
                **kwargs: Any
            ) -> Operation: ...

        @distributed_trace_async
        async def restart_web_apps(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                soft_restart: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlanPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlanPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @overload
        async def update_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        async def update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        async def update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...


    class azure.mgmt.web.aio.operations.CertificatesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace_async
        async def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def list(
                self, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Certificate]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Certificate]: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...


    class azure.mgmt.web.aio.operations.DeletedWebAppsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get_deleted_web_app_by_location(
                self, 
                location: str, 
                deleted_site_id: str, 
                **kwargs: Any
            ) -> DeletedSite: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> AsyncItemPaged[DeletedSite]: ...

        @distributed_trace
        def list_by_location(
                self, 
                location: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DeletedSite]: ...


    class azure.mgmt.web.aio.operations.DiagnosticsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def execute_site_analysis(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticAnalysis: ...

        @distributed_trace_async
        async def execute_site_analysis_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                slot: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticAnalysis: ...

        @distributed_trace_async
        async def execute_site_detector(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                diagnostic_category: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticDetectorResponse: ...

        @distributed_trace_async
        async def execute_site_detector_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                diagnostic_category: str, 
                slot: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticDetectorResponse: ...

        @distributed_trace_async
        async def get_hosting_environment_detector_response(
                self, 
                resource_group_name: str, 
                name: str, 
                detector_name: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DetectorResponse: ...

        @distributed_trace_async
        async def get_site_analysis(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                **kwargs: Any
            ) -> AnalysisDefinition: ...

        @distributed_trace_async
        async def get_site_analysis_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AnalysisDefinition: ...

        @distributed_trace_async
        async def get_site_detector(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                detector_name: str, 
                **kwargs: Any
            ) -> DetectorDefinitionResource: ...

        @distributed_trace_async
        async def get_site_detector_response(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DetectorResponse: ...

        @distributed_trace_async
        async def get_site_detector_response_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                slot: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DetectorResponse: ...

        @distributed_trace_async
        async def get_site_detector_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                detector_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> DetectorDefinitionResource: ...

        @distributed_trace_async
        async def get_site_diagnostic_category(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                **kwargs: Any
            ) -> DiagnosticCategory: ...

        @distributed_trace_async
        async def get_site_diagnostic_category_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                slot: str, 
                **kwargs: Any
            ) -> DiagnosticCategory: ...

        @distributed_trace
        def list_hosting_environment_detector_responses(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DetectorResponse]: ...

        @distributed_trace
        def list_site_analyses(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[AnalysisDefinition]: ...

        @distributed_trace
        def list_site_analyses_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[AnalysisDefinition]: ...

        @distributed_trace
        def list_site_detector_responses(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DetectorResponse]: ...

        @distributed_trace
        def list_site_detector_responses_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DetectorResponse]: ...

        @distributed_trace
        def list_site_detectors(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DetectorDefinitionResource]: ...

        @distributed_trace
        def list_site_detectors_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DetectorDefinitionResource]: ...

        @distributed_trace
        def list_site_diagnostic_categories(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DiagnosticCategory]: ...

        @distributed_trace
        def list_site_diagnostic_categories_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DiagnosticCategory]: ...


    class azure.mgmt.web.aio.operations.GetUsagesInLocationOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def list(
                self, 
                location: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmUsageQuota]: ...


    class azure.mgmt.web.aio.operations.GlobalOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get_deleted_web_app(
                self, 
                deleted_site_id: str, 
                **kwargs: Any
            ) -> DeletedSite: ...

        @distributed_trace_async
        async def get_deleted_web_app_snapshots(
                self, 
                deleted_site_id: str, 
                **kwargs: Any
            ) -> List[Snapshot]: ...

        @distributed_trace_async
        async def get_subscription_operation_with_async_response(
                self, 
                location: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> None: ...


    class azure.mgmt.web.aio.operations.KubeEnvironmentsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[KubeEnvironment]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[KubeEnvironment]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[KubeEnvironment]: ...

        @distributed_trace_async
        async def begin_delete(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> KubeEnvironment: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[KubeEnvironment]: ...

        @distributed_trace
        def list_by_subscription(self, **kwargs: Any) -> AsyncItemPaged[KubeEnvironment]: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KubeEnvironment: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KubeEnvironment: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KubeEnvironment: ...


    class azure.mgmt.web.aio.operations.ProviderOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get_available_stacks(
                self, 
                *, 
                os_type_selected: Optional[Union[str, ProviderOsTypeSelected]] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[ApplicationStackResource]: ...

        @distributed_trace
        def get_available_stacks_on_prem(
                self, 
                *, 
                os_type_selected: Optional[Union[str, ProviderOsTypeSelected]] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[ApplicationStackResource]: ...

        @distributed_trace
        def get_function_app_stacks(
                self, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[FunctionAppStack]: ...

        @distributed_trace
        def get_function_app_stacks_for_location(
                self, 
                location: str, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[FunctionAppStack]: ...

        @distributed_trace
        def get_web_app_stacks(
                self, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WebAppStack]: ...

        @distributed_trace
        def get_web_app_stacks_for_location(
                self, 
                location: str, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WebAppStack]: ...

        @distributed_trace
        def list_operations(self, **kwargs: Any) -> AsyncItemPaged[CsmOperationDescription]: ...


    class azure.mgmt.web.aio.operations.RecommendationsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def disable_all_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                environment_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def disable_all_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def disable_recommendation_for_hosting_environment(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_name: str, 
                *, 
                environment_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def disable_recommendation_for_site(
                self, 
                resource_group_name: str, 
                site_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def disable_recommendation_for_subscription(
                self, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get_rule_details_by_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                name: str, 
                *, 
                recommendation_id: Optional[str] = ..., 
                update_seen: Optional[bool] = ..., 
                **kwargs: Any
            ) -> RecommendationRule: ...

        @distributed_trace_async
        async def get_rule_details_by_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                name: str, 
                *, 
                recommendation_id: Optional[str] = ..., 
                update_seen: Optional[bool] = ..., 
                **kwargs: Any
            ) -> RecommendationRule: ...

        @distributed_trace
        def list(
                self, 
                *, 
                featured: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Recommendation]: ...

        @distributed_trace
        def list_history_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                expired_only: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Recommendation]: ...

        @distributed_trace
        def list_history_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                *, 
                expired_only: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Recommendation]: ...

        @distributed_trace
        def list_recommended_rules_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                featured: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Recommendation]: ...

        @distributed_trace
        def list_recommended_rules_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                *, 
                featured: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Recommendation]: ...

        @distributed_trace_async
        async def reset_all_filters(self, **kwargs: Any) -> None: ...

        @distributed_trace_async
        async def reset_all_filters_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                environment_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def reset_all_filters_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> None: ...


    class azure.mgmt.web.aio.operations.ResourceHealthMetadataOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get_by_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ResourceHealthMetadata: ...

        @distributed_trace_async
        async def get_by_site_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ResourceHealthMetadata: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> AsyncItemPaged[ResourceHealthMetadata]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceHealthMetadata]: ...

        @distributed_trace
        def list_by_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceHealthMetadata]: ...

        @distributed_trace
        def list_by_site_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ResourceHealthMetadata]: ...


    class azure.mgmt.web.aio.operations.SiteCertificatesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace_async
        async def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace_async
        async def get_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Certificate]: ...

        @distributed_trace
        def list_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Certificate]: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        async def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...


    class azure.mgmt.web.aio.operations.StaticSitesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_create_or_update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSiteARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteARMResource]: ...

        @overload
        async def begin_create_or_update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSiteARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteARMResource]: ...

        @overload
        async def begin_create_or_update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteARMResource]: ...

        @overload
        async def begin_create_or_update_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteCustomDomainOverviewARMResource]: ...

        @overload
        async def begin_create_or_update_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteCustomDomainOverviewARMResource]: ...

        @overload
        async def begin_create_or_update_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteCustomDomainOverviewARMResource]: ...

        @overload
        async def begin_create_zip_deployment_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_create_zip_deployment_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_create_zip_deployment_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_zip_deployment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_create_zip_deployment_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_create_zip_deployment_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_create_zip_deployment_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                static_site_zip_deployment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def begin_delete_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[Any]: ...

        @distributed_trace_async
        async def begin_delete_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def begin_delete_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def begin_delete_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def begin_detach_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_link_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        async def begin_link_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        async def begin_link_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        async def begin_link_backend_to_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        async def begin_link_backend_to_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        async def begin_link_backend_to_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        async def begin_register_user_provided_function_app_with_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        async def begin_register_user_provided_function_app_with_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        async def begin_register_user_provided_function_app_with_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        async def begin_register_user_provided_function_app_with_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        async def begin_register_user_provided_function_app_with_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        async def begin_register_user_provided_function_app_with_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        async def begin_validate_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_custom_domain_can_be_added_to_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_custom_domain_can_be_added_to_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_validate_custom_domain_can_be_added_to_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def create_or_update_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                basic_auth_envelope: StaticSiteBasicAuthPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @overload
        async def create_or_update_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                basic_auth_envelope: StaticSiteBasicAuthPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @overload
        async def create_or_update_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                basic_auth_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @overload
        async def create_or_update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def create_or_update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def create_or_update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def create_or_update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def create_or_update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def create_or_update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def create_or_update_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_or_update_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def create_user_roles_invitation_link(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_user_roles_invitation_envelope: StaticSiteUserInvitationRequestResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserInvitationResponseResource: ...

        @overload
        async def create_user_roles_invitation_link(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_user_roles_invitation_envelope: StaticSiteUserInvitationRequestResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserInvitationResponseResource: ...

        @overload
        async def create_user_roles_invitation_link(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_user_roles_invitation_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserInvitationResponseResource: ...

        @distributed_trace_async
        async def delete_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def detach_user_provided_function_app_from_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def detach_user_provided_function_app_from_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @distributed_trace_async
        async def get_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace_async
        async def get_build_database_connection_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace
        def get_build_database_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DatabaseConnection]: ...

        @distributed_trace
        def get_build_database_connections_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DatabaseConnection]: ...

        @distributed_trace_async
        async def get_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace_async
        async def get_database_connection_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace
        def get_database_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DatabaseConnection]: ...

        @distributed_trace
        def get_database_connections_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[DatabaseConnection]: ...

        @distributed_trace_async
        async def get_linked_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                **kwargs: Any
            ) -> StaticSiteLinkedBackendARMResource: ...

        @distributed_trace_async
        async def get_linked_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                **kwargs: Any
            ) -> StaticSiteLinkedBackendARMResource: ...

        @distributed_trace
        def get_linked_backends(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteLinkedBackendARMResource]: ...

        @distributed_trace
        def get_linked_backends_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteLinkedBackendARMResource]: ...

        @distributed_trace_async
        async def get_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_endpoint_connection_list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace_async
        async def get_private_link_resources(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace_async
        async def get_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @distributed_trace_async
        async def get_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> StaticSiteBuildARMResource: ...

        @distributed_trace
        def get_static_site_builds(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteBuildARMResource]: ...

        @distributed_trace_async
        async def get_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                **kwargs: Any
            ) -> StaticSiteCustomDomainOverviewARMResource: ...

        @distributed_trace
        def get_static_sites_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteARMResource]: ...

        @distributed_trace_async
        async def get_user_provided_function_app_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> StaticSiteUserProvidedFunctionAppARMResource: ...

        @distributed_trace_async
        async def get_user_provided_function_app_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> StaticSiteUserProvidedFunctionAppARMResource: ...

        @distributed_trace
        def get_user_provided_function_apps_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @distributed_trace
        def get_user_provided_function_apps_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> AsyncItemPaged[StaticSiteARMResource]: ...

        @distributed_trace
        def list_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteBasicAuthPropertiesARMResource]: ...

        @distributed_trace_async
        async def list_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_build_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteFunctionOverviewARMResource]: ...

        @distributed_trace_async
        async def list_static_site_configured_roles(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringList: ...

        @distributed_trace
        def list_static_site_custom_domains(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteCustomDomainOverviewARMResource]: ...

        @distributed_trace_async
        async def list_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteFunctionOverviewARMResource]: ...

        @distributed_trace_async
        async def list_static_site_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_users(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[StaticSiteUserARMResource]: ...

        @overload
        async def preview_workflow(
                self, 
                location: str, 
                static_sites_workflow_preview_request: StaticSitesWorkflowPreviewRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSitesWorkflowPreview: ...

        @overload
        async def preview_workflow(
                self, 
                location: str, 
                static_sites_workflow_preview_request: StaticSitesWorkflowPreviewRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSitesWorkflowPreview: ...

        @overload
        async def preview_workflow(
                self, 
                location: str, 
                static_sites_workflow_preview_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSitesWorkflowPreview: ...

        @overload
        async def reset_static_site_api_key(
                self, 
                resource_group_name: str, 
                name: str, 
                reset_properties_envelope: StaticSiteResetPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def reset_static_site_api_key(
                self, 
                resource_group_name: str, 
                name: str, 
                reset_properties_envelope: StaticSiteResetPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def reset_static_site_api_key(
                self, 
                resource_group_name: str, 
                name: str, 
                reset_properties_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def unlink_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                *, 
                is_cleaning_auth_config: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def unlink_backend_from_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                *, 
                is_cleaning_auth_config: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        async def update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @overload
        async def update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @overload
        async def update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @overload
        async def update_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                static_site_user_envelope: StaticSiteUserARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserARMResource: ...

        @overload
        async def update_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                static_site_user_envelope: StaticSiteUserARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserARMResource: ...

        @overload
        async def update_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                static_site_user_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserARMResource: ...


    class azure.mgmt.web.aio.operations.WebAppsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def add_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def add_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def add_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def add_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def add_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def add_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace_async
        async def analyze_custom_hostname(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                host_name: Optional[str] = ..., 
                **kwargs: Any
            ) -> CustomHostnameAnalysisResult: ...

        @distributed_trace_async
        async def analyze_custom_hostname_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                host_name: Optional[str] = ..., 
                **kwargs: Any
            ) -> CustomHostnameAnalysisResult: ...

        @overload
        async def apply_slot_config_to_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def apply_slot_config_to_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def apply_slot_config_to_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def apply_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def apply_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def apply_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_approve_or_reject_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        async def begin_create_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[FunctionEnvelope]: ...

        @overload
        async def begin_create_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[FunctionEnvelope]: ...

        @overload
        async def begin_create_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[FunctionEnvelope]: ...

        @overload
        async def begin_create_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[FunctionEnvelope]: ...

        @overload
        async def begin_create_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[FunctionEnvelope]: ...

        @overload
        async def begin_create_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[FunctionEnvelope]: ...

        @overload
        async def begin_create_instance_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_instance_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_instance_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_instance_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_instance_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_instance_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[MSDeployStatus]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Site]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Site]: ...

        @overload
        async def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Site]: ...

        @overload
        async def begin_create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Site]: ...

        @overload
        async def begin_create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Site]: ...

        @overload
        async def begin_create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Site]: ...

        @overload
        async def begin_create_or_update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteSourceControl]: ...

        @overload
        async def begin_create_or_update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteSourceControl]: ...

        @overload
        async def begin_create_or_update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteSourceControl]: ...

        @overload
        async def begin_create_or_update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteSourceControl]: ...

        @overload
        async def begin_create_or_update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteSourceControl]: ...

        @overload
        async def begin_create_or_update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteSourceControl]: ...

        @distributed_trace_async
        async def begin_delete_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[Any]: ...

        @distributed_trace_async
        async def begin_delete_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[Any]: ...

        @distributed_trace_async
        async def begin_get_production_site_deployment_status(
                self, 
                resource_group_name: str, 
                name: str, 
                deployment_status_id: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[CsmDeploymentStatus]: ...

        @distributed_trace_async
        async def begin_get_slot_site_deployment_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                deployment_status_id: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[CsmDeploymentStatus]: ...

        @distributed_trace_async
        async def begin_install_site_extension(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteExtensionInfo]: ...

        @distributed_trace_async
        async def begin_install_site_extension_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[SiteExtensionInfo]: ...

        @distributed_trace_async
        async def begin_list_publishing_credentials(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[User]: ...

        @distributed_trace_async
        async def begin_list_publishing_credentials_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[User]: ...

        @overload
        async def begin_migrate_my_sql(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_request_envelope: MigrateMySqlRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Operation]: ...

        @overload
        async def begin_migrate_my_sql(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_request_envelope: MigrateMySqlRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Operation]: ...

        @overload
        async def begin_migrate_my_sql(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[Operation]: ...

        @overload
        async def begin_migrate_storage(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_options: StorageMigrationOptions, 
                *, 
                content_type: str = "application/json", 
                subscription_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[StorageMigrationResponse]: ...

        @overload
        async def begin_migrate_storage(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_options: StorageMigrationOptions, 
                *, 
                content_type: str = "application/json", 
                subscription_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[StorageMigrationResponse]: ...

        @overload
        async def begin_migrate_storage(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_options: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                subscription_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[StorageMigrationResponse]: ...

        @overload
        async def begin_restore(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_backup_blob(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_backup_blob(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_backup_blob(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_backup_blob_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_backup_blob_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_backup_blob_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_deleted_app(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_deleted_app(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_deleted_app(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_deleted_app_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_deleted_app_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_from_deleted_app_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_restore_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def begin_start_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[List[NetworkTrace]]: ...

        @distributed_trace_async
        async def begin_start_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[List[NetworkTrace]]: ...

        @distributed_trace_async
        async def begin_start_web_site_network_trace_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[List[NetworkTrace]]: ...

        @distributed_trace_async
        async def begin_start_web_site_network_trace_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncLROPoller[List[NetworkTrace]]: ...

        @overload
        async def begin_swap_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_swap_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_swap_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_swap_slot_with_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_swap_slot_with_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def begin_swap_slot_with_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @overload
        async def create_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        async def create_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        async def create_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                deployment: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        async def create_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        async def create_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        async def create_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                deployment: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace_async
        async def create_one_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @overload
        async def create_or_update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def create_or_update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def create_or_update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def create_or_update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def create_or_update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def create_or_update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def create_or_update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def create_or_update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def create_or_update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def create_or_update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def create_or_update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def create_or_update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def create_or_update_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        async def create_or_update_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        async def create_or_update_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                host_name_binding: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        async def create_or_update_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                slot: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        async def create_or_update_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                slot: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        async def create_or_update_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                slot: str, 
                host_name_binding: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        async def create_or_update_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        async def create_or_update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def create_or_update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def create_or_update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def create_or_update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def create_or_update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def create_or_update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def create_or_update_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        async def create_or_update_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        async def create_or_update_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                public_certificate: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        async def create_or_update_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                slot: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        async def create_or_update_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                slot: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        async def create_or_update_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                slot: str, 
                public_certificate: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        async def create_or_update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def create_or_update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def create_or_update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def create_or_update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def create_or_update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def create_or_update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def create_or_update_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        async def create_or_update_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        async def create_or_update_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        async def create_or_update_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        async def create_or_update_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        async def create_or_update_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        async def create_or_update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def create_or_update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def create_or_update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def create_or_update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def create_or_update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def create_or_update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def create_or_update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def create_or_update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def create_or_update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def create_or_update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def create_or_update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def create_or_update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def create_or_update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def create_or_update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def create_or_update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def create_or_update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def create_or_update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def create_or_update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace_async
        async def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                delete_empty_server_farm: Optional[bool] = ..., 
                delete_metrics: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                host_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_instance_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_instance_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_site_extension(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_site_extension_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                delete_empty_server_farm: Optional[bool] = ..., 
                delete_metrics: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                additional_flags: Optional[str] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                additional_flags: Optional[str] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_swift_virtual_network(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_swift_virtual_network_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_triggered_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_triggered_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def delete_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def deploy_workflow_artifacts(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def deploy_workflow_artifacts(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def deploy_workflow_artifacts(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_artifacts: Optional[IO[bytes]] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def deploy_workflow_artifacts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def deploy_workflow_artifacts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def deploy_workflow_artifacts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_artifacts: Optional[IO[bytes]] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def discover_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        async def discover_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        async def discover_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        async def discover_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        async def discover_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        async def discover_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @distributed_trace_async
        async def generate_new_site_publishing_password(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def generate_new_site_publishing_password_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Site: ...

        @distributed_trace_async
        async def get_app_setting_key_vault_reference(
                self, 
                resource_group_name: str, 
                name: str, 
                app_setting_key: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace_async
        async def get_app_setting_key_vault_reference_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                app_setting_key: str, 
                slot: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace
        def get_app_settings_key_vault_references(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ApiKVReference]: ...

        @distributed_trace
        def get_app_settings_key_vault_references_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ApiKVReference]: ...

        @distributed_trace_async
        async def get_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @distributed_trace_async
        async def get_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @distributed_trace_async
        async def get_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace_async
        async def get_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace_async
        async def get_auth_settings_v2_without_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace_async
        async def get_auth_settings_v2_without_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace_async
        async def get_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> BackupRequest: ...

        @distributed_trace_async
        async def get_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> BackupRequest: ...

        @distributed_trace_async
        async def get_backup_status(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                **kwargs: Any
            ) -> BackupItem: ...

        @distributed_trace_async
        async def get_backup_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> BackupItem: ...

        @distributed_trace_async
        async def get_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace_async
        async def get_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace_async
        async def get_configuration_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace_async
        async def get_configuration_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace_async
        async def get_container_logs_zip(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Optional[AsyncIterator[bytes]]: ...

        @distributed_trace_async
        async def get_container_logs_zip_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Optional[AsyncIterator[bytes]]: ...

        @distributed_trace_async
        async def get_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> ContinuousWebJob: ...

        @distributed_trace_async
        async def get_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ContinuousWebJob: ...

        @distributed_trace_async
        async def get_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace_async
        async def get_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace_async
        async def get_diagnostic_logs_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @distributed_trace_async
        async def get_diagnostic_logs_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @distributed_trace_async
        async def get_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                **kwargs: Any
            ) -> Identifier: ...

        @distributed_trace_async
        async def get_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Identifier: ...

        @distributed_trace_async
        async def get_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace_async
        async def get_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace_async
        async def get_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> FunctionEnvelope: ...

        @distributed_trace_async
        async def get_functions_admin_token(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace_async
        async def get_functions_admin_token_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace_async
        async def get_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @distributed_trace_async
        async def get_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                host_name: str, 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @distributed_trace_async
        async def get_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace_async
        async def get_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace_async
        async def get_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> FunctionEnvelope: ...

        @distributed_trace_async
        async def get_instance_info(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> WebSiteInstanceStatus: ...

        @distributed_trace_async
        async def get_instance_info_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> WebSiteInstanceStatus: ...

        @distributed_trace_async
        async def get_instance_ms_deploy_log(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace_async
        async def get_instance_ms_deploy_log_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace_async
        async def get_instance_ms_deploy_status(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace_async
        async def get_instance_ms_deploy_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace_async
        async def get_instance_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace_async
        async def get_instance_process_dump(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @distributed_trace_async
        async def get_instance_process_dump_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @distributed_trace_async
        async def get_instance_process_module(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace_async
        async def get_instance_process_module_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace_async
        async def get_instance_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace_async
        async def get_instance_workflow_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_name: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @distributed_trace_async
        async def get_migrate_my_sql_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> MigrateMySqlStatus: ...

        @distributed_trace_async
        async def get_migrate_my_sql_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> MigrateMySqlStatus: ...

        @distributed_trace_async
        async def get_ms_deploy_log(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace_async
        async def get_ms_deploy_log_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace_async
        async def get_ms_deploy_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace_async
        async def get_ms_deploy_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace_async
        async def get_network_trace_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_trace_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_trace_operation_slot_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_trace_operation_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_traces(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_traces_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_traces_slot_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_network_traces_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace_async
        async def get_one_deploy_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @distributed_trace_async
        async def get_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace_async
        async def get_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace_async
        async def get_private_access(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @distributed_trace_async
        async def get_private_access_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @distributed_trace_async
        async def get_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_endpoint_connection_list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace
        def get_private_endpoint_connection_list_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace_async
        async def get_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace_async
        async def get_private_link_resources(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace_async
        async def get_private_link_resources_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace_async
        async def get_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace_async
        async def get_process_dump(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @distributed_trace_async
        async def get_process_dump_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @distributed_trace_async
        async def get_process_module(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace_async
        async def get_process_module_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                slot: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace_async
        async def get_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace_async
        async def get_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @distributed_trace_async
        async def get_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @distributed_trace_async
        async def get_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace_async
        async def get_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace_async
        async def get_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace_async
        async def get_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace_async
        async def get_site_connection_string_key_vault_reference(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_string_key: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace_async
        async def get_site_connection_string_key_vault_reference_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_string_key: str, 
                slot: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace
        def get_site_connection_string_key_vault_references(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ApiKVReference]: ...

        @distributed_trace
        def get_site_connection_string_key_vault_references_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ApiKVReference]: ...

        @distributed_trace_async
        async def get_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                **kwargs: Any
            ) -> SiteContainer: ...

        @distributed_trace_async
        async def get_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                **kwargs: Any
            ) -> SiteContainer: ...

        @distributed_trace_async
        async def get_site_extension(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                **kwargs: Any
            ) -> SiteExtensionInfo: ...

        @distributed_trace_async
        async def get_site_extension_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteExtensionInfo: ...

        @distributed_trace_async
        async def get_site_php_error_log_flag(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SitePhpErrorLogFlag: ...

        @distributed_trace_async
        async def get_site_php_error_log_flag_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SitePhpErrorLogFlag: ...

        @distributed_trace_async
        async def get_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Site: ...

        @distributed_trace_async
        async def get_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @distributed_trace_async
        async def get_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @distributed_trace_async
        async def get_swift_virtual_network_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @distributed_trace_async
        async def get_swift_virtual_network_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @distributed_trace_async
        async def get_triggered_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> TriggeredWebJob: ...

        @distributed_trace_async
        async def get_triggered_web_job_history(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                id: str, 
                **kwargs: Any
            ) -> TriggeredJobHistory: ...

        @distributed_trace_async
        async def get_triggered_web_job_history_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> TriggeredJobHistory: ...

        @distributed_trace_async
        async def get_triggered_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> TriggeredWebJob: ...

        @distributed_trace_async
        async def get_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace_async
        async def get_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                **kwargs: Any
            ) -> VnetGateway: ...

        @distributed_trace_async
        async def get_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> VnetGateway: ...

        @distributed_trace_async
        async def get_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace_async
        async def get_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> WebJob: ...

        @distributed_trace_async
        async def get_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> WebJob: ...

        @distributed_trace_async
        async def get_web_site_container_logs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Optional[AsyncIterator[bytes]]: ...

        @distributed_trace_async
        async def get_web_site_container_logs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Optional[AsyncIterator[bytes]]: ...

        @distributed_trace_async
        async def get_workflow(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @distributed_trace_async
        async def is_cloneable(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteCloneability: ...

        @distributed_trace_async
        async def is_cloneable_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteCloneability: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> AsyncItemPaged[Site]: ...

        @distributed_trace_async
        async def list_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @distributed_trace_async
        async def list_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def list_backup_status_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def list_backup_status_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def list_backup_status_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def list_backup_status_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def list_backup_status_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        async def list_backup_status_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @distributed_trace
        def list_backups(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[BackupItem]: ...

        @distributed_trace
        def list_backups_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[BackupItem]: ...

        @distributed_trace
        def list_basic_publishing_credentials_policies(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmPublishingCredentialsPoliciesEntity]: ...

        @distributed_trace
        def list_basic_publishing_credentials_policies_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmPublishingCredentialsPoliciesEntity]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                *, 
                include_slots: Optional[bool] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[Site]: ...

        @distributed_trace
        def list_configuration_snapshot_info(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteConfigurationSnapshotInfo]: ...

        @distributed_trace
        def list_configuration_snapshot_info_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteConfigurationSnapshotInfo]: ...

        @distributed_trace
        def list_configurations(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteConfigResource]: ...

        @distributed_trace
        def list_configurations_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteConfigResource]: ...

        @distributed_trace_async
        async def list_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @distributed_trace_async
        async def list_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @distributed_trace
        def list_continuous_web_jobs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ContinuousWebJob]: ...

        @distributed_trace
        def list_continuous_web_jobs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ContinuousWebJob]: ...

        @distributed_trace_async
        async def list_deployment_log(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace_async
        async def list_deployment_log_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace
        def list_deployments(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Deployment]: ...

        @distributed_trace
        def list_deployments_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Deployment]: ...

        @distributed_trace
        def list_domain_ownership_identifiers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Identifier]: ...

        @distributed_trace
        def list_domain_ownership_identifiers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Identifier]: ...

        @distributed_trace_async
        async def list_function_keys(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_function_keys_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_function_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace_async
        async def list_function_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace
        def list_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[FunctionEnvelope]: ...

        @distributed_trace_async
        async def list_host_keys(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> HostKeys: ...

        @distributed_trace_async
        async def list_host_keys_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> HostKeys: ...

        @distributed_trace
        def list_host_name_bindings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[HostNameBinding]: ...

        @distributed_trace
        def list_host_name_bindings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[HostNameBinding]: ...

        @distributed_trace_async
        async def list_hybrid_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace_async
        async def list_hybrid_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def list_instance_functions_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[FunctionEnvelope]: ...

        @distributed_trace
        def list_instance_identifiers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WebSiteInstanceStatus]: ...

        @distributed_trace
        def list_instance_identifiers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WebSiteInstanceStatus]: ...

        @distributed_trace
        def list_instance_process_modules(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_instance_process_modules_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_instance_process_threads(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_instance_process_threads_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_instance_processes(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_instance_processes_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_instance_workflows_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowEnvelope]: ...

        @distributed_trace_async
        async def list_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace_async
        async def list_network_features(
                self, 
                resource_group_name: str, 
                name: str, 
                view: str, 
                **kwargs: Any
            ) -> NetworkFeatures: ...

        @distributed_trace_async
        async def list_network_features_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                view: str, 
                slot: str, 
                **kwargs: Any
            ) -> NetworkFeatures: ...

        @distributed_trace
        def list_perf_mon_counters(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[PerfMonResponse]: ...

        @distributed_trace
        def list_perf_mon_counters_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[PerfMonResponse]: ...

        @distributed_trace_async
        async def list_premier_add_ons(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace_async
        async def list_premier_add_ons_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace
        def list_process_modules(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_process_modules_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_process_threads(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_process_threads_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_processes(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_processes_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_production_site_deployment_statuses(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmDeploymentStatus]: ...

        @distributed_trace
        def list_public_certificates(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[PublicCertificate]: ...

        @distributed_trace
        def list_public_certificates_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[PublicCertificate]: ...

        @overload
        async def list_publishing_profile_xml_with_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @overload
        async def list_publishing_profile_xml_with_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @overload
        async def list_publishing_profile_xml_with_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                publishing_profile_options: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @overload
        async def list_publishing_profile_xml_with_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @overload
        async def list_publishing_profile_xml_with_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @overload
        async def list_publishing_profile_xml_with_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                publishing_profile_options: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncIterator[bytes]: ...

        @distributed_trace_async
        async def list_relay_service_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace_async
        async def list_relay_service_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace
        def list_site_backups(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[BackupItem]: ...

        @distributed_trace
        def list_site_backups_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[BackupItem]: ...

        @distributed_trace
        def list_site_containers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteContainer]: ...

        @distributed_trace
        def list_site_containers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteContainer]: ...

        @distributed_trace
        def list_site_extensions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteExtensionInfo]: ...

        @distributed_trace
        def list_site_extensions_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[SiteExtensionInfo]: ...

        @distributed_trace_async
        async def list_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PushSettings: ...

        @distributed_trace_async
        async def list_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PushSettings: ...

        @distributed_trace_async
        async def list_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        def list_slot_differences_from_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_from_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_from_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AsyncItemPaged[SlotDifference]: ...

        @distributed_trace
        def list_slot_site_deployment_statuses_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmDeploymentStatus]: ...

        @distributed_trace
        def list_slots(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Site]: ...

        @distributed_trace
        def list_snapshots(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Snapshot]: ...

        @distributed_trace
        def list_snapshots_from_dr_secondary(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Snapshot]: ...

        @distributed_trace
        def list_snapshots_from_dr_secondary_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Snapshot]: ...

        @distributed_trace
        def list_snapshots_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[Snapshot]: ...

        @distributed_trace_async
        async def list_sync_function_triggers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace_async
        async def list_sync_function_triggers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace_async
        async def list_sync_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def list_sync_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def list_triggered_web_job_history(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[TriggeredJobHistory]: ...

        @distributed_trace
        def list_triggered_web_job_history_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[TriggeredJobHistory]: ...

        @distributed_trace
        def list_triggered_web_jobs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[TriggeredWebJob]: ...

        @distributed_trace
        def list_triggered_web_jobs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[TriggeredWebJob]: ...

        @distributed_trace
        def list_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmUsageQuota]: ...

        @distributed_trace
        def list_usages_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[CsmUsageQuota]: ...

        @distributed_trace_async
        async def list_vnet_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[VnetInfoResource]: ...

        @distributed_trace_async
        async def list_vnet_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[VnetInfoResource]: ...

        @distributed_trace
        def list_web_jobs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WebJob]: ...

        @distributed_trace
        def list_web_jobs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WebJob]: ...

        @distributed_trace
        def list_workflows(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowEnvelope]: ...

        @distributed_trace_async
        async def list_workflows_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @distributed_trace_async
        async def list_workflows_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @overload
        async def put_private_access_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        async def put_private_access_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        async def put_private_access_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                access: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        async def put_private_access_vnet_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        async def put_private_access_vnet_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        async def put_private_access_vnet_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                access: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @distributed_trace_async
        async def recover_site_configuration_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def recover_site_configuration_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def reset_production_slot_config(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def reset_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def restart(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                soft_restart: Optional[bool] = ..., 
                synchronous: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def restart_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                soft_restart: Optional[bool] = ..., 
                synchronous: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def run_triggered_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def run_triggered_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def start(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def start_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def start_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def start_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def start_web_site_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace_async
        async def start_web_site_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace_async
        async def stop(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_web_site_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def stop_web_site_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def sync_function_triggers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def sync_function_triggers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def sync_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def sync_functions_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def sync_repository(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def sync_repository_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        async def update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        async def update_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        async def update_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        async def update_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        async def update_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        async def update_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        async def update_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        async def update_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        async def update_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        async def update_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings_v2: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        async def update_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        async def update_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        async def update_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings_v2: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        async def update_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def update_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def update_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                azure_storage_accounts: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def update_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def update_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def update_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                azure_storage_accounts: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        async def update_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        async def update_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        async def update_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        async def update_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        async def update_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        async def update_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        async def update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        async def update_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        async def update_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        async def update_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_strings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        async def update_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        async def update_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        async def update_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_strings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        async def update_diagnostic_logs_config(
                self, 
                resource_group_name: str, 
                name: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        async def update_diagnostic_logs_config(
                self, 
                resource_group_name: str, 
                name: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        async def update_diagnostic_logs_config(
                self, 
                resource_group_name: str, 
                name: str, 
                site_logs_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        async def update_diagnostic_logs_config_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        async def update_diagnostic_logs_config_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        async def update_diagnostic_logs_config_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_logs_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        async def update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        async def update_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        async def update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace_async
        async def update_machine_key(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @overload
        async def update_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                metadata: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                metadata: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        async def update_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def update_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def update_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def update_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def update_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def update_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        async def update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        async def update_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        async def update_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        async def update_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        async def update_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                push_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        async def update_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        async def update_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        async def update_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                push_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        async def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        async def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        async def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        async def update_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_config_names: SlotConfigNamesResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        async def update_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_config_names: SlotConfigNamesResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        async def update_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_config_names: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        async def update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        async def update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        async def update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        async def update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        async def update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        async def update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        async def update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        async def update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        async def update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        async def update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...


    class azure.mgmt.web.aio.operations.WorkflowRunActionRepetitionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> WorkflowRunActionRepetitionDefinition: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowRunActionRepetitionDefinition]: ...

        @distributed_trace
        def list_expression_traces(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ExpressionRoot]: ...


    class azure.mgmt.web.aio.operations.WorkflowRunActionRepetitionsRequestHistoriesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                request_history_name: str, 
                **kwargs: Any
            ) -> RequestHistory: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[RequestHistory]: ...


    class azure.mgmt.web.aio.operations.WorkflowRunActionScopeRepetitionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> WorkflowRunActionRepetitionDefinition: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowRunActionRepetitionDefinition]: ...


    class azure.mgmt.web.aio.operations.WorkflowRunActionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> WorkflowRunAction: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowRunAction]: ...

        @distributed_trace
        def list_expression_traces(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> AsyncItemPaged[ExpressionRoot]: ...


    class azure.mgmt.web.aio.operations.WorkflowRunsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def cancel(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                **kwargs: Any
            ) -> WorkflowRun: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowRun]: ...


    class azure.mgmt.web.aio.operations.WorkflowTriggerHistoriesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def begin_resubmit(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                history_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                history_name: str, 
                **kwargs: Any
            ) -> WorkflowTriggerHistory: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowTriggerHistory]: ...


    class azure.mgmt.web.aio.operations.WorkflowTriggersOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def begin_run(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> AsyncLROPoller[None]: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> WorkflowTrigger: ...

        @distributed_trace_async
        async def get_schema_json(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> JsonSchema: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowTrigger]: ...

        @distributed_trace_async
        async def list_callback_url(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> WorkflowTriggerCallbackUrl: ...


    class azure.mgmt.web.aio.operations.WorkflowVersionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace_async
        async def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                version_id: str, 
                **kwargs: Any
            ) -> WorkflowVersion: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                *, 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> AsyncItemPaged[WorkflowVersion]: ...


    class azure.mgmt.web.aio.operations.WorkflowsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        async def regenerate_access_key(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                key_type: RegenerateActionParameter, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def regenerate_access_key(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                key_type: RegenerateActionParameter, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def regenerate_access_key(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                key_type: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def validate(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                validate: Workflow, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def validate(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                validate: Workflow, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        async def validate(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                validate: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...


namespace azure.mgmt.web.models

    class azure.mgmt.web.models.AbnormalTimePeriod(_Model):
        end_time: Optional[datetime]
        events: Optional[list[DetectorAbnormalTimePeriod]]
        solutions: Optional[list[Solution]]
        start_time: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                end_time: Optional[datetime] = ..., 
                events: Optional[list[DetectorAbnormalTimePeriod]] = ..., 
                solutions: Optional[list[Solution]] = ..., 
                start_time: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AddressResponse(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[AddressResponseProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[AddressResponseProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AddressResponseProperties(_Model):
        internal_ip_address: Optional[str]
        outbound_ip_addresses: Optional[list[str]]
        service_ip_address: Optional[str]
        vip_mappings: Optional[list[VirtualIPMapping]]

        @overload
        def __init__(
                self, 
                *, 
                internal_ip_address: Optional[str] = ..., 
                outbound_ip_addresses: Optional[list[str]] = ..., 
                service_ip_address: Optional[str] = ..., 
                vip_mappings: Optional[list[VirtualIPMapping]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AllowedAudiencesValidation(_Model):
        allowed_audiences: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                allowed_audiences: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AllowedPrincipals(_Model):
        groups: Optional[list[str]]
        identities: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                groups: Optional[list[str]] = ..., 
                identities: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AnalysisData(_Model):
        data: Optional[list[list[NameValuePair]]]
        detector_definition: Optional[DetectorDefinition]
        detector_meta_data: Optional[ResponseMetaData]
        metrics: Optional[list[DiagnosticMetricSet]]
        source: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                data: Optional[list[list[NameValuePair]]] = ..., 
                detector_definition: Optional[DetectorDefinition] = ..., 
                detector_meta_data: Optional[ResponseMetaData] = ..., 
                metrics: Optional[list[DiagnosticMetricSet]] = ..., 
                source: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AnalysisDefinition(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[AnalysisDefinitionProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[AnalysisDefinitionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AnalysisDefinitionProperties(_Model):
        description: Optional[str]


    class azure.mgmt.web.models.ApiDefinitionInfo(_Model):
        url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ApiKVReference(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[ApiKVReferenceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ApiKVReferenceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ApiKVReferenceProperties(_Model):
        active_version: Optional[str]
        details: Optional[str]
        identity_type: Optional[ManagedServiceIdentity]
        reference: Optional[str]
        secret_name: Optional[str]
        secret_version: Optional[str]
        source: Optional[Literal["KeyVault"]]
        status: Optional[Union[str, ResolveStatus]]
        vault_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                active_version: Optional[str] = ..., 
                details: Optional[str] = ..., 
                identity_type: Optional[ManagedServiceIdentity] = ..., 
                reference: Optional[str] = ..., 
                secret_name: Optional[str] = ..., 
                secret_version: Optional[str] = ..., 
                source: Optional[Literal[KeyVault]] = ..., 
                status: Optional[Union[str, ResolveStatus]] = ..., 
                vault_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ApiManagementConfig(_Model):
        id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppInsightsWebAppStackSettings(_Model):
        is_default_off: Optional[bool]
        is_supported: Optional[bool]


    class azure.mgmt.web.models.AppLogsConfiguration(_Model):
        destination: Optional[str]
        log_analytics_configuration: Optional[LogAnalyticsConfiguration]

        @overload
        def __init__(
                self, 
                *, 
                destination: Optional[str] = ..., 
                log_analytics_configuration: Optional[LogAnalyticsConfiguration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppRegistration(_Model):
        app_id: Optional[str]
        app_secret_setting_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                app_id: Optional[str] = ..., 
                app_secret_setting_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppServiceEnvironment(_Model):
        cluster_settings: Optional[list[NameValuePair]]
        custom_dns_suffix_configuration: Optional[CustomDnsSuffixConfiguration]
        dedicated_host_count: Optional[int]
        dns_suffix: Optional[str]
        front_end_scale_factor: Optional[int]
        has_linux_workers: Optional[bool]
        internal_load_balancing_mode: Optional[Union[str, LoadBalancingMode]]
        ipssl_address_count: Optional[int]
        maximum_number_of_machines: Optional[int]
        multi_role_count: Optional[int]
        multi_size: Optional[str]
        networking_configuration: Optional[AseV3NetworkingConfiguration]
        provisioning_state: Optional[Union[str, ProvisioningState]]
        status: Optional[Union[str, HostingEnvironmentStatus]]
        suspended: Optional[bool]
        upgrade_availability: Optional[Union[str, UpgradeAvailability]]
        upgrade_preference: Optional[Union[str, UpgradePreference]]
        user_whitelisted_ip_ranges: Optional[list[str]]
        virtual_network: VirtualNetworkProfile
        zone_redundant: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                cluster_settings: Optional[list[NameValuePair]] = ..., 
                custom_dns_suffix_configuration: Optional[CustomDnsSuffixConfiguration] = ..., 
                dedicated_host_count: Optional[int] = ..., 
                dns_suffix: Optional[str] = ..., 
                front_end_scale_factor: Optional[int] = ..., 
                internal_load_balancing_mode: Optional[Union[str, LoadBalancingMode]] = ..., 
                ipssl_address_count: Optional[int] = ..., 
                multi_size: Optional[str] = ..., 
                networking_configuration: Optional[AseV3NetworkingConfiguration] = ..., 
                upgrade_preference: Optional[Union[str, UpgradePreference]] = ..., 
                user_whitelisted_ip_ranges: Optional[list[str]] = ..., 
                virtual_network: VirtualNetworkProfile, 
                zone_redundant: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppServiceEnvironmentPatchResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[AppServiceEnvironment]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[AppServiceEnvironment] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AppServiceEnvironmentResource(TrackedResource):
        id: str
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[AppServiceEnvironment]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[AppServiceEnvironment] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AppServicePlan(TrackedResource):
        extended_location: Optional[ExtendedLocation]
        id: str
        identity: Optional[ManagedServiceIdentity]
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[AppServicePlanProperties]
        sku: Optional[SkuDescription]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                extended_location: Optional[ExtendedLocation] = ..., 
                identity: Optional[ManagedServiceIdentity] = ..., 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[AppServicePlanProperties] = ..., 
                sku: Optional[SkuDescription] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AppServicePlanPatchResource(ProxyOnlyResource):
        id: str
        identity: Optional[ManagedServiceIdentity]
        kind: str
        name: str
        properties: Optional[AppServicePlanPatchResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                identity: Optional[ManagedServiceIdentity] = ..., 
                kind: Optional[str] = ..., 
                properties: Optional[AppServicePlanPatchResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AppServicePlanPatchResourceProperties(_Model):
        elastic_scale_enabled: Optional[bool]
        free_offer_expiration_time: Optional[datetime]
        geo_region: Optional[str]
        hosting_environment_profile: Optional[HostingEnvironmentProfile]
        hyper_v: Optional[bool]
        is_spot: Optional[bool]
        is_xenon: Optional[bool]
        kube_environment_profile: Optional[KubeEnvironmentProfile]
        maximum_elastic_worker_count: Optional[int]
        maximum_number_of_workers: Optional[int]
        number_of_sites: Optional[int]
        number_of_workers: Optional[int]
        per_site_scaling: Optional[bool]
        provisioning_state: Optional[Union[str, ProvisioningState]]
        reserved: Optional[bool]
        resource_group: Optional[str]
        spot_expiration_time: Optional[datetime]
        status: Optional[Union[str, StatusOptions]]
        subscription: Optional[str]
        target_worker_count: Optional[int]
        target_worker_size_id: Optional[int]
        worker_tier_name: Optional[str]
        zone_redundant: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                elastic_scale_enabled: Optional[bool] = ..., 
                free_offer_expiration_time: Optional[datetime] = ..., 
                hosting_environment_profile: Optional[HostingEnvironmentProfile] = ..., 
                hyper_v: Optional[bool] = ..., 
                is_spot: Optional[bool] = ..., 
                is_xenon: Optional[bool] = ..., 
                kube_environment_profile: Optional[KubeEnvironmentProfile] = ..., 
                maximum_elastic_worker_count: Optional[int] = ..., 
                per_site_scaling: Optional[bool] = ..., 
                reserved: Optional[bool] = ..., 
                spot_expiration_time: Optional[datetime] = ..., 
                target_worker_count: Optional[int] = ..., 
                target_worker_size_id: Optional[int] = ..., 
                worker_tier_name: Optional[str] = ..., 
                zone_redundant: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppServicePlanProperties(_Model):
        async_scaling_enabled: Optional[bool]
        elastic_scale_enabled: Optional[bool]
        free_offer_expiration_time: Optional[datetime]
        geo_region: Optional[str]
        hosting_environment_profile: Optional[HostingEnvironmentProfile]
        hyper_v: Optional[bool]
        install_scripts: Optional[list[InstallScript]]
        is_custom_mode: Optional[bool]
        is_spot: Optional[bool]
        is_xenon: Optional[bool]
        kube_environment_profile: Optional[KubeEnvironmentProfile]
        maximum_elastic_worker_count: Optional[int]
        maximum_number_of_workers: Optional[int]
        network: Optional[ServerFarmNetworkSettings]
        number_of_sites: Optional[int]
        number_of_workers: Optional[int]
        per_site_scaling: Optional[bool]
        plan_default_identity: Optional[DefaultIdentity]
        provisioning_state: Optional[Union[str, ProvisioningState]]
        rdp_enabled: Optional[bool]
        registry_adapters: Optional[list[RegistryAdapter]]
        reserved: Optional[bool]
        resource_group: Optional[str]
        spot_expiration_time: Optional[datetime]
        status: Optional[Union[str, StatusOptions]]
        storage_mounts: Optional[list[StorageMount]]
        subscription: Optional[str]
        target_worker_count: Optional[int]
        target_worker_size_id: Optional[int]
        worker_tier_name: Optional[str]
        zone_redundant: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                async_scaling_enabled: Optional[bool] = ..., 
                elastic_scale_enabled: Optional[bool] = ..., 
                free_offer_expiration_time: Optional[datetime] = ..., 
                hosting_environment_profile: Optional[HostingEnvironmentProfile] = ..., 
                hyper_v: Optional[bool] = ..., 
                install_scripts: Optional[list[InstallScript]] = ..., 
                is_custom_mode: Optional[bool] = ..., 
                is_spot: Optional[bool] = ..., 
                is_xenon: Optional[bool] = ..., 
                kube_environment_profile: Optional[KubeEnvironmentProfile] = ..., 
                maximum_elastic_worker_count: Optional[int] = ..., 
                network: Optional[ServerFarmNetworkSettings] = ..., 
                per_site_scaling: Optional[bool] = ..., 
                plan_default_identity: Optional[DefaultIdentity] = ..., 
                rdp_enabled: Optional[bool] = ..., 
                registry_adapters: Optional[list[RegistryAdapter]] = ..., 
                reserved: Optional[bool] = ..., 
                spot_expiration_time: Optional[datetime] = ..., 
                storage_mounts: Optional[list[StorageMount]] = ..., 
                target_worker_count: Optional[int] = ..., 
                target_worker_size_id: Optional[int] = ..., 
                worker_tier_name: Optional[str] = ..., 
                zone_redundant: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppServicePlanRestrictions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BASIC = "Basic"
        FREE = "Free"
        NONE = "None"
        PREMIUM = "Premium"
        SHARED = "Shared"
        STANDARD = "Standard"


    class azure.mgmt.web.models.Apple(_Model):
        enabled: Optional[bool]
        login: Optional[LoginScopes]
        registration: Optional[AppleRegistration]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                login: Optional[LoginScopes] = ..., 
                registration: Optional[AppleRegistration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AppleRegistration(_Model):
        client_id: Optional[str]
        client_secret_setting_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_id: Optional[str] = ..., 
                client_secret_setting_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ApplicationLogsConfig(_Model):
        azure_blob_storage: Optional[AzureBlobStorageApplicationLogsConfig]
        azure_table_storage: Optional[AzureTableStorageApplicationLogsConfig]
        file_system: Optional[FileSystemApplicationLogsConfig]

        @overload
        def __init__(
                self, 
                *, 
                azure_blob_storage: Optional[AzureBlobStorageApplicationLogsConfig] = ..., 
                azure_table_storage: Optional[AzureTableStorageApplicationLogsConfig] = ..., 
                file_system: Optional[FileSystemApplicationLogsConfig] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ApplicationStack(_Model):
        dependency: Optional[str]
        display: Optional[str]
        frameworks: Optional[list[ApplicationStack]]
        is_deprecated: Optional[list[ApplicationStack]]
        major_versions: Optional[list[StackMajorVersion]]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                dependency: Optional[str] = ..., 
                display: Optional[str] = ..., 
                frameworks: Optional[list[ApplicationStack]] = ..., 
                is_deprecated: Optional[list[ApplicationStack]] = ..., 
                major_versions: Optional[list[StackMajorVersion]] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ApplicationStackResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[ApplicationStack]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ApplicationStack] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ArcConfiguration(_Model):
        artifact_storage_access_mode: Optional[str]
        artifact_storage_class_name: Optional[str]
        artifact_storage_mount_path: Optional[str]
        artifact_storage_node_name: Optional[str]
        artifacts_storage_type: Optional[Union[str, StorageType]]
        front_end_service_configuration: Optional[FrontEndConfiguration]
        kube_config: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                artifact_storage_access_mode: Optional[str] = ..., 
                artifact_storage_class_name: Optional[str] = ..., 
                artifact_storage_mount_path: Optional[str] = ..., 
                artifact_storage_node_name: Optional[str] = ..., 
                artifacts_storage_type: Optional[Union[str, StorageType]] = ..., 
                front_end_service_configuration: Optional[FrontEndConfiguration] = ..., 
                kube_config: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ArmIdWrapper(_Model):
        id: Optional[str]


    class azure.mgmt.web.models.ArmPlan(_Model):
        name: Optional[str]
        product: Optional[str]
        promotion_code: Optional[str]
        publisher: Optional[str]
        version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ..., 
                product: Optional[str] = ..., 
                promotion_code: Optional[str] = ..., 
                publisher: Optional[str] = ..., 
                version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AseRegion(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[AseRegionProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[AseRegionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AseRegionProperties(_Model):
        available_os: Optional[list[str]]
        available_sku: Optional[list[str]]
        dedicated_host: Optional[bool]
        display_name: Optional[str]
        standard: Optional[bool]
        zone_redundant: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                available_os: Optional[list[str]] = ..., 
                available_sku: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AseV3NetworkingConfiguration(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[AseV3NetworkingConfigurationProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[AseV3NetworkingConfigurationProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AseV3NetworkingConfigurationProperties(_Model):
        allow_new_private_endpoint_connections: Optional[bool]
        external_inbound_ip_addresses: Optional[list[str]]
        ftp_enabled: Optional[bool]
        inbound_ip_address_override: Optional[str]
        internal_inbound_ip_addresses: Optional[list[str]]
        linux_outbound_ip_addresses: Optional[list[str]]
        remote_debug_enabled: Optional[bool]
        windows_outbound_ip_addresses: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                allow_new_private_endpoint_connections: Optional[bool] = ..., 
                ftp_enabled: Optional[bool] = ..., 
                inbound_ip_address_override: Optional[str] = ..., 
                remote_debug_enabled: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AuthPlatform(_Model):
        config_file_path: Optional[str]
        enabled: Optional[bool]
        runtime_version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                config_file_path: Optional[str] = ..., 
                enabled: Optional[bool] = ..., 
                runtime_version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AuthType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ANONYMOUS = "Anonymous"
        SYSTEM_IDENTITY = "SystemIdentity"
        USER_ASSIGNED = "UserAssigned"
        USER_CREDENTIALS = "UserCredentials"


    class azure.mgmt.web.models.AuthenticationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        STORAGE_ACCOUNT_CONNECTION_STRING = "StorageAccountConnectionString"
        SYSTEM_ASSIGNED_IDENTITY = "SystemAssignedIdentity"
        USER_ASSIGNED_IDENTITY = "UserAssignedIdentity"


    class azure.mgmt.web.models.AutoGeneratedDomainNameLabelScope(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        NO_REUSE = "NoReuse"
        RESOURCE_GROUP_REUSE = "ResourceGroupReuse"
        SUBSCRIPTION_REUSE = "SubscriptionReuse"
        TENANT_REUSE = "TenantReuse"


    class azure.mgmt.web.models.AutoHealActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CUSTOM_ACTION = "CustomAction"
        LOG_EVENT = "LogEvent"
        RECYCLE = "Recycle"


    class azure.mgmt.web.models.AutoHealActions(_Model):
        action_type: Optional[Union[str, AutoHealActionType]]
        custom_action: Optional[AutoHealCustomAction]
        min_process_execution_time: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                action_type: Optional[Union[str, AutoHealActionType]] = ..., 
                custom_action: Optional[AutoHealCustomAction] = ..., 
                min_process_execution_time: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AutoHealCustomAction(_Model):
        exe: Optional[str]
        parameters: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                exe: Optional[str] = ..., 
                parameters: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AutoHealRules(_Model):
        actions: Optional[AutoHealActions]
        triggers: Optional[AutoHealTriggers]

        @overload
        def __init__(
                self, 
                *, 
                actions: Optional[AutoHealActions] = ..., 
                triggers: Optional[AutoHealTriggers] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AutoHealTriggers(_Model):
        private_bytes_in_kb: Optional[int]
        requests: Optional[RequestsBasedTrigger]
        slow_requests: Optional[SlowRequestsBasedTrigger]
        slow_requests_with_path: Optional[list[SlowRequestsBasedTrigger]]
        status_codes: Optional[list[StatusCodesBasedTrigger]]
        status_codes_range: Optional[list[StatusCodesRangeBasedTrigger]]

        @overload
        def __init__(
                self, 
                *, 
                private_bytes_in_kb: Optional[int] = ..., 
                requests: Optional[RequestsBasedTrigger] = ..., 
                slow_requests: Optional[SlowRequestsBasedTrigger] = ..., 
                slow_requests_with_path: Optional[list[SlowRequestsBasedTrigger]] = ..., 
                status_codes: Optional[list[StatusCodesBasedTrigger]] = ..., 
                status_codes_range: Optional[list[StatusCodesRangeBasedTrigger]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureActiveDirectory(_Model):
        enabled: Optional[bool]
        is_auto_provisioned: Optional[bool]
        login: Optional[AzureActiveDirectoryLogin]
        registration: Optional[AzureActiveDirectoryRegistration]
        validation: Optional[AzureActiveDirectoryValidation]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                is_auto_provisioned: Optional[bool] = ..., 
                login: Optional[AzureActiveDirectoryLogin] = ..., 
                registration: Optional[AzureActiveDirectoryRegistration] = ..., 
                validation: Optional[AzureActiveDirectoryValidation] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureActiveDirectoryLogin(_Model):
        disable_www_authenticate: Optional[bool]
        login_parameters: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                disable_www_authenticate: Optional[bool] = ..., 
                login_parameters: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureActiveDirectoryRegistration(_Model):
        client_id: Optional[str]
        client_secret_certificate_issuer: Optional[str]
        client_secret_certificate_subject_alternative_name: Optional[str]
        client_secret_certificate_thumbprint: Optional[str]
        client_secret_setting_name: Optional[str]
        open_id_issuer: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_id: Optional[str] = ..., 
                client_secret_certificate_issuer: Optional[str] = ..., 
                client_secret_certificate_subject_alternative_name: Optional[str] = ..., 
                client_secret_certificate_thumbprint: Optional[str] = ..., 
                client_secret_setting_name: Optional[str] = ..., 
                open_id_issuer: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureActiveDirectoryValidation(_Model):
        allowed_audiences: Optional[list[str]]
        default_authorization_policy: Optional[DefaultAuthorizationPolicy]
        jwt_claim_checks: Optional[JwtClaimChecks]

        @overload
        def __init__(
                self, 
                *, 
                allowed_audiences: Optional[list[str]] = ..., 
                default_authorization_policy: Optional[DefaultAuthorizationPolicy] = ..., 
                jwt_claim_checks: Optional[JwtClaimChecks] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureBlobStorageApplicationLogsConfig(_Model):
        level: Optional[Union[str, LogLevel]]
        retention_in_days: Optional[int]
        sas_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                level: Optional[Union[str, LogLevel]] = ..., 
                retention_in_days: Optional[int] = ..., 
                sas_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureBlobStorageHttpLogsConfig(_Model):
        enabled: Optional[bool]
        retention_in_days: Optional[int]
        sas_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                retention_in_days: Optional[int] = ..., 
                sas_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureResourceErrorInfo(ErrorInfo):
        code: str
        details: Optional[list[AzureResourceErrorInfo]]
        message: str

        @overload
        def __init__(
                self, 
                *, 
                code: str, 
                details: Optional[list[AzureResourceErrorInfo]] = ..., 
                message: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureResourceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        TRAFFIC_MANAGER = "TrafficManager"
        WEBSITE = "Website"


    class azure.mgmt.web.models.AzureStaticWebApps(_Model):
        enabled: Optional[bool]
        registration: Optional[AzureStaticWebAppsRegistration]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                registration: Optional[AzureStaticWebAppsRegistration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureStaticWebAppsRegistration(_Model):
        client_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureStorageInfoValue(_Model):
        access_key: Optional[str]
        account_name: Optional[str]
        mount_path: Optional[str]
        protocol: Optional[Union[str, AzureStorageProtocol]]
        share_name: Optional[str]
        state: Optional[Union[str, AzureStorageState]]
        type: Optional[Union[str, AzureStorageType]]

        @overload
        def __init__(
                self, 
                *, 
                access_key: Optional[str] = ..., 
                account_name: Optional[str] = ..., 
                mount_path: Optional[str] = ..., 
                protocol: Optional[Union[str, AzureStorageProtocol]] = ..., 
                share_name: Optional[str] = ..., 
                type: Optional[Union[str, AzureStorageType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.AzureStoragePropertyDictionaryResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[dict[str, AzureStorageInfoValue]]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[dict[str, AzureStorageInfoValue]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.AzureStorageProtocol(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        HTTP = "Http"
        NFS = "Nfs"
        SMB = "Smb"


    class azure.mgmt.web.models.AzureStorageState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        INVALID_CREDENTIALS = "InvalidCredentials"
        INVALID_SHARE = "InvalidShare"
        NOT_VALIDATED = "NotValidated"
        OK = "Ok"


    class azure.mgmt.web.models.AzureStorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        AZURE_BLOB = "AzureBlob"
        AZURE_FILES = "AzureFiles"


    class azure.mgmt.web.models.AzureTableStorageApplicationLogsConfig(_Model):
        level: Optional[Union[str, LogLevel]]
        sas_url: str

        @overload
        def __init__(
                self, 
                *, 
                level: Optional[Union[str, LogLevel]] = ..., 
                sas_url: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.BackupItem(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[BackupItemProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[BackupItemProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.BackupItemProperties(_Model):
        backup_id: Optional[int]
        blob_name: Optional[str]
        correlation_id: Optional[str]
        created: Optional[datetime]
        databases: Optional[list[DatabaseBackupSetting]]
        finished_time_stamp: Optional[datetime]
        last_restore_time_stamp: Optional[datetime]
        log: Optional[str]
        name: Optional[str]
        scheduled: Optional[bool]
        size_in_bytes: Optional[int]
        status: Optional[Union[str, BackupItemStatus]]
        storage_account_url: Optional[str]
        website_size_in_bytes: Optional[int]


    class azure.mgmt.web.models.BackupItemStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CREATED = "Created"
        DELETED = "Deleted"
        DELETE_FAILED = "DeleteFailed"
        DELETE_IN_PROGRESS = "DeleteInProgress"
        FAILED = "Failed"
        IN_PROGRESS = "InProgress"
        PARTIALLY_SUCCEEDED = "PartiallySucceeded"
        SKIPPED = "Skipped"
        SUCCEEDED = "Succeeded"
        TIMED_OUT = "TimedOut"


    class azure.mgmt.web.models.BackupRequest(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[BackupRequestProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[BackupRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.BackupRequestProperties(_Model):
        backup_name: Optional[str]
        backup_schedule: Optional[BackupSchedule]
        databases: Optional[list[DatabaseBackupSetting]]
        enabled: Optional[bool]
        storage_account_url: str

        @overload
        def __init__(
                self, 
                *, 
                backup_name: Optional[str] = ..., 
                backup_schedule: Optional[BackupSchedule] = ..., 
                databases: Optional[list[DatabaseBackupSetting]] = ..., 
                enabled: Optional[bool] = ..., 
                storage_account_url: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.BackupRestoreOperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CLONE = "Clone"
        CLOUD_FS = "CloudFS"
        DEFAULT = "Default"
        RELOCATION = "Relocation"
        SNAPSHOT = "Snapshot"


    class azure.mgmt.web.models.BackupSchedule(_Model):
        frequency_interval: int
        frequency_unit: Union[str, FrequencyUnit]
        keep_at_least_one_backup: bool
        last_execution_time: Optional[datetime]
        retention_period_in_days: int
        start_time: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                frequency_interval: int, 
                frequency_unit: Union[str, FrequencyUnit], 
                keep_at_least_one_backup: bool, 
                retention_period_in_days: int, 
                start_time: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.BasicAuthName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DEFAULT = "default"


    class azure.mgmt.web.models.BillingMeter(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[BillingMeterProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[BillingMeterProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.BillingMeterProperties(_Model):
        billing_location: Optional[str]
        friendly_name: Optional[str]
        meter_id: Optional[str]
        multiplier: Optional[float]
        os_type: Optional[str]
        resource_type: Optional[str]
        short_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                billing_location: Optional[str] = ..., 
                friendly_name: Optional[str] = ..., 
                meter_id: Optional[str] = ..., 
                multiplier: Optional[float] = ..., 
                os_type: Optional[str] = ..., 
                resource_type: Optional[str] = ..., 
                short_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.BlobStorageTokenStore(_Model):
        sas_url_setting_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                sas_url_setting_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.BuildStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DELETING = "Deleting"
        DEPLOYING = "Deploying"
        DETACHED = "Detached"
        FAILED = "Failed"
        READY = "Ready"
        UPLOADING = "Uploading"
        WAITING_FOR_DEPLOYMENT = "WaitingForDeployment"


    class azure.mgmt.web.models.BuiltInAuthenticationProvider(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        AZURE_ACTIVE_DIRECTORY = "AzureActiveDirectory"
        FACEBOOK = "Facebook"
        GITHUB = "Github"
        GOOGLE = "Google"
        MICROSOFT_ACCOUNT = "MicrosoftAccount"
        TWITTER = "Twitter"


    class azure.mgmt.web.models.Capability(_Model):
        name: Optional[str]
        reason: Optional[str]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ..., 
                reason: Optional[str] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Certificate(TrackedResource):
        id: str
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[CertificateProperties]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[CertificateProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CertificatePatchResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[CertificatePatchResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[CertificatePatchResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CertificatePatchResourceProperties(_Model):
        canonical_name: Optional[str]
        cer_blob: Optional[bytes]
        domain_validation_method: Optional[str]
        expiration_date: Optional[datetime]
        friendly_name: Optional[str]
        host_names: Optional[list[str]]
        hosting_environment_profile: Optional[HostingEnvironmentProfile]
        issue_date: Optional[datetime]
        issuer: Optional[str]
        key_vault_id: Optional[str]
        key_vault_secret_name: Optional[str]
        key_vault_secret_status: Optional[Union[str, KeyVaultSecretStatus]]
        password: Optional[str]
        pfx_blob: Optional[bytes]
        public_key_hash: Optional[str]
        self_link: Optional[str]
        server_farm_id: Optional[str]
        site_name: Optional[str]
        subject_name: Optional[str]
        thumbprint: Optional[str]
        valid: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                canonical_name: Optional[str] = ..., 
                domain_validation_method: Optional[str] = ..., 
                host_names: Optional[list[str]] = ..., 
                key_vault_id: Optional[str] = ..., 
                key_vault_secret_name: Optional[str] = ..., 
                pfx_blob: Optional[bytes] = ..., 
                server_farm_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CertificateProperties(_Model):
        canonical_name: Optional[str]
        cer_blob: Optional[bytes]
        domain_validation_method: Optional[str]
        expiration_date: Optional[datetime]
        friendly_name: Optional[str]
        host_names: Optional[list[str]]
        hosting_environment_profile: Optional[HostingEnvironmentProfile]
        issue_date: Optional[datetime]
        issuer: Optional[str]
        key_vault_id: Optional[str]
        key_vault_secret_name: Optional[str]
        key_vault_secret_status: Optional[Union[str, KeyVaultSecretStatus]]
        password: Optional[str]
        pfx_blob: Optional[bytes]
        public_key_hash: Optional[str]
        self_link: Optional[str]
        server_farm_id: Optional[str]
        site_name: Optional[str]
        subject_name: Optional[str]
        thumbprint: Optional[str]
        valid: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                canonical_name: Optional[str] = ..., 
                domain_validation_method: Optional[str] = ..., 
                host_names: Optional[list[str]] = ..., 
                key_vault_id: Optional[str] = ..., 
                key_vault_secret_name: Optional[str] = ..., 
                password: Optional[str] = ..., 
                pfx_blob: Optional[bytes] = ..., 
                server_farm_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Channels(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALL = "All"
        API = "Api"
        EMAIL = "Email"
        NOTIFICATION = "Notification"
        WEBHOOK = "Webhook"


    class azure.mgmt.web.models.CheckNameResourceTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        HOSTING_ENVIRONMENT = "HostingEnvironment"
        MICROSOFT_WEB_HOSTING_ENVIRONMENTS = "Microsoft.Web/hostingEnvironments"
        MICROSOFT_WEB_PUBLISHING_USERS = "Microsoft.Web/publishingUsers"
        MICROSOFT_WEB_SITES = "Microsoft.Web/sites"
        MICROSOFT_WEB_SITES_SLOTS = "Microsoft.Web/sites/slots"
        PUBLISHING_USER = "PublishingUser"
        SITE = "Site"
        SLOT = "Slot"


    class azure.mgmt.web.models.ClientCertMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        OPTIONAL = "Optional"
        OPTIONAL_INTERACTIVE_USER = "OptionalInteractiveUser"
        REQUIRED = "Required"


    class azure.mgmt.web.models.ClientRegistration(_Model):
        client_id: Optional[str]
        client_secret_setting_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_id: Optional[str] = ..., 
                client_secret_setting_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CloneAbilityResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CLONEABLE = "Cloneable"
        NOT_CLONEABLE = "NotCloneable"
        PARTIALLY_CLONEABLE = "PartiallyCloneable"


    class azure.mgmt.web.models.CloningInfo(_Model):
        app_settings_overrides: Optional[dict[str, str]]
        clone_custom_host_names: Optional[bool]
        clone_source_control: Optional[bool]
        configure_load_balancing: Optional[bool]
        correlation_id: Optional[str]
        hosting_environment: Optional[str]
        overwrite: Optional[bool]
        source_web_app_id: str
        source_web_app_location: Optional[str]
        traffic_manager_profile_id: Optional[str]
        traffic_manager_profile_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                app_settings_overrides: Optional[dict[str, str]] = ..., 
                clone_custom_host_names: Optional[bool] = ..., 
                clone_source_control: Optional[bool] = ..., 
                configure_load_balancing: Optional[bool] = ..., 
                correlation_id: Optional[str] = ..., 
                hosting_environment: Optional[str] = ..., 
                overwrite: Optional[bool] = ..., 
                source_web_app_id: str, 
                source_web_app_location: Optional[str] = ..., 
                traffic_manager_profile_id: Optional[str] = ..., 
                traffic_manager_profile_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ComputeModeOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DEDICATED = "Dedicated"
        DYNAMIC = "Dynamic"
        SHARED = "Shared"


    class azure.mgmt.web.models.ConnStringInfo(_Model):
        connection_string: Optional[str]
        name: Optional[str]
        type: Optional[Union[str, ConnectionStringType]]

        @overload
        def __init__(
                self, 
                *, 
                connection_string: Optional[str] = ..., 
                name: Optional[str] = ..., 
                type: Optional[Union[str, ConnectionStringType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ConnStringValueTypePair(_Model):
        type: Union[str, ConnectionStringType]
        value: str

        @overload
        def __init__(
                self, 
                *, 
                type: Union[str, ConnectionStringType], 
                value: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ConnectionStringDictionary(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[dict[str, ConnStringValueTypePair]]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[dict[str, ConnStringValueTypePair]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ConnectionStringType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        API_HUB = "ApiHub"
        CUSTOM = "Custom"
        DOC_DB = "DocDb"
        EVENT_HUB = "EventHub"
        MY_SQL = "MySql"
        NOTIFICATION_HUB = "NotificationHub"
        POSTGRE_SQL = "PostgreSQL"
        REDIS_CACHE = "RedisCache"
        SERVICE_BUS = "ServiceBus"
        SQL_AZURE = "SQLAzure"
        SQL_SERVER = "SQLServer"


    class azure.mgmt.web.models.ContainerAppsConfiguration(_Model):
        app_subnet_resource_id: Optional[str]
        control_plane_subnet_resource_id: Optional[str]
        dapr_ai_instrumentation_key: Optional[str]
        docker_bridge_cidr: Optional[str]
        platform_reserved_cidr: Optional[str]
        platform_reserved_dns_ip: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                app_subnet_resource_id: Optional[str] = ..., 
                control_plane_subnet_resource_id: Optional[str] = ..., 
                dapr_ai_instrumentation_key: Optional[str] = ..., 
                docker_bridge_cidr: Optional[str] = ..., 
                platform_reserved_cidr: Optional[str] = ..., 
                platform_reserved_dns_ip: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContainerCpuStatistics(_Model):
        cpu_usage: Optional[ContainerCpuUsage]
        online_cpu_count: Optional[int]
        system_cpu_usage: Optional[int]
        throttling_data: Optional[ContainerThrottlingData]

        @overload
        def __init__(
                self, 
                *, 
                cpu_usage: Optional[ContainerCpuUsage] = ..., 
                online_cpu_count: Optional[int] = ..., 
                system_cpu_usage: Optional[int] = ..., 
                throttling_data: Optional[ContainerThrottlingData] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContainerCpuUsage(_Model):
        kernel_mode_usage: Optional[int]
        per_cpu_usage: Optional[list[int]]
        total_usage: Optional[int]
        user_mode_usage: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                kernel_mode_usage: Optional[int] = ..., 
                per_cpu_usage: Optional[list[int]] = ..., 
                total_usage: Optional[int] = ..., 
                user_mode_usage: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContainerInfo(_Model):
        current_cpu_stats: Optional[ContainerCpuStatistics]
        current_time_stamp: Optional[datetime]
        eth0: Optional[ContainerNetworkInterfaceStatistics]
        id: Optional[str]
        memory_stats: Optional[ContainerMemoryStatistics]
        name: Optional[str]
        previous_cpu_stats: Optional[ContainerCpuStatistics]
        previous_time_stamp: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                current_cpu_stats: Optional[ContainerCpuStatistics] = ..., 
                current_time_stamp: Optional[datetime] = ..., 
                eth0: Optional[ContainerNetworkInterfaceStatistics] = ..., 
                id: Optional[str] = ..., 
                memory_stats: Optional[ContainerMemoryStatistics] = ..., 
                name: Optional[str] = ..., 
                previous_cpu_stats: Optional[ContainerCpuStatistics] = ..., 
                previous_time_stamp: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContainerMemoryStatistics(_Model):
        limit: Optional[int]
        max_usage: Optional[int]
        usage: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                limit: Optional[int] = ..., 
                max_usage: Optional[int] = ..., 
                usage: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContainerNetworkInterfaceStatistics(_Model):
        rx_bytes: Optional[int]
        rx_dropped: Optional[int]
        rx_errors: Optional[int]
        rx_packets: Optional[int]
        tx_bytes: Optional[int]
        tx_dropped: Optional[int]
        tx_errors: Optional[int]
        tx_packets: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                rx_bytes: Optional[int] = ..., 
                rx_dropped: Optional[int] = ..., 
                rx_errors: Optional[int] = ..., 
                rx_packets: Optional[int] = ..., 
                tx_bytes: Optional[int] = ..., 
                tx_dropped: Optional[int] = ..., 
                tx_errors: Optional[int] = ..., 
                tx_packets: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContainerThrottlingData(_Model):
        periods: Optional[int]
        throttled_periods: Optional[int]
        throttled_time: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                periods: Optional[int] = ..., 
                throttled_periods: Optional[int] = ..., 
                throttled_time: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContentHash(_Model):
        algorithm: Optional[str]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                algorithm: Optional[str] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContentLink(_Model):
        content_hash: Optional[ContentHash]
        content_size: Optional[int]
        content_version: Optional[str]
        metadata: Optional[Any]
        uri: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                uri: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContinuousWebJob(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[ContinuousWebJobProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ContinuousWebJobProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ContinuousWebJobProperties(_Model):
        detailed_status: Optional[str]
        error: Optional[str]
        extra_info_url: Optional[str]
        log_url: Optional[str]
        run_command: Optional[str]
        settings: Optional[dict[str, Any]]
        status: Optional[Union[str, ContinuousWebJobStatus]]
        url: Optional[str]
        using_sdk: Optional[bool]
        web_job_type: Optional[Union[str, WebJobType]]

        @overload
        def __init__(
                self, 
                *, 
                detailed_status: Optional[str] = ..., 
                error: Optional[str] = ..., 
                extra_info_url: Optional[str] = ..., 
                log_url: Optional[str] = ..., 
                run_command: Optional[str] = ..., 
                settings: Optional[dict[str, Any]] = ..., 
                status: Optional[Union[str, ContinuousWebJobStatus]] = ..., 
                url: Optional[str] = ..., 
                using_sdk: Optional[bool] = ..., 
                web_job_type: Optional[Union[str, WebJobType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ContinuousWebJobStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        INITIALIZING = "Initializing"
        PENDING_RESTART = "PendingRestart"
        RUNNING = "Running"
        STARTING = "Starting"
        STOPPED = "Stopped"


    class azure.mgmt.web.models.CookieExpiration(_Model):
        convention: Optional[Union[str, CookieExpirationConvention]]
        time_to_expiration: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                convention: Optional[Union[str, CookieExpirationConvention]] = ..., 
                time_to_expiration: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CookieExpirationConvention(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        FIXED_TIME = "FixedTime"
        IDENTITY_PROVIDER_DERIVED = "IdentityProviderDerived"


    class azure.mgmt.web.models.Correlation(_Model):
        client_tracking_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_tracking_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CorsSettings(_Model):
        allowed_origins: Optional[list[str]]
        support_credentials: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                allowed_origins: Optional[list[str]] = ..., 
                support_credentials: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        APPLICATION = "Application"
        KEY = "Key"
        MANAGED_IDENTITY = "ManagedIdentity"
        USER = "User"


    class azure.mgmt.web.models.CsmDeploymentStatus(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[CsmDeploymentStatusProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[CsmDeploymentStatusProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CsmDeploymentStatusProperties(_Model):
        deployment_id: Optional[str]
        errors: Optional[list[ErrorEntity]]
        failed_instances_logs: Optional[list[str]]
        number_of_instances_failed: Optional[int]
        number_of_instances_in_progress: Optional[int]
        number_of_instances_successful: Optional[int]
        status: Optional[Union[str, DeploymentBuildStatus]]

        @overload
        def __init__(
                self, 
                *, 
                deployment_id: Optional[str] = ..., 
                errors: Optional[list[ErrorEntity]] = ..., 
                failed_instances_logs: Optional[list[str]] = ..., 
                number_of_instances_failed: Optional[int] = ..., 
                number_of_instances_in_progress: Optional[int] = ..., 
                number_of_instances_successful: Optional[int] = ..., 
                status: Optional[Union[str, DeploymentBuildStatus]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmMoveResourceEnvelope(_Model):
        resources: Optional[list[str]]
        target_resource_group: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                resources: Optional[list[str]] = ..., 
                target_resource_group: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmOperationDescription(_Model):
        display: Optional[CsmOperationDisplay]
        is_data_action: Optional[bool]
        name: Optional[str]
        origin: Optional[str]
        properties: Optional[CsmOperationDescriptionProperties]

        @overload
        def __init__(
                self, 
                *, 
                display: Optional[CsmOperationDisplay] = ..., 
                is_data_action: Optional[bool] = ..., 
                name: Optional[str] = ..., 
                origin: Optional[str] = ..., 
                properties: Optional[CsmOperationDescriptionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmOperationDescriptionProperties(_Model):
        service_specification: Optional[ServiceSpecification]

        @overload
        def __init__(
                self, 
                *, 
                service_specification: Optional[ServiceSpecification] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmOperationDisplay(_Model):
        description: Optional[str]
        operation: Optional[str]
        provider: Optional[str]
        resource: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                operation: Optional[str] = ..., 
                provider: Optional[str] = ..., 
                resource: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmPublishingCredentialsPoliciesEntity(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[CsmPublishingCredentialsPoliciesEntityProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[CsmPublishingCredentialsPoliciesEntityProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CsmPublishingCredentialsPoliciesEntityProperties(_Model):
        allow: bool

        @overload
        def __init__(
                self, 
                *, 
                allow: bool
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmPublishingProfileOptions(_Model):
        format: Optional[Union[str, PublishingProfileFormat]]
        include_disaster_recovery_endpoints: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                format: Optional[Union[str, PublishingProfileFormat]] = ..., 
                include_disaster_recovery_endpoints: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmSlotEntity(_Model):
        preserve_vnet: bool
        target_slot: str

        @overload
        def __init__(
                self, 
                *, 
                preserve_vnet: bool, 
                target_slot: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CsmUsageQuota(_Model):
        current_value: Optional[int]
        limit: Optional[int]
        name: Optional[LocalizableString]
        next_reset_time: Optional[datetime]
        unit: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                current_value: Optional[int] = ..., 
                limit: Optional[int] = ..., 
                name: Optional[LocalizableString] = ..., 
                next_reset_time: Optional[datetime] = ..., 
                unit: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CustomDnsSuffixConfiguration(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[CustomDnsSuffixConfigurationProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[CustomDnsSuffixConfigurationProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CustomDnsSuffixConfigurationProperties(_Model):
        certificate_url: Optional[str]
        dns_suffix: Optional[str]
        key_vault_reference_identity: Optional[str]
        provisioning_details: Optional[str]
        provisioning_state: Optional[Union[str, CustomDnsSuffixProvisioningState]]

        @overload
        def __init__(
                self, 
                *, 
                certificate_url: Optional[str] = ..., 
                dns_suffix: Optional[str] = ..., 
                key_vault_reference_identity: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CustomDnsSuffixProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DEGRADED = "Degraded"
        FAILED = "Failed"
        IN_PROGRESS = "InProgress"
        SUCCEEDED = "Succeeded"


    class azure.mgmt.web.models.CustomDomainStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ADDING = "Adding"
        DELETING = "Deleting"
        FAILED = "Failed"
        READY = "Ready"
        RETRIEVING_VALIDATION_TOKEN = "RetrievingValidationToken"
        UNHEALTHY = "Unhealthy"
        VALIDATING = "Validating"


    class azure.mgmt.web.models.CustomHostNameDnsRecordType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        A = "A"
        C_NAME = "CName"


    class azure.mgmt.web.models.CustomHostnameAnalysisResult(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[CustomHostnameAnalysisResultProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[CustomHostnameAnalysisResultProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CustomHostnameAnalysisResultProperties(_Model):
        a_records: Optional[list[str]]
        alternate_c_name_records: Optional[list[str]]
        alternate_txt_records: Optional[list[str]]
        c_name_records: Optional[list[str]]
        conflicting_app_resource_id: Optional[str]
        custom_domain_verification_failure_info: Optional[ErrorEntity]
        custom_domain_verification_test: Optional[Union[str, DnsVerificationTestResult]]
        has_conflict_across_subscription: Optional[bool]
        has_conflict_on_scale_unit: Optional[bool]
        is_hostname_already_verified: Optional[bool]
        txt_records: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                a_records: Optional[list[str]] = ..., 
                alternate_c_name_records: Optional[list[str]] = ..., 
                alternate_txt_records: Optional[list[str]] = ..., 
                c_name_records: Optional[list[str]] = ..., 
                txt_records: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CustomHostnameSites(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[CustomHostnameSitesProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[CustomHostnameSitesProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.CustomHostnameSitesProperties(_Model):
        custom_hostname: Optional[str]
        region: Optional[str]
        site_resource_ids: Optional[list[Identifier]]

        @overload
        def __init__(
                self, 
                *, 
                custom_hostname: Optional[str] = ..., 
                region: Optional[str] = ..., 
                site_resource_ids: Optional[list[Identifier]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.CustomOpenIdConnectProvider(_Model):
        enabled: Optional[bool]
        login: Optional[OpenIdConnectLogin]
        registration: Optional[OpenIdConnectRegistration]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                login: Optional[OpenIdConnectLogin] = ..., 
                registration: Optional[OpenIdConnectRegistration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DaprConfig(_Model):
        app_id: Optional[str]
        app_port: Optional[int]
        enable_api_logging: Optional[bool]
        enabled: Optional[bool]
        http_max_request_size: Optional[int]
        http_read_buffer_size: Optional[int]
        log_level: Optional[Union[str, DaprLogLevel]]

        @overload
        def __init__(
                self, 
                *, 
                app_id: Optional[str] = ..., 
                app_port: Optional[int] = ..., 
                enable_api_logging: Optional[bool] = ..., 
                enabled: Optional[bool] = ..., 
                http_max_request_size: Optional[int] = ..., 
                http_read_buffer_size: Optional[int] = ..., 
                log_level: Optional[Union[str, DaprLogLevel]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DaprLogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DEBUG = "debug"
        ERROR = "error"
        INFO = "info"
        WARN = "warn"


    class azure.mgmt.web.models.DataProviderMetadata(_Model):
        property_bag: Optional[list[KeyValuePairStringObject]]
        provider_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                provider_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DataSource(_Model):
        data_source_uri: Optional[list[NameValuePair]]
        instructions: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                data_source_uri: Optional[list[NameValuePair]] = ..., 
                instructions: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DataTableResponseColumn(_Model):
        column_name: Optional[str]
        column_type: Optional[str]
        data_type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                column_name: Optional[str] = ..., 
                column_type: Optional[str] = ..., 
                data_type: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DataTableResponseObject(_Model):
        columns: Optional[list[DataTableResponseColumn]]
        rows: Optional[list[list[str]]]
        table_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                columns: Optional[list[DataTableResponseColumn]] = ..., 
                rows: Optional[list[list[str]]] = ..., 
                table_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DatabaseBackupSetting(_Model):
        connection_string: Optional[str]
        connection_string_name: Optional[str]
        database_type: Union[str, DatabaseType]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                connection_string: Optional[str] = ..., 
                connection_string_name: Optional[str] = ..., 
                database_type: Union[str, DatabaseType], 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DatabaseConnection(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[DatabaseConnectionProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DatabaseConnectionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DatabaseConnectionOverview(_Model):
        configuration_files: Optional[list[StaticSiteDatabaseConnectionConfigurationFileOverview]]
        connection_identity: Optional[str]
        name: Optional[str]
        region: Optional[str]
        resource_id: Optional[str]


    class azure.mgmt.web.models.DatabaseConnectionPatchRequest(_Model):
        properties: Optional[DatabaseConnectionPatchRequestProperties]

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                properties: Optional[DatabaseConnectionPatchRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DatabaseConnectionPatchRequestProperties(_Model):
        connection_identity: Optional[str]
        connection_string: Optional[str]
        region: Optional[str]
        resource_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                connection_identity: Optional[str] = ..., 
                connection_string: Optional[str] = ..., 
                region: Optional[str] = ..., 
                resource_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DatabaseConnectionProperties(_Model):
        configuration_files: Optional[list[StaticSiteDatabaseConnectionConfigurationFileOverview]]
        connection_identity: Optional[str]
        connection_string: Optional[str]
        region: str
        resource_id: str

        @overload
        def __init__(
                self, 
                *, 
                connection_identity: Optional[str] = ..., 
                connection_string: Optional[str] = ..., 
                region: str, 
                resource_id: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DatabaseType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        LOCAL_MY_SQL = "LocalMySql"
        MY_SQL = "MySql"
        POSTGRE_SQL = "PostgreSql"
        SQL_AZURE = "SqlAzure"


    class azure.mgmt.web.models.DayOfWeek(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        FRIDAY = "Friday"
        MONDAY = "Monday"
        SATURDAY = "Saturday"
        SUNDAY = "Sunday"
        THURSDAY = "Thursday"
        TUESDAY = "Tuesday"
        WEDNESDAY = "Wednesday"


    class azure.mgmt.web.models.DaysOfWeek(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        FRIDAY = "Friday"
        MONDAY = "Monday"
        SATURDAY = "Saturday"
        SUNDAY = "Sunday"
        THURSDAY = "Thursday"
        TUESDAY = "Tuesday"
        WEDNESDAY = "Wednesday"


    class azure.mgmt.web.models.DefaultAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALLOW = "Allow"
        DENY = "Deny"


    class azure.mgmt.web.models.DefaultAuthorizationPolicy(_Model):
        allowed_applications: Optional[list[str]]
        allowed_principals: Optional[AllowedPrincipals]

        @overload
        def __init__(
                self, 
                *, 
                allowed_applications: Optional[list[str]] = ..., 
                allowed_principals: Optional[AllowedPrincipals] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DefaultErrorResponse(_Model):
        error: Optional[DefaultErrorResponseError]


    class azure.mgmt.web.models.DefaultErrorResponseError(_Model):
        code: Optional[str]
        details: Optional[list[DefaultErrorResponseErrorDetailsItem]]
        innererror: Optional[str]
        message: Optional[str]
        target: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                details: Optional[list[DefaultErrorResponseErrorDetailsItem]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DefaultErrorResponseErrorDetailsItem(_Model):
        code: Optional[str]
        message: Optional[str]
        target: Optional[str]


    class azure.mgmt.web.models.DefaultIdentity(_Model):
        identity_type: Optional[Union[str, ManagedServiceIdentityType]]
        user_assigned_identity_resource_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                identity_type: Optional[Union[str, ManagedServiceIdentityType]] = ..., 
                user_assigned_identity_resource_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DeletedAppRestoreRequest(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[DeletedAppRestoreRequestProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DeletedAppRestoreRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DeletedAppRestoreRequestProperties(_Model):
        deleted_site_id: Optional[str]
        recover_configuration: Optional[bool]
        snapshot_time: Optional[str]
        use_dr_secondary: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                deleted_site_id: Optional[str] = ..., 
                recover_configuration: Optional[bool] = ..., 
                snapshot_time: Optional[str] = ..., 
                use_dr_secondary: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DeletedSite(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[DeletedSiteProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DeletedSiteProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DeletedSiteProperties(_Model):
        deleted_site_id: Optional[int]
        deleted_site_name: Optional[str]
        deleted_timestamp: Optional[str]
        geo_region_name: Optional[str]
        kind: Optional[str]
        resource_group: Optional[str]
        slot: Optional[str]
        subscription: Optional[str]


    class azure.mgmt.web.models.Deployment(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[DeploymentProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DeploymentProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DeploymentBuildStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BUILD_ABORTED = "BuildAborted"
        BUILD_FAILED = "BuildFailed"
        BUILD_IN_PROGRESS = "BuildInProgress"
        BUILD_PENDING = "BuildPending"
        BUILD_REQUEST_RECEIVED = "BuildRequestReceived"
        BUILD_SUCCESSFUL = "BuildSuccessful"
        POST_BUILD_RESTART_REQUIRED = "PostBuildRestartRequired"
        RUNTIME_FAILED = "RuntimeFailed"
        RUNTIME_STARTING = "RuntimeStarting"
        RUNTIME_SUCCESSFUL = "RuntimeSuccessful"
        START_POLLING = "StartPolling"
        START_POLLING_WITH_RESTART = "StartPollingWithRestart"
        TIMED_OUT = "TimedOut"


    class azure.mgmt.web.models.DeploymentLocations(_Model):
        hosting_environment_deployment_infos: Optional[list[HostingEnvironmentDeploymentInfo]]
        hosting_environments: Optional[list[AppServiceEnvironment]]
        locations: Optional[list[GeoRegion]]

        @overload
        def __init__(
                self, 
                *, 
                hosting_environment_deployment_infos: Optional[list[HostingEnvironmentDeploymentInfo]] = ..., 
                hosting_environments: Optional[list[AppServiceEnvironment]] = ..., 
                locations: Optional[list[GeoRegion]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DeploymentProperties(_Model):
        active: Optional[bool]
        author: Optional[str]
        author_email: Optional[str]
        deployer: Optional[str]
        details: Optional[str]
        end_time: Optional[datetime]
        message: Optional[str]
        start_time: Optional[datetime]
        status: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                active: Optional[bool] = ..., 
                author: Optional[str] = ..., 
                author_email: Optional[str] = ..., 
                deployer: Optional[str] = ..., 
                details: Optional[str] = ..., 
                end_time: Optional[datetime] = ..., 
                message: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                status: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DetectorAbnormalTimePeriod(_Model):
        end_time: Optional[datetime]
        message: Optional[str]
        meta_data: Optional[list[list[NameValuePair]]]
        priority: Optional[float]
        solutions: Optional[list[Solution]]
        source: Optional[str]
        start_time: Optional[datetime]
        type: Optional[Union[str, IssueType]]

        @overload
        def __init__(
                self, 
                *, 
                end_time: Optional[datetime] = ..., 
                message: Optional[str] = ..., 
                meta_data: Optional[list[list[NameValuePair]]] = ..., 
                priority: Optional[float] = ..., 
                solutions: Optional[list[Solution]] = ..., 
                source: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                type: Optional[Union[str, IssueType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DetectorDefinition(_Model):
        description: Optional[str]
        display_name: Optional[str]
        is_enabled: Optional[bool]
        rank: Optional[float]


    class azure.mgmt.web.models.DetectorDefinitionResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[DetectorDefinition]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DetectorDefinition] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DetectorInfo(_Model):
        analysis_type: Optional[list[str]]
        author: Optional[str]
        category: Optional[str]
        description: Optional[str]
        id: Optional[str]
        name: Optional[str]
        score: Optional[float]
        support_topic_list: Optional[list[SupportTopic]]
        type: Optional[Union[str, DetectorType]]


    class azure.mgmt.web.models.DetectorResponse(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[DetectorResponseProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DetectorResponseProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DetectorResponseProperties(_Model):
        data_providers_metadata: Optional[list[DataProviderMetadata]]
        dataset: Optional[list[DiagnosticData]]
        metadata: Optional[DetectorInfo]
        status: Optional[Status]
        suggested_utterances: Optional[QueryUtterancesResults]

        @overload
        def __init__(
                self, 
                *, 
                data_providers_metadata: Optional[list[DataProviderMetadata]] = ..., 
                dataset: Optional[list[DiagnosticData]] = ..., 
                metadata: Optional[DetectorInfo] = ..., 
                status: Optional[Status] = ..., 
                suggested_utterances: Optional[QueryUtterancesResults] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DetectorType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ANALYSIS = "Analysis"
        CATEGORY_OVERVIEW = "CategoryOverview"
        DETECTOR = "Detector"


    class azure.mgmt.web.models.DiagnosticAnalysis(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[DiagnosticAnalysisProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DiagnosticAnalysisProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DiagnosticAnalysisProperties(_Model):
        abnormal_time_periods: Optional[list[AbnormalTimePeriod]]
        end_time: Optional[datetime]
        non_correlated_detectors: Optional[list[DetectorDefinition]]
        payload: Optional[list[AnalysisData]]
        start_time: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                abnormal_time_periods: Optional[list[AbnormalTimePeriod]] = ..., 
                end_time: Optional[datetime] = ..., 
                non_correlated_detectors: Optional[list[DetectorDefinition]] = ..., 
                payload: Optional[list[AnalysisData]] = ..., 
                start_time: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DiagnosticCategory(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[DiagnosticCategoryProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DiagnosticCategoryProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DiagnosticCategoryProperties(_Model):
        description: Optional[str]


    class azure.mgmt.web.models.DiagnosticData(_Model):
        rendering_properties: Optional[Rendering]
        table: Optional[DataTableResponseObject]

        @overload
        def __init__(
                self, 
                *, 
                rendering_properties: Optional[Rendering] = ..., 
                table: Optional[DataTableResponseObject] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DiagnosticDetectorResponse(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[DiagnosticDetectorResponseProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[DiagnosticDetectorResponseProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.DiagnosticDetectorResponseProperties(_Model):
        abnormal_time_periods: Optional[list[DetectorAbnormalTimePeriod]]
        data: Optional[list[list[NameValuePair]]]
        detector_definition: Optional[DetectorDefinition]
        end_time: Optional[datetime]
        issue_detected: Optional[bool]
        metrics: Optional[list[DiagnosticMetricSet]]
        response_meta_data: Optional[ResponseMetaData]
        start_time: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                abnormal_time_periods: Optional[list[DetectorAbnormalTimePeriod]] = ..., 
                data: Optional[list[list[NameValuePair]]] = ..., 
                detector_definition: Optional[DetectorDefinition] = ..., 
                end_time: Optional[datetime] = ..., 
                issue_detected: Optional[bool] = ..., 
                metrics: Optional[list[DiagnosticMetricSet]] = ..., 
                response_meta_data: Optional[ResponseMetaData] = ..., 
                start_time: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DiagnosticMetricSample(_Model):
        is_aggregated: Optional[bool]
        maximum: Optional[float]
        minimum: Optional[float]
        role_instance: Optional[str]
        timestamp: Optional[datetime]
        total: Optional[float]

        @overload
        def __init__(
                self, 
                *, 
                is_aggregated: Optional[bool] = ..., 
                maximum: Optional[float] = ..., 
                minimum: Optional[float] = ..., 
                role_instance: Optional[str] = ..., 
                timestamp: Optional[datetime] = ..., 
                total: Optional[float] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DiagnosticMetricSet(_Model):
        end_time: Optional[datetime]
        name: Optional[str]
        start_time: Optional[datetime]
        time_grain: Optional[str]
        unit: Optional[str]
        values_property: Optional[list[DiagnosticMetricSample]]

        @overload
        def __init__(
                self, 
                *, 
                end_time: Optional[datetime] = ..., 
                name: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                unit: Optional[str] = ..., 
                values_property: Optional[list[DiagnosticMetricSample]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Dimension(_Model):
        display_name: Optional[str]
        internal_name: Optional[str]
        name: Optional[str]
        to_be_exported_for_shoebox: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                display_name: Optional[str] = ..., 
                internal_name: Optional[str] = ..., 
                name: Optional[str] = ..., 
                to_be_exported_for_shoebox: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DnlResourceNameAvailability(_Model):
        host_name: Optional[str]
        message: Optional[str]
        name_available: Optional[bool]
        reason: Optional[Union[str, InAvailabilityReasonType]]

        @overload
        def __init__(
                self, 
                *, 
                host_name: Optional[str] = ..., 
                message: Optional[str] = ..., 
                name_available: Optional[bool] = ..., 
                reason: Optional[Union[str, InAvailabilityReasonType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DnlResourceNameAvailabilityRequest(_Model):
        auto_generated_domain_name_label_scope: Optional[str]
        name: str
        resource_group_name: Optional[str]
        type: Union[str, CheckNameResourceTypes]

        @overload
        def __init__(
                self, 
                *, 
                auto_generated_domain_name_label_scope: Optional[str] = ..., 
                name: str, 
                resource_group_name: Optional[str] = ..., 
                type: Union[str, CheckNameResourceTypes]
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.DnsVerificationTestResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        FAILED = "Failed"
        PASSED = "Passed"
        SKIPPED = "Skipped"


    class azure.mgmt.web.models.EnabledConfig(_Model):
        enabled: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.EndpointDependency(_Model):
        domain_name: Optional[str]
        endpoint_details: Optional[list[EndpointDetail]]

        @overload
        def __init__(
                self, 
                *, 
                domain_name: Optional[str] = ..., 
                endpoint_details: Optional[list[EndpointDetail]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.EndpointDetail(_Model):
        ip_address: Optional[str]
        is_accessible: Optional[bool]
        latency: Optional[float]
        port: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                ip_address: Optional[str] = ..., 
                is_accessible: Optional[bool] = ..., 
                latency: Optional[float] = ..., 
                port: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.EnterpriseGradeCdnStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DISABLED = "Disabled"
        DISABLING = "Disabling"
        ENABLED = "Enabled"
        ENABLING = "Enabling"


    class azure.mgmt.web.models.EnvironmentVariable(_Model):
        name: str
        value: str

        @overload
        def __init__(
                self, 
                *, 
                name: str, 
                value: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ErrorEntity(_Model):
        code: Optional[str]
        details: Optional[list[ErrorEntity]]
        extended_code: Optional[str]
        inner_errors: Optional[list[ErrorEntity]]
        message: Optional[str]
        message_template: Optional[str]
        parameters: Optional[list[str]]
        target: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                details: Optional[list[ErrorEntity]] = ..., 
                extended_code: Optional[str] = ..., 
                inner_errors: Optional[list[ErrorEntity]] = ..., 
                message: Optional[str] = ..., 
                message_template: Optional[str] = ..., 
                parameters: Optional[list[str]] = ..., 
                target: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ErrorInfo(_Model):
        code: str

        @overload
        def __init__(
                self, 
                *, 
                code: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ErrorProperties(_Model):
        code: Optional[str]
        message: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                message: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Experiments(_Model):
        ramp_up_rules: Optional[list[RampUpRule]]

        @overload
        def __init__(
                self, 
                *, 
                ramp_up_rules: Optional[list[RampUpRule]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Expression(_Model):
        error: Optional[AzureResourceErrorInfo]
        subexpressions: Optional[list[Expression]]
        text: Optional[str]
        value: Optional[Any]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[AzureResourceErrorInfo] = ..., 
                subexpressions: Optional[list[Expression]] = ..., 
                text: Optional[str] = ..., 
                value: Optional[Any] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ExpressionRoot(Expression):
        error: AzureResourceErrorInfo
        path: Optional[str]
        subexpressions: list[Expression]
        text: str
        value: any

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[AzureResourceErrorInfo] = ..., 
                path: Optional[str] = ..., 
                subexpressions: Optional[list[Expression]] = ..., 
                text: Optional[str] = ..., 
                value: Optional[Any] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ExtendedLocation(_Model):
        name: Optional[str]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Facebook(_Model):
        enabled: Optional[bool]
        graph_api_version: Optional[str]
        login: Optional[LoginScopes]
        registration: Optional[AppRegistration]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                graph_api_version: Optional[str] = ..., 
                login: Optional[LoginScopes] = ..., 
                registration: Optional[AppRegistration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FileSystemApplicationLogsConfig(_Model):
        level: Optional[Union[str, LogLevel]]

        @overload
        def __init__(
                self, 
                *, 
                level: Optional[Union[str, LogLevel]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FileSystemHttpLogsConfig(_Model):
        enabled: Optional[bool]
        retention_in_days: Optional[int]
        retention_in_mb: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                retention_in_days: Optional[int] = ..., 
                retention_in_mb: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FileSystemTokenStore(_Model):
        directory: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                directory: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FlowAccessControlConfiguration(_Model):
        actions: Optional[FlowAccessControlConfigurationPolicy]
        contents: Optional[FlowAccessControlConfigurationPolicy]
        triggers: Optional[FlowAccessControlConfigurationPolicy]
        workflow_management: Optional[FlowAccessControlConfigurationPolicy]

        @overload
        def __init__(
                self, 
                *, 
                actions: Optional[FlowAccessControlConfigurationPolicy] = ..., 
                contents: Optional[FlowAccessControlConfigurationPolicy] = ..., 
                triggers: Optional[FlowAccessControlConfigurationPolicy] = ..., 
                workflow_management: Optional[FlowAccessControlConfigurationPolicy] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FlowAccessControlConfigurationPolicy(_Model):
        allowed_caller_ip_addresses: Optional[list[IpAddressRange]]
        open_authentication_policies: Optional[OpenAuthenticationAccessPolicies]

        @overload
        def __init__(
                self, 
                *, 
                allowed_caller_ip_addresses: Optional[list[IpAddressRange]] = ..., 
                open_authentication_policies: Optional[OpenAuthenticationAccessPolicies] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FlowEndpoints(_Model):
        access_endpoint_ip_addresses: Optional[list[IpAddress]]
        outgoing_ip_addresses: Optional[list[IpAddress]]

        @overload
        def __init__(
                self, 
                *, 
                access_endpoint_ip_addresses: Optional[list[IpAddress]] = ..., 
                outgoing_ip_addresses: Optional[list[IpAddress]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FlowEndpointsConfiguration(_Model):
        connector: Optional[FlowEndpoints]
        workflow: Optional[FlowEndpoints]

        @overload
        def __init__(
                self, 
                *, 
                connector: Optional[FlowEndpoints] = ..., 
                workflow: Optional[FlowEndpoints] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ForwardProxy(_Model):
        convention: Optional[Union[str, ForwardProxyConvention]]
        custom_host_header_name: Optional[str]
        custom_proto_header_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                convention: Optional[Union[str, ForwardProxyConvention]] = ..., 
                custom_host_header_name: Optional[str] = ..., 
                custom_proto_header_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ForwardProxyConvention(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CUSTOM = "Custom"
        NO_PROXY = "NoProxy"
        STANDARD = "Standard"


    class azure.mgmt.web.models.FrequencyUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DAY = "Day"
        HOUR = "Hour"


    class azure.mgmt.web.models.FrontEndConfiguration(_Model):
        kind: Optional[Union[str, FrontEndServiceType]]

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[Union[str, FrontEndServiceType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FrontEndServiceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        LOAD_BALANCER = "LoadBalancer"
        NODE_PORT = "NodePort"


    class azure.mgmt.web.models.FtpsState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALL_ALLOWED = "AllAllowed"
        DISABLED = "Disabled"
        FTPS_ONLY = "FtpsOnly"


    class azure.mgmt.web.models.FunctionAppConfig(_Model):
        deployment: Optional[FunctionsDeployment]
        runtime: Optional[FunctionsRuntime]
        scale_and_concurrency: Optional[FunctionsScaleAndConcurrency]
        site_update_strategy: Optional[FunctionsSiteUpdateStrategy]

        @overload
        def __init__(
                self, 
                *, 
                deployment: Optional[FunctionsDeployment] = ..., 
                runtime: Optional[FunctionsRuntime] = ..., 
                scale_and_concurrency: Optional[FunctionsScaleAndConcurrency] = ..., 
                site_update_strategy: Optional[FunctionsSiteUpdateStrategy] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionAppMajorVersion(_Model):
        display_text: Optional[str]
        minor_versions: Optional[list[FunctionAppMinorVersion]]
        value: Optional[str]


    class azure.mgmt.web.models.FunctionAppMinorVersion(_Model):
        display_text: Optional[str]
        stack_settings: Optional[FunctionAppRuntimes]
        value: Optional[str]


    class azure.mgmt.web.models.FunctionAppRuntimeSettings(_Model):
        app_insights_settings: Optional[AppInsightsWebAppStackSettings]
        app_settings_dictionary: Optional[dict[str, str]]
        end_of_life_date: Optional[datetime]
        git_hub_action_settings: Optional[GitHubActionWebAppStackSettings]
        is_auto_update: Optional[bool]
        is_default: Optional[bool]
        is_deprecated: Optional[bool]
        is_early_access: Optional[bool]
        is_hidden: Optional[bool]
        is_preview: Optional[bool]
        remote_debugging_supported: Optional[bool]
        runtime_version: Optional[str]
        site_config_properties_dictionary: Optional[SiteConfigPropertiesDictionary]
        supported_functions_extension_versions: Optional[list[str]]


    class azure.mgmt.web.models.FunctionAppRuntimes(_Model):
        linux_runtime_settings: Optional[FunctionAppRuntimeSettings]
        windows_runtime_settings: Optional[FunctionAppRuntimeSettings]


    class azure.mgmt.web.models.FunctionAppStack(ProxyOnlyResource):
        id: str
        kind: str
        location: Optional[str]
        name: str
        properties: Optional[FunctionAppStackProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[FunctionAppStackProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.FunctionAppStackProperties(_Model):
        display_text: Optional[str]
        major_versions: Optional[list[FunctionAppMajorVersion]]
        preferred_os: Optional[Union[str, StackPreferredOs]]
        value: Optional[str]


    class azure.mgmt.web.models.FunctionEnvelope(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[FunctionEnvelopeProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[FunctionEnvelopeProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.FunctionEnvelopeProperties(_Model):
        config: Optional[Any]
        config_href: Optional[str]
        files: Optional[dict[str, str]]
        function_app_id: Optional[str]
        href: Optional[str]
        invoke_url_template: Optional[str]
        is_disabled: Optional[bool]
        language: Optional[str]
        script_href: Optional[str]
        script_root_path_href: Optional[str]
        secrets_file_href: Optional[str]
        test_data: Optional[str]
        test_data_href: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                config: Optional[Any] = ..., 
                config_href: Optional[str] = ..., 
                files: Optional[dict[str, str]] = ..., 
                function_app_id: Optional[str] = ..., 
                href: Optional[str] = ..., 
                invoke_url_template: Optional[str] = ..., 
                is_disabled: Optional[bool] = ..., 
                language: Optional[str] = ..., 
                script_href: Optional[str] = ..., 
                script_root_path_href: Optional[str] = ..., 
                secrets_file_href: Optional[str] = ..., 
                test_data: Optional[str] = ..., 
                test_data_href: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionSecrets(_Model):
        key: Optional[str]
        trigger_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                key: Optional[str] = ..., 
                trigger_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsAlwaysReadyConfig(_Model):
        instance_count: Optional[int]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                instance_count: Optional[int] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsDeployment(_Model):
        storage: Optional[FunctionsDeploymentStorage]

        @overload
        def __init__(
                self, 
                *, 
                storage: Optional[FunctionsDeploymentStorage] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsDeploymentStorage(_Model):
        authentication: Optional[FunctionsDeploymentStorageAuthentication]
        type: Optional[Union[str, FunctionsDeploymentStorageType]]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                authentication: Optional[FunctionsDeploymentStorageAuthentication] = ..., 
                type: Optional[Union[str, FunctionsDeploymentStorageType]] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsDeploymentStorageAuthentication(_Model):
        storage_account_connection_string_name: Optional[str]
        type: Optional[Union[str, AuthenticationType]]
        user_assigned_identity_resource_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                storage_account_connection_string_name: Optional[str] = ..., 
                type: Optional[Union[str, AuthenticationType]] = ..., 
                user_assigned_identity_resource_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsDeploymentStorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BLOB_CONTAINER = "blobContainer"


    class azure.mgmt.web.models.FunctionsRuntime(_Model):
        name: Optional[Union[str, RuntimeName]]
        version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[Union[str, RuntimeName]] = ..., 
                version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsScaleAndConcurrency(_Model):
        always_ready: Optional[list[FunctionsAlwaysReadyConfig]]
        instance_memory_mb: Optional[int]
        maximum_instance_count: Optional[int]
        triggers: Optional[FunctionsScaleAndConcurrencyTriggers]

        @overload
        def __init__(
                self, 
                *, 
                always_ready: Optional[list[FunctionsAlwaysReadyConfig]] = ..., 
                instance_memory_mb: Optional[int] = ..., 
                maximum_instance_count: Optional[int] = ..., 
                triggers: Optional[FunctionsScaleAndConcurrencyTriggers] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsScaleAndConcurrencyTriggers(_Model):
        http: Optional[FunctionsScaleAndConcurrencyTriggersHttp]

        @overload
        def __init__(
                self, 
                *, 
                http: Optional[FunctionsScaleAndConcurrencyTriggersHttp] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsScaleAndConcurrencyTriggersHttp(_Model):
        per_instance_concurrency: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                per_instance_concurrency: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.FunctionsSiteUpdateStrategy(_Model):
        type: Optional[Union[str, SiteUpdateStrategyType]]

        @overload
        def __init__(
                self, 
                *, 
                type: Optional[Union[str, SiteUpdateStrategyType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.GeoRegion(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[GeoRegionProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[GeoRegionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.GeoRegionProperties(_Model):
        description: Optional[str]
        display_name: Optional[str]
        org_domain: Optional[str]


    class azure.mgmt.web.models.GitHub(_Model):
        enabled: Optional[bool]
        login: Optional[LoginScopes]
        registration: Optional[ClientRegistration]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                login: Optional[LoginScopes] = ..., 
                registration: Optional[ClientRegistration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.GitHubActionCodeConfiguration(_Model):
        runtime_stack: Optional[str]
        runtime_version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                runtime_stack: Optional[str] = ..., 
                runtime_version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.GitHubActionConfiguration(_Model):
        code_configuration: Optional[GitHubActionCodeConfiguration]
        container_configuration: Optional[GitHubActionContainerConfiguration]
        generate_workflow_file: Optional[bool]
        is_linux: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                code_configuration: Optional[GitHubActionCodeConfiguration] = ..., 
                container_configuration: Optional[GitHubActionContainerConfiguration] = ..., 
                generate_workflow_file: Optional[bool] = ..., 
                is_linux: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.GitHubActionContainerConfiguration(_Model):
        image_name: Optional[str]
        password: Optional[str]
        server_url: Optional[str]
        username: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                image_name: Optional[str] = ..., 
                password: Optional[str] = ..., 
                server_url: Optional[str] = ..., 
                username: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.GitHubActionWebAppStackSettings(_Model):
        is_supported: Optional[bool]
        supported_version: Optional[str]


    class azure.mgmt.web.models.GlobalCsmSkuDescription(_Model):
        capabilities: Optional[list[Capability]]
        capacity: Optional[SkuCapacity]
        family: Optional[str]
        locations: Optional[list[str]]
        name: Optional[str]
        size: Optional[str]
        tier: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                capabilities: Optional[list[Capability]] = ..., 
                capacity: Optional[SkuCapacity] = ..., 
                family: Optional[str] = ..., 
                locations: Optional[list[str]] = ..., 
                name: Optional[str] = ..., 
                size: Optional[str] = ..., 
                tier: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.GlobalValidation(_Model):
        excluded_paths: Optional[list[str]]
        redirect_to_provider: Optional[str]
        require_authentication: Optional[bool]
        unauthenticated_client_action: Optional[Union[str, UnauthenticatedClientActionV2]]

        @overload
        def __init__(
                self, 
                *, 
                excluded_paths: Optional[list[str]] = ..., 
                redirect_to_provider: Optional[str] = ..., 
                require_authentication: Optional[bool] = ..., 
                unauthenticated_client_action: Optional[Union[str, UnauthenticatedClientActionV2]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Google(_Model):
        enabled: Optional[bool]
        login: Optional[LoginScopes]
        registration: Optional[ClientRegistration]
        validation: Optional[AllowedAudiencesValidation]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                login: Optional[LoginScopes] = ..., 
                registration: Optional[ClientRegistration] = ..., 
                validation: Optional[AllowedAudiencesValidation] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HandlerMapping(_Model):
        arguments: Optional[str]
        extension: Optional[str]
        script_processor: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                arguments: Optional[str] = ..., 
                extension: Optional[str] = ..., 
                script_processor: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostKeys(_Model):
        function_keys: Optional[dict[str, str]]
        master_key: Optional[str]
        system_keys: Optional[dict[str, str]]

        @overload
        def __init__(
                self, 
                *, 
                function_keys: Optional[dict[str, str]] = ..., 
                master_key: Optional[str] = ..., 
                system_keys: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostNameBinding(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[HostNameBindingProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[HostNameBindingProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.HostNameBindingProperties(_Model):
        azure_resource_name: Optional[str]
        azure_resource_type: Optional[Union[str, AzureResourceType]]
        custom_host_name_dns_record_type: Optional[Union[str, CustomHostNameDnsRecordType]]
        domain_id: Optional[str]
        host_name_type: Optional[Union[str, HostNameType]]
        site_name: Optional[str]
        ssl_state: Optional[Union[str, SslState]]
        thumbprint: Optional[str]
        virtual_ip: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                azure_resource_name: Optional[str] = ..., 
                azure_resource_type: Optional[Union[str, AzureResourceType]] = ..., 
                custom_host_name_dns_record_type: Optional[Union[str, CustomHostNameDnsRecordType]] = ..., 
                domain_id: Optional[str] = ..., 
                host_name_type: Optional[Union[str, HostNameType]] = ..., 
                site_name: Optional[str] = ..., 
                ssl_state: Optional[Union[str, SslState]] = ..., 
                thumbprint: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostNameSslState(_Model):
        host_type: Optional[Union[str, HostType]]
        name: Optional[str]
        ssl_state: Optional[Union[str, SslState]]
        thumbprint: Optional[str]
        to_update: Optional[bool]
        virtual_ip: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                host_type: Optional[Union[str, HostType]] = ..., 
                name: Optional[str] = ..., 
                ssl_state: Optional[Union[str, SslState]] = ..., 
                thumbprint: Optional[str] = ..., 
                to_update: Optional[bool] = ..., 
                virtual_ip: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostNameType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        MANAGED = "Managed"
        VERIFIED = "Verified"


    class azure.mgmt.web.models.HostType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        REPOSITORY = "Repository"
        STANDARD = "Standard"


    class azure.mgmt.web.models.HostingEnvironmentDeploymentInfo(_Model):
        location: Optional[str]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                location: Optional[str] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostingEnvironmentDiagnostics(_Model):
        diagnostics_output: Optional[str]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                diagnostics_output: Optional[str] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostingEnvironmentProfile(_Model):
        id: Optional[str]
        name: Optional[str]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HostingEnvironmentStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DELETING = "Deleting"
        PREPARING = "Preparing"
        READY = "Ready"
        SCALING = "Scaling"


    class azure.mgmt.web.models.HttpLogsConfig(_Model):
        azure_blob_storage: Optional[AzureBlobStorageHttpLogsConfig]
        file_system: Optional[FileSystemHttpLogsConfig]

        @overload
        def __init__(
                self, 
                *, 
                azure_blob_storage: Optional[AzureBlobStorageHttpLogsConfig] = ..., 
                file_system: Optional[FileSystemHttpLogsConfig] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HttpSettings(_Model):
        forward_proxy: Optional[ForwardProxy]
        require_https: Optional[bool]
        routes: Optional[HttpSettingsRoutes]

        @overload
        def __init__(
                self, 
                *, 
                forward_proxy: Optional[ForwardProxy] = ..., 
                require_https: Optional[bool] = ..., 
                routes: Optional[HttpSettingsRoutes] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HttpSettingsRoutes(_Model):
        api_prefix: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                api_prefix: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.HybridConnection(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[HybridConnectionProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[HybridConnectionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.HybridConnectionKey(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[HybridConnectionKeyProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[HybridConnectionKeyProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.HybridConnectionKeyProperties(_Model):
        send_key_name: Optional[str]
        send_key_value: Optional[str]


    class azure.mgmt.web.models.HybridConnectionLimits(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[HybridConnectionLimitsProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[HybridConnectionLimitsProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.HybridConnectionLimitsProperties(_Model):
        current: Optional[int]
        maximum: Optional[int]


    class azure.mgmt.web.models.HybridConnectionProperties(_Model):
        hostname: Optional[str]
        port: Optional[int]
        relay_arm_uri: Optional[str]
        relay_name: Optional[str]
        send_key_name: Optional[str]
        send_key_value: Optional[str]
        service_bus_namespace: Optional[str]
        service_bus_suffix: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                hostname: Optional[str] = ..., 
                port: Optional[int] = ..., 
                relay_arm_uri: Optional[str] = ..., 
                relay_name: Optional[str] = ..., 
                send_key_name: Optional[str] = ..., 
                send_key_value: Optional[str] = ..., 
                service_bus_namespace: Optional[str] = ..., 
                service_bus_suffix: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.IPMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        I_PV4 = "IPv4"
        I_PV4_AND_I_PV6 = "IPv4AndIPv6"
        I_PV6 = "IPv6"


    class azure.mgmt.web.models.Identifier(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[IdentifierProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[IdentifierProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.IdentifierProperties(_Model):
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.IdentityProviders(_Model):
        apple: Optional[Apple]
        azure_active_directory: Optional[AzureActiveDirectory]
        azure_static_web_apps: Optional[AzureStaticWebApps]
        custom_open_id_connect_providers: Optional[dict[str, CustomOpenIdConnectProvider]]
        facebook: Optional[Facebook]
        git_hub: Optional[GitHub]
        google: Optional[Google]
        legacy_microsoft_account: Optional[LegacyMicrosoftAccount]
        twitter: Optional[Twitter]

        @overload
        def __init__(
                self, 
                *, 
                apple: Optional[Apple] = ..., 
                azure_active_directory: Optional[AzureActiveDirectory] = ..., 
                azure_static_web_apps: Optional[AzureStaticWebApps] = ..., 
                custom_open_id_connect_providers: Optional[dict[str, CustomOpenIdConnectProvider]] = ..., 
                facebook: Optional[Facebook] = ..., 
                git_hub: Optional[GitHub] = ..., 
                google: Optional[Google] = ..., 
                legacy_microsoft_account: Optional[LegacyMicrosoftAccount] = ..., 
                twitter: Optional[Twitter] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.InAvailabilityReasonType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALREADY_EXISTS = "AlreadyExists"
        INVALID = "Invalid"


    class azure.mgmt.web.models.InboundEnvironmentEndpoint(_Model):
        description: Optional[str]
        endpoints: Optional[list[str]]
        ports: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                endpoints: Optional[list[str]] = ..., 
                ports: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.InsightStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CRITICAL = "Critical"
        INFO = "Info"
        NONE = "None"
        SUCCESS = "Success"
        WARNING = "Warning"


    class azure.mgmt.web.models.InstallScript(_Model):
        name: Optional[str]
        source: Optional[InstallScriptSource]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ..., 
                source: Optional[InstallScriptSource] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.InstallScriptSource(_Model):
        source_uri: Optional[str]
        type: Optional[Union[str, InstallScriptType]]

        @overload
        def __init__(
                self, 
                *, 
                source_uri: Optional[str] = ..., 
                type: Optional[Union[str, InstallScriptType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.InstallScriptType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        PLATFORM_STORAGE = "PlatformStorage"
        REMOTE_AZURE_BLOB = "RemoteAzureBlob"


    class azure.mgmt.web.models.IpAddress(_Model):
        address: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                address: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.IpAddressRange(_Model):
        address_range: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                address_range: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.IpFilterTag(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DEFAULT = "Default"
        SERVICE_TAG = "ServiceTag"
        XFF_PROXY = "XffProxy"


    class azure.mgmt.web.models.IpSecurityRestriction(_Model):
        action: Optional[str]
        description: Optional[str]
        headers: Optional[dict[str, list[str]]]
        ip_address: Optional[str]
        name: Optional[str]
        priority: Optional[int]
        subnet_mask: Optional[str]
        subnet_traffic_tag: Optional[int]
        tag: Optional[Union[str, IpFilterTag]]
        vnet_subnet_resource_id: Optional[str]
        vnet_traffic_tag: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                action: Optional[str] = ..., 
                description: Optional[str] = ..., 
                headers: Optional[dict[str, list[str]]] = ..., 
                ip_address: Optional[str] = ..., 
                name: Optional[str] = ..., 
                priority: Optional[int] = ..., 
                subnet_mask: Optional[str] = ..., 
                subnet_traffic_tag: Optional[int] = ..., 
                tag: Optional[Union[str, IpFilterTag]] = ..., 
                vnet_subnet_resource_id: Optional[str] = ..., 
                vnet_traffic_tag: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.IssueType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        APP_CRASH = "AppCrash"
        APP_DEPLOYMENT = "AppDeployment"
        ASE_DEPLOYMENT = "AseDeployment"
        OTHER = "Other"
        PLATFORM_ISSUE = "PlatformIssue"
        RUNTIME_ISSUE_DETECTED = "RuntimeIssueDetected"
        SERVICE_INCIDENT = "ServiceIncident"
        USER_ISSUE = "UserIssue"


    class azure.mgmt.web.models.JsonSchema(_Model):
        content: Optional[str]
        title: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                content: Optional[str] = ..., 
                title: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.JwtClaimChecks(_Model):
        allowed_client_applications: Optional[list[str]]
        allowed_groups: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                allowed_client_applications: Optional[list[str]] = ..., 
                allowed_groups: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.KeyInfo(_Model):
        name: Optional[str]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.KeyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        NOT_SPECIFIED = "NotSpecified"
        PRIMARY = "Primary"
        SECONDARY = "Secondary"


    class azure.mgmt.web.models.KeyValuePairStringObject(_Model):
        key: Optional[str]
        value: Optional[Any]


    class azure.mgmt.web.models.KeyVaultReferenceWithStatus(_Model):
        reference_status: Optional[str]
        secret_uri: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                reference_status: Optional[str] = ..., 
                secret_uri: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.KeyVaultSecretStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        AZURE_SERVICE_UNAUTHORIZED_TO_ACCESS_KEY_VAULT = "AzureServiceUnauthorizedToAccessKeyVault"
        CERTIFICATE_ORDER_FAILED = "CertificateOrderFailed"
        EXTERNAL_PRIVATE_KEY = "ExternalPrivateKey"
        INITIALIZED = "Initialized"
        KEY_VAULT_DOES_NOT_EXIST = "KeyVaultDoesNotExist"
        KEY_VAULT_SECRET_DOES_NOT_EXIST = "KeyVaultSecretDoesNotExist"
        OPERATION_NOT_PERMITTED_ON_KEY_VAULT = "OperationNotPermittedOnKeyVault"
        SUCCEEDED = "Succeeded"
        UNKNOWN = "Unknown"
        UNKNOWN_ERROR = "UnknownError"
        WAITING_ON_CERTIFICATE_ORDER = "WaitingOnCertificateOrder"


    class azure.mgmt.web.models.Kind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        STATEFUL = "Stateful"
        STATELESS = "Stateless"


    class azure.mgmt.web.models.KubeEnvironment(TrackedResource):
        extended_location: Optional[ExtendedLocation]
        id: str
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[KubeEnvironmentProperties]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                extended_location: Optional[ExtendedLocation] = ..., 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[KubeEnvironmentProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.KubeEnvironmentPatchResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[KubeEnvironmentPatchResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[KubeEnvironmentPatchResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.KubeEnvironmentPatchResourceProperties(_Model):
        aks_resource_id: Optional[str]
        app_logs_configuration: Optional[AppLogsConfiguration]
        arc_configuration: Optional[ArcConfiguration]
        container_apps_configuration: Optional[ContainerAppsConfiguration]
        default_domain: Optional[str]
        deployment_errors: Optional[str]
        internal_load_balancer_enabled: Optional[bool]
        provisioning_state: Optional[Union[str, KubeEnvironmentProvisioningState]]
        static_ip: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                aks_resource_id: Optional[str] = ..., 
                app_logs_configuration: Optional[AppLogsConfiguration] = ..., 
                arc_configuration: Optional[ArcConfiguration] = ..., 
                container_apps_configuration: Optional[ContainerAppsConfiguration] = ..., 
                internal_load_balancer_enabled: Optional[bool] = ..., 
                static_ip: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.KubeEnvironmentProfile(_Model):
        id: Optional[str]
        name: Optional[str]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.KubeEnvironmentProperties(_Model):
        aks_resource_id: Optional[str]
        app_logs_configuration: Optional[AppLogsConfiguration]
        arc_configuration: Optional[ArcConfiguration]
        container_apps_configuration: Optional[ContainerAppsConfiguration]
        default_domain: Optional[str]
        deployment_errors: Optional[str]
        environment_type: Optional[str]
        internal_load_balancer_enabled: Optional[bool]
        provisioning_state: Optional[Union[str, KubeEnvironmentProvisioningState]]
        static_ip: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                aks_resource_id: Optional[str] = ..., 
                app_logs_configuration: Optional[AppLogsConfiguration] = ..., 
                arc_configuration: Optional[ArcConfiguration] = ..., 
                container_apps_configuration: Optional[ContainerAppsConfiguration] = ..., 
                environment_type: Optional[str] = ..., 
                internal_load_balancer_enabled: Optional[bool] = ..., 
                static_ip: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.KubeEnvironmentProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CANCELED = "Canceled"
        FAILED = "Failed"
        INFRASTRUCTURE_SETUP_COMPLETE = "InfrastructureSetupComplete"
        INFRASTRUCTURE_SETUP_IN_PROGRESS = "InfrastructureSetupInProgress"
        INITIALIZATION_IN_PROGRESS = "InitializationInProgress"
        SCHEDULED_FOR_DELETE = "ScheduledForDelete"
        SUCCEEDED = "Succeeded"
        UPGRADE_FAILED = "UpgradeFailed"
        UPGRADE_REQUESTED = "UpgradeRequested"
        WAITING = "Waiting"


    class azure.mgmt.web.models.LegacyMicrosoftAccount(_Model):
        enabled: Optional[bool]
        login: Optional[LoginScopes]
        registration: Optional[ClientRegistration]
        validation: Optional[AllowedAudiencesValidation]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                login: Optional[LoginScopes] = ..., 
                registration: Optional[ClientRegistration] = ..., 
                validation: Optional[AllowedAudiencesValidation] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.LinuxJavaContainerSettings(_Model):
        end_of_life_date: Optional[datetime]
        is_auto_update: Optional[bool]
        is_deprecated: Optional[bool]
        is_early_access: Optional[bool]
        is_hidden: Optional[bool]
        is_preview: Optional[bool]
        java11_runtime: Optional[str]
        java8_runtime: Optional[str]


    class azure.mgmt.web.models.LoadBalancingMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        NONE = "None"
        PUBLISHING = "Publishing"
        WEB = "Web"
        WEB_PUBLISHING = "Web, Publishing"


    class azure.mgmt.web.models.LocalizableString(_Model):
        localized_value: Optional[str]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                localized_value: Optional[str] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.LogAnalyticsConfiguration(_Model):
        customer_id: Optional[str]
        shared_key: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                customer_id: Optional[str] = ..., 
                shared_key: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.LogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ERROR = "Error"
        INFORMATION = "Information"
        OFF = "Off"
        VERBOSE = "Verbose"
        WARNING = "Warning"


    class azure.mgmt.web.models.LogSpecification(_Model):
        blob_duration: Optional[str]
        display_name: Optional[str]
        log_filter_pattern: Optional[str]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                blob_duration: Optional[str] = ..., 
                display_name: Optional[str] = ..., 
                log_filter_pattern: Optional[str] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Login(_Model):
        allowed_external_redirect_urls: Optional[list[str]]
        cookie_expiration: Optional[CookieExpiration]
        nonce: Optional[Nonce]
        preserve_url_fragments_for_logins: Optional[bool]
        routes: Optional[LoginRoutes]
        token_store: Optional[TokenStore]

        @overload
        def __init__(
                self, 
                *, 
                allowed_external_redirect_urls: Optional[list[str]] = ..., 
                cookie_expiration: Optional[CookieExpiration] = ..., 
                nonce: Optional[Nonce] = ..., 
                preserve_url_fragments_for_logins: Optional[bool] = ..., 
                routes: Optional[LoginRoutes] = ..., 
                token_store: Optional[TokenStore] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.LoginRoutes(_Model):
        logout_endpoint: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                logout_endpoint: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.LoginScopes(_Model):
        scopes: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                scopes: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.MSDeploy(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[MSDeployProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[MSDeployProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.MSDeployCore(_Model):
        app_offline: Optional[bool]
        connection_string: Optional[str]
        db_type: Optional[str]
        package_uri: Optional[str]
        set_parameters: Optional[dict[str, str]]
        set_parameters_xml_file_uri: Optional[str]
        skip_app_data: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                app_offline: Optional[bool] = ..., 
                connection_string: Optional[str] = ..., 
                db_type: Optional[str] = ..., 
                package_uri: Optional[str] = ..., 
                set_parameters: Optional[dict[str, str]] = ..., 
                set_parameters_xml_file_uri: Optional[str] = ..., 
                skip_app_data: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.MSDeployLog(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[MSDeployLogProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[MSDeployLogProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.MSDeployLogEntry(_Model):
        message: Optional[str]
        time: Optional[datetime]
        type: Optional[Union[str, MSDeployLogEntryType]]


    class azure.mgmt.web.models.MSDeployLogEntryType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ERROR = "Error"
        MESSAGE = "Message"
        WARNING = "Warning"


    class azure.mgmt.web.models.MSDeployLogProperties(_Model):
        entries: Optional[list[MSDeployLogEntry]]


    class azure.mgmt.web.models.MSDeployProperties(MSDeployCore):
        add_on_packages: Optional[list[MSDeployCore]]
        app_offline: bool
        connection_string: str
        db_type: str
        package_uri: str
        set_parameters: dict[str, str]
        set_parameters_xml_file_uri: str
        skip_app_data: bool

        @overload
        def __init__(
                self, 
                *, 
                add_on_packages: Optional[list[MSDeployCore]] = ..., 
                app_offline: Optional[bool] = ..., 
                connection_string: Optional[str] = ..., 
                db_type: Optional[str] = ..., 
                package_uri: Optional[str] = ..., 
                set_parameters: Optional[dict[str, str]] = ..., 
                set_parameters_xml_file_uri: Optional[str] = ..., 
                skip_app_data: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.MSDeployProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ACCEPTED = "accepted"
        CANCELED = "canceled"
        FAILED = "failed"
        RUNNING = "running"
        SUCCEEDED = "succeeded"


    class azure.mgmt.web.models.MSDeployStatus(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[MSDeployStatusProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[MSDeployStatusProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.MSDeployStatusProperties(_Model):
        complete: Optional[bool]
        deployer: Optional[str]
        end_time: Optional[datetime]
        provisioning_state: Optional[Union[str, MSDeployProvisioningState]]
        start_time: Optional[datetime]


    class azure.mgmt.web.models.ManagedPipelineMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CLASSIC = "Classic"
        INTEGRATED = "Integrated"


    class azure.mgmt.web.models.ManagedServiceIdentity(_Model):
        principal_id: Optional[str]
        tenant_id: Optional[str]
        type: Optional[Union[str, ManagedServiceIdentityType]]
        user_assigned_identities: Optional[dict[str, UserAssignedIdentity]]

        @overload
        def __init__(
                self, 
                *, 
                type: Optional[Union[str, ManagedServiceIdentityType]] = ..., 
                user_assigned_identities: Optional[dict[str, UserAssignedIdentity]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        NONE = "None"
        SYSTEM_ASSIGNED = "SystemAssigned"
        SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned, UserAssigned"
        USER_ASSIGNED = "UserAssigned"


    class azure.mgmt.web.models.MetricAvailability(_Model):
        blob_duration: Optional[str]
        time_grain: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                blob_duration: Optional[str] = ..., 
                time_grain: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.MetricSpecification(_Model):
        aggregation_type: Optional[str]
        availabilities: Optional[list[MetricAvailability]]
        category: Optional[str]
        dimensions: Optional[list[Dimension]]
        display_description: Optional[str]
        display_name: Optional[str]
        enable_regional_mdm_account: Optional[bool]
        fill_gap_with_zero: Optional[bool]
        is_internal: Optional[bool]
        metric_filter_pattern: Optional[str]
        name: Optional[str]
        source_mdm_account: Optional[str]
        source_mdm_namespace: Optional[str]
        supported_aggregation_types: Optional[list[str]]
        supported_time_grain_types: Optional[list[str]]
        supports_instance_level_aggregation: Optional[bool]
        unit: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                aggregation_type: Optional[str] = ..., 
                availabilities: Optional[list[MetricAvailability]] = ..., 
                category: Optional[str] = ..., 
                dimensions: Optional[list[Dimension]] = ..., 
                display_description: Optional[str] = ..., 
                display_name: Optional[str] = ..., 
                enable_regional_mdm_account: Optional[bool] = ..., 
                fill_gap_with_zero: Optional[bool] = ..., 
                is_internal: Optional[bool] = ..., 
                metric_filter_pattern: Optional[str] = ..., 
                name: Optional[str] = ..., 
                source_mdm_account: Optional[str] = ..., 
                source_mdm_namespace: Optional[str] = ..., 
                supported_aggregation_types: Optional[list[str]] = ..., 
                supported_time_grain_types: Optional[list[str]] = ..., 
                supports_instance_level_aggregation: Optional[bool] = ..., 
                unit: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.MigrateMySqlRequest(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[MigrateMySqlRequestProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[MigrateMySqlRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.MigrateMySqlRequestProperties(_Model):
        connection_string: str
        migration_type: Union[str, MySqlMigrationType]

        @overload
        def __init__(
                self, 
                *, 
                connection_string: str, 
                migration_type: Union[str, MySqlMigrationType]
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.MigrateMySqlStatus(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[MigrateMySqlStatusProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[MigrateMySqlStatusProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.MigrateMySqlStatusProperties(_Model):
        local_my_sql_enabled: Optional[bool]
        migration_operation_status: Optional[Union[str, OperationStatus]]
        operation_id: Optional[str]


    class azure.mgmt.web.models.MySqlMigrationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        LOCAL_TO_REMOTE = "LocalToRemote"
        REMOTE_TO_LOCAL = "RemoteToLocal"


    class azure.mgmt.web.models.NameIdentifier(_Model):
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.NameValuePair(_Model):
        name: Optional[str]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.NetworkFeatures(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[NetworkFeaturesProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[NetworkFeaturesProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.NetworkFeaturesProperties(_Model):
        hybrid_connections: Optional[list[RelayServiceConnectionEntity]]
        hybrid_connections_v2: Optional[list[HybridConnection]]
        virtual_network_connection: Optional[VnetInfo]
        virtual_network_name: Optional[str]


    class azure.mgmt.web.models.NetworkTrace(_Model):
        message: Optional[str]
        path: Optional[str]
        status: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                message: Optional[str] = ..., 
                path: Optional[str] = ..., 
                status: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Nonce(_Model):
        nonce_expiration_interval: Optional[str]
        validate_nonce: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                nonce_expiration_interval: Optional[str] = ..., 
                validate_nonce: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.NotificationLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CRITICAL = "Critical"
        INFORMATION = "Information"
        NON_URGENT_SUGGESTION = "NonUrgentSuggestion"
        WARNING = "Warning"


    class azure.mgmt.web.models.OpenAuthenticationAccessPolicies(_Model):
        policies: Optional[dict[str, OpenAuthenticationAccessPolicy]]

        @overload
        def __init__(
                self, 
                *, 
                policies: Optional[dict[str, OpenAuthenticationAccessPolicy]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OpenAuthenticationAccessPolicy(_Model):
        claims: Optional[list[OpenAuthenticationPolicyClaim]]
        type: Optional[Union[str, OpenAuthenticationProviderType]]

        @overload
        def __init__(
                self, 
                *, 
                claims: Optional[list[OpenAuthenticationPolicyClaim]] = ..., 
                type: Optional[Union[str, OpenAuthenticationProviderType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OpenAuthenticationPolicyClaim(_Model):
        name: Optional[str]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                name: Optional[str] = ..., 
                value: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OpenAuthenticationProviderType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        AAD = "AAD"


    class azure.mgmt.web.models.OpenIdConnectClientCredential(_Model):
        client_secret_setting_name: Optional[str]
        method: Optional[Literal["ClientSecretPost"]]

        @overload
        def __init__(
                self, 
                *, 
                client_secret_setting_name: Optional[str] = ..., 
                method: Optional[Literal[ClientSecretPost]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OpenIdConnectConfig(_Model):
        authorization_endpoint: Optional[str]
        certification_uri: Optional[str]
        issuer: Optional[str]
        token_endpoint: Optional[str]
        well_known_open_id_configuration: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                authorization_endpoint: Optional[str] = ..., 
                certification_uri: Optional[str] = ..., 
                issuer: Optional[str] = ..., 
                token_endpoint: Optional[str] = ..., 
                well_known_open_id_configuration: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OpenIdConnectLogin(_Model):
        name_claim_type: Optional[str]
        scopes: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                name_claim_type: Optional[str] = ..., 
                scopes: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OpenIdConnectRegistration(_Model):
        client_credential: Optional[OpenIdConnectClientCredential]
        client_id: Optional[str]
        open_id_connect_configuration: Optional[OpenIdConnectConfig]

        @overload
        def __init__(
                self, 
                *, 
                client_credential: Optional[OpenIdConnectClientCredential] = ..., 
                client_id: Optional[str] = ..., 
                open_id_connect_configuration: Optional[OpenIdConnectConfig] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Operation(_Model):
        created_time: Optional[datetime]
        errors: Optional[list[ErrorEntity]]
        expiration_time: Optional[datetime]
        geo_master_operation_id: Optional[str]
        id: Optional[str]
        modified_time: Optional[datetime]
        name: Optional[str]
        status: Optional[Union[str, OperationStatus]]

        @overload
        def __init__(
                self, 
                *, 
                created_time: Optional[datetime] = ..., 
                errors: Optional[list[ErrorEntity]] = ..., 
                expiration_time: Optional[datetime] = ..., 
                geo_master_operation_id: Optional[str] = ..., 
                id: Optional[str] = ..., 
                modified_time: Optional[datetime] = ..., 
                name: Optional[str] = ..., 
                status: Optional[Union[str, OperationStatus]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OperationResult(OperationResultProperties):
        code: str
        correlation: RunActionCorrelation
        end_time: datetime
        error: any
        inputs: Optional[Any]
        inputs_link: Optional[ContentLink]
        iteration_count: Optional[int]
        outputs: Optional[Any]
        outputs_link: Optional[ContentLink]
        retry_history: Optional[list[RetryHistory]]
        start_time: datetime
        status: Union[str, WorkflowStatus]
        tracked_properties: Optional[Any]
        tracking_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                correlation: Optional[RunActionCorrelation] = ..., 
                end_time: Optional[datetime] = ..., 
                error: Optional[Any] = ..., 
                iteration_count: Optional[int] = ..., 
                retry_history: Optional[list[RetryHistory]] = ..., 
                start_time: Optional[datetime] = ..., 
                status: Optional[Union[str, WorkflowStatus]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OperationResultProperties(_Model):
        code: Optional[str]
        correlation: Optional[RunActionCorrelation]
        end_time: Optional[datetime]
        error: Optional[Any]
        start_time: Optional[datetime]
        status: Optional[Union[str, WorkflowStatus]]

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                correlation: Optional[RunActionCorrelation] = ..., 
                end_time: Optional[datetime] = ..., 
                error: Optional[Any] = ..., 
                start_time: Optional[datetime] = ..., 
                status: Optional[Union[str, WorkflowStatus]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OperationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CREATED = "Created"
        FAILED = "Failed"
        IN_PROGRESS = "InProgress"
        SUCCEEDED = "Succeeded"
        TIMED_OUT = "TimedOut"


    class azure.mgmt.web.models.OutboundEnvironmentEndpoint(_Model):
        category: Optional[str]
        endpoints: Optional[list[EndpointDependency]]

        @overload
        def __init__(
                self, 
                *, 
                category: Optional[str] = ..., 
                endpoints: Optional[list[EndpointDependency]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.OutboundVnetRouting(_Model):
        all_traffic: Optional[bool]
        application_traffic: Optional[bool]
        backup_restore_traffic: Optional[bool]
        content_share_traffic: Optional[bool]
        image_pull_traffic: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                all_traffic: Optional[bool] = ..., 
                application_traffic: Optional[bool] = ..., 
                backup_restore_traffic: Optional[bool] = ..., 
                content_share_traffic: Optional[bool] = ..., 
                image_pull_traffic: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ParameterType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ARRAY = "Array"
        BOOL = "Bool"
        FLOAT = "Float"
        INT = "Int"
        NOT_SPECIFIED = "NotSpecified"
        OBJECT = "Object"
        SECURE_OBJECT = "SecureObject"
        SECURE_STRING = "SecureString"
        STRING = "String"


    class azure.mgmt.web.models.PerfMonResponse(_Model):
        code: Optional[str]
        data: Optional[PerfMonSet]
        message: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                data: Optional[PerfMonSet] = ..., 
                message: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PerfMonSample(_Model):
        instance_name: Optional[str]
        time: Optional[datetime]
        value: Optional[float]

        @overload
        def __init__(
                self, 
                *, 
                instance_name: Optional[str] = ..., 
                time: Optional[datetime] = ..., 
                value: Optional[float] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PerfMonSet(_Model):
        end_time: Optional[datetime]
        name: Optional[str]
        start_time: Optional[datetime]
        time_grain: Optional[str]
        values_property: Optional[list[PerfMonSample]]

        @overload
        def __init__(
                self, 
                *, 
                end_time: Optional[datetime] = ..., 
                name: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                values_property: Optional[list[PerfMonSample]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PremierAddOn(TrackedResource):
        id: str
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[PremierAddOnProperties]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[PremierAddOnProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.PremierAddOnOffer(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[PremierAddOnOfferProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[PremierAddOnOfferProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.PremierAddOnOfferProperties(_Model):
        legal_terms_url: Optional[str]
        marketplace_offer: Optional[str]
        marketplace_publisher: Optional[str]
        privacy_policy_url: Optional[str]
        product: Optional[str]
        promo_code_required: Optional[bool]
        quota: Optional[int]
        sku: Optional[str]
        vendor: Optional[str]
        web_hosting_plan_restrictions: Optional[Union[str, AppServicePlanRestrictions]]

        @overload
        def __init__(
                self, 
                *, 
                legal_terms_url: Optional[str] = ..., 
                marketplace_offer: Optional[str] = ..., 
                marketplace_publisher: Optional[str] = ..., 
                privacy_policy_url: Optional[str] = ..., 
                product: Optional[str] = ..., 
                promo_code_required: Optional[bool] = ..., 
                quota: Optional[int] = ..., 
                sku: Optional[str] = ..., 
                vendor: Optional[str] = ..., 
                web_hosting_plan_restrictions: Optional[Union[str, AppServicePlanRestrictions]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PremierAddOnPatchResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[PremierAddOnPatchResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[PremierAddOnPatchResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.PremierAddOnPatchResourceProperties(_Model):
        marketplace_offer: Optional[str]
        marketplace_publisher: Optional[str]
        product: Optional[str]
        sku: Optional[str]
        vendor: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                marketplace_offer: Optional[str] = ..., 
                marketplace_publisher: Optional[str] = ..., 
                product: Optional[str] = ..., 
                sku: Optional[str] = ..., 
                vendor: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PremierAddOnProperties(_Model):
        marketplace_offer: Optional[str]
        marketplace_publisher: Optional[str]
        product: Optional[str]
        sku: Optional[str]
        vendor: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                marketplace_offer: Optional[str] = ..., 
                marketplace_publisher: Optional[str] = ..., 
                product: Optional[str] = ..., 
                sku: Optional[str] = ..., 
                vendor: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PrivateAccess(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[PrivateAccessProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[PrivateAccessProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.PrivateAccessProperties(_Model):
        enabled: Optional[bool]
        virtual_networks: Optional[list[PrivateAccessVirtualNetwork]]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                virtual_networks: Optional[list[PrivateAccessVirtualNetwork]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PrivateAccessSubnet(_Model):
        key: Optional[int]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                key: Optional[int] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PrivateAccessVirtualNetwork(_Model):
        key: Optional[int]
        name: Optional[str]
        resource_id: Optional[str]
        subnets: Optional[list[PrivateAccessSubnet]]

        @overload
        def __init__(
                self, 
                *, 
                key: Optional[int] = ..., 
                name: Optional[str] = ..., 
                resource_id: Optional[str] = ..., 
                subnets: Optional[list[PrivateAccessSubnet]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PrivateLinkConnectionState(_Model):
        actions_required: Optional[str]
        description: Optional[str]
        status: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                actions_required: Optional[str] = ..., 
                description: Optional[str] = ..., 
                status: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PrivateLinkResource(_Model):
        id: str
        name: str
        properties: PrivateLinkResourceProperties
        type: str

        @overload
        def __init__(
                self, 
                *, 
                id: str, 
                name: str, 
                properties: PrivateLinkResourceProperties, 
                type: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PrivateLinkResourceProperties(_Model):
        group_id: Optional[str]
        required_members: Optional[list[str]]
        required_zone_names: Optional[list[str]]


    class azure.mgmt.web.models.PrivateLinkResourcesWrapper(_Model):
        value: list[PrivateLinkResource]

        @overload
        def __init__(
                self, 
                *, 
                value: list[PrivateLinkResource]
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ProcessInfo(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[ProcessInfoProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ProcessInfoProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ProcessInfoProperties(_Model):
        children: Optional[list[str]]
        command_line: Optional[str]
        deployment_name: Optional[str]
        description: Optional[str]
        environment_variables: Optional[dict[str, str]]
        file_name: Optional[str]
        handle_count: Optional[int]
        href: Optional[str]
        identifier: Optional[int]
        iis_profile_timeout_in_seconds: Optional[float]
        is_iis_profile_running: Optional[bool]
        is_profile_running: Optional[bool]
        is_scm_site: Optional[bool]
        is_webjob: Optional[bool]
        minidump: Optional[str]
        module_count: Optional[int]
        modules: Optional[list[ProcessModuleInfo]]
        non_paged_system_memory: Optional[int]
        open_file_handles: Optional[list[str]]
        paged_memory: Optional[int]
        paged_system_memory: Optional[int]
        parent: Optional[str]
        peak_paged_memory: Optional[int]
        peak_virtual_memory: Optional[int]
        peak_working_set: Optional[int]
        private_memory: Optional[int]
        privileged_cpu_time: Optional[str]
        start_time: Optional[datetime]
        thread_count: Optional[int]
        threads: Optional[list[ProcessThreadInfo]]
        time_stamp: Optional[datetime]
        total_cpu_time: Optional[str]
        user_cpu_time: Optional[str]
        user_name: Optional[str]
        virtual_memory: Optional[int]
        working_set: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                children: Optional[list[str]] = ..., 
                command_line: Optional[str] = ..., 
                deployment_name: Optional[str] = ..., 
                description: Optional[str] = ..., 
                environment_variables: Optional[dict[str, str]] = ..., 
                file_name: Optional[str] = ..., 
                handle_count: Optional[int] = ..., 
                href: Optional[str] = ..., 
                iis_profile_timeout_in_seconds: Optional[float] = ..., 
                is_iis_profile_running: Optional[bool] = ..., 
                is_profile_running: Optional[bool] = ..., 
                is_scm_site: Optional[bool] = ..., 
                is_webjob: Optional[bool] = ..., 
                minidump: Optional[str] = ..., 
                module_count: Optional[int] = ..., 
                modules: Optional[list[ProcessModuleInfo]] = ..., 
                non_paged_system_memory: Optional[int] = ..., 
                open_file_handles: Optional[list[str]] = ..., 
                paged_memory: Optional[int] = ..., 
                paged_system_memory: Optional[int] = ..., 
                parent: Optional[str] = ..., 
                peak_paged_memory: Optional[int] = ..., 
                peak_virtual_memory: Optional[int] = ..., 
                peak_working_set: Optional[int] = ..., 
                private_memory: Optional[int] = ..., 
                privileged_cpu_time: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                thread_count: Optional[int] = ..., 
                threads: Optional[list[ProcessThreadInfo]] = ..., 
                time_stamp: Optional[datetime] = ..., 
                total_cpu_time: Optional[str] = ..., 
                user_cpu_time: Optional[str] = ..., 
                user_name: Optional[str] = ..., 
                virtual_memory: Optional[int] = ..., 
                working_set: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ProcessModuleInfo(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[ProcessModuleInfoProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ProcessModuleInfoProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ProcessModuleInfoProperties(_Model):
        base_address: Optional[str]
        file_description: Optional[str]
        file_name: Optional[str]
        file_path: Optional[str]
        file_version: Optional[str]
        href: Optional[str]
        is_debug: Optional[bool]
        language: Optional[str]
        module_memory_size: Optional[int]
        product: Optional[str]
        product_version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                base_address: Optional[str] = ..., 
                file_description: Optional[str] = ..., 
                file_name: Optional[str] = ..., 
                file_path: Optional[str] = ..., 
                file_version: Optional[str] = ..., 
                href: Optional[str] = ..., 
                is_debug: Optional[bool] = ..., 
                language: Optional[str] = ..., 
                module_memory_size: Optional[int] = ..., 
                product: Optional[str] = ..., 
                product_version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ProcessThreadInfo(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[ProcessThreadInfoProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ProcessThreadInfoProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ProcessThreadInfoProperties(_Model):
        base_priority: Optional[int]
        current_priority: Optional[int]
        href: Optional[str]
        identifier: Optional[int]
        priority_level: Optional[str]
        process: Optional[str]
        start_address: Optional[str]
        start_time: Optional[datetime]
        state: Optional[str]
        total_processor_time: Optional[str]
        user_processor_time: Optional[str]
        wait_reason: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                base_priority: Optional[int] = ..., 
                current_priority: Optional[int] = ..., 
                href: Optional[str] = ..., 
                priority_level: Optional[str] = ..., 
                process: Optional[str] = ..., 
                start_address: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                state: Optional[str] = ..., 
                total_processor_time: Optional[str] = ..., 
                user_processor_time: Optional[str] = ..., 
                wait_reason: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ProviderOsTypeSelected(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALL = "All"
        LINUX = "Linux"
        LINUX_FUNCTIONS = "LinuxFunctions"
        WINDOWS = "Windows"
        WINDOWS_FUNCTIONS = "WindowsFunctions"


    class azure.mgmt.web.models.ProviderStackOsType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALL = "All"
        LINUX = "Linux"
        WINDOWS = "Windows"


    class azure.mgmt.web.models.ProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CANCELED = "Canceled"
        DELETING = "Deleting"
        FAILED = "Failed"
        IN_PROGRESS = "InProgress"
        SUCCEEDED = "Succeeded"


    class azure.mgmt.web.models.ProxyOnlyResource(_Model):
        id: Optional[str]
        kind: Optional[str]
        name: Optional[str]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ProxyResource(Resource):
        id: str
        name: str
        system_data: SystemData
        type: str


    class azure.mgmt.web.models.PublicCertificate(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[PublicCertificateProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[PublicCertificateProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.PublicCertificateLocation(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CURRENT_USER_MY = "CurrentUserMy"
        LOCAL_MACHINE_MY = "LocalMachineMy"
        UNKNOWN = "Unknown"


    class azure.mgmt.web.models.PublicCertificateProperties(_Model):
        blob: Optional[bytes]
        public_certificate_location: Optional[Union[str, PublicCertificateLocation]]
        thumbprint: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                blob: Optional[bytes] = ..., 
                public_certificate_location: Optional[Union[str, PublicCertificateLocation]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.PublishingProfileFormat(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        FILE_ZILLA3 = "FileZilla3"
        FTP = "Ftp"
        WEB_DEPLOY = "WebDeploy"


    class azure.mgmt.web.models.PushSettings(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[PushSettingsProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[PushSettingsProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.PushSettingsProperties(_Model):
        dynamic_tags_json: Optional[str]
        is_push_enabled: bool
        tag_whitelist_json: Optional[str]
        tags_requiring_auth: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                dynamic_tags_json: Optional[str] = ..., 
                is_push_enabled: bool, 
                tag_whitelist_json: Optional[str] = ..., 
                tags_requiring_auth: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.QueryUtterancesResult(_Model):
        sample_utterance: Optional[SampleUtterance]
        score: Optional[float]

        @overload
        def __init__(
                self, 
                *, 
                sample_utterance: Optional[SampleUtterance] = ..., 
                score: Optional[float] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.QueryUtterancesResults(_Model):
        query: Optional[str]
        results: Optional[list[QueryUtterancesResult]]

        @overload
        def __init__(
                self, 
                *, 
                query: Optional[str] = ..., 
                results: Optional[list[QueryUtterancesResult]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RampUpRule(_Model):
        action_host_name: Optional[str]
        change_decision_callback_url: Optional[str]
        change_interval_in_minutes: Optional[int]
        change_step: Optional[float]
        max_reroute_percentage: Optional[float]
        min_reroute_percentage: Optional[float]
        name: Optional[str]
        reroute_percentage: Optional[float]

        @overload
        def __init__(
                self, 
                *, 
                action_host_name: Optional[str] = ..., 
                change_decision_callback_url: Optional[str] = ..., 
                change_interval_in_minutes: Optional[int] = ..., 
                change_step: Optional[float] = ..., 
                max_reroute_percentage: Optional[float] = ..., 
                min_reroute_percentage: Optional[float] = ..., 
                name: Optional[str] = ..., 
                reroute_percentage: Optional[float] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Recommendation(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[RecommendationProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[RecommendationProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.RecommendationProperties(_Model):
        action_name: Optional[str]
        blade_name: Optional[str]
        category_tags: Optional[list[str]]
        channels: Optional[Union[str, Channels]]
        creation_time: Optional[datetime]
        display_name: Optional[str]
        enabled: Optional[int]
        end_time: Optional[datetime]
        extension_name: Optional[str]
        forward_link: Optional[str]
        is_dynamic: Optional[bool]
        level: Optional[Union[str, NotificationLevel]]
        message: Optional[str]
        next_notification_time: Optional[datetime]
        notification_expiration_time: Optional[datetime]
        notified_time: Optional[datetime]
        recommendation_id: Optional[str]
        resource_id: Optional[str]
        resource_scope: Optional[Union[str, ResourceScopeType]]
        rule_name: Optional[str]
        score: Optional[float]
        start_time: Optional[datetime]
        states: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                action_name: Optional[str] = ..., 
                blade_name: Optional[str] = ..., 
                channels: Optional[Union[str, Channels]] = ..., 
                creation_time: Optional[datetime] = ..., 
                display_name: Optional[str] = ..., 
                enabled: Optional[int] = ..., 
                end_time: Optional[datetime] = ..., 
                extension_name: Optional[str] = ..., 
                forward_link: Optional[str] = ..., 
                is_dynamic: Optional[bool] = ..., 
                level: Optional[Union[str, NotificationLevel]] = ..., 
                message: Optional[str] = ..., 
                next_notification_time: Optional[datetime] = ..., 
                notification_expiration_time: Optional[datetime] = ..., 
                notified_time: Optional[datetime] = ..., 
                recommendation_id: Optional[str] = ..., 
                resource_id: Optional[str] = ..., 
                resource_scope: Optional[Union[str, ResourceScopeType]] = ..., 
                rule_name: Optional[str] = ..., 
                score: Optional[float] = ..., 
                start_time: Optional[datetime] = ..., 
                states: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RecommendationRule(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[RecommendationRuleProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[RecommendationRuleProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.RecommendationRuleProperties(_Model):
        action_name: Optional[str]
        blade_name: Optional[str]
        category_tags: Optional[list[str]]
        channels: Optional[Union[str, Channels]]
        description: Optional[str]
        display_name: Optional[str]
        extension_name: Optional[str]
        forward_link: Optional[str]
        is_dynamic: Optional[bool]
        level: Optional[Union[str, NotificationLevel]]
        message: Optional[str]
        recommendation_id: Optional[str]
        recommendation_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                action_name: Optional[str] = ..., 
                blade_name: Optional[str] = ..., 
                channels: Optional[Union[str, Channels]] = ..., 
                description: Optional[str] = ..., 
                display_name: Optional[str] = ..., 
                extension_name: Optional[str] = ..., 
                forward_link: Optional[str] = ..., 
                is_dynamic: Optional[bool] = ..., 
                level: Optional[Union[str, NotificationLevel]] = ..., 
                message: Optional[str] = ..., 
                recommendation_id: Optional[str] = ..., 
                recommendation_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RecurrenceFrequency(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DAY = "Day"
        HOUR = "Hour"
        MINUTE = "Minute"
        MONTH = "Month"
        NOT_SPECIFIED = "NotSpecified"
        SECOND = "Second"
        WEEK = "Week"
        YEAR = "Year"


    class azure.mgmt.web.models.RecurrenceSchedule(_Model):
        hours: Optional[list[int]]
        minutes: Optional[list[int]]
        month_days: Optional[list[int]]
        monthly_occurrences: Optional[list[RecurrenceScheduleOccurrence]]
        week_days: Optional[list[Union[str, DaysOfWeek]]]

        @overload
        def __init__(
                self, 
                *, 
                hours: Optional[list[int]] = ..., 
                minutes: Optional[list[int]] = ..., 
                month_days: Optional[list[int]] = ..., 
                monthly_occurrences: Optional[list[RecurrenceScheduleOccurrence]] = ..., 
                week_days: Optional[list[Union[str, DaysOfWeek]]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RecurrenceScheduleOccurrence(_Model):
        day: Optional[Union[str, DayOfWeek]]
        occurrence: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                day: Optional[Union[str, DayOfWeek]] = ..., 
                occurrence: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RedundancyMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ACTIVE_ACTIVE = "ActiveActive"
        FAILOVER = "Failover"
        GEO_REDUNDANT = "GeoRedundant"
        MANUAL = "Manual"
        NONE = "None"


    class azure.mgmt.web.models.RegenerateActionParameter(_Model):
        key_type: Optional[Union[str, KeyType]]

        @overload
        def __init__(
                self, 
                *, 
                key_type: Optional[Union[str, KeyType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RegistryAdapter(_Model):
        key_vault_secret_reference: Optional[KeyVaultReferenceWithStatus]
        registry_key: Optional[str]
        type: Optional[Union[str, RegistryAdapterType]]

        @overload
        def __init__(
                self, 
                *, 
                key_vault_secret_reference: Optional[KeyVaultReferenceWithStatus] = ..., 
                registry_key: Optional[str] = ..., 
                type: Optional[Union[str, RegistryAdapterType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RegistryAdapterType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BINARY = "Binary"
        D_WORD = "DWord"
        EXPAND_STRING = "Expand_String"
        MULTI_STRING = "Multi_String"
        Q_WORD = "QWord"
        STRING = "String"


    class azure.mgmt.web.models.RelayServiceConnectionEntity(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[RelayServiceConnectionEntityProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[RelayServiceConnectionEntityProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.RelayServiceConnectionEntityProperties(_Model):
        biztalk_uri: Optional[str]
        entity_connection_string: Optional[str]
        entity_name: Optional[str]
        hostname: Optional[str]
        port: Optional[int]
        resource_connection_string: Optional[str]
        resource_type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                biztalk_uri: Optional[str] = ..., 
                entity_connection_string: Optional[str] = ..., 
                entity_name: Optional[str] = ..., 
                hostname: Optional[str] = ..., 
                port: Optional[int] = ..., 
                resource_connection_string: Optional[str] = ..., 
                resource_type: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RemotePrivateEndpointConnection(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[RemotePrivateEndpointConnectionProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[RemotePrivateEndpointConnectionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.RemotePrivateEndpointConnectionARMResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[RemotePrivateEndpointConnectionARMResourceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[RemotePrivateEndpointConnectionARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.RemotePrivateEndpointConnectionARMResourceProperties(_Model):
        ip_addresses: Optional[list[str]]
        private_endpoint: Optional[ArmIdWrapper]
        private_link_service_connection_state: Optional[PrivateLinkConnectionState]
        provisioning_state: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                ip_addresses: Optional[list[str]] = ..., 
                private_endpoint: Optional[ArmIdWrapper] = ..., 
                private_link_service_connection_state: Optional[PrivateLinkConnectionState] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RemotePrivateEndpointConnectionProperties(_Model):
        ip_addresses: Optional[list[str]]
        private_endpoint: Optional[ArmIdWrapper]
        private_link_service_connection_state: Optional[PrivateLinkConnectionState]
        provisioning_state: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                ip_addresses: Optional[list[str]] = ..., 
                private_endpoint: Optional[ArmIdWrapper] = ..., 
                private_link_service_connection_state: Optional[PrivateLinkConnectionState] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Rendering(_Model):
        description: Optional[str]
        title: Optional[str]
        type: Optional[Union[str, RenderingType]]

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                title: Optional[str] = ..., 
                type: Optional[Union[str, RenderingType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RenderingType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        APP_INSIGHT = "AppInsight"
        APP_INSIGHT_ENABLEMENT = "AppInsightEnablement"
        CARD = "Card"
        CHANGES_VIEW = "ChangesView"
        CHANGE_ANALYSIS_ONBOARDING = "ChangeAnalysisOnboarding"
        CHANGE_SETS = "ChangeSets"
        DATA_SUMMARY = "DataSummary"
        DEPENDENCY_GRAPH = "DependencyGraph"
        DETECTOR = "Detector"
        DOWN_TIME = "DownTime"
        DROP_DOWN = "DropDown"
        DYNAMIC_INSIGHT = "DynamicInsight"
        EMAIL = "Email"
        FORM = "Form"
        GUAGE = "Guage"
        INSIGHTS = "Insights"
        MARKDOWN = "Markdown"
        NO_GRAPH = "NoGraph"
        PIE_CHART = "PieChart"
        SEARCH_COMPONENT = "SearchComponent"
        SOLUTION = "Solution"
        SUMMARY_CARD = "SummaryCard"
        TABLE = "Table"
        TIME_SERIES = "TimeSeries"
        TIME_SERIES_PER_INSTANCE = "TimeSeriesPerInstance"


    class azure.mgmt.web.models.RepetitionIndex(_Model):
        item_index: int
        scope_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                item_index: int, 
                scope_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Request(_Model):
        headers: Optional[Any]
        method: Optional[str]
        uri: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                headers: Optional[Any] = ..., 
                method: Optional[str] = ..., 
                uri: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RequestHistory(TrackedResource):
        id: str
        location: str
        name: str
        properties: Optional[RequestHistoryProperties]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        @overload
        def __init__(
                self, 
                *, 
                location: str, 
                properties: Optional[RequestHistoryProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RequestHistoryProperties(_Model):
        end_time: Optional[datetime]
        request: Optional[Request]
        response: Optional[Response]
        start_time: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                end_time: Optional[datetime] = ..., 
                request: Optional[Request] = ..., 
                response: Optional[Response] = ..., 
                start_time: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RequestsBasedTrigger(_Model):
        count: Optional[int]
        time_interval: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                count: Optional[int] = ..., 
                time_interval: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResolveStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ACCESS_TO_KEY_VAULT_DENIED = "AccessToKeyVaultDenied"
        FETCH_TIMED_OUT = "FetchTimedOut"
        INITIALIZED = "Initialized"
        INVALID_SYNTAX = "InvalidSyntax"
        MSI_NOT_ENABLED = "MSINotEnabled"
        OTHER_REASONS = "OtherReasons"
        RESOLVED = "Resolved"
        SECRET_NOT_FOUND = "SecretNotFound"
        SECRET_VERSION_NOT_FOUND = "SecretVersionNotFound"
        UNAUTHORIZED_CLIENT = "UnauthorizedClient"
        VAULT_NOT_FOUND = "VaultNotFound"


    class azure.mgmt.web.models.Resource(_Model):
        id: Optional[str]
        name: Optional[str]
        system_data: Optional[SystemData]
        type: Optional[str]


    class azure.mgmt.web.models.ResourceConfig(_Model):
        cpu: Optional[float]
        memory: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                cpu: Optional[float] = ..., 
                memory: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResourceHealthMetadata(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[ResourceHealthMetadataProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ResourceHealthMetadataProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ResourceHealthMetadataProperties(_Model):
        category: Optional[str]
        signal_availability: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                category: Optional[str] = ..., 
                signal_availability: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResourceMetricAvailability(_Model):
        retention: Optional[str]
        time_grain: Optional[str]


    class azure.mgmt.web.models.ResourceMetricDefinition(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[ResourceMetricDefinitionProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[ResourceMetricDefinitionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ResourceMetricDefinitionProperties(_Model):
        metric_availabilities: Optional[list[ResourceMetricAvailability]]
        primary_aggregation_type: Optional[str]
        properties: Optional[dict[str, str]]
        resource_uri: Optional[str]
        unit: Optional[str]


    class azure.mgmt.web.models.ResourceNameAvailability(_Model):
        message: Optional[str]
        name_available: Optional[bool]
        reason: Optional[Union[str, InAvailabilityReasonType]]

        @overload
        def __init__(
                self, 
                *, 
                message: Optional[str] = ..., 
                name_available: Optional[bool] = ..., 
                reason: Optional[Union[str, InAvailabilityReasonType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResourceNameAvailabilityRequest(_Model):
        environment_id: Optional[str]
        is_fqdn: Optional[bool]
        name: str
        type: Union[str, CheckNameResourceTypes]

        @overload
        def __init__(
                self, 
                *, 
                environment_id: Optional[str] = ..., 
                is_fqdn: Optional[bool] = ..., 
                name: str, 
                type: Union[str, CheckNameResourceTypes]
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResourceReference(_Model):
        id: Optional[str]
        name: Optional[str]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResourceScopeType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        SERVER_FARM = "ServerFarm"
        SUBSCRIPTION = "Subscription"
        WEB_SITE = "WebSite"


    class azure.mgmt.web.models.Response(_Model):
        body_link: Optional[ContentLink]
        headers: Optional[Any]
        status_code: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                body_link: Optional[ContentLink] = ..., 
                headers: Optional[Any] = ..., 
                status_code: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResponseMessageEnvelopeRemotePrivateEndpointConnection(_Model):
        error: Optional[ErrorEntity]
        id: Optional[str]
        identity: Optional[ManagedServiceIdentity]
        location: Optional[str]
        name: Optional[str]
        plan: Optional[ArmPlan]
        properties: Optional[RemotePrivateEndpointConnection]
        sku: Optional[SkuDescription]
        status: Optional[str]
        tags: Optional[dict[str, str]]
        type: Optional[str]
        zones: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[ErrorEntity] = ..., 
                id: Optional[str] = ..., 
                identity: Optional[ManagedServiceIdentity] = ..., 
                location: Optional[str] = ..., 
                name: Optional[str] = ..., 
                plan: Optional[ArmPlan] = ..., 
                properties: Optional[RemotePrivateEndpointConnection] = ..., 
                sku: Optional[SkuDescription] = ..., 
                status: Optional[str] = ..., 
                tags: Optional[dict[str, str]] = ..., 
                type: Optional[str] = ..., 
                zones: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ResponseMetaData(_Model):
        data_source: Optional[DataSource]

        @overload
        def __init__(
                self, 
                *, 
                data_source: Optional[DataSource] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RestoreRequest(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[RestoreRequestProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[RestoreRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.RestoreRequestProperties(_Model):
        adjust_connection_strings: Optional[bool]
        app_service_plan: Optional[str]
        blob_name: Optional[str]
        databases: Optional[list[DatabaseBackupSetting]]
        hosting_environment: Optional[str]
        ignore_conflicting_host_names: Optional[bool]
        ignore_databases: Optional[bool]
        operation_type: Optional[Union[str, BackupRestoreOperationType]]
        overwrite: bool
        site_name: Optional[str]
        storage_account_url: str

        @overload
        def __init__(
                self, 
                *, 
                adjust_connection_strings: Optional[bool] = ..., 
                app_service_plan: Optional[str] = ..., 
                blob_name: Optional[str] = ..., 
                databases: Optional[list[DatabaseBackupSetting]] = ..., 
                hosting_environment: Optional[str] = ..., 
                ignore_conflicting_host_names: Optional[bool] = ..., 
                ignore_databases: Optional[bool] = ..., 
                operation_type: Optional[Union[str, BackupRestoreOperationType]] = ..., 
                overwrite: bool, 
                site_name: Optional[str] = ..., 
                storage_account_url: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RetryHistory(_Model):
        client_request_id: Optional[str]
        code: Optional[str]
        end_time: Optional[datetime]
        error: Optional[WorkflowErrorResponse]
        service_request_id: Optional[str]
        start_time: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                client_request_id: Optional[str] = ..., 
                code: Optional[str] = ..., 
                end_time: Optional[datetime] = ..., 
                error: Optional[WorkflowErrorResponse] = ..., 
                service_request_id: Optional[str] = ..., 
                start_time: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RouteType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DEFAULT = "DEFAULT"
        INHERITED = "INHERITED"
        STATIC = "STATIC"


    class azure.mgmt.web.models.RunActionCorrelation(RunCorrelation):
        action_tracking_id: Optional[str]
        client_keywords: list[str]
        client_tracking_id: str

        @overload
        def __init__(
                self, 
                *, 
                action_tracking_id: Optional[str] = ..., 
                client_keywords: Optional[list[str]] = ..., 
                client_tracking_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RunCorrelation(_Model):
        client_keywords: Optional[list[str]]
        client_tracking_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_keywords: Optional[list[str]] = ..., 
                client_tracking_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.RuntimeName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CUSTOM = "custom"
        DOTNET_ISOLATED = "dotnet-isolated"
        JAVA = "java"
        NODE = "node"
        POWERSHELL = "powershell"
        PYTHON = "python"


    class azure.mgmt.web.models.SampleUtterance(_Model):
        links: Optional[list[str]]
        qid: Optional[str]
        text: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                links: Optional[list[str]] = ..., 
                qid: Optional[str] = ..., 
                text: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ScmType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BITBUCKET_GIT = "BitbucketGit"
        BITBUCKET_HG = "BitbucketHg"
        CODE_PLEX_GIT = "CodePlexGit"
        CODE_PLEX_HG = "CodePlexHg"
        DROPBOX = "Dropbox"
        EXTERNAL_GIT = "ExternalGit"
        EXTERNAL_HG = "ExternalHg"
        GIT_HUB = "GitHub"
        LOCAL_GIT = "LocalGit"
        NONE = "None"
        ONE_DRIVE = "OneDrive"
        TFS = "Tfs"
        VSO = "VSO"
        VSTSRM = "VSTSRM"


    class azure.mgmt.web.models.ServerFarmInstance(_Model):
        instance_name: Optional[str]
        ip_address: Optional[str]
        status: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                instance_name: Optional[str] = ..., 
                ip_address: Optional[str] = ..., 
                status: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ServerFarmInstanceDetails(_Model):
        instance_count: Optional[int]
        instances: Optional[list[ServerFarmInstance]]
        server_farm_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                instance_count: Optional[int] = ..., 
                instances: Optional[list[ServerFarmInstance]] = ..., 
                server_farm_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ServerFarmNetworkSettings(_Model):
        virtual_network_subnet_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                virtual_network_subnet_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ServerFarmRdpDetails(_Model):
        rdp_password: Optional[str]
        rdp_password_expiry: Optional[datetime]

        @overload
        def __init__(
                self, 
                *, 
                rdp_password: Optional[str] = ..., 
                rdp_password_expiry: Optional[datetime] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ServiceSpecification(_Model):
        log_specifications: Optional[list[LogSpecification]]
        metric_specifications: Optional[list[MetricSpecification]]

        @overload
        def __init__(
                self, 
                *, 
                log_specifications: Optional[list[LogSpecification]] = ..., 
                metric_specifications: Optional[list[MetricSpecification]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Site(TrackedResource):
        extended_location: Optional[ExtendedLocation]
        id: str
        identity: Optional[ManagedServiceIdentity]
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[SiteProperties]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                extended_location: Optional[ExtendedLocation] = ..., 
                identity: Optional[ManagedServiceIdentity] = ..., 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[SiteProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteAuthSettings(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[SiteAuthSettingsProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteAuthSettingsProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteAuthSettingsProperties(_Model):
        aad_claims_authorization: Optional[str]
        additional_login_params: Optional[list[str]]
        allowed_audiences: Optional[list[str]]
        allowed_external_redirect_urls: Optional[list[str]]
        auth_file_path: Optional[str]
        client_id: Optional[str]
        client_secret: Optional[str]
        client_secret_certificate_thumbprint: Optional[str]
        client_secret_setting_name: Optional[str]
        config_version: Optional[str]
        default_provider: Optional[Union[str, BuiltInAuthenticationProvider]]
        enabled: Optional[bool]
        facebook_app_id: Optional[str]
        facebook_app_secret: Optional[str]
        facebook_app_secret_setting_name: Optional[str]
        facebook_o_auth_scopes: Optional[list[str]]
        git_hub_client_id: Optional[str]
        git_hub_client_secret: Optional[str]
        git_hub_client_secret_setting_name: Optional[str]
        git_hub_o_auth_scopes: Optional[list[str]]
        google_client_id: Optional[str]
        google_client_secret: Optional[str]
        google_client_secret_setting_name: Optional[str]
        google_o_auth_scopes: Optional[list[str]]
        is_auth_from_file: Optional[str]
        issuer: Optional[str]
        microsoft_account_client_id: Optional[str]
        microsoft_account_client_secret: Optional[str]
        microsoft_account_client_secret_setting_name: Optional[str]
        microsoft_account_o_auth_scopes: Optional[list[str]]
        runtime_version: Optional[str]
        token_refresh_extension_hours: Optional[float]
        token_store_enabled: Optional[bool]
        twitter_consumer_key: Optional[str]
        twitter_consumer_secret: Optional[str]
        twitter_consumer_secret_setting_name: Optional[str]
        unauthenticated_client_action: Optional[Union[str, UnauthenticatedClientAction]]
        validate_issuer: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                aad_claims_authorization: Optional[str] = ..., 
                additional_login_params: Optional[list[str]] = ..., 
                allowed_audiences: Optional[list[str]] = ..., 
                allowed_external_redirect_urls: Optional[list[str]] = ..., 
                auth_file_path: Optional[str] = ..., 
                client_id: Optional[str] = ..., 
                client_secret: Optional[str] = ..., 
                client_secret_certificate_thumbprint: Optional[str] = ..., 
                client_secret_setting_name: Optional[str] = ..., 
                config_version: Optional[str] = ..., 
                default_provider: Optional[Union[str, BuiltInAuthenticationProvider]] = ..., 
                enabled: Optional[bool] = ..., 
                facebook_app_id: Optional[str] = ..., 
                facebook_app_secret: Optional[str] = ..., 
                facebook_app_secret_setting_name: Optional[str] = ..., 
                facebook_o_auth_scopes: Optional[list[str]] = ..., 
                git_hub_client_id: Optional[str] = ..., 
                git_hub_client_secret: Optional[str] = ..., 
                git_hub_client_secret_setting_name: Optional[str] = ..., 
                git_hub_o_auth_scopes: Optional[list[str]] = ..., 
                google_client_id: Optional[str] = ..., 
                google_client_secret: Optional[str] = ..., 
                google_client_secret_setting_name: Optional[str] = ..., 
                google_o_auth_scopes: Optional[list[str]] = ..., 
                is_auth_from_file: Optional[str] = ..., 
                issuer: Optional[str] = ..., 
                microsoft_account_client_id: Optional[str] = ..., 
                microsoft_account_client_secret: Optional[str] = ..., 
                microsoft_account_client_secret_setting_name: Optional[str] = ..., 
                microsoft_account_o_auth_scopes: Optional[list[str]] = ..., 
                runtime_version: Optional[str] = ..., 
                token_refresh_extension_hours: Optional[float] = ..., 
                token_store_enabled: Optional[bool] = ..., 
                twitter_consumer_key: Optional[str] = ..., 
                twitter_consumer_secret: Optional[str] = ..., 
                twitter_consumer_secret_setting_name: Optional[str] = ..., 
                unauthenticated_client_action: Optional[Union[str, UnauthenticatedClientAction]] = ..., 
                validate_issuer: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteAuthSettingsV2(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SiteAuthSettingsV2Properties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteAuthSettingsV2Properties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteAuthSettingsV2Properties(_Model):
        global_validation: Optional[GlobalValidation]
        http_settings: Optional[HttpSettings]
        identity_providers: Optional[IdentityProviders]
        login: Optional[Login]
        platform: Optional[AuthPlatform]

        @overload
        def __init__(
                self, 
                *, 
                global_validation: Optional[GlobalValidation] = ..., 
                http_settings: Optional[HttpSettings] = ..., 
                identity_providers: Optional[IdentityProviders] = ..., 
                login: Optional[Login] = ..., 
                platform: Optional[AuthPlatform] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteAvailabilityState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DISASTER_RECOVERY_MODE = "DisasterRecoveryMode"
        LIMITED = "Limited"
        NORMAL = "Normal"


    class azure.mgmt.web.models.SiteCloneability(_Model):
        blocking_characteristics: Optional[list[SiteCloneabilityCriterion]]
        blocking_features: Optional[list[SiteCloneabilityCriterion]]
        result: Optional[Union[str, CloneAbilityResult]]
        unsupported_features: Optional[list[SiteCloneabilityCriterion]]

        @overload
        def __init__(
                self, 
                *, 
                blocking_characteristics: Optional[list[SiteCloneabilityCriterion]] = ..., 
                blocking_features: Optional[list[SiteCloneabilityCriterion]] = ..., 
                result: Optional[Union[str, CloneAbilityResult]] = ..., 
                unsupported_features: Optional[list[SiteCloneabilityCriterion]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteCloneabilityCriterion(_Model):
        description: Optional[str]
        name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteConfig(_Model):
        acr_use_managed_identity_creds: Optional[bool]
        acr_user_managed_identity_id: Optional[str]
        always_on: Optional[bool]
        api_definition: Optional[ApiDefinitionInfo]
        api_management_config: Optional[ApiManagementConfig]
        app_command_line: Optional[str]
        app_settings: Optional[list[NameValuePair]]
        auto_heal_enabled: Optional[bool]
        auto_heal_rules: Optional[AutoHealRules]
        auto_swap_slot_name: Optional[str]
        azure_storage_accounts: Optional[dict[str, AzureStorageInfoValue]]
        connection_strings: Optional[list[ConnStringInfo]]
        cors: Optional[CorsSettings]
        default_documents: Optional[list[str]]
        detailed_error_logging_enabled: Optional[bool]
        document_root: Optional[str]
        elastic_web_app_scale_limit: Optional[int]
        experiments: Optional[Experiments]
        ftps_state: Optional[Union[str, FtpsState]]
        function_app_scale_limit: Optional[int]
        functions_runtime_scale_monitoring_enabled: Optional[bool]
        handler_mappings: Optional[list[HandlerMapping]]
        health_check_path: Optional[str]
        http20_enabled: Optional[bool]
        http20_proxy_flag: Optional[int]
        http_logging_enabled: Optional[bool]
        ip_security_restrictions: Optional[list[IpSecurityRestriction]]
        ip_security_restrictions_default_action: Optional[Union[str, DefaultAction]]
        java_container: Optional[str]
        java_container_version: Optional[str]
        java_version: Optional[str]
        key_vault_reference_identity: Optional[str]
        limits: Optional[SiteLimits]
        linux_fx_version: Optional[str]
        load_balancing: Optional[Union[str, SiteLoadBalancing]]
        local_my_sql_enabled: Optional[bool]
        logs_directory_size_limit: Optional[int]
        machine_key: Optional[SiteMachineKey]
        managed_pipeline_mode: Optional[Union[str, ManagedPipelineMode]]
        managed_service_identity_id: Optional[int]
        metadata: Optional[list[NameValuePair]]
        min_tls_cipher_suite: Optional[Union[str, TlsCipherSuites]]
        min_tls_version: Optional[Union[str, SupportedTlsVersions]]
        minimum_elastic_instance_count: Optional[int]
        net_framework_version: Optional[str]
        node_version: Optional[str]
        number_of_workers: Optional[int]
        php_version: Optional[str]
        power_shell_version: Optional[str]
        pre_warmed_instance_count: Optional[int]
        public_network_access: Optional[str]
        publishing_username: Optional[str]
        push: Optional[PushSettings]
        python_version: Optional[str]
        remote_debugging_enabled: Optional[bool]
        remote_debugging_version: Optional[str]
        request_tracing_enabled: Optional[bool]
        request_tracing_expiration_time: Optional[datetime]
        scm_ip_security_restrictions: Optional[list[IpSecurityRestriction]]
        scm_ip_security_restrictions_default_action: Optional[Union[str, DefaultAction]]
        scm_ip_security_restrictions_use_main: Optional[bool]
        scm_min_tls_version: Optional[Union[str, SupportedTlsVersions]]
        scm_type: Optional[Union[str, ScmType]]
        tracing_options: Optional[str]
        use32_bit_worker_process: Optional[bool]
        virtual_applications: Optional[list[VirtualApplication]]
        vnet_name: Optional[str]
        vnet_private_ports_count: Optional[int]
        vnet_route_all_enabled: Optional[bool]
        web_sockets_enabled: Optional[bool]
        website_time_zone: Optional[str]
        windows_fx_version: Optional[str]
        x_managed_service_identity_id: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                acr_use_managed_identity_creds: Optional[bool] = ..., 
                acr_user_managed_identity_id: Optional[str] = ..., 
                always_on: Optional[bool] = ..., 
                api_definition: Optional[ApiDefinitionInfo] = ..., 
                api_management_config: Optional[ApiManagementConfig] = ..., 
                app_command_line: Optional[str] = ..., 
                app_settings: Optional[list[NameValuePair]] = ..., 
                auto_heal_enabled: Optional[bool] = ..., 
                auto_heal_rules: Optional[AutoHealRules] = ..., 
                auto_swap_slot_name: Optional[str] = ..., 
                azure_storage_accounts: Optional[dict[str, AzureStorageInfoValue]] = ..., 
                connection_strings: Optional[list[ConnStringInfo]] = ..., 
                cors: Optional[CorsSettings] = ..., 
                default_documents: Optional[list[str]] = ..., 
                detailed_error_logging_enabled: Optional[bool] = ..., 
                document_root: Optional[str] = ..., 
                elastic_web_app_scale_limit: Optional[int] = ..., 
                experiments: Optional[Experiments] = ..., 
                ftps_state: Optional[Union[str, FtpsState]] = ..., 
                function_app_scale_limit: Optional[int] = ..., 
                functions_runtime_scale_monitoring_enabled: Optional[bool] = ..., 
                handler_mappings: Optional[list[HandlerMapping]] = ..., 
                health_check_path: Optional[str] = ..., 
                http20_enabled: Optional[bool] = ..., 
                http20_proxy_flag: Optional[int] = ..., 
                http_logging_enabled: Optional[bool] = ..., 
                ip_security_restrictions: Optional[list[IpSecurityRestriction]] = ..., 
                ip_security_restrictions_default_action: Optional[Union[str, DefaultAction]] = ..., 
                java_container: Optional[str] = ..., 
                java_container_version: Optional[str] = ..., 
                java_version: Optional[str] = ..., 
                key_vault_reference_identity: Optional[str] = ..., 
                limits: Optional[SiteLimits] = ..., 
                linux_fx_version: Optional[str] = ..., 
                load_balancing: Optional[Union[str, SiteLoadBalancing]] = ..., 
                local_my_sql_enabled: Optional[bool] = ..., 
                logs_directory_size_limit: Optional[int] = ..., 
                managed_pipeline_mode: Optional[Union[str, ManagedPipelineMode]] = ..., 
                managed_service_identity_id: Optional[int] = ..., 
                metadata: Optional[list[NameValuePair]] = ..., 
                min_tls_cipher_suite: Optional[Union[str, TlsCipherSuites]] = ..., 
                min_tls_version: Optional[Union[str, SupportedTlsVersions]] = ..., 
                minimum_elastic_instance_count: Optional[int] = ..., 
                net_framework_version: Optional[str] = ..., 
                node_version: Optional[str] = ..., 
                number_of_workers: Optional[int] = ..., 
                php_version: Optional[str] = ..., 
                power_shell_version: Optional[str] = ..., 
                pre_warmed_instance_count: Optional[int] = ..., 
                public_network_access: Optional[str] = ..., 
                publishing_username: Optional[str] = ..., 
                push: Optional[PushSettings] = ..., 
                python_version: Optional[str] = ..., 
                remote_debugging_enabled: Optional[bool] = ..., 
                remote_debugging_version: Optional[str] = ..., 
                request_tracing_enabled: Optional[bool] = ..., 
                request_tracing_expiration_time: Optional[datetime] = ..., 
                scm_ip_security_restrictions: Optional[list[IpSecurityRestriction]] = ..., 
                scm_ip_security_restrictions_default_action: Optional[Union[str, DefaultAction]] = ..., 
                scm_ip_security_restrictions_use_main: Optional[bool] = ..., 
                scm_min_tls_version: Optional[Union[str, SupportedTlsVersions]] = ..., 
                scm_type: Optional[Union[str, ScmType]] = ..., 
                tracing_options: Optional[str] = ..., 
                use32_bit_worker_process: Optional[bool] = ..., 
                virtual_applications: Optional[list[VirtualApplication]] = ..., 
                vnet_name: Optional[str] = ..., 
                vnet_private_ports_count: Optional[int] = ..., 
                vnet_route_all_enabled: Optional[bool] = ..., 
                web_sockets_enabled: Optional[bool] = ..., 
                website_time_zone: Optional[str] = ..., 
                windows_fx_version: Optional[str] = ..., 
                x_managed_service_identity_id: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteConfigPropertiesDictionary(_Model):
        java_version: Optional[str]
        linux_fx_version: Optional[str]
        power_shell_version: Optional[str]
        use32_bit_worker_process: Optional[bool]


    class azure.mgmt.web.models.SiteConfigResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SiteConfig]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteConfig] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteConfigurationSnapshotInfo(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[SiteConfigurationSnapshotInfoProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteConfigurationSnapshotInfoProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteConfigurationSnapshotInfoProperties(_Model):
        snapshot_id: Optional[int]
        time: Optional[datetime]


    class azure.mgmt.web.models.SiteContainer(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SiteContainerProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteContainerProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteContainerProperties(_Model):
        auth_type: Optional[Union[str, AuthType]]
        created_time: Optional[datetime]
        environment_variables: Optional[list[EnvironmentVariable]]
        image: str
        inherit_app_settings_and_connection_strings: Optional[bool]
        is_main: bool
        last_modified_time: Optional[datetime]
        password_secret: Optional[str]
        start_up_command: Optional[str]
        target_port: Optional[str]
        user_managed_identity_client_id: Optional[str]
        user_name: Optional[str]
        volume_mounts: Optional[list[VolumeMount]]

        @overload
        def __init__(
                self, 
                *, 
                auth_type: Optional[Union[str, AuthType]] = ..., 
                environment_variables: Optional[list[EnvironmentVariable]] = ..., 
                image: str, 
                inherit_app_settings_and_connection_strings: Optional[bool] = ..., 
                is_main: bool, 
                password_secret: Optional[str] = ..., 
                start_up_command: Optional[str] = ..., 
                target_port: Optional[str] = ..., 
                user_managed_identity_client_id: Optional[str] = ..., 
                user_name: Optional[str] = ..., 
                volume_mounts: Optional[list[VolumeMount]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteDnsConfig(_Model):
        dns_alt_server: Optional[str]
        dns_legacy_sort_order: Optional[bool]
        dns_max_cache_timeout: Optional[int]
        dns_retry_attempt_count: Optional[int]
        dns_retry_attempt_timeout: Optional[int]
        dns_servers: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                dns_alt_server: Optional[str] = ..., 
                dns_max_cache_timeout: Optional[int] = ..., 
                dns_retry_attempt_count: Optional[int] = ..., 
                dns_retry_attempt_timeout: Optional[int] = ..., 
                dns_servers: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteExtensionInfo(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SiteExtensionInfoProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteExtensionInfoProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteExtensionInfoProperties(_Model):
        authors: Optional[list[str]]
        comment: Optional[str]
        description: Optional[str]
        download_count: Optional[int]
        extension_id: Optional[str]
        extension_type: Optional[Union[str, SiteExtensionType]]
        extension_url: Optional[str]
        feed_url: Optional[str]
        icon_url: Optional[str]
        installed_date_time: Optional[datetime]
        installer_command_line_params: Optional[str]
        license_url: Optional[str]
        local_is_latest_version: Optional[bool]
        local_path: Optional[str]
        project_url: Optional[str]
        provisioning_state: Optional[str]
        published_date_time: Optional[datetime]
        summary: Optional[str]
        title: Optional[str]
        version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                authors: Optional[list[str]] = ..., 
                comment: Optional[str] = ..., 
                description: Optional[str] = ..., 
                download_count: Optional[int] = ..., 
                extension_id: Optional[str] = ..., 
                extension_type: Optional[Union[str, SiteExtensionType]] = ..., 
                extension_url: Optional[str] = ..., 
                feed_url: Optional[str] = ..., 
                icon_url: Optional[str] = ..., 
                installed_date_time: Optional[datetime] = ..., 
                installer_command_line_params: Optional[str] = ..., 
                license_url: Optional[str] = ..., 
                local_is_latest_version: Optional[bool] = ..., 
                local_path: Optional[str] = ..., 
                project_url: Optional[str] = ..., 
                provisioning_state: Optional[str] = ..., 
                published_date_time: Optional[datetime] = ..., 
                summary: Optional[str] = ..., 
                title: Optional[str] = ..., 
                version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteExtensionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        GALLERY = "Gallery"
        WEB_ROOT = "WebRoot"


    class azure.mgmt.web.models.SiteLimits(_Model):
        max_disk_size_in_mb: Optional[int]
        max_memory_in_mb: Optional[int]
        max_percentage_cpu: Optional[float]

        @overload
        def __init__(
                self, 
                *, 
                max_disk_size_in_mb: Optional[int] = ..., 
                max_memory_in_mb: Optional[int] = ..., 
                max_percentage_cpu: Optional[float] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteLoadBalancing(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        LEAST_REQUESTS = "LeastRequests"
        LEAST_REQUESTS_WITH_TIE_BREAKER = "LeastRequestsWithTieBreaker"
        LEAST_RESPONSE_TIME = "LeastResponseTime"
        PER_SITE_ROUND_ROBIN = "PerSiteRoundRobin"
        REQUEST_HASH = "RequestHash"
        WEIGHTED_ROUND_ROBIN = "WeightedRoundRobin"
        WEIGHTED_TOTAL_TRAFFIC = "WeightedTotalTraffic"


    class azure.mgmt.web.models.SiteLogsConfig(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SiteLogsConfigProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteLogsConfigProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteLogsConfigProperties(_Model):
        application_logs: Optional[ApplicationLogsConfig]
        detailed_error_messages: Optional[EnabledConfig]
        failed_requests_tracing: Optional[EnabledConfig]
        http_logs: Optional[HttpLogsConfig]

        @overload
        def __init__(
                self, 
                *, 
                application_logs: Optional[ApplicationLogsConfig] = ..., 
                detailed_error_messages: Optional[EnabledConfig] = ..., 
                failed_requests_tracing: Optional[EnabledConfig] = ..., 
                http_logs: Optional[HttpLogsConfig] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteMachineKey(_Model):
        decryption: Optional[str]
        decryption_key: Optional[str]
        validation: Optional[str]
        validation_key: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                decryption: Optional[str] = ..., 
                decryption_key: Optional[str] = ..., 
                validation: Optional[str] = ..., 
                validation_key: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SitePatchResource(ProxyOnlyResource):
        id: str
        identity: Optional[ManagedServiceIdentity]
        kind: str
        name: str
        properties: Optional[SitePatchResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                identity: Optional[ManagedServiceIdentity] = ..., 
                kind: Optional[str] = ..., 
                properties: Optional[SitePatchResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SitePatchResourceProperties(_Model):
        availability_state: Optional[Union[str, SiteAvailabilityState]]
        client_affinity_enabled: Optional[bool]
        client_affinity_proxy_enabled: Optional[bool]
        client_cert_enabled: Optional[bool]
        client_cert_exclusion_paths: Optional[str]
        client_cert_mode: Optional[Union[str, ClientCertMode]]
        cloning_info: Optional[CloningInfo]
        container_size: Optional[int]
        custom_domain_verification_id: Optional[str]
        daily_memory_time_quota: Optional[int]
        default_host_name: Optional[str]
        dns_configuration: Optional[SiteDnsConfig]
        enabled: Optional[bool]
        enabled_host_names: Optional[list[str]]
        host_name_ssl_states: Optional[list[HostNameSslState]]
        host_names: Optional[list[str]]
        host_names_disabled: Optional[bool]
        hosting_environment_profile: Optional[HostingEnvironmentProfile]
        https_only: Optional[bool]
        hyper_v: Optional[bool]
        in_progress_operation_id: Optional[str]
        is_default_container: Optional[bool]
        is_xenon: Optional[bool]
        key_vault_reference_identity: Optional[str]
        last_modified_time_utc: Optional[datetime]
        max_number_of_workers: Optional[int]
        outbound_ip_addresses: Optional[str]
        possible_outbound_ip_addresses: Optional[str]
        public_network_access: Optional[str]
        redundancy_mode: Optional[Union[str, RedundancyMode]]
        repository_site_name: Optional[str]
        reserved: Optional[bool]
        resource_group: Optional[str]
        scm_site_also_stopped: Optional[bool]
        server_farm_id: Optional[str]
        site_config: Optional[SiteConfig]
        slot_swap_status: Optional[SlotSwapStatus]
        state: Optional[str]
        storage_account_required: Optional[bool]
        suspended_till: Optional[datetime]
        target_swap_slot: Optional[str]
        traffic_manager_host_names: Optional[list[str]]
        usage_state: Optional[Union[str, UsageState]]
        virtual_network_subnet_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                client_affinity_enabled: Optional[bool] = ..., 
                client_affinity_proxy_enabled: Optional[bool] = ..., 
                client_cert_enabled: Optional[bool] = ..., 
                client_cert_exclusion_paths: Optional[str] = ..., 
                client_cert_mode: Optional[Union[str, ClientCertMode]] = ..., 
                cloning_info: Optional[CloningInfo] = ..., 
                container_size: Optional[int] = ..., 
                custom_domain_verification_id: Optional[str] = ..., 
                daily_memory_time_quota: Optional[int] = ..., 
                dns_configuration: Optional[SiteDnsConfig] = ..., 
                enabled: Optional[bool] = ..., 
                host_name_ssl_states: Optional[list[HostNameSslState]] = ..., 
                host_names_disabled: Optional[bool] = ..., 
                hosting_environment_profile: Optional[HostingEnvironmentProfile] = ..., 
                https_only: Optional[bool] = ..., 
                hyper_v: Optional[bool] = ..., 
                is_xenon: Optional[bool] = ..., 
                key_vault_reference_identity: Optional[str] = ..., 
                public_network_access: Optional[str] = ..., 
                redundancy_mode: Optional[Union[str, RedundancyMode]] = ..., 
                reserved: Optional[bool] = ..., 
                scm_site_also_stopped: Optional[bool] = ..., 
                server_farm_id: Optional[str] = ..., 
                site_config: Optional[SiteConfig] = ..., 
                storage_account_required: Optional[bool] = ..., 
                virtual_network_subnet_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SitePhpErrorLogFlag(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[SitePhpErrorLogFlagProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SitePhpErrorLogFlagProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SitePhpErrorLogFlagProperties(_Model):
        local_log_errors: Optional[str]
        local_log_errors_max_length: Optional[str]
        master_log_errors: Optional[str]
        master_log_errors_max_length: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                local_log_errors: Optional[str] = ..., 
                local_log_errors_max_length: Optional[str] = ..., 
                master_log_errors: Optional[str] = ..., 
                master_log_errors_max_length: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteProperties(_Model):
        auto_generated_domain_name_label_scope: Optional[Union[str, AutoGeneratedDomainNameLabelScope]]
        availability_state: Optional[Union[str, SiteAvailabilityState]]
        client_affinity_enabled: Optional[bool]
        client_affinity_partitioning_enabled: Optional[bool]
        client_affinity_proxy_enabled: Optional[bool]
        client_cert_enabled: Optional[bool]
        client_cert_exclusion_paths: Optional[str]
        client_cert_mode: Optional[Union[str, ClientCertMode]]
        cloning_info: Optional[CloningInfo]
        container_size: Optional[int]
        custom_domain_verification_id: Optional[str]
        daily_memory_time_quota: Optional[int]
        dapr_config: Optional[DaprConfig]
        default_host_name: Optional[str]
        dns_configuration: Optional[SiteDnsConfig]
        enabled: Optional[bool]
        enabled_host_names: Optional[list[str]]
        end_to_end_encryption_enabled: Optional[bool]
        function_app_config: Optional[FunctionAppConfig]
        host_name_ssl_states: Optional[list[HostNameSslState]]
        host_names: Optional[list[str]]
        host_names_disabled: Optional[bool]
        hosting_environment_profile: Optional[HostingEnvironmentProfile]
        https_only: Optional[bool]
        hyper_v: Optional[bool]
        in_progress_operation_id: Optional[str]
        ip_mode: Optional[Union[str, IPMode]]
        is_default_container: Optional[bool]
        is_xenon: Optional[bool]
        key_vault_reference_identity: Optional[str]
        last_modified_time_utc: Optional[datetime]
        managed_environment_id: Optional[str]
        max_number_of_workers: Optional[int]
        outbound_ip_addresses: Optional[str]
        outbound_vnet_routing: Optional[OutboundVnetRouting]
        possible_outbound_ip_addresses: Optional[str]
        public_network_access: Optional[str]
        redundancy_mode: Optional[Union[str, RedundancyMode]]
        repository_site_name: Optional[str]
        reserved: Optional[bool]
        resource_config: Optional[ResourceConfig]
        resource_group: Optional[str]
        scm_site_also_stopped: Optional[bool]
        server_farm_id: Optional[str]
        site_config: Optional[SiteConfig]
        sku: Optional[str]
        slot_swap_status: Optional[SlotSwapStatus]
        ssh_enabled: Optional[bool]
        state: Optional[str]
        storage_account_required: Optional[bool]
        suspended_till: Optional[datetime]
        target_swap_slot: Optional[str]
        traffic_manager_host_names: Optional[list[str]]
        usage_state: Optional[Union[str, UsageState]]
        virtual_network_subnet_id: Optional[str]
        workload_profile_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                auto_generated_domain_name_label_scope: Optional[Union[str, AutoGeneratedDomainNameLabelScope]] = ..., 
                client_affinity_enabled: Optional[bool] = ..., 
                client_affinity_partitioning_enabled: Optional[bool] = ..., 
                client_affinity_proxy_enabled: Optional[bool] = ..., 
                client_cert_enabled: Optional[bool] = ..., 
                client_cert_exclusion_paths: Optional[str] = ..., 
                client_cert_mode: Optional[Union[str, ClientCertMode]] = ..., 
                cloning_info: Optional[CloningInfo] = ..., 
                container_size: Optional[int] = ..., 
                custom_domain_verification_id: Optional[str] = ..., 
                daily_memory_time_quota: Optional[int] = ..., 
                dapr_config: Optional[DaprConfig] = ..., 
                dns_configuration: Optional[SiteDnsConfig] = ..., 
                enabled: Optional[bool] = ..., 
                end_to_end_encryption_enabled: Optional[bool] = ..., 
                function_app_config: Optional[FunctionAppConfig] = ..., 
                host_name_ssl_states: Optional[list[HostNameSslState]] = ..., 
                host_names_disabled: Optional[bool] = ..., 
                hosting_environment_profile: Optional[HostingEnvironmentProfile] = ..., 
                https_only: Optional[bool] = ..., 
                hyper_v: Optional[bool] = ..., 
                ip_mode: Optional[Union[str, IPMode]] = ..., 
                is_xenon: Optional[bool] = ..., 
                key_vault_reference_identity: Optional[str] = ..., 
                managed_environment_id: Optional[str] = ..., 
                outbound_vnet_routing: Optional[OutboundVnetRouting] = ..., 
                public_network_access: Optional[str] = ..., 
                redundancy_mode: Optional[Union[str, RedundancyMode]] = ..., 
                reserved: Optional[bool] = ..., 
                resource_config: Optional[ResourceConfig] = ..., 
                scm_site_also_stopped: Optional[bool] = ..., 
                server_farm_id: Optional[str] = ..., 
                site_config: Optional[SiteConfig] = ..., 
                ssh_enabled: Optional[bool] = ..., 
                storage_account_required: Optional[bool] = ..., 
                virtual_network_subnet_id: Optional[str] = ..., 
                workload_profile_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteRuntimeState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        READY = "READY"
        STOPPED = "STOPPED"
        UNKNOWN = "UNKNOWN"


    class azure.mgmt.web.models.SiteSourceControl(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SiteSourceControlProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SiteSourceControlProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SiteSourceControlProperties(_Model):
        branch: Optional[str]
        deployment_rollback_enabled: Optional[bool]
        git_hub_action_configuration: Optional[GitHubActionConfiguration]
        is_git_hub_action: Optional[bool]
        is_manual_integration: Optional[bool]
        is_mercurial: Optional[bool]
        repo_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                branch: Optional[str] = ..., 
                deployment_rollback_enabled: Optional[bool] = ..., 
                git_hub_action_configuration: Optional[GitHubActionConfiguration] = ..., 
                is_git_hub_action: Optional[bool] = ..., 
                is_manual_integration: Optional[bool] = ..., 
                is_mercurial: Optional[bool] = ..., 
                repo_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SiteUpdateStrategyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        RECREATE = "Recreate"
        ROLLING_UPDATE = "RollingUpdate"


    class azure.mgmt.web.models.SkuCapacity(_Model):
        default: Optional[int]
        elastic_maximum: Optional[int]
        maximum: Optional[int]
        minimum: Optional[int]
        scale_type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                default: Optional[int] = ..., 
                elastic_maximum: Optional[int] = ..., 
                maximum: Optional[int] = ..., 
                minimum: Optional[int] = ..., 
                scale_type: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SkuDescription(_Model):
        capabilities: Optional[list[Capability]]
        capacity: Optional[int]
        family: Optional[str]
        locations: Optional[list[str]]
        name: Optional[str]
        size: Optional[str]
        sku_capacity: Optional[SkuCapacity]
        tier: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                capabilities: Optional[list[Capability]] = ..., 
                capacity: Optional[int] = ..., 
                family: Optional[str] = ..., 
                locations: Optional[list[str]] = ..., 
                name: Optional[str] = ..., 
                size: Optional[str] = ..., 
                sku_capacity: Optional[SkuCapacity] = ..., 
                tier: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SkuInfo(_Model):
        capacity: Optional[SkuCapacity]
        resource_type: Optional[str]
        sku: Optional[SkuDescription]

        @overload
        def __init__(
                self, 
                *, 
                capacity: Optional[SkuCapacity] = ..., 
                resource_type: Optional[str] = ..., 
                sku: Optional[SkuDescription] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SkuInfos(_Model):
        resource_type: Optional[str]
        skus: Optional[list[GlobalCsmSkuDescription]]

        @overload
        def __init__(
                self, 
                *, 
                resource_type: Optional[str] = ..., 
                skus: Optional[list[GlobalCsmSkuDescription]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SkuName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BASIC = "Basic"
        DYNAMIC = "Dynamic"
        ELASTIC_ISOLATED = "ElasticIsolated"
        ELASTIC_PREMIUM = "ElasticPremium"
        FLEX_CONSUMPTION = "FlexConsumption"
        FREE = "Free"
        ISOLATED = "Isolated"
        ISOLATED_V2 = "IsolatedV2"
        PREMIUM = "Premium"
        PREMIUM_CONTAINER = "PremiumContainer"
        PREMIUM_V2 = "PremiumV2"
        PREMIUM_V3 = "PremiumV3"
        SHARED = "Shared"
        STANDARD = "Standard"


    class azure.mgmt.web.models.SlotConfigNames(_Model):
        app_setting_names: Optional[list[str]]
        azure_storage_config_names: Optional[list[str]]
        connection_string_names: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                app_setting_names: Optional[list[str]] = ..., 
                azure_storage_config_names: Optional[list[str]] = ..., 
                connection_string_names: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SlotConfigNamesResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SlotConfigNames]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SlotConfigNames] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SlotDifference(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[SlotDifferenceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SlotDifferenceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SlotDifferenceProperties(_Model):
        description: Optional[str]
        diff_rule: Optional[str]
        level: Optional[str]
        setting_name: Optional[str]
        setting_type: Optional[str]
        value_in_current_slot: Optional[str]
        value_in_target_slot: Optional[str]


    class azure.mgmt.web.models.SlotSwapStatus(_Model):
        destination_slot_name: Optional[str]
        source_slot_name: Optional[str]
        timestamp_utc: Optional[datetime]


    class azure.mgmt.web.models.SlowRequestsBasedTrigger(_Model):
        count: Optional[int]
        path: Optional[str]
        time_interval: Optional[str]
        time_taken: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                count: Optional[int] = ..., 
                path: Optional[str] = ..., 
                time_interval: Optional[str] = ..., 
                time_taken: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Snapshot(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[SnapshotProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SnapshotProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SnapshotProperties(_Model):
        time: Optional[str]


    class azure.mgmt.web.models.SnapshotRecoverySource(_Model):
        id: Optional[str]
        location: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                id: Optional[str] = ..., 
                location: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SnapshotRestoreRequest(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[SnapshotRestoreRequestProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SnapshotRestoreRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SnapshotRestoreRequestProperties(_Model):
        ignore_conflicting_host_names: Optional[bool]
        overwrite: bool
        recover_configuration: Optional[bool]
        recovery_source: Optional[SnapshotRecoverySource]
        snapshot_time: Optional[str]
        use_dr_secondary: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                ignore_conflicting_host_names: Optional[bool] = ..., 
                overwrite: bool, 
                recover_configuration: Optional[bool] = ..., 
                recovery_source: Optional[SnapshotRecoverySource] = ..., 
                snapshot_time: Optional[str] = ..., 
                use_dr_secondary: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Solution(_Model):
        data: Optional[list[list[NameValuePair]]]
        description: Optional[str]
        display_name: Optional[str]
        id: Optional[float]
        metadata: Optional[list[list[NameValuePair]]]
        order: Optional[float]
        type: Optional[Union[str, SolutionType]]

        @overload
        def __init__(
                self, 
                *, 
                data: Optional[list[list[NameValuePair]]] = ..., 
                description: Optional[str] = ..., 
                display_name: Optional[str] = ..., 
                id: Optional[float] = ..., 
                metadata: Optional[list[list[NameValuePair]]] = ..., 
                order: Optional[float] = ..., 
                type: Optional[Union[str, SolutionType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SolutionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BEST_PRACTICES = "BestPractices"
        DEEP_INVESTIGATION = "DeepInvestigation"
        QUICK_SOLUTION = "QuickSolution"


    class azure.mgmt.web.models.SourceControl(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SourceControlProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SourceControlProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SourceControlProperties(_Model):
        expiration_time: Optional[datetime]
        refresh_token: Optional[str]
        token: Optional[str]
        token_secret: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                expiration_time: Optional[datetime] = ..., 
                refresh_token: Optional[str] = ..., 
                token: Optional[str] = ..., 
                token_secret: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SslState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DISABLED = "Disabled"
        IP_BASED_ENABLED = "IpBasedEnabled"
        SNI_ENABLED = "SniEnabled"


    class azure.mgmt.web.models.StackMajorVersion(_Model):
        app_settings_dictionary: Optional[dict[str, Any]]
        application_insights: Optional[bool]
        display_version: Optional[str]
        is_default: Optional[bool]
        is_deprecated: Optional[bool]
        is_hidden: Optional[bool]
        is_preview: Optional[bool]
        minor_versions: Optional[list[StackMinorVersion]]
        runtime_version: Optional[str]
        site_config_properties_dictionary: Optional[dict[str, Any]]

        @overload
        def __init__(
                self, 
                *, 
                app_settings_dictionary: Optional[dict[str, Any]] = ..., 
                application_insights: Optional[bool] = ..., 
                display_version: Optional[str] = ..., 
                is_default: Optional[bool] = ..., 
                is_deprecated: Optional[bool] = ..., 
                is_hidden: Optional[bool] = ..., 
                is_preview: Optional[bool] = ..., 
                minor_versions: Optional[list[StackMinorVersion]] = ..., 
                runtime_version: Optional[str] = ..., 
                site_config_properties_dictionary: Optional[dict[str, Any]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StackMinorVersion(_Model):
        display_version: Optional[str]
        is_default: Optional[bool]
        is_remote_debugging_enabled: Optional[bool]
        runtime_version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                display_version: Optional[str] = ..., 
                is_default: Optional[bool] = ..., 
                is_remote_debugging_enabled: Optional[bool] = ..., 
                runtime_version: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StackPreferredOs(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        LINUX = "Linux"
        WINDOWS = "Windows"


    class azure.mgmt.web.models.StagingEnvironmentPolicy(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        DISABLED = "Disabled"
        ENABLED = "Enabled"


    class azure.mgmt.web.models.StampCapacity(_Model):
        available_capacity: Optional[int]
        compute_mode: Optional[Union[str, ComputeModeOptions]]
        exclude_from_capacity_allocation: Optional[bool]
        is_applicable_for_all_compute_modes: Optional[bool]
        is_linux: Optional[bool]
        name: Optional[str]
        site_mode: Optional[str]
        total_capacity: Optional[int]
        unit: Optional[str]
        worker_size: Optional[Union[str, WorkerSizeOptions]]
        worker_size_id: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                available_capacity: Optional[int] = ..., 
                compute_mode: Optional[Union[str, ComputeModeOptions]] = ..., 
                exclude_from_capacity_allocation: Optional[bool] = ..., 
                is_applicable_for_all_compute_modes: Optional[bool] = ..., 
                is_linux: Optional[bool] = ..., 
                name: Optional[str] = ..., 
                site_mode: Optional[str] = ..., 
                total_capacity: Optional[int] = ..., 
                unit: Optional[str] = ..., 
                worker_size: Optional[Union[str, WorkerSizeOptions]] = ..., 
                worker_size_id: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSite(_Model):
        allow_config_file_updates: Optional[bool]
        branch: Optional[str]
        build_properties: Optional[StaticSiteBuildProperties]
        content_distribution_endpoint: Optional[str]
        custom_domains: Optional[list[str]]
        database_connections: Optional[list[DatabaseConnectionOverview]]
        default_hostname: Optional[str]
        enterprise_grade_cdn_status: Optional[Union[str, EnterpriseGradeCdnStatus]]
        key_vault_reference_identity: Optional[str]
        linked_backends: Optional[list[StaticSiteLinkedBackend]]
        private_endpoint_connections: Optional[list[ResponseMessageEnvelopeRemotePrivateEndpointConnection]]
        provider: Optional[str]
        public_network_access: Optional[str]
        repository_token: Optional[str]
        repository_url: Optional[str]
        staging_environment_policy: Optional[Union[str, StagingEnvironmentPolicy]]
        template_properties: Optional[StaticSiteTemplateOptions]
        user_provided_function_apps: Optional[list[StaticSiteUserProvidedFunctionApp]]

        @overload
        def __init__(
                self, 
                *, 
                allow_config_file_updates: Optional[bool] = ..., 
                branch: Optional[str] = ..., 
                build_properties: Optional[StaticSiteBuildProperties] = ..., 
                enterprise_grade_cdn_status: Optional[Union[str, EnterpriseGradeCdnStatus]] = ..., 
                provider: Optional[str] = ..., 
                public_network_access: Optional[str] = ..., 
                repository_token: Optional[str] = ..., 
                repository_url: Optional[str] = ..., 
                staging_environment_policy: Optional[Union[str, StagingEnvironmentPolicy]] = ..., 
                template_properties: Optional[StaticSiteTemplateOptions] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteARMResource(TrackedResource):
        id: str
        identity: Optional[ManagedServiceIdentity]
        kind: Optional[str]
        location: str
        name: str
        properties: Optional[StaticSite]
        sku: Optional[SkuDescription]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                identity: Optional[ManagedServiceIdentity] = ..., 
                kind: Optional[str] = ..., 
                location: str, 
                properties: Optional[StaticSite] = ..., 
                sku: Optional[SkuDescription] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteBasicAuthPropertiesARMResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[StaticSiteBasicAuthPropertiesARMResourceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteBasicAuthPropertiesARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteBasicAuthPropertiesARMResourceProperties(_Model):
        applicable_environments_mode: str
        environments: Optional[list[str]]
        password: Optional[str]
        secret_state: Optional[str]
        secret_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                applicable_environments_mode: str, 
                environments: Optional[list[str]] = ..., 
                password: Optional[str] = ..., 
                secret_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteBuildARMResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[StaticSiteBuildARMResourceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteBuildARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteBuildARMResourceProperties(_Model):
        build_id: Optional[str]
        created_time_utc: Optional[datetime]
        database_connections: Optional[list[DatabaseConnectionOverview]]
        hostname: Optional[str]
        last_updated_on: Optional[datetime]
        linked_backends: Optional[list[StaticSiteLinkedBackend]]
        pull_request_title: Optional[str]
        source_branch: Optional[str]
        status: Optional[Union[str, BuildStatus]]
        user_provided_function_apps: Optional[list[StaticSiteUserProvidedFunctionApp]]


    class azure.mgmt.web.models.StaticSiteBuildProperties(_Model):
        api_build_command: Optional[str]
        api_location: Optional[str]
        app_artifact_location: Optional[str]
        app_build_command: Optional[str]
        app_location: Optional[str]
        github_action_secret_name_override: Optional[str]
        output_location: Optional[str]
        skip_github_action_workflow_generation: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                api_build_command: Optional[str] = ..., 
                api_location: Optional[str] = ..., 
                app_artifact_location: Optional[str] = ..., 
                app_build_command: Optional[str] = ..., 
                app_location: Optional[str] = ..., 
                github_action_secret_name_override: Optional[str] = ..., 
                output_location: Optional[str] = ..., 
                skip_github_action_workflow_generation: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteCustomDomainOverviewARMResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[StaticSiteCustomDomainOverviewARMResourceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteCustomDomainOverviewARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteCustomDomainOverviewARMResourceProperties(_Model):
        created_on: Optional[datetime]
        domain_name: Optional[str]
        error_message: Optional[str]
        status: Optional[Union[str, CustomDomainStatus]]
        validation_token: Optional[str]


    class azure.mgmt.web.models.StaticSiteCustomDomainRequestPropertiesARMResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteCustomDomainRequestPropertiesARMResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteCustomDomainRequestPropertiesARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteCustomDomainRequestPropertiesARMResourceProperties(_Model):
        validation_method: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                validation_method: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteDatabaseConnectionConfigurationFileOverview(_Model):
        contents: Optional[str]
        file_name: Optional[str]
        type: Optional[str]


    class azure.mgmt.web.models.StaticSiteFunctionOverviewARMResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteFunctionOverviewARMResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteFunctionOverviewARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteFunctionOverviewARMResourceProperties(_Model):
        function_name: Optional[str]
        trigger_type: Optional[Union[str, TriggerTypes]]


    class azure.mgmt.web.models.StaticSiteLinkedBackend(_Model):
        backend_resource_id: Optional[str]
        created_on: Optional[datetime]
        provisioning_state: Optional[str]
        region: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                backend_resource_id: Optional[str] = ..., 
                region: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteLinkedBackendARMResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[StaticSiteLinkedBackendARMResourceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteLinkedBackendARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteLinkedBackendARMResourceProperties(_Model):
        backend_resource_id: Optional[str]
        created_on: Optional[datetime]
        provisioning_state: Optional[str]
        region: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                backend_resource_id: Optional[str] = ..., 
                region: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSitePatchResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSite]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSite] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteResetPropertiesARMResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteResetPropertiesARMResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteResetPropertiesARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteResetPropertiesARMResourceProperties(_Model):
        repository_token: Optional[str]
        should_update_repository: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                repository_token: Optional[str] = ..., 
                should_update_repository: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteTemplateOptions(_Model):
        description: Optional[str]
        is_private: Optional[bool]
        owner: Optional[str]
        repository_name: Optional[str]
        template_repository_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                is_private: Optional[bool] = ..., 
                owner: Optional[str] = ..., 
                repository_name: Optional[str] = ..., 
                template_repository_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserARMResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteUserARMResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteUserARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserARMResourceProperties(_Model):
        display_name: Optional[str]
        provider: Optional[str]
        roles: Optional[str]
        user_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                roles: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserInvitationRequestResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteUserInvitationRequestResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteUserInvitationRequestResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserInvitationRequestResourceProperties(_Model):
        domain: Optional[str]
        num_hours_to_expiration: Optional[int]
        provider: Optional[str]
        roles: Optional[str]
        user_details: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                domain: Optional[str] = ..., 
                num_hours_to_expiration: Optional[int] = ..., 
                provider: Optional[str] = ..., 
                roles: Optional[str] = ..., 
                user_details: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserInvitationResponseResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteUserInvitationResponseResourceProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteUserInvitationResponseResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserInvitationResponseResourceProperties(_Model):
        expires_on: Optional[datetime]
        invitation_url: Optional[str]


    class azure.mgmt.web.models.StaticSiteUserProvidedFunctionApp(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteUserProvidedFunctionAppProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteUserProvidedFunctionAppProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserProvidedFunctionAppARMResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[StaticSiteUserProvidedFunctionAppARMResourceProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteUserProvidedFunctionAppARMResourceProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserProvidedFunctionAppARMResourceProperties(_Model):
        created_on: Optional[datetime]
        function_app_region: Optional[str]
        function_app_resource_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                function_app_region: Optional[str] = ..., 
                function_app_resource_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteUserProvidedFunctionAppProperties(_Model):
        created_on: Optional[datetime]
        function_app_region: Optional[str]
        function_app_resource_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                function_app_region: Optional[str] = ..., 
                function_app_resource_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteZipDeployment(_Model):
        api_zip_url: Optional[str]
        app_zip_url: Optional[str]
        deployment_title: Optional[str]
        function_language: Optional[str]
        provider: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                api_zip_url: Optional[str] = ..., 
                app_zip_url: Optional[str] = ..., 
                deployment_title: Optional[str] = ..., 
                function_language: Optional[str] = ..., 
                provider: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StaticSiteZipDeploymentARMResource(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSiteZipDeployment]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSiteZipDeployment] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSitesWorkflowPreview(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSitesWorkflowPreviewProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSitesWorkflowPreviewProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSitesWorkflowPreviewProperties(_Model):
        contents: Optional[str]
        path: Optional[str]


    class azure.mgmt.web.models.StaticSitesWorkflowPreviewRequest(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StaticSitesWorkflowPreviewRequestProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StaticSitesWorkflowPreviewRequestProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StaticSitesWorkflowPreviewRequestProperties(_Model):
        branch: Optional[str]
        build_properties: Optional[StaticSiteBuildProperties]
        repository_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                branch: Optional[str] = ..., 
                build_properties: Optional[StaticSiteBuildProperties] = ..., 
                repository_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.Status(_Model):
        message: Optional[str]
        status_id: Optional[Union[str, InsightStatus]]

        @overload
        def __init__(
                self, 
                *, 
                message: Optional[str] = ..., 
                status_id: Optional[Union[str, InsightStatus]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StatusCodesBasedTrigger(_Model):
        count: Optional[int]
        path: Optional[str]
        status: Optional[int]
        sub_status: Optional[int]
        time_interval: Optional[str]
        win32_status: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                count: Optional[int] = ..., 
                path: Optional[str] = ..., 
                status: Optional[int] = ..., 
                sub_status: Optional[int] = ..., 
                time_interval: Optional[str] = ..., 
                win32_status: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StatusCodesRangeBasedTrigger(_Model):
        count: Optional[int]
        path: Optional[str]
        status_codes: Optional[str]
        time_interval: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                count: Optional[int] = ..., 
                path: Optional[str] = ..., 
                status_codes: Optional[str] = ..., 
                time_interval: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StatusOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CREATING = "Creating"
        PENDING = "Pending"
        READY = "Ready"


    class azure.mgmt.web.models.StorageMigrationOptions(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StorageMigrationOptionsProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StorageMigrationOptionsProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StorageMigrationOptionsProperties(_Model):
        azurefiles_connection_string: str
        azurefiles_share: str
        block_write_access_to_site: Optional[bool]
        switch_site_after_migration: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                azurefiles_connection_string: str, 
                azurefiles_share: str, 
                block_write_access_to_site: Optional[bool] = ..., 
                switch_site_after_migration: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StorageMigrationResponse(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[StorageMigrationResponseProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[StorageMigrationResponseProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StorageMigrationResponseProperties(_Model):
        operation_id: Optional[str]


    class azure.mgmt.web.models.StorageMount(_Model):
        credentials_key_vault_reference: Optional[KeyVaultReferenceWithStatus]
        destination_path: Optional[str]
        name: Optional[str]
        source: Optional[str]
        type: Optional[Union[str, StorageMountType]]

        @overload
        def __init__(
                self, 
                *, 
                credentials_key_vault_reference: Optional[KeyVaultReferenceWithStatus] = ..., 
                destination_path: Optional[str] = ..., 
                name: Optional[str] = ..., 
                source: Optional[str] = ..., 
                type: Optional[Union[str, StorageMountType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.StorageMountType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        AZURE_FILES = "AzureFiles"
        FILE_SHARE = "FileShare"
        LOCAL_STORAGE = "LocalStorage"


    class azure.mgmt.web.models.StorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        LOCAL_NODE = "LocalNode"
        NETWORK_FILE_SYSTEM = "NetworkFileSystem"


    class azure.mgmt.web.models.StringDictionary(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[dict[str, str]]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.StringList(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[list[str]]
        type: str

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SupportTopic(_Model):
        id: Optional[str]
        pes_id: Optional[str]


    class azure.mgmt.web.models.SupportedTlsVersions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ONE0 = "1.0"
        ONE1 = "1.1"
        ONE2 = "1.2"
        ONE3 = "1.3"


    class azure.mgmt.web.models.SwiftVirtualNetwork(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[SwiftVirtualNetworkProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[SwiftVirtualNetworkProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.SwiftVirtualNetworkProperties(_Model):
        subnet_resource_id: Optional[str]
        swift_supported: Optional[bool]

        @overload
        def __init__(
                self, 
                *, 
                subnet_resource_id: Optional[str] = ..., 
                swift_supported: Optional[bool] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.SystemData(_Model):
        created_at: Optional[datetime]
        created_by: Optional[str]
        created_by_type: Optional[Union[str, CreatedByType]]
        last_modified_at: Optional[datetime]
        last_modified_by: Optional[str]
        last_modified_by_type: Optional[Union[str, CreatedByType]]

        @overload
        def __init__(
                self, 
                *, 
                created_at: Optional[datetime] = ..., 
                created_by: Optional[str] = ..., 
                created_by_type: Optional[Union[str, CreatedByType]] = ..., 
                last_modified_at: Optional[datetime] = ..., 
                last_modified_by: Optional[str] = ..., 
                last_modified_by_type: Optional[Union[str, CreatedByType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TlsCipherSuites(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        TLS_AES128_GCM_SHA256 = "TLS_AES_128_GCM_SHA256"
        TLS_AES256_GCM_SHA384 = "TLS_AES_256_GCM_SHA384"
        TLS_ECDHE_ECDSA_WITH_AES128_CBC_SHA256 = "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256"
        TLS_ECDHE_ECDSA_WITH_AES128_GCM_SHA256 = "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256"
        TLS_ECDHE_ECDSA_WITH_AES256_GCM_SHA384 = "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384"
        TLS_ECDHE_RSA_WITH_AES128_CBC_SHA = "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA"
        TLS_ECDHE_RSA_WITH_AES128_CBC_SHA256 = "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256"
        TLS_ECDHE_RSA_WITH_AES128_GCM_SHA256 = "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256"
        TLS_ECDHE_RSA_WITH_AES256_CBC_SHA = "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA"
        TLS_ECDHE_RSA_WITH_AES256_CBC_SHA384 = "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384"
        TLS_ECDHE_RSA_WITH_AES256_GCM_SHA384 = "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384"
        TLS_RSA_WITH_AES128_CBC_SHA = "TLS_RSA_WITH_AES_128_CBC_SHA"
        TLS_RSA_WITH_AES128_CBC_SHA256 = "TLS_RSA_WITH_AES_128_CBC_SHA256"
        TLS_RSA_WITH_AES128_GCM_SHA256 = "TLS_RSA_WITH_AES_128_GCM_SHA256"
        TLS_RSA_WITH_AES256_CBC_SHA = "TLS_RSA_WITH_AES_256_CBC_SHA"
        TLS_RSA_WITH_AES256_CBC_SHA256 = "TLS_RSA_WITH_AES_256_CBC_SHA256"
        TLS_RSA_WITH_AES256_GCM_SHA384 = "TLS_RSA_WITH_AES_256_GCM_SHA384"


    class azure.mgmt.web.models.TokenStore(_Model):
        azure_blob_storage: Optional[BlobStorageTokenStore]
        enabled: Optional[bool]
        file_system: Optional[FileSystemTokenStore]
        token_refresh_extension_hours: Optional[float]

        @overload
        def __init__(
                self, 
                *, 
                azure_blob_storage: Optional[BlobStorageTokenStore] = ..., 
                enabled: Optional[bool] = ..., 
                file_system: Optional[FileSystemTokenStore] = ..., 
                token_refresh_extension_hours: Optional[float] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TrackedResource(Resource):
        id: str
        location: str
        name: str
        system_data: SystemData
        tags: Optional[dict[str, str]]
        type: str

        @overload
        def __init__(
                self, 
                *, 
                location: str, 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TriggerTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        HTTP_TRIGGER = "HttpTrigger"
        UNKNOWN = "Unknown"


    class azure.mgmt.web.models.TriggeredJobHistory(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[TriggeredJobHistoryProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[TriggeredJobHistoryProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.TriggeredJobHistoryProperties(_Model):
        runs: Optional[list[TriggeredJobRun]]

        @overload
        def __init__(
                self, 
                *, 
                runs: Optional[list[TriggeredJobRun]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TriggeredJobRun(_Model):
        duration: Optional[str]
        end_time: Optional[datetime]
        error_url: Optional[str]
        job_name: Optional[str]
        output_url: Optional[str]
        start_time: Optional[datetime]
        status: Optional[Union[str, TriggeredWebJobStatus]]
        trigger: Optional[str]
        url: Optional[str]
        web_job_id: Optional[str]
        web_job_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                duration: Optional[str] = ..., 
                end_time: Optional[datetime] = ..., 
                error_url: Optional[str] = ..., 
                job_name: Optional[str] = ..., 
                output_url: Optional[str] = ..., 
                start_time: Optional[datetime] = ..., 
                status: Optional[Union[str, TriggeredWebJobStatus]] = ..., 
                trigger: Optional[str] = ..., 
                url: Optional[str] = ..., 
                web_job_id: Optional[str] = ..., 
                web_job_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TriggeredWebJob(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[TriggeredWebJobProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[TriggeredWebJobProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.TriggeredWebJobProperties(_Model):
        error: Optional[str]
        extra_info_url: Optional[str]
        history_url: Optional[str]
        latest_run: Optional[TriggeredJobRun]
        public_network_access: Optional[str]
        run_command: Optional[str]
        scheduler_logs_url: Optional[str]
        settings: Optional[dict[str, Any]]
        storage_account_required: Optional[bool]
        url: Optional[str]
        using_sdk: Optional[bool]
        web_job_type: Optional[Union[str, WebJobType]]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[str] = ..., 
                extra_info_url: Optional[str] = ..., 
                history_url: Optional[str] = ..., 
                latest_run: Optional[TriggeredJobRun] = ..., 
                public_network_access: Optional[str] = ..., 
                run_command: Optional[str] = ..., 
                scheduler_logs_url: Optional[str] = ..., 
                settings: Optional[dict[str, Any]] = ..., 
                storage_account_required: Optional[bool] = ..., 
                url: Optional[str] = ..., 
                using_sdk: Optional[bool] = ..., 
                web_job_type: Optional[Union[str, WebJobType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TriggeredWebJobStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ABORTED = "Aborted"
        ERROR = "Error"
        FAILED = "Failed"
        RUNNING = "Running"
        SUCCESS = "Success"


    class azure.mgmt.web.models.Twitter(_Model):
        enabled: Optional[bool]
        registration: Optional[TwitterRegistration]

        @overload
        def __init__(
                self, 
                *, 
                enabled: Optional[bool] = ..., 
                registration: Optional[TwitterRegistration] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.TwitterRegistration(_Model):
        consumer_key: Optional[str]
        consumer_secret_setting_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                consumer_key: Optional[str] = ..., 
                consumer_secret_setting_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.UnauthenticatedClientAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALLOW_ANONYMOUS = "AllowAnonymous"
        REDIRECT_TO_LOGIN_PAGE = "RedirectToLoginPage"


    class azure.mgmt.web.models.UnauthenticatedClientActionV2(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ALLOW_ANONYMOUS = "AllowAnonymous"
        REDIRECT_TO_LOGIN_PAGE = "RedirectToLoginPage"
        RETURN401 = "Return401"
        RETURN403 = "Return403"


    class azure.mgmt.web.models.UpgradeAvailability(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        NONE = "None"
        READY = "Ready"


    class azure.mgmt.web.models.UpgradePreference(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        EARLY = "Early"
        LATE = "Late"
        MANUAL = "Manual"
        NONE = "None"


    class azure.mgmt.web.models.Usage(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[UsageProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[UsageProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.UsageProperties(_Model):
        compute_mode: Optional[Union[str, ComputeModeOptions]]
        current_value: Optional[int]
        display_name: Optional[str]
        limit: Optional[int]
        next_reset_time: Optional[datetime]
        resource_name: Optional[str]
        site_mode: Optional[str]
        unit: Optional[str]


    class azure.mgmt.web.models.UsageState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        EXCEEDED = "Exceeded"
        NORMAL = "Normal"


    class azure.mgmt.web.models.User(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[UserProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[UserProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.UserAssignedIdentity(_Model):
        client_id: Optional[str]
        principal_id: Optional[str]


    class azure.mgmt.web.models.UserProperties(_Model):
        publishing_password: Optional[str]
        publishing_password_hash: Optional[str]
        publishing_password_hash_salt: Optional[str]
        publishing_user_name: str
        scm_uri: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                publishing_password: Optional[str] = ..., 
                publishing_password_hash: Optional[str] = ..., 
                publishing_password_hash_salt: Optional[str] = ..., 
                publishing_user_name: str, 
                scm_uri: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ValidateProperties(_Model):
        app_service_environment: Optional[AppServiceEnvironment]
        capacity: Optional[int]
        container_image_platform: Optional[str]
        container_image_repository: Optional[str]
        container_image_tag: Optional[str]
        container_registry_base_url: Optional[str]
        container_registry_password: Optional[str]
        container_registry_username: Optional[str]
        hosting_environment: Optional[str]
        is_spot: Optional[bool]
        is_xenon: Optional[bool]
        need_linux_workers: Optional[bool]
        server_farm_id: Optional[str]
        sku_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                app_service_environment: Optional[AppServiceEnvironment] = ..., 
                capacity: Optional[int] = ..., 
                container_image_platform: Optional[str] = ..., 
                container_image_repository: Optional[str] = ..., 
                container_image_tag: Optional[str] = ..., 
                container_registry_base_url: Optional[str] = ..., 
                container_registry_password: Optional[str] = ..., 
                container_registry_username: Optional[str] = ..., 
                hosting_environment: Optional[str] = ..., 
                is_spot: Optional[bool] = ..., 
                is_xenon: Optional[bool] = ..., 
                need_linux_workers: Optional[bool] = ..., 
                server_farm_id: Optional[str] = ..., 
                sku_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ValidateRequest(_Model):
        location: str
        name: str
        properties: ValidateProperties
        type: Union[str, ValidateResourceTypes]

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                location: str, 
                name: str, 
                properties: ValidateProperties, 
                type: Union[str, ValidateResourceTypes]
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.ValidateResourceTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        MICROSOFT_WEB_HOSTING_ENVIRONMENTS = "Microsoft.Web/hostingEnvironments"
        SERVER_FARM = "ServerFarm"
        SITE = "Site"


    class azure.mgmt.web.models.ValidateResponse(_Model):
        error: Optional[ValidateResponseError]
        status: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[ValidateResponseError] = ..., 
                status: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.ValidateResponseError(_Model):
        code: Optional[str]
        message: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                message: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VirtualApplication(_Model):
        physical_path: Optional[str]
        preload_enabled: Optional[bool]
        virtual_directories: Optional[list[VirtualDirectory]]
        virtual_path: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                physical_path: Optional[str] = ..., 
                preload_enabled: Optional[bool] = ..., 
                virtual_directories: Optional[list[VirtualDirectory]] = ..., 
                virtual_path: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VirtualDirectory(_Model):
        physical_path: Optional[str]
        virtual_path: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                physical_path: Optional[str] = ..., 
                virtual_path: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VirtualIPMapping(_Model):
        in_use: Optional[bool]
        internal_http_port: Optional[int]
        internal_https_port: Optional[int]
        service_name: Optional[str]
        virtual_ip: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                in_use: Optional[bool] = ..., 
                internal_http_port: Optional[int] = ..., 
                internal_https_port: Optional[int] = ..., 
                service_name: Optional[str] = ..., 
                virtual_ip: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VirtualNetworkProfile(_Model):
        id: str
        name: Optional[str]
        subnet: Optional[str]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                id: str, 
                subnet: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VnetGateway(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[VnetGatewayProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[VnetGatewayProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.VnetGatewayProperties(_Model):
        vnet_name: Optional[str]
        vpn_package_uri: str

        @overload
        def __init__(
                self, 
                *, 
                vnet_name: Optional[str] = ..., 
                vpn_package_uri: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VnetInfo(_Model):
        cert_blob: Optional[str]
        cert_thumbprint: Optional[str]
        dns_servers: Optional[str]
        is_swift: Optional[bool]
        resync_required: Optional[bool]
        routes: Optional[list[VnetRoute]]
        vnet_resource_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                cert_blob: Optional[str] = ..., 
                dns_servers: Optional[str] = ..., 
                is_swift: Optional[bool] = ..., 
                vnet_resource_id: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VnetInfoResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[VnetInfo]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[VnetInfo] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.VnetParameters(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[VnetParametersProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[VnetParametersProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.VnetParametersProperties(_Model):
        subnet_resource_id: Optional[str]
        vnet_name: Optional[str]
        vnet_resource_group: Optional[str]
        vnet_subnet_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                subnet_resource_id: Optional[str] = ..., 
                vnet_name: Optional[str] = ..., 
                vnet_resource_group: Optional[str] = ..., 
                vnet_subnet_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VnetRoute(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[VnetRouteProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[VnetRouteProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.VnetRouteProperties(_Model):
        end_address: Optional[str]
        route_type: Optional[Union[str, RouteType]]
        start_address: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                end_address: Optional[str] = ..., 
                route_type: Optional[Union[str, RouteType]] = ..., 
                start_address: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VnetValidationFailureDetails(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[VnetValidationFailureDetailsProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[VnetValidationFailureDetailsProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.VnetValidationFailureDetailsProperties(_Model):
        failed: Optional[bool]
        failed_tests: Optional[list[VnetValidationTestFailure]]
        message: Optional[str]
        warnings: Optional[list[VnetValidationTestFailure]]

        @overload
        def __init__(
                self, 
                *, 
                failed: Optional[bool] = ..., 
                failed_tests: Optional[list[VnetValidationTestFailure]] = ..., 
                message: Optional[str] = ..., 
                warnings: Optional[list[VnetValidationTestFailure]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VnetValidationTestFailure(ProxyOnlyResource):
        id: str
        kind: str
        name: str
        properties: Optional[VnetValidationTestFailureProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[VnetValidationTestFailureProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.VnetValidationTestFailureProperties(_Model):
        details: Optional[str]
        test_name: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                details: Optional[str] = ..., 
                test_name: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.VolumeMount(_Model):
        container_mount_path: str
        data: Optional[str]
        read_only: Optional[bool]
        volume_sub_path: str

        @overload
        def __init__(
                self, 
                *, 
                container_mount_path: str, 
                data: Optional[str] = ..., 
                read_only: Optional[bool] = ..., 
                volume_sub_path: str
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WebAppMajorVersion(_Model):
        display_text: Optional[str]
        minor_versions: Optional[list[WebAppMinorVersion]]
        value: Optional[str]


    class azure.mgmt.web.models.WebAppMinorVersion(_Model):
        display_text: Optional[str]
        stack_settings: Optional[WebAppRuntimes]
        value: Optional[str]


    class azure.mgmt.web.models.WebAppRuntimeSettings(_Model):
        app_insights_settings: Optional[AppInsightsWebAppStackSettings]
        end_of_life_date: Optional[datetime]
        git_hub_action_settings: Optional[GitHubActionWebAppStackSettings]
        is_auto_update: Optional[bool]
        is_deprecated: Optional[bool]
        is_early_access: Optional[bool]
        is_hidden: Optional[bool]
        is_preview: Optional[bool]
        remote_debugging_supported: Optional[bool]
        runtime_version: Optional[str]


    class azure.mgmt.web.models.WebAppRuntimes(_Model):
        linux_container_settings: Optional[LinuxJavaContainerSettings]
        linux_runtime_settings: Optional[WebAppRuntimeSettings]
        windows_container_settings: Optional[WindowsJavaContainerSettings]
        windows_runtime_settings: Optional[WebAppRuntimeSettings]


    class azure.mgmt.web.models.WebAppStack(ProxyOnlyResource):
        id: str
        kind: str
        location: Optional[str]
        name: str
        properties: Optional[WebAppStackProperties]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[WebAppStackProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WebAppStackProperties(_Model):
        display_text: Optional[str]
        major_versions: Optional[list[WebAppMajorVersion]]
        preferred_os: Optional[Union[str, StackPreferredOs]]
        value: Optional[str]


    class azure.mgmt.web.models.WebJob(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[WebJobProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[WebJobProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WebJobProperties(_Model):
        error: Optional[str]
        extra_info_url: Optional[str]
        run_command: Optional[str]
        settings: Optional[dict[str, Any]]
        url: Optional[str]
        using_sdk: Optional[bool]
        web_job_type: Optional[Union[str, WebJobType]]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[str] = ..., 
                extra_info_url: Optional[str] = ..., 
                run_command: Optional[str] = ..., 
                settings: Optional[dict[str, Any]] = ..., 
                url: Optional[str] = ..., 
                using_sdk: Optional[bool] = ..., 
                web_job_type: Optional[Union[str, WebJobType]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WebJobType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        CONTINUOUS = "Continuous"
        TRIGGERED = "Triggered"


    class azure.mgmt.web.models.WebSiteInstanceStatus(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[WebSiteInstanceStatusProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[WebSiteInstanceStatusProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WebSiteInstanceStatusProperties(_Model):
        console_url: Optional[str]
        containers: Optional[dict[str, ContainerInfo]]
        detector_url: Optional[str]
        health_check_url: Optional[str]
        physical_zone: Optional[str]
        state: Optional[Union[str, SiteRuntimeState]]
        status_url: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                console_url: Optional[str] = ..., 
                containers: Optional[dict[str, ContainerInfo]] = ..., 
                detector_url: Optional[str] = ..., 
                health_check_url: Optional[str] = ..., 
                physical_zone: Optional[str] = ..., 
                state: Optional[Union[str, SiteRuntimeState]] = ..., 
                status_url: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WindowsJavaContainerSettings(_Model):
        end_of_life_date: Optional[datetime]
        is_auto_update: Optional[bool]
        is_deprecated: Optional[bool]
        is_early_access: Optional[bool]
        is_hidden: Optional[bool]
        is_preview: Optional[bool]
        java_container: Optional[str]
        java_container_version: Optional[str]


    class azure.mgmt.web.models.WorkerPool(_Model):
        compute_mode: Optional[Union[str, ComputeModeOptions]]
        instance_names: Optional[list[str]]
        worker_count: Optional[int]
        worker_size: Optional[str]
        worker_size_id: Optional[int]

        @overload
        def __init__(
                self, 
                *, 
                compute_mode: Optional[Union[str, ComputeModeOptions]] = ..., 
                worker_count: Optional[int] = ..., 
                worker_size: Optional[str] = ..., 
                worker_size_id: Optional[int] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkerPoolResource(ProxyResource):
        id: str
        kind: Optional[str]
        name: str
        properties: Optional[WorkerPool]
        sku: Optional[SkuDescription]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                properties: Optional[WorkerPool] = ..., 
                sku: Optional[SkuDescription] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkerSizeOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        D1 = "D1"
        D2 = "D2"
        D3 = "D3"
        DEFAULT = "Default"
        LARGE = "Large"
        LARGE_V3 = "LargeV3"
        MEDIUM = "Medium"
        MEDIUM_V3 = "MediumV3"
        NESTED_SMALL = "NestedSmall"
        NESTED_SMALL_LINUX = "NestedSmallLinux"
        SMALL = "Small"
        SMALL_V3 = "SmallV3"


    class azure.mgmt.web.models.Workflow(WorkflowResource):
        id: str
        identity: Optional[ManagedServiceIdentity]
        location: str
        name: str
        properties: Optional[WorkflowProperties]
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                identity: Optional[ManagedServiceIdentity] = ..., 
                location: Optional[str] = ..., 
                properties: Optional[WorkflowProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowArtifacts(_Model):
        app_settings: Optional[Any]
        files: Optional[dict[str, Any]]
        files_to_delete: Optional[list[str]]

        @overload
        def __init__(
                self, 
                *, 
                app_settings: Optional[Any] = ..., 
                files: Optional[dict[str, Any]] = ..., 
                files_to_delete: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowEnvelope(ProxyResource):
        id: str
        kind: Optional[str]
        location: Optional[str]
        name: str
        properties: Optional[WorkflowEnvelopeProperties]
        system_data: SystemData
        type: str

        @overload
        def __init__(
                self, 
                *, 
                kind: Optional[str] = ..., 
                location: Optional[str] = ..., 
                properties: Optional[WorkflowEnvelopeProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowEnvelopeProperties(_Model):
        files: Optional[dict[str, Any]]
        flow_state: Optional[Union[str, WorkflowState]]
        health: Optional[WorkflowHealth]

        @overload
        def __init__(
                self, 
                *, 
                files: Optional[dict[str, Any]] = ..., 
                flow_state: Optional[Union[str, WorkflowState]] = ..., 
                health: Optional[WorkflowHealth] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowErrorResponse(_Model):
        error: Optional[ErrorProperties]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[ErrorProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowHealth(_Model):
        error: Optional[ErrorEntity]
        state: Union[str, WorkflowHealthState]

        @overload
        def __init__(
                self, 
                *, 
                error: Optional[ErrorEntity] = ..., 
                state: Union[str, WorkflowHealthState]
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowHealthState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        HEALTHY = "Healthy"
        NOT_SPECIFIED = "NotSpecified"
        UNHEALTHY = "Unhealthy"
        UNKNOWN = "Unknown"


    class azure.mgmt.web.models.WorkflowOutputParameter(WorkflowParameter):
        description: str
        error: Optional[Any]
        metadata: any
        type: Union[str, ParameterType]
        value: any

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                metadata: Optional[Any] = ..., 
                type: Optional[Union[str, ParameterType]] = ..., 
                value: Optional[Any] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowParameter(_Model):
        description: Optional[str]
        metadata: Optional[Any]
        type: Optional[Union[str, ParameterType]]
        value: Optional[Any]

        @overload
        def __init__(
                self, 
                *, 
                description: Optional[str] = ..., 
                metadata: Optional[Any] = ..., 
                type: Optional[Union[str, ParameterType]] = ..., 
                value: Optional[Any] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowProperties(_Model):
        access_control: Optional[FlowAccessControlConfiguration]
        access_endpoint: Optional[str]
        changed_time: Optional[datetime]
        created_time: Optional[datetime]
        definition: Optional[Any]
        endpoints_configuration: Optional[FlowEndpointsConfiguration]
        integration_account: Optional[ResourceReference]
        integration_service_environment: Optional[ResourceReference]
        kind: Optional[Union[str, Kind]]
        parameters: Optional[dict[str, WorkflowParameter]]
        provisioning_state: Optional[Union[str, WorkflowProvisioningState]]
        sku: Optional[WorkflowSku]
        state: Optional[Union[str, WorkflowState]]
        version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                access_control: Optional[FlowAccessControlConfiguration] = ..., 
                definition: Optional[Any] = ..., 
                endpoints_configuration: Optional[FlowEndpointsConfiguration] = ..., 
                integration_account: Optional[ResourceReference] = ..., 
                integration_service_environment: Optional[ResourceReference] = ..., 
                kind: Optional[Union[str, Kind]] = ..., 
                parameters: Optional[dict[str, WorkflowParameter]] = ..., 
                state: Optional[Union[str, WorkflowState]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ACCEPTED = "Accepted"
        CANCELED = "Canceled"
        COMPLETED = "Completed"
        CREATED = "Created"
        CREATING = "Creating"
        DELETED = "Deleted"
        DELETING = "Deleting"
        FAILED = "Failed"
        IN_PROGRESS = "InProgress"
        MOVING = "Moving"
        NOT_SPECIFIED = "NotSpecified"
        PENDING = "Pending"
        READY = "Ready"
        REGISTERED = "Registered"
        REGISTERING = "Registering"
        RENEWING = "Renewing"
        RUNNING = "Running"
        SUCCEEDED = "Succeeded"
        UNREGISTERED = "Unregistered"
        UNREGISTERING = "Unregistering"
        UPDATING = "Updating"
        WAITING = "Waiting"


    class azure.mgmt.web.models.WorkflowResource(_Model):
        id: Optional[str]
        location: Optional[str]
        name: Optional[str]
        tags: Optional[dict[str, str]]
        type: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                location: Optional[str] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowRun(ProxyResource):
        id: str
        name: str
        properties: Optional[WorkflowRunProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                properties: Optional[WorkflowRunProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowRunAction(ProxyResource):
        id: str
        name: str
        properties: Optional[WorkflowRunActionProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                properties: Optional[WorkflowRunActionProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowRunActionProperties(_Model):
        code: Optional[str]
        correlation: Optional[RunActionCorrelation]
        end_time: Optional[datetime]
        error: Optional[Any]
        inputs_link: Optional[ContentLink]
        outputs_link: Optional[ContentLink]
        retry_history: Optional[list[RetryHistory]]
        start_time: Optional[datetime]
        status: Optional[Union[str, WorkflowStatus]]
        tracked_properties: Optional[Any]
        tracking_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                correlation: Optional[RunActionCorrelation] = ..., 
                retry_history: Optional[list[RetryHistory]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowRunActionRepetitionDefinition(TrackedResource):
        id: str
        location: str
        name: str
        properties: WorkflowRunActionRepetitionProperties
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                location: str, 
                properties: WorkflowRunActionRepetitionProperties, 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowRunActionRepetitionProperties(OperationResult):
        code: str
        correlation: RunActionCorrelation
        end_time: datetime
        error: any
        inputs: any
        inputs_link: ContentLink
        iteration_count: int
        outputs: any
        outputs_link: ContentLink
        repetition_indexes: Optional[list[RepetitionIndex]]
        retry_history: list[RetryHistory]
        start_time: datetime
        status: Union[str, WorkflowStatus]
        tracked_properties: any
        tracking_id: str

        @overload
        def __init__(
                self, 
                *, 
                code: Optional[str] = ..., 
                correlation: Optional[RunActionCorrelation] = ..., 
                end_time: Optional[datetime] = ..., 
                error: Optional[Any] = ..., 
                iteration_count: Optional[int] = ..., 
                repetition_indexes: Optional[list[RepetitionIndex]] = ..., 
                retry_history: Optional[list[RetryHistory]] = ..., 
                start_time: Optional[datetime] = ..., 
                status: Optional[Union[str, WorkflowStatus]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowRunProperties(_Model):
        code: Optional[str]
        correlation: Optional[Correlation]
        correlation_id: Optional[str]
        end_time: Optional[datetime]
        error: Optional[Any]
        outputs: Optional[dict[str, WorkflowOutputParameter]]
        response: Optional[WorkflowRunTrigger]
        start_time: Optional[datetime]
        status: Optional[Union[str, WorkflowStatus]]
        trigger: Optional[WorkflowRunTrigger]
        wait_end_time: Optional[datetime]
        workflow: Optional[ResourceReference]

        @overload
        def __init__(
                self, 
                *, 
                correlation: Optional[Correlation] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowRunTrigger(_Model):
        code: Optional[str]
        correlation: Optional[Correlation]
        end_time: Optional[datetime]
        error: Optional[Any]
        inputs: Optional[Any]
        inputs_link: Optional[ContentLink]
        name: Optional[str]
        outputs: Optional[Any]
        outputs_link: Optional[ContentLink]
        scheduled_time: Optional[datetime]
        start_time: Optional[datetime]
        status: Optional[Union[str, WorkflowStatus]]
        tracked_properties: Optional[Any]
        tracking_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                correlation: Optional[Correlation] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowSku(_Model):
        name: Union[str, WorkflowSkuName]
        plan: Optional[ResourceReference]

        @overload
        def __init__(
                self, 
                *, 
                name: Union[str, WorkflowSkuName], 
                plan: Optional[ResourceReference] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowSkuName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        BASIC = "Basic"
        FREE = "Free"
        NOT_SPECIFIED = "NotSpecified"
        PREMIUM = "Premium"
        SHARED = "Shared"
        STANDARD = "Standard"


    class azure.mgmt.web.models.WorkflowState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        COMPLETED = "Completed"
        DELETED = "Deleted"
        DISABLED = "Disabled"
        ENABLED = "Enabled"
        NOT_SPECIFIED = "NotSpecified"
        SUSPENDED = "Suspended"


    class azure.mgmt.web.models.WorkflowStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ABORTED = "Aborted"
        CANCELLED = "Cancelled"
        FAILED = "Failed"
        FAULTED = "Faulted"
        IGNORED = "Ignored"
        NOT_SPECIFIED = "NotSpecified"
        PAUSED = "Paused"
        RUNNING = "Running"
        SKIPPED = "Skipped"
        SUCCEEDED = "Succeeded"
        SUSPENDED = "Suspended"
        TIMED_OUT = "TimedOut"
        WAITING = "Waiting"


    class azure.mgmt.web.models.WorkflowTrigger(ProxyResource):
        id: str
        name: str
        properties: Optional[WorkflowTriggerProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                properties: Optional[WorkflowTriggerProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowTriggerCallbackUrl(_Model):
        base_path: Optional[str]
        method: Optional[str]
        queries: Optional[WorkflowTriggerListCallbackUrlQueries]
        relative_path: Optional[str]
        relative_path_parameters: Optional[list[str]]
        value: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                queries: Optional[WorkflowTriggerListCallbackUrlQueries] = ..., 
                relative_path_parameters: Optional[list[str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowTriggerHistory(ProxyResource):
        id: str
        name: str
        properties: Optional[WorkflowTriggerHistoryProperties]
        system_data: SystemData
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                properties: Optional[WorkflowTriggerHistoryProperties] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowTriggerHistoryProperties(_Model):
        code: Optional[str]
        correlation: Optional[Correlation]
        end_time: Optional[datetime]
        error: Optional[Any]
        fired: Optional[bool]
        inputs_link: Optional[ContentLink]
        outputs_link: Optional[ContentLink]
        run: Optional[ResourceReference]
        scheduled_time: Optional[datetime]
        start_time: Optional[datetime]
        status: Optional[Union[str, WorkflowStatus]]
        tracking_id: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                correlation: Optional[Correlation] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowTriggerListCallbackUrlQueries(_Model):
        api_version: Optional[str]
        se: Optional[str]
        sig: Optional[str]
        sp: Optional[str]
        sv: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                api_version: Optional[str] = ..., 
                se: Optional[str] = ..., 
                sig: Optional[str] = ..., 
                sp: Optional[str] = ..., 
                sv: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowTriggerProperties(_Model):
        changed_time: Optional[datetime]
        created_time: Optional[datetime]
        last_execution_time: Optional[datetime]
        next_execution_time: Optional[datetime]
        provisioning_state: Optional[Union[str, WorkflowTriggerProvisioningState]]
        recurrence: Optional[WorkflowTriggerRecurrence]
        state: Optional[Union[str, WorkflowState]]
        status: Optional[Union[str, WorkflowStatus]]
        workflow: Optional[ResourceReference]


    class azure.mgmt.web.models.WorkflowTriggerProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
        ACCEPTED = "Accepted"
        CANCELED = "Canceled"
        COMPLETED = "Completed"
        CREATED = "Created"
        CREATING = "Creating"
        DELETED = "Deleted"
        DELETING = "Deleting"
        FAILED = "Failed"
        MOVING = "Moving"
        NOT_SPECIFIED = "NotSpecified"
        READY = "Ready"
        REGISTERED = "Registered"
        REGISTERING = "Registering"
        RUNNING = "Running"
        SUCCEEDED = "Succeeded"
        UNREGISTERED = "Unregistered"
        UNREGISTERING = "Unregistering"
        UPDATING = "Updating"


    class azure.mgmt.web.models.WorkflowTriggerRecurrence(_Model):
        end_time: Optional[str]
        frequency: Optional[Union[str, RecurrenceFrequency]]
        interval: Optional[int]
        schedule: Optional[RecurrenceSchedule]
        start_time: Optional[str]
        time_zone: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                end_time: Optional[str] = ..., 
                frequency: Optional[Union[str, RecurrenceFrequency]] = ..., 
                interval: Optional[int] = ..., 
                schedule: Optional[RecurrenceSchedule] = ..., 
                start_time: Optional[str] = ..., 
                time_zone: Optional[str] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


    class azure.mgmt.web.models.WorkflowVersion(TrackedResource):
        id: str
        location: str
        name: str
        properties: Optional[WorkflowVersionProperties]
        system_data: SystemData
        tags: dict[str, str]
        type: str

        def __getattr__(self, name: str) -> Any: ...

        @overload
        def __init__(
                self, 
                *, 
                location: str, 
                properties: Optional[WorkflowVersionProperties] = ..., 
                tags: Optional[dict[str, str]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...

        def __setattr__(
                self, 
                key: str, 
                value: Any
            ) -> None: ...


    class azure.mgmt.web.models.WorkflowVersionProperties(_Model):
        access_control: Optional[FlowAccessControlConfiguration]
        access_endpoint: Optional[str]
        changed_time: Optional[datetime]
        created_time: Optional[datetime]
        definition: Optional[Any]
        endpoints_configuration: Optional[FlowEndpointsConfiguration]
        integration_account: Optional[ResourceReference]
        parameters: Optional[dict[str, WorkflowParameter]]
        provisioning_state: Optional[Union[str, WorkflowProvisioningState]]
        sku: Optional[WorkflowSku]
        state: Optional[Union[str, WorkflowState]]
        version: Optional[str]

        @overload
        def __init__(
                self, 
                *, 
                access_control: Optional[FlowAccessControlConfiguration] = ..., 
                definition: Optional[Any] = ..., 
                endpoints_configuration: Optional[FlowEndpointsConfiguration] = ..., 
                integration_account: Optional[ResourceReference] = ..., 
                parameters: Optional[dict[str, WorkflowParameter]] = ..., 
                state: Optional[Union[str, WorkflowState]] = ...
            ) -> None: ...

        @overload
        def __init__(self, mapping: Mapping[str, Any]) -> None: ...


namespace azure.mgmt.web.operations

    class azure.mgmt.web.operations.AppServiceEnvironmentsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_change_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_info: VirtualNetworkProfile, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[ItemPaged[Site]]: ...

        @overload
        def begin_change_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_info: VirtualNetworkProfile, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[ItemPaged[Site]]: ...

        @overload
        def begin_change_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_info: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[ItemPaged[Site]]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[AppServiceEnvironmentResource]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[AppServiceEnvironmentResource]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[AppServiceEnvironmentResource]: ...

        @overload
        def begin_create_or_update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[WorkerPoolResource]: ...

        @overload
        def begin_create_or_update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[WorkerPoolResource]: ...

        @overload
        def begin_create_or_update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[WorkerPoolResource]: ...

        @overload
        def begin_create_or_update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[WorkerPoolResource]: ...

        @overload
        def begin_create_or_update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[WorkerPoolResource]: ...

        @overload
        def begin_create_or_update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[WorkerPoolResource]: ...

        @distributed_trace
        def begin_delete(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                force_delete: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def begin_delete_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> LROPoller[Any]: ...

        @distributed_trace
        def begin_resume(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[ItemPaged[Site]]: ...

        @distributed_trace
        def begin_suspend(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[ItemPaged[Site]]: ...

        @distributed_trace
        def begin_upgrade(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def delete_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @distributed_trace
        def get_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @distributed_trace
        def get_ase_v3_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @distributed_trace
        def get_diagnostics_item(
                self, 
                resource_group_name: str, 
                name: str, 
                diagnostics_name: str, 
                **kwargs: Any
            ) -> HostingEnvironmentDiagnostics: ...

        @distributed_trace
        def get_inbound_network_dependencies_endpoints(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[InboundEnvironmentEndpoint]: ...

        @distributed_trace
        def get_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @distributed_trace
        def get_outbound_network_dependencies_endpoints(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[OutboundEnvironmentEndpoint]: ...

        @distributed_trace
        def get_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_endpoint_connection_list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace
        def get_private_link_resources(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace
        def get_vip_info(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AddressResponse: ...

        @distributed_trace
        def get_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> ItemPaged[AppServiceEnvironmentResource]: ...

        @distributed_trace
        def list_app_service_plans(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[AppServicePlan]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> ItemPaged[AppServiceEnvironmentResource]: ...

        @distributed_trace
        def list_capacities(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StampCapacity]: ...

        @distributed_trace
        def list_diagnostics(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[HostingEnvironmentDiagnostics]: ...

        @distributed_trace
        def list_multi_role_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_multi_role_pool_instance_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                instance: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_multi_role_pool_skus(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[SkuInfo]: ...

        @distributed_trace
        def list_multi_role_pools(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[WorkerPoolResource]: ...

        @distributed_trace
        def list_multi_role_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Usage]: ...

        @distributed_trace
        def list_operations(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[Operation]: ...

        @distributed_trace
        def list_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[CsmUsageQuota]: ...

        @distributed_trace
        def list_web_apps(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                properties_to_include: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Site]: ...

        @distributed_trace
        def list_web_worker_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_web_worker_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> ItemPaged[Usage]: ...

        @distributed_trace
        def list_worker_pool_instance_metric_definitions(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                instance: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceMetricDefinition]: ...

        @distributed_trace
        def list_worker_pool_skus(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                **kwargs: Any
            ) -> ItemPaged[SkuInfo]: ...

        @distributed_trace
        def list_worker_pools(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[WorkerPoolResource]: ...

        @distributed_trace
        def reboot(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def test_upgrade_available_notification(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: AppServiceEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServiceEnvironmentResource: ...

        @overload
        def update_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                custom_dns_suffix_configuration: CustomDnsSuffixConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @overload
        def update_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                custom_dns_suffix_configuration: CustomDnsSuffixConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @overload
        def update_ase_custom_dns_suffix_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                custom_dns_suffix_configuration: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CustomDnsSuffixConfiguration: ...

        @overload
        def update_ase_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                ase_networking_configuration: AseV3NetworkingConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @overload
        def update_ase_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                ase_networking_configuration: AseV3NetworkingConfiguration, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @overload
        def update_ase_networking_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                ase_networking_configuration: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AseV3NetworkingConfiguration: ...

        @overload
        def update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        def update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        def update_multi_role_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                multi_role_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        def update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        def update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: WorkerPoolResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...

        @overload
        def update_worker_pool(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_pool_name: str, 
                worker_pool_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> WorkerPoolResource: ...


    class azure.mgmt.web.operations.AppServicePlansOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlan, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[AppServicePlan]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlan, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[AppServicePlan]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[AppServicePlan]: ...

        @overload
        def create_or_update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        def create_or_update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        def create_or_update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @distributed_trace
        def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @distributed_trace
        def get_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def get_hybrid_connection_plan_limit(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> HybridConnectionLimits: ...

        @distributed_trace
        def get_route_for_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                **kwargs: Any
            ) -> List[VnetRoute]: ...

        @distributed_trace
        def get_server_farm_instance_details(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ServerFarmInstanceDetails: ...

        @distributed_trace
        def get_server_farm_rdp_password(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ServerFarmRdpDetails: ...

        @distributed_trace
        def get_server_farm_skus(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @distributed_trace
        def get_vnet_from_server_farm(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace
        def get_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                **kwargs: Any
            ) -> VnetGateway: ...

        @distributed_trace
        def list(
                self, 
                *, 
                detailed: Optional[bool] = ..., 
                **kwargs: Any
            ) -> ItemPaged[AppServicePlan]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> ItemPaged[AppServicePlan]: ...

        @distributed_trace
        def list_capabilities(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[Capability]: ...

        @distributed_trace
        def list_hybrid_connection_keys(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> HybridConnectionKey: ...

        @distributed_trace
        def list_hybrid_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[HybridConnection]: ...

        @distributed_trace
        def list_routes_for_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> List[VnetRoute]: ...

        @distributed_trace
        def list_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[CsmUsageQuota]: ...

        @distributed_trace
        def list_vnets(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[VnetInfoResource]: ...

        @distributed_trace
        def list_web_apps(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                skip_token: Optional[str] = ..., 
                top: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Site]: ...

        @distributed_trace
        def list_web_apps_by_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> ItemPaged[str]: ...

        @distributed_trace
        def reboot_worker(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def recycle_managed_instance_worker(
                self, 
                resource_group_name: str, 
                name: str, 
                worker_name: str, 
                **kwargs: Any
            ) -> Operation: ...

        @distributed_trace
        def restart_web_apps(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                soft_restart: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlanPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: AppServicePlanPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                app_service_plan: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AppServicePlan: ...

        @overload
        def update_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        def update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: VnetRoute, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...

        @overload
        def update_vnet_route(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                route_name: str, 
                route: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetRoute: ...


    class azure.mgmt.web.operations.CertificatesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def list(
                self, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Certificate]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> ItemPaged[Certificate]: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...


    class azure.mgmt.web.operations.DeletedWebAppsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get_deleted_web_app_by_location(
                self, 
                location: str, 
                deleted_site_id: str, 
                **kwargs: Any
            ) -> DeletedSite: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> ItemPaged[DeletedSite]: ...

        @distributed_trace
        def list_by_location(
                self, 
                location: str, 
                **kwargs: Any
            ) -> ItemPaged[DeletedSite]: ...


    class azure.mgmt.web.operations.DiagnosticsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def execute_site_analysis(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticAnalysis: ...

        @distributed_trace
        def execute_site_analysis_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                slot: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticAnalysis: ...

        @distributed_trace
        def execute_site_detector(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                diagnostic_category: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticDetectorResponse: ...

        @distributed_trace
        def execute_site_detector_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                diagnostic_category: str, 
                slot: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DiagnosticDetectorResponse: ...

        @distributed_trace
        def get_hosting_environment_detector_response(
                self, 
                resource_group_name: str, 
                name: str, 
                detector_name: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DetectorResponse: ...

        @distributed_trace
        def get_site_analysis(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                **kwargs: Any
            ) -> AnalysisDefinition: ...

        @distributed_trace
        def get_site_analysis_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                analysis_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AnalysisDefinition: ...

        @distributed_trace
        def get_site_detector(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                detector_name: str, 
                **kwargs: Any
            ) -> DetectorDefinitionResource: ...

        @distributed_trace
        def get_site_detector_response(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DetectorResponse: ...

        @distributed_trace
        def get_site_detector_response_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                detector_name: str, 
                slot: str, 
                *, 
                end_time: Optional[datetime] = ..., 
                start_time: Optional[datetime] = ..., 
                time_grain: Optional[str] = ..., 
                **kwargs: Any
            ) -> DetectorResponse: ...

        @distributed_trace
        def get_site_detector_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                detector_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> DetectorDefinitionResource: ...

        @distributed_trace
        def get_site_diagnostic_category(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                **kwargs: Any
            ) -> DiagnosticCategory: ...

        @distributed_trace
        def get_site_diagnostic_category_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                slot: str, 
                **kwargs: Any
            ) -> DiagnosticCategory: ...

        @distributed_trace
        def list_hosting_environment_detector_responses(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[DetectorResponse]: ...

        @distributed_trace
        def list_site_analyses(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                **kwargs: Any
            ) -> ItemPaged[AnalysisDefinition]: ...

        @distributed_trace
        def list_site_analyses_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[AnalysisDefinition]: ...

        @distributed_trace
        def list_site_detector_responses(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> ItemPaged[DetectorResponse]: ...

        @distributed_trace
        def list_site_detector_responses_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[DetectorResponse]: ...

        @distributed_trace
        def list_site_detectors(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                **kwargs: Any
            ) -> ItemPaged[DetectorDefinitionResource]: ...

        @distributed_trace
        def list_site_detectors_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                diagnostic_category: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[DetectorDefinitionResource]: ...

        @distributed_trace
        def list_site_diagnostic_categories(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> ItemPaged[DiagnosticCategory]: ...

        @distributed_trace
        def list_site_diagnostic_categories_slot(
                self, 
                resource_group_name: str, 
                site_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[DiagnosticCategory]: ...


    class azure.mgmt.web.operations.GetUsagesInLocationOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def list(
                self, 
                location: str, 
                **kwargs: Any
            ) -> ItemPaged[CsmUsageQuota]: ...


    class azure.mgmt.web.operations.GlobalOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get_deleted_web_app(
                self, 
                deleted_site_id: str, 
                **kwargs: Any
            ) -> DeletedSite: ...

        @distributed_trace
        def get_deleted_web_app_snapshots(
                self, 
                deleted_site_id: str, 
                **kwargs: Any
            ) -> List[Snapshot]: ...

        @distributed_trace
        def get_subscription_operation_with_async_response(
                self, 
                location: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> None: ...


    class azure.mgmt.web.operations.KubeEnvironmentsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[KubeEnvironment]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[KubeEnvironment]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[KubeEnvironment]: ...

        @distributed_trace
        def begin_delete(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> KubeEnvironment: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> ItemPaged[KubeEnvironment]: ...

        @distributed_trace
        def list_by_subscription(self, **kwargs: Any) -> ItemPaged[KubeEnvironment]: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KubeEnvironment: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: KubeEnvironmentPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KubeEnvironment: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                kube_environment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KubeEnvironment: ...


    class azure.mgmt.web.operations.ProviderOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get_available_stacks(
                self, 
                *, 
                os_type_selected: Optional[Union[str, ProviderOsTypeSelected]] = ..., 
                **kwargs: Any
            ) -> ItemPaged[ApplicationStackResource]: ...

        @distributed_trace
        def get_available_stacks_on_prem(
                self, 
                *, 
                os_type_selected: Optional[Union[str, ProviderOsTypeSelected]] = ..., 
                **kwargs: Any
            ) -> ItemPaged[ApplicationStackResource]: ...

        @distributed_trace
        def get_function_app_stacks(
                self, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> ItemPaged[FunctionAppStack]: ...

        @distributed_trace
        def get_function_app_stacks_for_location(
                self, 
                location: str, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> ItemPaged[FunctionAppStack]: ...

        @distributed_trace
        def get_web_app_stacks(
                self, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WebAppStack]: ...

        @distributed_trace
        def get_web_app_stacks_for_location(
                self, 
                location: str, 
                *, 
                stack_os_type: Optional[Union[str, ProviderStackOsType]] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WebAppStack]: ...

        @distributed_trace
        def list_operations(self, **kwargs: Any) -> ItemPaged[CsmOperationDescription]: ...


    class azure.mgmt.web.operations.RecommendationsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def disable_all_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                environment_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def disable_all_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def disable_recommendation_for_hosting_environment(
                self, 
                resource_group_name: str, 
                name: str, 
                hosting_environment_name: str, 
                *, 
                environment_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def disable_recommendation_for_site(
                self, 
                resource_group_name: str, 
                site_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def disable_recommendation_for_subscription(
                self, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get_rule_details_by_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                name: str, 
                *, 
                recommendation_id: Optional[str] = ..., 
                update_seen: Optional[bool] = ..., 
                **kwargs: Any
            ) -> RecommendationRule: ...

        @distributed_trace
        def get_rule_details_by_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                name: str, 
                *, 
                recommendation_id: Optional[str] = ..., 
                update_seen: Optional[bool] = ..., 
                **kwargs: Any
            ) -> RecommendationRule: ...

        @distributed_trace
        def list(
                self, 
                *, 
                featured: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Recommendation]: ...

        @distributed_trace
        def list_history_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                expired_only: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Recommendation]: ...

        @distributed_trace
        def list_history_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                *, 
                expired_only: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Recommendation]: ...

        @distributed_trace
        def list_recommended_rules_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                featured: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Recommendation]: ...

        @distributed_trace
        def list_recommended_rules_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                *, 
                featured: Optional[bool] = ..., 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Recommendation]: ...

        @distributed_trace
        def reset_all_filters(self, **kwargs: Any) -> None: ...

        @distributed_trace
        def reset_all_filters_for_hosting_environment(
                self, 
                resource_group_name: str, 
                hosting_environment_name: str, 
                *, 
                environment_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def reset_all_filters_for_web_app(
                self, 
                resource_group_name: str, 
                site_name: str, 
                **kwargs: Any
            ) -> None: ...


    class azure.mgmt.web.operations.ResourceHealthMetadataOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get_by_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ResourceHealthMetadata: ...

        @distributed_trace
        def get_by_site_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ResourceHealthMetadata: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> ItemPaged[ResourceHealthMetadata]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceHealthMetadata]: ...

        @distributed_trace
        def list_by_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceHealthMetadata]: ...

        @distributed_trace
        def list_by_site_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ResourceHealthMetadata]: ...


    class azure.mgmt.web.operations.SiteCertificatesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: Certificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def get_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                **kwargs: Any
            ) -> Certificate: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Certificate]: ...

        @distributed_trace
        def list_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[Certificate]: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: CertificatePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...

        @overload
        def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                certificate_name: str, 
                certificate_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Certificate: ...


    class azure.mgmt.web.operations.StaticSitesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_create_or_update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSiteARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteARMResource]: ...

        @overload
        def begin_create_or_update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSiteARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteARMResource]: ...

        @overload
        def begin_create_or_update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteARMResource]: ...

        @overload
        def begin_create_or_update_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteCustomDomainOverviewARMResource]: ...

        @overload
        def begin_create_or_update_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteCustomDomainOverviewARMResource]: ...

        @overload
        def begin_create_or_update_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteCustomDomainOverviewARMResource]: ...

        @overload
        def begin_create_zip_deployment_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_create_zip_deployment_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_create_zip_deployment_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_zip_deployment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_create_zip_deployment_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_create_zip_deployment_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                static_site_zip_deployment_envelope: StaticSiteZipDeploymentARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_create_zip_deployment_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                static_site_zip_deployment_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def begin_delete_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> LROPoller[Any]: ...

        @distributed_trace
        def begin_delete_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def begin_delete_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def begin_delete_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def begin_detach_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_link_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        def begin_link_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        def begin_link_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        def begin_link_backend_to_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        def begin_link_backend_to_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        def begin_link_backend_to_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[StaticSiteLinkedBackendARMResource]: ...

        @overload
        def begin_register_user_provided_function_app_with_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        def begin_register_user_provided_function_app_with_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        def begin_register_user_provided_function_app_with_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        def begin_register_user_provided_function_app_with_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        def begin_register_user_provided_function_app_with_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: StaticSiteUserProvidedFunctionAppARMResource, 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        def begin_register_user_provided_function_app_with_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                static_site_user_provided_function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                is_forced: Optional[bool] = ..., 
                **kwargs: Any
            ) -> LROPoller[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @overload
        def begin_validate_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: StaticSiteLinkedBackendARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                static_site_linked_backend_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_custom_domain_can_be_added_to_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_custom_domain_can_be_added_to_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: StaticSiteCustomDomainRequestPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_validate_custom_domain_can_be_added_to_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                static_site_custom_domain_request_properties_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def create_or_update_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                basic_auth_envelope: StaticSiteBasicAuthPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @overload
        def create_or_update_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                basic_auth_envelope: StaticSiteBasicAuthPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @overload
        def create_or_update_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                basic_auth_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @overload
        def create_or_update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def create_or_update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def create_or_update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def create_or_update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def create_or_update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def create_or_update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def create_or_update_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_or_update_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def create_user_roles_invitation_link(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_user_roles_invitation_envelope: StaticSiteUserInvitationRequestResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserInvitationResponseResource: ...

        @overload
        def create_user_roles_invitation_link(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_user_roles_invitation_envelope: StaticSiteUserInvitationRequestResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserInvitationResponseResource: ...

        @overload
        def create_user_roles_invitation_link(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_user_roles_invitation_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserInvitationResponseResource: ...

        @distributed_trace
        def delete_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def detach_user_provided_function_app_from_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def detach_user_provided_function_app_from_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                basic_auth_name: Union[str, BasicAuthName], 
                **kwargs: Any
            ) -> StaticSiteBasicAuthPropertiesARMResource: ...

        @distributed_trace
        def get_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace
        def get_build_database_connection_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace
        def get_build_database_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> ItemPaged[DatabaseConnection]: ...

        @distributed_trace
        def get_build_database_connections_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> ItemPaged[DatabaseConnection]: ...

        @distributed_trace
        def get_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace
        def get_database_connection_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @distributed_trace
        def get_database_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[DatabaseConnection]: ...

        @distributed_trace
        def get_database_connections_with_details(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[DatabaseConnection]: ...

        @distributed_trace
        def get_linked_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                **kwargs: Any
            ) -> StaticSiteLinkedBackendARMResource: ...

        @distributed_trace
        def get_linked_backend_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                **kwargs: Any
            ) -> StaticSiteLinkedBackendARMResource: ...

        @distributed_trace
        def get_linked_backends(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteLinkedBackendARMResource]: ...

        @distributed_trace
        def get_linked_backends_for_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteLinkedBackendARMResource]: ...

        @distributed_trace
        def get_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_endpoint_connection_list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace
        def get_private_link_resources(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace
        def get_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @distributed_trace
        def get_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> StaticSiteBuildARMResource: ...

        @distributed_trace
        def get_static_site_builds(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteBuildARMResource]: ...

        @distributed_trace
        def get_static_site_custom_domain(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_name: str, 
                **kwargs: Any
            ) -> StaticSiteCustomDomainOverviewARMResource: ...

        @distributed_trace
        def get_static_sites_by_resource_group(
                self, 
                resource_group_name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteARMResource]: ...

        @distributed_trace
        def get_user_provided_function_app_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> StaticSiteUserProvidedFunctionAppARMResource: ...

        @distributed_trace
        def get_user_provided_function_app_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                function_app_name: str, 
                **kwargs: Any
            ) -> StaticSiteUserProvidedFunctionAppARMResource: ...

        @distributed_trace
        def get_user_provided_function_apps_for_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @distributed_trace
        def get_user_provided_function_apps_for_static_site_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteUserProvidedFunctionAppARMResource]: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> ItemPaged[StaticSiteARMResource]: ...

        @distributed_trace
        def list_basic_auth(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteBasicAuthPropertiesARMResource]: ...

        @distributed_trace
        def list_static_site_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_build_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_build_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_build_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteFunctionOverviewARMResource]: ...

        @distributed_trace
        def list_static_site_configured_roles(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringList: ...

        @distributed_trace
        def list_static_site_custom_domains(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteCustomDomainOverviewARMResource]: ...

        @distributed_trace
        def list_static_site_function_app_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteFunctionOverviewARMResource]: ...

        @distributed_trace
        def list_static_site_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_static_site_users(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                **kwargs: Any
            ) -> ItemPaged[StaticSiteUserARMResource]: ...

        @overload
        def preview_workflow(
                self, 
                location: str, 
                static_sites_workflow_preview_request: StaticSitesWorkflowPreviewRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSitesWorkflowPreview: ...

        @overload
        def preview_workflow(
                self, 
                location: str, 
                static_sites_workflow_preview_request: StaticSitesWorkflowPreviewRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSitesWorkflowPreview: ...

        @overload
        def preview_workflow(
                self, 
                location: str, 
                static_sites_workflow_preview_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSitesWorkflowPreview: ...

        @overload
        def reset_static_site_api_key(
                self, 
                resource_group_name: str, 
                name: str, 
                reset_properties_envelope: StaticSiteResetPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def reset_static_site_api_key(
                self, 
                resource_group_name: str, 
                name: str, 
                reset_properties_envelope: StaticSiteResetPropertiesARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def reset_static_site_api_key(
                self, 
                resource_group_name: str, 
                name: str, 
                reset_properties_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def unlink_backend(
                self, 
                resource_group_name: str, 
                name: str, 
                linked_backend_name: str, 
                *, 
                is_cleaning_auth_config: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def unlink_backend_from_build(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                linked_backend_name: str, 
                *, 
                is_cleaning_auth_config: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @overload
        def update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def update_build_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                environment_name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: DatabaseConnectionPatchRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def update_database_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                database_connection_name: str, 
                database_connection_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> DatabaseConnection: ...

        @overload
        def update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @overload
        def update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: StaticSitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @overload
        def update_static_site(
                self, 
                resource_group_name: str, 
                name: str, 
                static_site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteARMResource: ...

        @overload
        def update_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                static_site_user_envelope: StaticSiteUserARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserARMResource: ...

        @overload
        def update_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                static_site_user_envelope: StaticSiteUserARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserARMResource: ...

        @overload
        def update_static_site_user(
                self, 
                resource_group_name: str, 
                name: str, 
                authprovider: str, 
                userid: str, 
                static_site_user_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StaticSiteUserARMResource: ...


    class azure.mgmt.web.operations.WebAppsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def add_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def add_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def add_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def add_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def add_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOn, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def add_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace
        def analyze_custom_hostname(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                host_name: Optional[str] = ..., 
                **kwargs: Any
            ) -> CustomHostnameAnalysisResult: ...

        @distributed_trace
        def analyze_custom_hostname_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                host_name: Optional[str] = ..., 
                **kwargs: Any
            ) -> CustomHostnameAnalysisResult: ...

        @overload
        def apply_slot_config_to_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def apply_slot_config_to_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def apply_slot_config_to_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def apply_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def apply_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def apply_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                private_endpoint_wrapper: RemotePrivateEndpointConnectionARMResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_approve_or_reject_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                private_endpoint_wrapper: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[RemotePrivateEndpointConnectionARMResource]: ...

        @overload
        def begin_create_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[FunctionEnvelope]: ...

        @overload
        def begin_create_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[FunctionEnvelope]: ...

        @overload
        def begin_create_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[FunctionEnvelope]: ...

        @overload
        def begin_create_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[FunctionEnvelope]: ...

        @overload
        def begin_create_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                function_envelope: FunctionEnvelope, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[FunctionEnvelope]: ...

        @overload
        def begin_create_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                function_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[FunctionEnvelope]: ...

        @overload
        def begin_create_instance_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_instance_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_instance_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_instance_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_instance_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_instance_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_ms_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                ms_deploy: MSDeploy, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_ms_deploy_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                ms_deploy: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[MSDeployStatus]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Site]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Site]: ...

        @overload
        def begin_create_or_update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Site]: ...

        @overload
        def begin_create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Site]: ...

        @overload
        def begin_create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: Site, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Site]: ...

        @overload
        def begin_create_or_update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Site]: ...

        @overload
        def begin_create_or_update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[SiteSourceControl]: ...

        @overload
        def begin_create_or_update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[SiteSourceControl]: ...

        @overload
        def begin_create_or_update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[SiteSourceControl]: ...

        @overload
        def begin_create_or_update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[SiteSourceControl]: ...

        @overload
        def begin_create_or_update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[SiteSourceControl]: ...

        @overload
        def begin_create_or_update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[SiteSourceControl]: ...

        @distributed_trace
        def begin_delete_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> LROPoller[Any]: ...

        @distributed_trace
        def begin_delete_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> LROPoller[Any]: ...

        @distributed_trace
        def begin_get_production_site_deployment_status(
                self, 
                resource_group_name: str, 
                name: str, 
                deployment_status_id: str, 
                **kwargs: Any
            ) -> LROPoller[CsmDeploymentStatus]: ...

        @distributed_trace
        def begin_get_slot_site_deployment_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                deployment_status_id: str, 
                **kwargs: Any
            ) -> LROPoller[CsmDeploymentStatus]: ...

        @distributed_trace
        def begin_install_site_extension(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                **kwargs: Any
            ) -> LROPoller[SiteExtensionInfo]: ...

        @distributed_trace
        def begin_install_site_extension_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> LROPoller[SiteExtensionInfo]: ...

        @distributed_trace
        def begin_list_publishing_credentials(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> LROPoller[User]: ...

        @distributed_trace
        def begin_list_publishing_credentials_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> LROPoller[User]: ...

        @overload
        def begin_migrate_my_sql(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_request_envelope: MigrateMySqlRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Operation]: ...

        @overload
        def begin_migrate_my_sql(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_request_envelope: MigrateMySqlRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Operation]: ...

        @overload
        def begin_migrate_my_sql(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_request_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[Operation]: ...

        @overload
        def begin_migrate_storage(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_options: StorageMigrationOptions, 
                *, 
                content_type: str = "application/json", 
                subscription_name: str, 
                **kwargs: Any
            ) -> LROPoller[StorageMigrationResponse]: ...

        @overload
        def begin_migrate_storage(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_options: StorageMigrationOptions, 
                *, 
                content_type: str = "application/json", 
                subscription_name: str, 
                **kwargs: Any
            ) -> LROPoller[StorageMigrationResponse]: ...

        @overload
        def begin_migrate_storage(
                self, 
                resource_group_name: str, 
                name: str, 
                migration_options: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                subscription_name: str, 
                **kwargs: Any
            ) -> LROPoller[StorageMigrationResponse]: ...

        @overload
        def begin_restore(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_backup_blob(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_backup_blob(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_backup_blob(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_backup_blob_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_backup_blob_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_backup_blob_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_deleted_app(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_deleted_app(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_deleted_app(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_deleted_app_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_deleted_app_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: DeletedAppRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_from_deleted_app_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: SnapshotRestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_restore_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                restore_request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def begin_start_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> LROPoller[List[NetworkTrace]]: ...

        @distributed_trace
        def begin_start_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> LROPoller[List[NetworkTrace]]: ...

        @distributed_trace
        def begin_start_web_site_network_trace_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> LROPoller[List[NetworkTrace]]: ...

        @distributed_trace
        def begin_start_web_site_network_trace_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> LROPoller[List[NetworkTrace]]: ...

        @overload
        def begin_swap_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_swap_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_swap_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_swap_slot_with_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_swap_slot_with_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def begin_swap_slot_with_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @overload
        def create_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        def create_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        def create_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                deployment: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        def create_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        def create_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                deployment: Deployment, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @overload
        def create_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                deployment: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace
        def create_one_deploy_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @overload
        def create_or_update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def create_or_update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def create_or_update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def create_or_update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def create_or_update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def create_or_update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def create_or_update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def create_or_update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def create_or_update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def create_or_update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def create_or_update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def create_or_update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def create_or_update_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        def create_or_update_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        def create_or_update_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                host_name_binding: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        def create_or_update_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                slot: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        def create_or_update_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                slot: str, 
                host_name_binding: HostNameBinding, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        def create_or_update_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                slot: str, 
                host_name_binding: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @overload
        def create_or_update_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                key: KeyInfo, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                key: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> KeyInfo: ...

        @overload
        def create_or_update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def create_or_update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def create_or_update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def create_or_update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def create_or_update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def create_or_update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def create_or_update_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        def create_or_update_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        def create_or_update_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                public_certificate: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        def create_or_update_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                slot: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        def create_or_update_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                slot: str, 
                public_certificate: PublicCertificate, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        def create_or_update_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                slot: str, 
                public_certificate: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @overload
        def create_or_update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def create_or_update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def create_or_update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def create_or_update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def create_or_update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def create_or_update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def create_or_update_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        def create_or_update_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        def create_or_update_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        def create_or_update_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        def create_or_update_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                request: SiteContainer, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        def create_or_update_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteContainer: ...

        @overload
        def create_or_update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def create_or_update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def create_or_update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def create_or_update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def create_or_update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def create_or_update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def create_or_update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def create_or_update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def create_or_update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def create_or_update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def create_or_update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def create_or_update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def create_or_update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def create_or_update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def create_or_update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def create_or_update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def create_or_update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def create_or_update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace
        def delete(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                delete_empty_server_farm: Optional[bool] = ..., 
                delete_metrics: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_function_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_function_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                key_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                host_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_host_secret(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_host_secret_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                key_type: str, 
                key_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_instance_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_instance_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_site_extension(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_site_extension_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                delete_empty_server_farm: Optional[bool] = ..., 
                delete_metrics: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                additional_flags: Optional[str] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                additional_flags: Optional[str] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_swift_virtual_network(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_swift_virtual_network_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_triggered_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_triggered_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def delete_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @overload
        def deploy_workflow_artifacts(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def deploy_workflow_artifacts(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def deploy_workflow_artifacts(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_artifacts: Optional[IO[bytes]] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def deploy_workflow_artifacts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def deploy_workflow_artifacts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_artifacts: Optional[WorkflowArtifacts] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def deploy_workflow_artifacts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_artifacts: Optional[IO[bytes]] = None, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def discover_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        def discover_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        def discover_backup(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        def discover_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        def discover_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: RestoreRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @overload
        def discover_backup_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RestoreRequest: ...

        @distributed_trace
        def generate_new_site_publishing_password(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def generate_new_site_publishing_password_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Site: ...

        @distributed_trace
        def get_app_setting_key_vault_reference(
                self, 
                resource_group_name: str, 
                name: str, 
                app_setting_key: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace
        def get_app_setting_key_vault_reference_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                app_setting_key: str, 
                slot: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace
        def get_app_settings_key_vault_references(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[ApiKVReference]: ...

        @distributed_trace
        def get_app_settings_key_vault_references_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ApiKVReference]: ...

        @distributed_trace
        def get_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @distributed_trace
        def get_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @distributed_trace
        def get_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace
        def get_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace
        def get_auth_settings_v2_without_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace
        def get_auth_settings_v2_without_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @distributed_trace
        def get_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> BackupRequest: ...

        @distributed_trace
        def get_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> BackupRequest: ...

        @distributed_trace
        def get_backup_status(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                **kwargs: Any
            ) -> BackupItem: ...

        @distributed_trace
        def get_backup_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> BackupItem: ...

        @distributed_trace
        def get_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace
        def get_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace
        def get_configuration_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace
        def get_configuration_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @distributed_trace
        def get_container_logs_zip(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Optional[Iterator[bytes]]: ...

        @distributed_trace
        def get_container_logs_zip_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Optional[Iterator[bytes]]: ...

        @distributed_trace
        def get_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> ContinuousWebJob: ...

        @distributed_trace
        def get_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ContinuousWebJob: ...

        @distributed_trace
        def get_deployment(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace
        def get_deployment_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace
        def get_diagnostic_logs_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @distributed_trace
        def get_diagnostic_logs_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @distributed_trace
        def get_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                **kwargs: Any
            ) -> Identifier: ...

        @distributed_trace
        def get_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Identifier: ...

        @distributed_trace
        def get_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace
        def get_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace
        def get_function(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> FunctionEnvelope: ...

        @distributed_trace
        def get_functions_admin_token(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace
        def get_functions_admin_token_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace
        def get_host_name_binding(
                self, 
                resource_group_name: str, 
                name: str, 
                host_name: str, 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @distributed_trace
        def get_host_name_binding_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                host_name: str, 
                **kwargs: Any
            ) -> HostNameBinding: ...

        @distributed_trace
        def get_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def get_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def get_instance_function_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> FunctionEnvelope: ...

        @distributed_trace
        def get_instance_info(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> WebSiteInstanceStatus: ...

        @distributed_trace
        def get_instance_info_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> WebSiteInstanceStatus: ...

        @distributed_trace
        def get_instance_ms_deploy_log(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace
        def get_instance_ms_deploy_log_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace
        def get_instance_ms_deploy_status(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace
        def get_instance_ms_deploy_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace
        def get_instance_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace
        def get_instance_process_dump(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @distributed_trace
        def get_instance_process_dump_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @distributed_trace
        def get_instance_process_module(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace
        def get_instance_process_module_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace
        def get_instance_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace
        def get_instance_workflow_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                workflow_name: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @distributed_trace
        def get_migrate_my_sql_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> MigrateMySqlStatus: ...

        @distributed_trace
        def get_migrate_my_sql_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> MigrateMySqlStatus: ...

        @distributed_trace
        def get_ms_deploy_log(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace
        def get_ms_deploy_log_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> MSDeployLog: ...

        @distributed_trace
        def get_ms_deploy_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace
        def get_ms_deploy_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> MSDeployStatus: ...

        @distributed_trace
        def get_network_trace_operation(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_trace_operation_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_trace_operation_slot_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_trace_operation_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_traces(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_traces_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_traces_slot_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_network_traces_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                operation_id: str, 
                **kwargs: Any
            ) -> List[NetworkTrace]: ...

        @distributed_trace
        def get_one_deploy_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @distributed_trace
        def get_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace
        def get_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace
        def get_private_access(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @distributed_trace
        def get_private_access_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @distributed_trace
        def get_private_endpoint_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_endpoint_connection_list(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace
        def get_private_endpoint_connection_list_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[RemotePrivateEndpointConnectionARMResource]: ...

        @distributed_trace
        def get_private_endpoint_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                private_endpoint_connection_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> RemotePrivateEndpointConnectionARMResource: ...

        @distributed_trace
        def get_private_link_resources(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace
        def get_private_link_resources_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PrivateLinkResourcesWrapper: ...

        @distributed_trace
        def get_process(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace
        def get_process_dump(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @distributed_trace
        def get_process_dump_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @distributed_trace
        def get_process_module(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace
        def get_process_module_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                base_address: str, 
                slot: str, 
                **kwargs: Any
            ) -> ProcessModuleInfo: ...

        @distributed_trace
        def get_process_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> ProcessInfo: ...

        @distributed_trace
        def get_public_certificate(
                self, 
                resource_group_name: str, 
                name: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @distributed_trace
        def get_public_certificate_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                public_certificate_name: str, 
                **kwargs: Any
            ) -> PublicCertificate: ...

        @distributed_trace
        def get_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace
        def get_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace
        def get_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace
        def get_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @distributed_trace
        def get_site_connection_string_key_vault_reference(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_string_key: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace
        def get_site_connection_string_key_vault_reference_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_string_key: str, 
                slot: str, 
                **kwargs: Any
            ) -> ApiKVReference: ...

        @distributed_trace
        def get_site_connection_string_key_vault_references(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[ApiKVReference]: ...

        @distributed_trace
        def get_site_connection_string_key_vault_references_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ApiKVReference]: ...

        @distributed_trace
        def get_site_container(
                self, 
                resource_group_name: str, 
                name: str, 
                container_name: str, 
                **kwargs: Any
            ) -> SiteContainer: ...

        @distributed_trace
        def get_site_container_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                container_name: str, 
                **kwargs: Any
            ) -> SiteContainer: ...

        @distributed_trace
        def get_site_extension(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                **kwargs: Any
            ) -> SiteExtensionInfo: ...

        @distributed_trace
        def get_site_extension_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                site_extension_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteExtensionInfo: ...

        @distributed_trace
        def get_site_php_error_log_flag(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SitePhpErrorLogFlag: ...

        @distributed_trace
        def get_site_php_error_log_flag_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SitePhpErrorLogFlag: ...

        @distributed_trace
        def get_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Site: ...

        @distributed_trace
        def get_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @distributed_trace
        def get_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @distributed_trace
        def get_swift_virtual_network_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @distributed_trace
        def get_swift_virtual_network_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @distributed_trace
        def get_triggered_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> TriggeredWebJob: ...

        @distributed_trace
        def get_triggered_web_job_history(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                id: str, 
                **kwargs: Any
            ) -> TriggeredJobHistory: ...

        @distributed_trace
        def get_triggered_web_job_history_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> TriggeredJobHistory: ...

        @distributed_trace
        def get_triggered_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> TriggeredWebJob: ...

        @distributed_trace
        def get_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace
        def get_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                **kwargs: Any
            ) -> VnetGateway: ...

        @distributed_trace
        def get_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> VnetGateway: ...

        @distributed_trace
        def get_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @distributed_trace
        def get_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> WebJob: ...

        @distributed_trace
        def get_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> WebJob: ...

        @distributed_trace
        def get_web_site_container_logs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Optional[Iterator[bytes]]: ...

        @distributed_trace
        def get_web_site_container_logs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> Optional[Iterator[bytes]]: ...

        @distributed_trace
        def get_workflow(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @distributed_trace
        def is_cloneable(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SiteCloneability: ...

        @distributed_trace
        def is_cloneable_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> SiteCloneability: ...

        @distributed_trace
        def list(self, **kwargs: Any) -> ItemPaged[Site]: ...

        @distributed_trace
        def list_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @distributed_trace
        def list_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def list_backup_status_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def list_backup_status_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def list_backup_status_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def list_backup_status_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def list_backup_status_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @overload
        def list_backup_status_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                backup_id: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupItem: ...

        @distributed_trace
        def list_backups(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[BackupItem]: ...

        @distributed_trace
        def list_backups_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[BackupItem]: ...

        @distributed_trace
        def list_basic_publishing_credentials_policies(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[CsmPublishingCredentialsPoliciesEntity]: ...

        @distributed_trace
        def list_basic_publishing_credentials_policies_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[CsmPublishingCredentialsPoliciesEntity]: ...

        @distributed_trace
        def list_by_resource_group(
                self, 
                resource_group_name: str, 
                *, 
                include_slots: Optional[bool] = ..., 
                **kwargs: Any
            ) -> ItemPaged[Site]: ...

        @distributed_trace
        def list_configuration_snapshot_info(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteConfigurationSnapshotInfo]: ...

        @distributed_trace
        def list_configuration_snapshot_info_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteConfigurationSnapshotInfo]: ...

        @distributed_trace
        def list_configurations(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteConfigResource]: ...

        @distributed_trace
        def list_configurations_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteConfigResource]: ...

        @distributed_trace
        def list_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @distributed_trace
        def list_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @distributed_trace
        def list_continuous_web_jobs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[ContinuousWebJob]: ...

        @distributed_trace
        def list_continuous_web_jobs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ContinuousWebJob]: ...

        @distributed_trace
        def list_deployment_log(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace
        def list_deployment_log_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                id: str, 
                slot: str, 
                **kwargs: Any
            ) -> Deployment: ...

        @distributed_trace
        def list_deployments(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Deployment]: ...

        @distributed_trace
        def list_deployments_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[Deployment]: ...

        @distributed_trace
        def list_domain_ownership_identifiers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Identifier]: ...

        @distributed_trace
        def list_domain_ownership_identifiers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[Identifier]: ...

        @distributed_trace
        def list_function_keys(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_function_keys_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_function_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace
        def list_function_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                function_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace
        def list_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[FunctionEnvelope]: ...

        @distributed_trace
        def list_host_keys(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> HostKeys: ...

        @distributed_trace
        def list_host_keys_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> HostKeys: ...

        @distributed_trace
        def list_host_name_bindings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[HostNameBinding]: ...

        @distributed_trace
        def list_host_name_bindings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[HostNameBinding]: ...

        @distributed_trace
        def list_hybrid_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def list_hybrid_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def list_instance_functions_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[FunctionEnvelope]: ...

        @distributed_trace
        def list_instance_identifiers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[WebSiteInstanceStatus]: ...

        @distributed_trace
        def list_instance_identifiers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[WebSiteInstanceStatus]: ...

        @distributed_trace
        def list_instance_process_modules(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_instance_process_modules_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_instance_process_threads(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_instance_process_threads_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_instance_processes(
                self, 
                resource_group_name: str, 
                name: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_instance_processes_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                instance_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_instance_workflows_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[WorkflowEnvelope]: ...

        @distributed_trace
        def list_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> StringDictionary: ...

        @distributed_trace
        def list_network_features(
                self, 
                resource_group_name: str, 
                name: str, 
                view: str, 
                **kwargs: Any
            ) -> NetworkFeatures: ...

        @distributed_trace
        def list_network_features_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                view: str, 
                slot: str, 
                **kwargs: Any
            ) -> NetworkFeatures: ...

        @distributed_trace
        def list_perf_mon_counters(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[PerfMonResponse]: ...

        @distributed_trace
        def list_perf_mon_counters_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[PerfMonResponse]: ...

        @distributed_trace
        def list_premier_add_ons(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace
        def list_premier_add_ons_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @distributed_trace
        def list_process_modules(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_process_modules_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessModuleInfo]: ...

        @distributed_trace
        def list_process_threads(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_process_threads_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                process_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessThreadInfo]: ...

        @distributed_trace
        def list_processes(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_processes_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[ProcessInfo]: ...

        @distributed_trace
        def list_production_site_deployment_statuses(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[CsmDeploymentStatus]: ...

        @distributed_trace
        def list_public_certificates(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[PublicCertificate]: ...

        @distributed_trace
        def list_public_certificates_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[PublicCertificate]: ...

        @overload
        def list_publishing_profile_xml_with_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @overload
        def list_publishing_profile_xml_with_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @overload
        def list_publishing_profile_xml_with_secrets(
                self, 
                resource_group_name: str, 
                name: str, 
                publishing_profile_options: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @overload
        def list_publishing_profile_xml_with_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @overload
        def list_publishing_profile_xml_with_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                publishing_profile_options: CsmPublishingProfileOptions, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @overload
        def list_publishing_profile_xml_with_secrets_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                publishing_profile_options: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Iterator[bytes]: ...

        @distributed_trace
        def list_relay_service_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace
        def list_relay_service_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @distributed_trace
        def list_site_backups(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[BackupItem]: ...

        @distributed_trace
        def list_site_backups_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[BackupItem]: ...

        @distributed_trace
        def list_site_containers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteContainer]: ...

        @distributed_trace
        def list_site_containers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteContainer]: ...

        @distributed_trace
        def list_site_extensions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteExtensionInfo]: ...

        @distributed_trace
        def list_site_extensions_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[SiteExtensionInfo]: ...

        @distributed_trace
        def list_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> PushSettings: ...

        @distributed_trace
        def list_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> PushSettings: ...

        @distributed_trace
        def list_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        def list_slot_differences_from_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_from_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_from_production(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: CsmSlotEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[SlotDifference]: ...

        @overload
        def list_slot_differences_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                slot_swap_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ItemPaged[SlotDifference]: ...

        @distributed_trace
        def list_slot_site_deployment_statuses_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[CsmDeploymentStatus]: ...

        @distributed_trace
        def list_slots(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Site]: ...

        @distributed_trace
        def list_snapshots(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Snapshot]: ...

        @distributed_trace
        def list_snapshots_from_dr_secondary(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[Snapshot]: ...

        @distributed_trace
        def list_snapshots_from_dr_secondary_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[Snapshot]: ...

        @distributed_trace
        def list_snapshots_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[Snapshot]: ...

        @distributed_trace
        def list_sync_function_triggers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace
        def list_sync_function_triggers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> FunctionSecrets: ...

        @distributed_trace
        def list_sync_status(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def list_sync_status_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def list_triggered_web_job_history(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> ItemPaged[TriggeredJobHistory]: ...

        @distributed_trace
        def list_triggered_web_job_history_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[TriggeredJobHistory]: ...

        @distributed_trace
        def list_triggered_web_jobs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[TriggeredWebJob]: ...

        @distributed_trace
        def list_triggered_web_jobs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[TriggeredWebJob]: ...

        @distributed_trace
        def list_usages(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[CsmUsageQuota]: ...

        @distributed_trace
        def list_usages_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                filter: Optional[str] = ..., 
                **kwargs: Any
            ) -> ItemPaged[CsmUsageQuota]: ...

        @distributed_trace
        def list_vnet_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> List[VnetInfoResource]: ...

        @distributed_trace
        def list_vnet_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> List[VnetInfoResource]: ...

        @distributed_trace
        def list_web_jobs(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[WebJob]: ...

        @distributed_trace
        def list_web_jobs_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> ItemPaged[WebJob]: ...

        @distributed_trace
        def list_workflows(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> ItemPaged[WorkflowEnvelope]: ...

        @distributed_trace
        def list_workflows_connections(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @distributed_trace
        def list_workflows_connections_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> WorkflowEnvelope: ...

        @overload
        def put_private_access_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        def put_private_access_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        def put_private_access_vnet(
                self, 
                resource_group_name: str, 
                name: str, 
                access: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        def put_private_access_vnet_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        def put_private_access_vnet_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                access: PrivateAccess, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @overload
        def put_private_access_vnet_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                access: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PrivateAccess: ...

        @distributed_trace
        def recover_site_configuration_snapshot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def recover_site_configuration_snapshot_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                snapshot_id: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def reset_production_slot_config(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def reset_slot_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def restart(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                soft_restart: Optional[bool] = ..., 
                synchronous: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def restart_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                soft_restart: Optional[bool] = ..., 
                synchronous: Optional[bool] = ..., 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def run_triggered_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def run_triggered_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def start(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def start_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def start_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def start_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def start_web_site_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace
        def start_web_site_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                *, 
                duration_in_seconds: Optional[int] = ..., 
                max_frame_length: Optional[int] = ..., 
                sas_url: Optional[str] = ..., 
                **kwargs: Any
            ) -> str: ...

        @distributed_trace
        def stop(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_continuous_web_job(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_continuous_web_job_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                web_job_name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_web_site_network_trace(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def stop_web_site_network_trace_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def sync_function_triggers(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def sync_function_triggers_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def sync_functions(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def sync_functions_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def sync_repository(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def sync_repository_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                **kwargs: Any
            ) -> None: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        def update(
                self, 
                resource_group_name: str, 
                name: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        def update_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_application_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                app_settings: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_application_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                app_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        def update_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        def update_auth_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        def update_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        def update_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings: SiteAuthSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        def update_auth_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettings: ...

        @overload
        def update_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        def update_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        def update_auth_settings_v2(
                self, 
                resource_group_name: str, 
                name: str, 
                site_auth_settings_v2: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        def update_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        def update_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings_v2: SiteAuthSettingsV2, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        def update_auth_settings_v2_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_auth_settings_v2: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteAuthSettingsV2: ...

        @overload
        def update_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def update_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def update_azure_storage_accounts(
                self, 
                resource_group_name: str, 
                name: str, 
                azure_storage_accounts: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def update_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def update_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                azure_storage_accounts: AzureStoragePropertyDictionaryResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def update_azure_storage_accounts_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                azure_storage_accounts: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> AzureStoragePropertyDictionaryResource: ...

        @overload
        def update_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        def update_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        def update_backup_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        def update_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        def update_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: BackupRequest, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        def update_backup_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                request: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> BackupRequest: ...

        @overload
        def update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def update_configuration(
                self, 
                resource_group_name: str, 
                name: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: SiteConfigResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def update_configuration_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteConfigResource: ...

        @overload
        def update_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        def update_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        def update_connection_strings(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_strings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        def update_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        def update_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_strings: ConnectionStringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        def update_connection_strings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_strings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> ConnectionStringDictionary: ...

        @overload
        def update_diagnostic_logs_config(
                self, 
                resource_group_name: str, 
                name: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        def update_diagnostic_logs_config(
                self, 
                resource_group_name: str, 
                name: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        def update_diagnostic_logs_config(
                self, 
                resource_group_name: str, 
                name: str, 
                site_logs_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        def update_diagnostic_logs_config_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        def update_diagnostic_logs_config_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_logs_config: SiteLogsConfig, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        def update_diagnostic_logs_config_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_logs_config: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteLogsConfig: ...

        @overload
        def update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def update_domain_ownership_identifier(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: Identifier, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def update_domain_ownership_identifier_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                domain_ownership_identifier_name: str, 
                slot: str, 
                domain_ownership_identifier: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Identifier: ...

        @overload
        def update_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_ftp_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_ftp_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def update_hybrid_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: HybridConnection, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @overload
        def update_hybrid_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                namespace_name: str, 
                relay_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> HybridConnection: ...

        @distributed_trace
        def update_machine_key(
                self, 
                resource_group_name: str, 
                name: str, 
                **kwargs: Any
            ) -> Any: ...

        @overload
        def update_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_metadata(
                self, 
                resource_group_name: str, 
                name: str, 
                metadata: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                metadata: StringDictionary, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_metadata_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                metadata: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> StringDictionary: ...

        @overload
        def update_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def update_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def update_premier_add_on(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def update_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def update_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: PremierAddOnPatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def update_premier_add_on_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                premier_add_on_name: str, 
                slot: str, 
                premier_add_on: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PremierAddOn: ...

        @overload
        def update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def update_relay_service_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: RelayServiceConnectionEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def update_relay_service_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                entity_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> RelayServiceConnectionEntity: ...

        @overload
        def update_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_scm_allowed(
                self, 
                resource_group_name: str, 
                name: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: CsmPublishingCredentialsPoliciesEntity, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_scm_allowed_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                csm_publishing_access_policies_entity: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> CsmPublishingCredentialsPoliciesEntity: ...

        @overload
        def update_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        def update_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        def update_site_push_settings(
                self, 
                resource_group_name: str, 
                name: str, 
                push_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        def update_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        def update_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                push_settings: PushSettings, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        def update_site_push_settings_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                push_settings: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> PushSettings: ...

        @overload
        def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: SitePatchResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        def update_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> Site: ...

        @overload
        def update_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_config_names: SlotConfigNamesResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        def update_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_config_names: SlotConfigNamesResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        def update_slot_configuration_names(
                self, 
                resource_group_name: str, 
                name: str, 
                slot_config_names: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SlotConfigNamesResource: ...

        @overload
        def update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        def update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        def update_source_control(
                self, 
                resource_group_name: str, 
                name: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        def update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        def update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: SiteSourceControl, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        def update_source_control_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                site_source_control: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SiteSourceControl: ...

        @overload
        def update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def update_swift_virtual_network_connection_with_check(
                self, 
                resource_group_name: str, 
                name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: SwiftVirtualNetwork, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def update_swift_virtual_network_connection_with_check_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> SwiftVirtualNetwork: ...

        @overload
        def update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def update_vnet_connection(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_connection_gateway(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: VnetGateway, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_connection_gateway_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                gateway_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetGateway: ...

        @overload
        def update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: VnetInfoResource, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...

        @overload
        def update_vnet_connection_slot(
                self, 
                resource_group_name: str, 
                name: str, 
                vnet_name: str, 
                slot: str, 
                connection_envelope: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> VnetInfoResource: ...


    class azure.mgmt.web.operations.WorkflowRunActionRepetitionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> WorkflowRunActionRepetitionDefinition: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> ItemPaged[WorkflowRunActionRepetitionDefinition]: ...

        @distributed_trace
        def list_expression_traces(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> ItemPaged[ExpressionRoot]: ...


    class azure.mgmt.web.operations.WorkflowRunActionRepetitionsRequestHistoriesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                request_history_name: str, 
                **kwargs: Any
            ) -> RequestHistory: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> ItemPaged[RequestHistory]: ...


    class azure.mgmt.web.operations.WorkflowRunActionScopeRepetitionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                repetition_name: str, 
                **kwargs: Any
            ) -> WorkflowRunActionRepetitionDefinition: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> ItemPaged[WorkflowRunActionRepetitionDefinition]: ...


    class azure.mgmt.web.operations.WorkflowRunActionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> WorkflowRunAction: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WorkflowRunAction]: ...

        @distributed_trace
        def list_expression_traces(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                action_name: str, 
                **kwargs: Any
            ) -> ItemPaged[ExpressionRoot]: ...


    class azure.mgmt.web.operations.WorkflowRunsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def cancel(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                **kwargs: Any
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                run_name: str, 
                **kwargs: Any
            ) -> WorkflowRun: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WorkflowRun]: ...


    class azure.mgmt.web.operations.WorkflowTriggerHistoriesOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def begin_resubmit(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                history_name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                history_name: str, 
                **kwargs: Any
            ) -> WorkflowTriggerHistory: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WorkflowTriggerHistory]: ...


    class azure.mgmt.web.operations.WorkflowTriggersOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def begin_run(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> LROPoller[None]: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> WorkflowTrigger: ...

        @distributed_trace
        def get_schema_json(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> JsonSchema: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                *, 
                filter: Optional[str] = ..., 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WorkflowTrigger]: ...

        @distributed_trace
        def list_callback_url(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                trigger_name: str, 
                **kwargs: Any
            ) -> WorkflowTriggerCallbackUrl: ...


    class azure.mgmt.web.operations.WorkflowVersionsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @distributed_trace
        def get(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                version_id: str, 
                **kwargs: Any
            ) -> WorkflowVersion: ...

        @distributed_trace
        def list(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                *, 
                top: Optional[int] = ..., 
                **kwargs: Any
            ) -> ItemPaged[WorkflowVersion]: ...


    class azure.mgmt.web.operations.WorkflowsOperations:

        def __init__(
                self, 
                *args, 
                **kwargs
            ) -> None: ...

        @overload
        def regenerate_access_key(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                key_type: RegenerateActionParameter, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def regenerate_access_key(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                key_type: RegenerateActionParameter, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def regenerate_access_key(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                key_type: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def validate(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                validate: Workflow, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def validate(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                validate: Workflow, 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...

        @overload
        def validate(
                self, 
                resource_group_name: str, 
                name: str, 
                workflow_name: str, 
                validate: IO[bytes], 
                *, 
                content_type: str = "application/json", 
                **kwargs: Any
            ) -> None: ...


namespace azure.mgmt.web.types

    class azure.mgmt.web.types.AllowedAudiencesValidation(TypedDict, total=False):
        allowedAudiences: list[str]
        allowed_audiences: list[str]


    class azure.mgmt.web.types.AllowedPrincipals(TypedDict, total=False):
        groups: list[str]
        identities: list[str]


    class azure.mgmt.web.types.ApiDefinitionInfo(TypedDict, total=False):
        key "url": str
        url: str


    class azure.mgmt.web.types.ApiManagementConfig(TypedDict, total=False):
        key "id": str
        id: str


    class azure.mgmt.web.types.AppLogsConfiguration(TypedDict, total=False):
        key "destination": str
        key "logAnalyticsConfiguration": ForwardRef('LogAnalyticsConfiguration', module='types')
        destination: str
        log_analytics_configuration: LogAnalyticsConfiguration


    class azure.mgmt.web.types.AppRegistration(TypedDict, total=False):
        key "appId": str
        key "appSecretSettingName": str
        app_id: str
        app_secret_setting_name: str


    class azure.mgmt.web.types.AppServiceEnvironment(TypedDict, total=False):
        key "customDnsSuffixConfiguration": ForwardRef('CustomDnsSuffixConfiguration', module='types')
        key "dedicatedHostCount": int
        key "dnsSuffix": str
        key "frontEndScaleFactor": int
        key "hasLinuxWorkers": bool
        key "internalLoadBalancingMode": Union[str, LoadBalancingMode]
        key "ipsslAddressCount": int
        key "maximumNumberOfMachines": int
        key "multiRoleCount": int
        key "multiSize": str
        key "networkingConfiguration": ForwardRef('AseV3NetworkingConfiguration', module='types')
        key "provisioningState": Union[str, ProvisioningState]
        key "status": Union[str, HostingEnvironmentStatus]
        key "suspended": bool
        key "upgradeAvailability": Union[str, UpgradeAvailability]
        key "upgradePreference": Union[str, UpgradePreference]
        key "virtualNetwork": Required[VirtualNetworkProfile]
        key "zoneRedundant": bool
        clusterSettings: list[NameValuePair]
        cluster_settings: list[NameValuePair]
        custom_dns_suffix_configuration: CustomDnsSuffixConfiguration
        dedicated_host_count: int
        dns_suffix: str
        front_end_scale_factor: int
        has_linux_workers: bool
        internal_load_balancing_mode: Union[str, LoadBalancingMode]
        ipssl_address_count: int
        maximum_number_of_machines: int
        multi_role_count: int
        multi_size: str
        networking_configuration: AseV3NetworkingConfiguration
        provisioning_state: Union[str, ProvisioningState]
        status: Union[str, HostingEnvironmentStatus]
        suspended: bool
        upgrade_availability: Union[str, UpgradeAvailability]
        upgrade_preference: Union[str, UpgradePreference]
        userWhitelistedIpRanges: list[str]
        user_whitelisted_ip_ranges: list[str]
        virtual_network: VirtualNetworkProfile
        zone_redundant: bool


    class azure.mgmt.web.types.AppServiceEnvironmentPatchResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('AppServiceEnvironment', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: AppServiceEnvironment
        type: str


    class azure.mgmt.web.types.AppServiceEnvironmentResource(TrackedResource):
        key "id": str
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('AppServiceEnvironment', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        location: str
        name: str
        properties: AppServiceEnvironment
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.AppServicePlan(TrackedResource):
        key "extendedLocation": ForwardRef('ExtendedLocation', module='types')
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('AppServicePlanProperties', module='types')
        key "sku": ForwardRef('SkuDescription', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        extended_location: ExtendedLocation
        id: str
        identity: ManagedServiceIdentity
        kind: str
        location: str
        name: str
        properties: AppServicePlanProperties
        sku: SkuDescription
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.AppServicePlanPatchResource(ProxyOnlyResource):
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "kind": str
        key "name": str
        key "properties": ForwardRef('AppServicePlanPatchResourceProperties', module='types')
        key "type": str
        id: str
        identity: ManagedServiceIdentity
        kind: str
        name: str
        properties: AppServicePlanPatchResourceProperties
        type: str


    class azure.mgmt.web.types.AppServicePlanPatchResourceProperties(TypedDict, total=False):
        key "elasticScaleEnabled": bool
        key "freeOfferExpirationTime": str
        key "geoRegion": str
        key "hostingEnvironmentProfile": ForwardRef('HostingEnvironmentProfile', module='types')
        key "hyperV": bool
        key "isSpot": bool
        key "isXenon": bool
        key "kubeEnvironmentProfile": ForwardRef('KubeEnvironmentProfile', module='types')
        key "maximumElasticWorkerCount": int
        key "maximumNumberOfWorkers": int
        key "numberOfSites": int
        key "numberOfWorkers": int
        key "perSiteScaling": bool
        key "provisioningState": Union[str, ProvisioningState]
        key "reserved": bool
        key "resourceGroup": str
        key "spotExpirationTime": str
        key "status": Union[str, StatusOptions]
        key "subscription": str
        key "targetWorkerCount": int
        key "targetWorkerSizeId": int
        key "workerTierName": str
        key "zoneRedundant": bool
        elastic_scale_enabled: bool
        free_offer_expiration_time: str
        geo_region: str
        hosting_environment_profile: HostingEnvironmentProfile
        hyper_v: bool
        is_spot: bool
        is_xenon: bool
        kube_environment_profile: KubeEnvironmentProfile
        maximum_elastic_worker_count: int
        maximum_number_of_workers: int
        number_of_sites: int
        number_of_workers: int
        per_site_scaling: bool
        provisioning_state: Union[str, ProvisioningState]
        reserved: bool
        resource_group: str
        spot_expiration_time: str
        status: Union[str, StatusOptions]
        subscription: str
        target_worker_count: int
        target_worker_size_id: int
        worker_tier_name: str
        zone_redundant: bool


    class azure.mgmt.web.types.AppServicePlanProperties(TypedDict, total=False):
        key "asyncScalingEnabled": bool
        key "elasticScaleEnabled": bool
        key "freeOfferExpirationTime": str
        key "geoRegion": str
        key "hostingEnvironmentProfile": ForwardRef('HostingEnvironmentProfile', module='types')
        key "hyperV": bool
        key "isCustomMode": bool
        key "isSpot": bool
        key "isXenon": bool
        key "kubeEnvironmentProfile": ForwardRef('KubeEnvironmentProfile', module='types')
        key "maximumElasticWorkerCount": int
        key "maximumNumberOfWorkers": int
        key "network": ForwardRef('ServerFarmNetworkSettings', module='types')
        key "numberOfSites": int
        key "numberOfWorkers": int
        key "perSiteScaling": bool
        key "planDefaultIdentity": ForwardRef('DefaultIdentity', module='types')
        key "provisioningState": Union[str, ProvisioningState]
        key "rdpEnabled": bool
        key "reserved": bool
        key "resourceGroup": str
        key "spotExpirationTime": str
        key "status": Union[str, StatusOptions]
        key "subscription": str
        key "targetWorkerCount": int
        key "targetWorkerSizeId": int
        key "workerTierName": str
        key "zoneRedundant": bool
        async_scaling_enabled: bool
        elastic_scale_enabled: bool
        free_offer_expiration_time: str
        geo_region: str
        hosting_environment_profile: HostingEnvironmentProfile
        hyper_v: bool
        installScripts: list[InstallScript]
        install_scripts: list[InstallScript]
        is_custom_mode: bool
        is_spot: bool
        is_xenon: bool
        kube_environment_profile: KubeEnvironmentProfile
        maximum_elastic_worker_count: int
        maximum_number_of_workers: int
        network: ServerFarmNetworkSettings
        number_of_sites: int
        number_of_workers: int
        per_site_scaling: bool
        plan_default_identity: DefaultIdentity
        provisioning_state: Union[str, ProvisioningState]
        rdp_enabled: bool
        registryAdapters: list[RegistryAdapter]
        registry_adapters: list[RegistryAdapter]
        reserved: bool
        resource_group: str
        spot_expiration_time: str
        status: Union[str, StatusOptions]
        storageMounts: list[StorageMount]
        storage_mounts: list[StorageMount]
        subscription: str
        target_worker_count: int
        target_worker_size_id: int
        worker_tier_name: str
        zone_redundant: bool


    class azure.mgmt.web.types.Apple(TypedDict, total=False):
        key "enabled": bool
        key "login": ForwardRef('LoginScopes', module='types')
        key "registration": ForwardRef('AppleRegistration', module='types')
        enabled: bool
        login: LoginScopes
        registration: AppleRegistration


    class azure.mgmt.web.types.AppleRegistration(TypedDict, total=False):
        key "clientId": str
        key "clientSecretSettingName": str
        client_id: str
        client_secret_setting_name: str


    class azure.mgmt.web.types.ApplicationLogsConfig(TypedDict, total=False):
        key "azureBlobStorage": ForwardRef('AzureBlobStorageApplicationLogsConfig', module='types')
        key "azureTableStorage": ForwardRef('AzureTableStorageApplicationLogsConfig', module='types')
        key "fileSystem": ForwardRef('FileSystemApplicationLogsConfig', module='types')
        azure_blob_storage: AzureBlobStorageApplicationLogsConfig
        azure_table_storage: AzureTableStorageApplicationLogsConfig
        file_system: FileSystemApplicationLogsConfig


    class azure.mgmt.web.types.ArcConfiguration(TypedDict, total=False):
        key "artifactStorageAccessMode": str
        key "artifactStorageClassName": str
        key "artifactStorageMountPath": str
        key "artifactStorageNodeName": str
        key "artifactsStorageType": Union[str, StorageType]
        key "frontEndServiceConfiguration": ForwardRef('FrontEndConfiguration', module='types')
        key "kubeConfig": str
        artifact_storage_access_mode: str
        artifact_storage_class_name: str
        artifact_storage_mount_path: str
        artifact_storage_node_name: str
        artifacts_storage_type: Union[str, StorageType]
        front_end_service_configuration: FrontEndConfiguration
        kube_config: str


    class azure.mgmt.web.types.ArmIdWrapper(TypedDict, total=False):
        key "id": str
        id: str


    class azure.mgmt.web.types.ArmPlan(TypedDict, total=False):
        key "name": str
        key "product": str
        key "promotionCode": str
        key "publisher": str
        key "version": str
        name: str
        product: str
        promotion_code: str
        publisher: str
        version: str


    class azure.mgmt.web.types.AseV3NetworkingConfiguration(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('AseV3NetworkingConfigurationProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: AseV3NetworkingConfigurationProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.AseV3NetworkingConfigurationProperties(TypedDict, total=False):
        key "allowNewPrivateEndpointConnections": bool
        key "ftpEnabled": bool
        key "inboundIpAddressOverride": str
        key "remoteDebugEnabled": bool
        allow_new_private_endpoint_connections: bool
        externalInboundIpAddresses: list[str]
        external_inbound_ip_addresses: list[str]
        ftp_enabled: bool
        inbound_ip_address_override: str
        internalInboundIpAddresses: list[str]
        internal_inbound_ip_addresses: list[str]
        linuxOutboundIpAddresses: list[str]
        linux_outbound_ip_addresses: list[str]
        remote_debug_enabled: bool
        windowsOutboundIpAddresses: list[str]
        windows_outbound_ip_addresses: list[str]


    class azure.mgmt.web.types.AuthPlatform(TypedDict, total=False):
        key "configFilePath": str
        key "enabled": bool
        key "runtimeVersion": str
        config_file_path: str
        enabled: bool
        runtime_version: str


    class azure.mgmt.web.types.AutoHealActions(TypedDict, total=False):
        key "actionType": Union[str, AutoHealActionType]
        key "customAction": ForwardRef('AutoHealCustomAction', module='types')
        key "minProcessExecutionTime": str
        action_type: Union[str, AutoHealActionType]
        custom_action: AutoHealCustomAction
        min_process_execution_time: str


    class azure.mgmt.web.types.AutoHealCustomAction(TypedDict, total=False):
        key "exe": str
        key "parameters": str
        exe: str
        parameters: str


    class azure.mgmt.web.types.AutoHealRules(TypedDict, total=False):
        key "actions": ForwardRef('AutoHealActions', module='types')
        key "triggers": ForwardRef('AutoHealTriggers', module='types')
        actions: AutoHealActions
        triggers: AutoHealTriggers


    class azure.mgmt.web.types.AutoHealTriggers(TypedDict, total=False):
        key "privateBytesInKB": int
        key "requests": ForwardRef('RequestsBasedTrigger', module='types')
        key "slowRequests": ForwardRef('SlowRequestsBasedTrigger', module='types')
        private_bytes_in_kb: int
        requests: RequestsBasedTrigger
        slowRequestsWithPath: list[SlowRequestsBasedTrigger]
        slow_requests: SlowRequestsBasedTrigger
        slow_requests_with_path: list[SlowRequestsBasedTrigger]
        statusCodes: list[StatusCodesBasedTrigger]
        statusCodesRange: list[StatusCodesRangeBasedTrigger]
        status_codes: list[StatusCodesBasedTrigger]
        status_codes_range: list[StatusCodesRangeBasedTrigger]


    class azure.mgmt.web.types.AzureActiveDirectory(TypedDict, total=False):
        key "enabled": bool
        key "isAutoProvisioned": bool
        key "login": ForwardRef('AzureActiveDirectoryLogin', module='types')
        key "registration": ForwardRef('AzureActiveDirectoryRegistration', module='types')
        key "validation": ForwardRef('AzureActiveDirectoryValidation', module='types')
        enabled: bool
        is_auto_provisioned: bool
        login: AzureActiveDirectoryLogin
        registration: AzureActiveDirectoryRegistration
        validation: AzureActiveDirectoryValidation


    class azure.mgmt.web.types.AzureActiveDirectoryLogin(TypedDict, total=False):
        key "disableWWWAuthenticate": bool
        disable_www_authenticate: bool
        loginParameters: list[str]
        login_parameters: list[str]


    class azure.mgmt.web.types.AzureActiveDirectoryRegistration(TypedDict, total=False):
        key "clientId": str
        key "clientSecretCertificateIssuer": str
        key "clientSecretCertificateSubjectAlternativeName": str
        key "clientSecretCertificateThumbprint": str
        key "clientSecretSettingName": str
        key "openIdIssuer": str
        client_id: str
        client_secret_certificate_issuer: str
        client_secret_certificate_subject_alternative_name: str
        client_secret_certificate_thumbprint: str
        client_secret_setting_name: str
        open_id_issuer: str


    class azure.mgmt.web.types.AzureActiveDirectoryValidation(TypedDict, total=False):
        key "defaultAuthorizationPolicy": ForwardRef('DefaultAuthorizationPolicy', module='types')
        key "jwtClaimChecks": ForwardRef('JwtClaimChecks', module='types')
        allowedAudiences: list[str]
        allowed_audiences: list[str]
        default_authorization_policy: DefaultAuthorizationPolicy
        jwt_claim_checks: JwtClaimChecks


    class azure.mgmt.web.types.AzureBlobStorageApplicationLogsConfig(TypedDict, total=False):
        key "level": Union[str, LogLevel]
        key "retentionInDays": int
        key "sasUrl": str
        level: Union[str, LogLevel]
        retention_in_days: int
        sas_url: str


    class azure.mgmt.web.types.AzureBlobStorageHttpLogsConfig(TypedDict, total=False):
        key "enabled": bool
        key "retentionInDays": int
        key "sasUrl": str
        enabled: bool
        retention_in_days: int
        sas_url: str


    class azure.mgmt.web.types.AzureStaticWebApps(TypedDict, total=False):
        key "enabled": bool
        key "registration": ForwardRef('AzureStaticWebAppsRegistration', module='types')
        enabled: bool
        registration: AzureStaticWebAppsRegistration


    class azure.mgmt.web.types.AzureStaticWebAppsRegistration(TypedDict, total=False):
        key "clientId": str
        client_id: str


    class azure.mgmt.web.types.AzureStorageInfoValue(TypedDict, total=False):
        key "accessKey": str
        key "accountName": str
        key "mountPath": str
        key "protocol": Union[str, AzureStorageProtocol]
        key "shareName": str
        key "state": Union[str, AzureStorageState]
        key "type": Union[str, AzureStorageType]
        access_key: str
        account_name: str
        mount_path: str
        protocol: Union[str, AzureStorageProtocol]
        share_name: str
        state: Union[str, AzureStorageState]
        type: Union[str, AzureStorageType]


    class azure.mgmt.web.types.AzureStoragePropertyDictionaryResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "type": str
        id: str
        kind: str
        name: str
        properties: dict[str, AzureStorageInfoValue]
        type: str


    class azure.mgmt.web.types.AzureTableStorageApplicationLogsConfig(TypedDict, total=False):
        key "level": Union[str, LogLevel]
        key "sasUrl": Required[str]
        level: Union[str, LogLevel]
        sas_url: str


    class azure.mgmt.web.types.BackupRequest(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('BackupRequestProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: BackupRequestProperties
        type: str


    class azure.mgmt.web.types.BackupRequestProperties(TypedDict, total=False):
        key "backupName": str
        key "backupSchedule": ForwardRef('BackupSchedule', module='types')
        key "enabled": bool
        key "storageAccountUrl": Required[str]
        backup_name: str
        backup_schedule: BackupSchedule
        databases: list[DatabaseBackupSetting]
        enabled: bool
        storage_account_url: str


    class azure.mgmt.web.types.BackupSchedule(TypedDict, total=False):
        key "frequencyInterval": Required[int]
        key "frequencyUnit": Required[Union[str, FrequencyUnit]]
        key "keepAtLeastOneBackup": Required[bool]
        key "lastExecutionTime": str
        key "retentionPeriodInDays": Required[int]
        key "startTime": str
        frequency_interval: int
        frequency_unit: Union[str, FrequencyUnit]
        keep_at_least_one_backup: bool
        last_execution_time: str
        retention_period_in_days: int
        start_time: str


    class azure.mgmt.web.types.BlobStorageTokenStore(TypedDict, total=False):
        key "sasUrlSettingName": str
        sas_url_setting_name: str


    class azure.mgmt.web.types.Capability(TypedDict, total=False):
        key "name": str
        key "reason": str
        key "value": str
        name: str
        reason: str
        value: str


    class azure.mgmt.web.types.Certificate(TrackedResource):
        key "id": str
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('CertificateProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        location: str
        name: str
        properties: CertificateProperties
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.CertificatePatchResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('CertificatePatchResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: CertificatePatchResourceProperties
        type: str


    class azure.mgmt.web.types.CertificatePatchResourceProperties(TypedDict, total=False):
        key "canonicalName": str
        key "cerBlob": str
        key "domainValidationMethod": str
        key "expirationDate": str
        key "friendlyName": str
        key "hostingEnvironmentProfile": ForwardRef('HostingEnvironmentProfile', module='types')
        key "issueDate": str
        key "issuer": str
        key "keyVaultId": str
        key "keyVaultSecretName": str
        key "keyVaultSecretStatus": Union[str, KeyVaultSecretStatus]
        key "password": str
        key "pfxBlob": str
        key "publicKeyHash": str
        key "selfLink": str
        key "serverFarmId": str
        key "siteName": str
        key "subjectName": str
        key "thumbprint": str
        key "valid": bool
        canonical_name: str
        cer_blob: str
        domain_validation_method: str
        expiration_date: str
        friendly_name: str
        hostNames: list[str]
        host_names: list[str]
        hosting_environment_profile: HostingEnvironmentProfile
        issue_date: str
        issuer: str
        key_vault_id: str
        key_vault_secret_name: str
        key_vault_secret_status: Union[str, KeyVaultSecretStatus]
        password: str
        pfx_blob: str
        public_key_hash: str
        self_link: str
        server_farm_id: str
        site_name: str
        subject_name: str
        thumbprint: str
        valid: bool


    class azure.mgmt.web.types.CertificateProperties(TypedDict, total=False):
        key "canonicalName": str
        key "cerBlob": str
        key "domainValidationMethod": str
        key "expirationDate": str
        key "friendlyName": str
        key "hostingEnvironmentProfile": ForwardRef('HostingEnvironmentProfile', module='types')
        key "issueDate": str
        key "issuer": str
        key "keyVaultId": str
        key "keyVaultSecretName": str
        key "keyVaultSecretStatus": Union[str, KeyVaultSecretStatus]
        key "password": str
        key "pfxBlob": str
        key "publicKeyHash": str
        key "selfLink": str
        key "serverFarmId": str
        key "siteName": str
        key "subjectName": str
        key "thumbprint": str
        key "valid": bool
        canonical_name: str
        cer_blob: str
        domain_validation_method: str
        expiration_date: str
        friendly_name: str
        hostNames: list[str]
        host_names: list[str]
        hosting_environment_profile: HostingEnvironmentProfile
        issue_date: str
        issuer: str
        key_vault_id: str
        key_vault_secret_name: str
        key_vault_secret_status: Union[str, KeyVaultSecretStatus]
        password: str
        pfx_blob: str
        public_key_hash: str
        self_link: str
        server_farm_id: str
        site_name: str
        subject_name: str
        thumbprint: str
        valid: bool


    class azure.mgmt.web.types.ClientRegistration(TypedDict, total=False):
        key "clientId": str
        key "clientSecretSettingName": str
        client_id: str
        client_secret_setting_name: str


    class azure.mgmt.web.types.CloningInfo(TypedDict, total=False):
        key "cloneCustomHostNames": bool
        key "cloneSourceControl": bool
        key "configureLoadBalancing": bool
        key "correlationId": str
        key "hostingEnvironment": str
        key "overwrite": bool
        key "sourceWebAppId": Required[str]
        key "sourceWebAppLocation": str
        key "trafficManagerProfileId": str
        key "trafficManagerProfileName": str
        appSettingsOverrides: dict[str, str]
        app_settings_overrides: dict[str, str]
        clone_custom_host_names: bool
        clone_source_control: bool
        configure_load_balancing: bool
        correlation_id: str
        hosting_environment: str
        overwrite: bool
        source_web_app_id: str
        source_web_app_location: str
        traffic_manager_profile_id: str
        traffic_manager_profile_name: str


    class azure.mgmt.web.types.ConnStringInfo(TypedDict, total=False):
        key "connectionString": str
        key "name": str
        key "type": Union[str, ConnectionStringType]
        connection_string: str
        name: str
        type: Union[str, ConnectionStringType]


    class azure.mgmt.web.types.ConnStringValueTypePair(TypedDict, total=False):
        key "type": Required[Union[str, ConnectionStringType]]
        key "value": Required[str]
        type: Union[str, ConnectionStringType]
        value: str


    class azure.mgmt.web.types.ConnectionStringDictionary(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "type": str
        id: str
        kind: str
        name: str
        properties: dict[str, ConnStringValueTypePair]
        type: str


    class azure.mgmt.web.types.ContainerAppsConfiguration(TypedDict, total=False):
        key "appSubnetResourceId": str
        key "controlPlaneSubnetResourceId": str
        key "daprAIInstrumentationKey": str
        key "dockerBridgeCidr": str
        key "platformReservedCidr": str
        key "platformReservedDnsIP": str
        app_subnet_resource_id: str
        control_plane_subnet_resource_id: str
        dapr_ai_instrumentation_key: str
        docker_bridge_cidr: str
        platform_reserved_cidr: str
        platform_reserved_dns_ip: str


    class azure.mgmt.web.types.CookieExpiration(TypedDict, total=False):
        key "convention": Union[str, CookieExpirationConvention]
        key "timeToExpiration": str
        convention: Union[str, CookieExpirationConvention]
        time_to_expiration: str


    class azure.mgmt.web.types.CorsSettings(TypedDict, total=False):
        key "supportCredentials": bool
        allowedOrigins: list[str]
        allowed_origins: list[str]
        support_credentials: bool


    class azure.mgmt.web.types.CsmMoveResourceEnvelope(TypedDict, total=False):
        key "targetResourceGroup": str
        resources: list[str]
        target_resource_group: str


    class azure.mgmt.web.types.CsmPublishingCredentialsPoliciesEntity(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('CsmPublishingCredentialsPoliciesEntityProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: CsmPublishingCredentialsPoliciesEntityProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.CsmPublishingCredentialsPoliciesEntityProperties(TypedDict, total=False):
        key "allow": Required[bool]
        allow: bool


    class azure.mgmt.web.types.CsmPublishingProfileOptions(TypedDict, total=False):
        key "format": Union[str, PublishingProfileFormat]
        key "includeDisasterRecoveryEndpoints": bool
        format: Union[str, PublishingProfileFormat]
        include_disaster_recovery_endpoints: bool


    class azure.mgmt.web.types.CsmSlotEntity(TypedDict, total=False):
        key "preserveVnet": Required[bool]
        key "targetSlot": Required[str]
        preserve_vnet: bool
        target_slot: str


    class azure.mgmt.web.types.CustomDnsSuffixConfiguration(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('CustomDnsSuffixConfigurationProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: CustomDnsSuffixConfigurationProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.CustomDnsSuffixConfigurationProperties(TypedDict, total=False):
        key "certificateUrl": str
        key "dnsSuffix": str
        key "keyVaultReferenceIdentity": str
        key "provisioningDetails": str
        key "provisioningState": Union[str, CustomDnsSuffixProvisioningState]
        certificate_url: str
        dns_suffix: str
        key_vault_reference_identity: str
        provisioning_details: str
        provisioning_state: Union[str, CustomDnsSuffixProvisioningState]


    class azure.mgmt.web.types.CustomOpenIdConnectProvider(TypedDict, total=False):
        key "enabled": bool
        key "login": ForwardRef('OpenIdConnectLogin', module='types')
        key "registration": ForwardRef('OpenIdConnectRegistration', module='types')
        enabled: bool
        login: OpenIdConnectLogin
        registration: OpenIdConnectRegistration


    class azure.mgmt.web.types.DaprConfig(TypedDict, total=False):
        key "appId": str
        key "appPort": int
        key "enableApiLogging": bool
        key "enabled": bool
        key "httpMaxRequestSize": int
        key "httpReadBufferSize": int
        key "logLevel": Union[str, DaprLogLevel]
        app_id: str
        app_port: int
        enable_api_logging: bool
        enabled: bool
        http_max_request_size: int
        http_read_buffer_size: int
        log_level: Union[str, DaprLogLevel]


    class azure.mgmt.web.types.DatabaseBackupSetting(TypedDict, total=False):
        key "connectionString": str
        key "connectionStringName": str
        key "databaseType": Required[Union[str, DatabaseType]]
        key "name": str
        connection_string: str
        connection_string_name: str
        database_type: Union[str, DatabaseType]
        name: str


    class azure.mgmt.web.types.DatabaseConnection(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('DatabaseConnectionProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: DatabaseConnectionProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.DatabaseConnectionOverview(TypedDict, total=False):
        key "connectionIdentity": str
        key "name": str
        key "region": str
        key "resourceId": str
        configurationFiles: list[StaticSiteDatabaseConnectionConfigurationFileOverview]
        configuration_files: list[StaticSiteDatabaseConnectionConfigurationFileOverview]
        connection_identity: str
        name: str
        region: str
        resource_id: str


    class azure.mgmt.web.types.DatabaseConnectionPatchRequest(TypedDict, total=False):
        key "properties": ForwardRef('DatabaseConnectionPatchRequestProperties', module='types')
        properties: DatabaseConnectionPatchRequestProperties


    class azure.mgmt.web.types.DatabaseConnectionPatchRequestProperties(TypedDict, total=False):
        key "connectionIdentity": str
        key "connectionString": str
        key "region": str
        key "resourceId": str
        connection_identity: str
        connection_string: str
        region: str
        resource_id: str


    class azure.mgmt.web.types.DatabaseConnectionProperties(TypedDict, total=False):
        key "connectionIdentity": str
        key "connectionString": str
        key "region": Required[str]
        key "resourceId": Required[str]
        configurationFiles: list[StaticSiteDatabaseConnectionConfigurationFileOverview]
        configuration_files: list[StaticSiteDatabaseConnectionConfigurationFileOverview]
        connection_identity: str
        connection_string: str
        region: str
        resource_id: str


    class azure.mgmt.web.types.DefaultAuthorizationPolicy(TypedDict, total=False):
        key "allowedPrincipals": ForwardRef('AllowedPrincipals', module='types')
        allowedApplications: list[str]
        allowed_applications: list[str]
        allowed_principals: AllowedPrincipals


    class azure.mgmt.web.types.DefaultIdentity(TypedDict, total=False):
        key "identityType": Union[str, ManagedServiceIdentityType]
        key "userAssignedIdentityResourceId": str
        identity_type: Union[str, ManagedServiceIdentityType]
        user_assigned_identity_resource_id: str


    class azure.mgmt.web.types.DeletedAppRestoreRequest(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('DeletedAppRestoreRequestProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: DeletedAppRestoreRequestProperties
        type: str


    class azure.mgmt.web.types.DeletedAppRestoreRequestProperties(TypedDict, total=False):
        key "deletedSiteId": str
        key "recoverConfiguration": bool
        key "snapshotTime": str
        key "useDRSecondary": bool
        deleted_site_id: str
        recover_configuration: bool
        snapshot_time: str
        use_dr_secondary: bool


    class azure.mgmt.web.types.Deployment(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('DeploymentProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: DeploymentProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.DeploymentProperties(TypedDict, total=False):
        key "active": bool
        key "author": str
        key "author_email": str
        key "deployer": str
        key "details": str
        key "end_time": str
        key "message": str
        key "start_time": str
        key "status": int
        active: bool
        author: str
        author_email: str
        deployer: str
        details: str
        end_time: str
        message: str
        start_time: str
        status: int


    class azure.mgmt.web.types.DnlResourceNameAvailabilityRequest(TypedDict, total=False):
        key "autoGeneratedDomainNameLabelScope": str
        key "name": Required[str]
        key "resourceGroupName": str
        key "type": Required[Union[str, CheckNameResourceTypes]]
        auto_generated_domain_name_label_scope: str
        name: str
        resource_group_name: str
        type: Union[str, CheckNameResourceTypes]


    class azure.mgmt.web.types.EnabledConfig(TypedDict, total=False):
        key "enabled": bool
        enabled: bool


    class azure.mgmt.web.types.EnvironmentVariable(TypedDict, total=False):
        key "name": Required[str]
        key "value": Required[str]
        name: str
        value: str


    class azure.mgmt.web.types.ErrorEntity(TypedDict, total=False):
        key "code": str
        key "extendedCode": str
        key "message": str
        key "messageTemplate": str
        key "target": str
        code: str
        details: list[ErrorEntity]
        extended_code: str
        innerErrors: list[ErrorEntity]
        inner_errors: list[ErrorEntity]
        message: str
        message_template: str
        parameters: list[str]
        target: str


    class azure.mgmt.web.types.Experiments(TypedDict, total=False):
        rampUpRules: list[RampUpRule]
        ramp_up_rules: list[RampUpRule]


    class azure.mgmt.web.types.ExtendedLocation(TypedDict, total=False):
        key "name": str
        key "type": str
        name: str
        type: str


    class azure.mgmt.web.types.Facebook(TypedDict, total=False):
        key "enabled": bool
        key "graphApiVersion": str
        key "login": ForwardRef('LoginScopes', module='types')
        key "registration": ForwardRef('AppRegistration', module='types')
        enabled: bool
        graph_api_version: str
        login: LoginScopes
        registration: AppRegistration


    class azure.mgmt.web.types.FileSystemApplicationLogsConfig(TypedDict, total=False):
        key "level": Union[str, LogLevel]
        level: Union[str, LogLevel]


    class azure.mgmt.web.types.FileSystemHttpLogsConfig(TypedDict, total=False):
        key "enabled": bool
        key "retentionInDays": int
        key "retentionInMb": int
        enabled: bool
        retention_in_days: int
        retention_in_mb: int


    class azure.mgmt.web.types.FileSystemTokenStore(TypedDict, total=False):
        key "directory": str
        directory: str


    class azure.mgmt.web.types.FlowAccessControlConfiguration(TypedDict, total=False):
        key "actions": ForwardRef('FlowAccessControlConfigurationPolicy', module='types')
        key "contents": ForwardRef('FlowAccessControlConfigurationPolicy', module='types')
        key "triggers": ForwardRef('FlowAccessControlConfigurationPolicy', module='types')
        key "workflowManagement": ForwardRef('FlowAccessControlConfigurationPolicy', module='types')
        actions: FlowAccessControlConfigurationPolicy
        contents: FlowAccessControlConfigurationPolicy
        triggers: FlowAccessControlConfigurationPolicy
        workflow_management: FlowAccessControlConfigurationPolicy


    class azure.mgmt.web.types.FlowAccessControlConfigurationPolicy(TypedDict, total=False):
        key "openAuthenticationPolicies": ForwardRef('OpenAuthenticationAccessPolicies', module='types')
        allowedCallerIpAddresses: list[IpAddressRange]
        allowed_caller_ip_addresses: list[IpAddressRange]
        open_authentication_policies: OpenAuthenticationAccessPolicies


    class azure.mgmt.web.types.FlowEndpoints(TypedDict, total=False):
        accessEndpointIpAddresses: list[IpAddress]
        access_endpoint_ip_addresses: list[IpAddress]
        outgoingIpAddresses: list[IpAddress]
        outgoing_ip_addresses: list[IpAddress]


    class azure.mgmt.web.types.FlowEndpointsConfiguration(TypedDict, total=False):
        key "connector": ForwardRef('FlowEndpoints', module='types')
        key "workflow": ForwardRef('FlowEndpoints', module='types')
        connector: FlowEndpoints
        workflow: FlowEndpoints


    class azure.mgmt.web.types.ForwardProxy(TypedDict, total=False):
        key "convention": Union[str, ForwardProxyConvention]
        key "customHostHeaderName": str
        key "customProtoHeaderName": str
        convention: Union[str, ForwardProxyConvention]
        custom_host_header_name: str
        custom_proto_header_name: str


    class azure.mgmt.web.types.FrontEndConfiguration(TypedDict, total=False):
        key "kind": Union[str, FrontEndServiceType]
        kind: Union[str, FrontEndServiceType]


    class azure.mgmt.web.types.FunctionAppConfig(TypedDict, total=False):
        key "deployment": ForwardRef('FunctionsDeployment', module='types')
        key "runtime": ForwardRef('FunctionsRuntime', module='types')
        key "scaleAndConcurrency": ForwardRef('FunctionsScaleAndConcurrency', module='types')
        key "siteUpdateStrategy": ForwardRef('FunctionsSiteUpdateStrategy', module='types')
        deployment: FunctionsDeployment
        runtime: FunctionsRuntime
        scale_and_concurrency: FunctionsScaleAndConcurrency
        site_update_strategy: FunctionsSiteUpdateStrategy


    class azure.mgmt.web.types.FunctionEnvelope(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('FunctionEnvelopeProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: FunctionEnvelopeProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.FunctionEnvelopeProperties(TypedDict, total=False):
        key "config": Any
        key "config_href": str
        key "function_app_id": str
        key "href": str
        key "invoke_url_template": str
        key "isDisabled": bool
        key "language": str
        key "script_href": str
        key "script_root_path_href": str
        key "secrets_file_href": str
        key "test_data": str
        key "test_data_href": str
        config: Any
        config_href: str
        files: dict[str, str]
        function_app_id: str
        href: str
        invoke_url_template: str
        is_disabled: bool
        language: str
        script_href: str
        script_root_path_href: str
        secrets_file_href: str
        test_data: str
        test_data_href: str


    class azure.mgmt.web.types.FunctionsAlwaysReadyConfig(TypedDict, total=False):
        key "instanceCount": int
        key "name": str
        instance_count: int
        name: str


    class azure.mgmt.web.types.FunctionsDeployment(TypedDict, total=False):
        key "storage": ForwardRef('FunctionsDeploymentStorage', module='types')
        storage: FunctionsDeploymentStorage


    class azure.mgmt.web.types.FunctionsDeploymentStorage(TypedDict, total=False):
        key "authentication": ForwardRef('FunctionsDeploymentStorageAuthentication', module='types')
        key "type": Union[str, FunctionsDeploymentStorageType]
        key "value": str
        authentication: FunctionsDeploymentStorageAuthentication
        type: Union[str, FunctionsDeploymentStorageType]
        value: str


    class azure.mgmt.web.types.FunctionsDeploymentStorageAuthentication(TypedDict, total=False):
        key "storageAccountConnectionStringName": str
        key "type": Union[str, AuthenticationType]
        key "userAssignedIdentityResourceId": str
        storage_account_connection_string_name: str
        type: Union[str, AuthenticationType]
        user_assigned_identity_resource_id: str


    class azure.mgmt.web.types.FunctionsRuntime(TypedDict, total=False):
        key "name": Union[str, RuntimeName]
        key "version": Optional[str]
        name: Union[str, RuntimeName]
        version: str


    class azure.mgmt.web.types.FunctionsScaleAndConcurrency(TypedDict, total=False):
        key "instanceMemoryMB": int
        key "maximumInstanceCount": int
        key "triggers": ForwardRef('FunctionsScaleAndConcurrencyTriggers', module='types')
        alwaysReady: list[FunctionsAlwaysReadyConfig]
        always_ready: list[FunctionsAlwaysReadyConfig]
        instance_memory_mb: int
        maximum_instance_count: int
        triggers: FunctionsScaleAndConcurrencyTriggers


    class azure.mgmt.web.types.FunctionsScaleAndConcurrencyTriggers(TypedDict, total=False):
        key "http": ForwardRef('FunctionsScaleAndConcurrencyTriggersHttp', module='types')
        http: FunctionsScaleAndConcurrencyTriggersHttp


    class azure.mgmt.web.types.FunctionsScaleAndConcurrencyTriggersHttp(TypedDict, total=False):
        key "perInstanceConcurrency": int
        per_instance_concurrency: int


    class azure.mgmt.web.types.FunctionsSiteUpdateStrategy(TypedDict, total=False):
        key "type": Union[str, SiteUpdateStrategyType]
        type: Union[str, SiteUpdateStrategyType]


    class azure.mgmt.web.types.GitHub(TypedDict, total=False):
        key "enabled": bool
        key "login": ForwardRef('LoginScopes', module='types')
        key "registration": ForwardRef('ClientRegistration', module='types')
        enabled: bool
        login: LoginScopes
        registration: ClientRegistration


    class azure.mgmt.web.types.GitHubActionCodeConfiguration(TypedDict, total=False):
        key "runtimeStack": str
        key "runtimeVersion": str
        runtime_stack: str
        runtime_version: str


    class azure.mgmt.web.types.GitHubActionConfiguration(TypedDict, total=False):
        key "codeConfiguration": ForwardRef('GitHubActionCodeConfiguration', module='types')
        key "containerConfiguration": ForwardRef('GitHubActionContainerConfiguration', module='types')
        key "generateWorkflowFile": bool
        key "isLinux": bool
        code_configuration: GitHubActionCodeConfiguration
        container_configuration: GitHubActionContainerConfiguration
        generate_workflow_file: bool
        is_linux: bool


    class azure.mgmt.web.types.GitHubActionContainerConfiguration(TypedDict, total=False):
        key "imageName": str
        key "password": str
        key "serverUrl": str
        key "username": str
        image_name: str
        password: str
        server_url: str
        username: str


    class azure.mgmt.web.types.GlobalValidation(TypedDict, total=False):
        key "redirectToProvider": str
        key "requireAuthentication": bool
        key "unauthenticatedClientAction": Union[str, UnauthenticatedClientActionV2]
        excludedPaths: list[str]
        excluded_paths: list[str]
        redirect_to_provider: str
        require_authentication: bool
        unauthenticated_client_action: Union[str, UnauthenticatedClientActionV2]


    class azure.mgmt.web.types.Google(TypedDict, total=False):
        key "enabled": bool
        key "login": ForwardRef('LoginScopes', module='types')
        key "registration": ForwardRef('ClientRegistration', module='types')
        key "validation": ForwardRef('AllowedAudiencesValidation', module='types')
        enabled: bool
        login: LoginScopes
        registration: ClientRegistration
        validation: AllowedAudiencesValidation


    class azure.mgmt.web.types.HandlerMapping(TypedDict, total=False):
        key "arguments": str
        key "extension": str
        key "scriptProcessor": str
        arguments: str
        extension: str
        script_processor: str


    class azure.mgmt.web.types.HostNameBinding(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('HostNameBindingProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: HostNameBindingProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.HostNameBindingProperties(TypedDict, total=False):
        key "azureResourceName": str
        key "azureResourceType": Union[str, AzureResourceType]
        key "customHostNameDnsRecordType": Union[str, CustomHostNameDnsRecordType]
        key "domainId": str
        key "hostNameType": Union[str, HostNameType]
        key "siteName": str
        key "sslState": Union[str, SslState]
        key "thumbprint": str
        key "virtualIP": str
        azure_resource_name: str
        azure_resource_type: Union[str, AzureResourceType]
        custom_host_name_dns_record_type: Union[str, CustomHostNameDnsRecordType]
        domain_id: str
        host_name_type: Union[str, HostNameType]
        site_name: str
        ssl_state: Union[str, SslState]
        thumbprint: str
        virtual_ip: str


    class azure.mgmt.web.types.HostNameSslState(TypedDict, total=False):
        key "hostType": Union[str, HostType]
        key "name": str
        key "sslState": Union[str, SslState]
        key "thumbprint": str
        key "toUpdate": bool
        key "virtualIP": str
        host_type: Union[str, HostType]
        name: str
        ssl_state: Union[str, SslState]
        thumbprint: str
        to_update: bool
        virtual_ip: str


    class azure.mgmt.web.types.HostingEnvironmentProfile(TypedDict, total=False):
        key "id": str
        key "name": str
        key "type": str
        id: str
        name: str
        type: str


    class azure.mgmt.web.types.HttpLogsConfig(TypedDict, total=False):
        key "azureBlobStorage": ForwardRef('AzureBlobStorageHttpLogsConfig', module='types')
        key "fileSystem": ForwardRef('FileSystemHttpLogsConfig', module='types')
        azure_blob_storage: AzureBlobStorageHttpLogsConfig
        file_system: FileSystemHttpLogsConfig


    class azure.mgmt.web.types.HttpSettings(TypedDict, total=False):
        key "forwardProxy": ForwardRef('ForwardProxy', module='types')
        key "requireHttps": bool
        key "routes": ForwardRef('HttpSettingsRoutes', module='types')
        forward_proxy: ForwardProxy
        require_https: bool
        routes: HttpSettingsRoutes


    class azure.mgmt.web.types.HttpSettingsRoutes(TypedDict, total=False):
        key "apiPrefix": str
        api_prefix: str


    class azure.mgmt.web.types.HybridConnection(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('HybridConnectionProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: HybridConnectionProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.HybridConnectionProperties(TypedDict, total=False):
        key "hostname": str
        key "port": int
        key "relayArmUri": str
        key "relayName": str
        key "sendKeyName": str
        key "sendKeyValue": str
        key "serviceBusNamespace": str
        key "serviceBusSuffix": str
        hostname: str
        port: int
        relay_arm_uri: str
        relay_name: str
        send_key_name: str
        send_key_value: str
        service_bus_namespace: str
        service_bus_suffix: str


    class azure.mgmt.web.types.Identifier(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('IdentifierProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: IdentifierProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.IdentifierProperties(TypedDict, total=False):
        key "id": str
        value: str


    class azure.mgmt.web.types.IdentityProviders(TypedDict, total=False):
        key "apple": ForwardRef('Apple', module='types')
        key "azureActiveDirectory": ForwardRef('AzureActiveDirectory', module='types')
        key "azureStaticWebApps": ForwardRef('AzureStaticWebApps', module='types')
        key "facebook": ForwardRef('Facebook', module='types')
        key "gitHub": ForwardRef('GitHub', module='types')
        key "google": ForwardRef('Google', module='types')
        key "legacyMicrosoftAccount": ForwardRef('LegacyMicrosoftAccount', module='types')
        key "twitter": ForwardRef('Twitter', module='types')
        apple: Apple
        azure_active_directory: AzureActiveDirectory
        azure_static_web_apps: AzureStaticWebApps
        customOpenIdConnectProviders: dict[str, CustomOpenIdConnectProvider]
        custom_open_id_connect_providers: dict[str, CustomOpenIdConnectProvider]
        facebook: Facebook
        git_hub: GitHub
        google: Google
        legacy_microsoft_account: LegacyMicrosoftAccount
        twitter: Twitter


    class azure.mgmt.web.types.InstallScript(TypedDict, total=False):
        key "name": str
        key "source": ForwardRef('InstallScriptSource', module='types')
        name: str
        source: InstallScriptSource


    class azure.mgmt.web.types.InstallScriptSource(TypedDict, total=False):
        key "sourceUri": str
        key "type": Union[str, InstallScriptType]
        source_uri: str
        type: Union[str, InstallScriptType]


    class azure.mgmt.web.types.IpAddress(TypedDict, total=False):
        key "address": str
        address: str


    class azure.mgmt.web.types.IpAddressRange(TypedDict, total=False):
        key "addressRange": str
        address_range: str


    class azure.mgmt.web.types.IpSecurityRestriction(TypedDict, total=False):
        key "action": str
        key "description": str
        key "ipAddress": str
        key "name": str
        key "priority": int
        key "subnetMask": str
        key "subnetTrafficTag": int
        key "tag": Union[str, IpFilterTag]
        key "vnetSubnetResourceId": str
        key "vnetTrafficTag": int
        action: str
        description: str
        headers: dict[str, list[str]]
        ip_address: str
        name: str
        priority: int
        subnet_mask: str
        subnet_traffic_tag: int
        tag: Union[str, IpFilterTag]
        vnet_subnet_resource_id: str
        vnet_traffic_tag: int


    class azure.mgmt.web.types.JwtClaimChecks(TypedDict, total=False):
        allowedClientApplications: list[str]
        allowedGroups: list[str]
        allowed_client_applications: list[str]
        allowed_groups: list[str]


    class azure.mgmt.web.types.KeyInfo(TypedDict, total=False):
        key "name": str
        key "value": str
        name: str
        value: str


    class azure.mgmt.web.types.KeyVaultReferenceWithStatus(TypedDict, total=False):
        key "referenceStatus": str
        key "secretUri": str
        reference_status: str
        secret_uri: str


    class azure.mgmt.web.types.KubeEnvironment(TrackedResource):
        key "extendedLocation": ForwardRef('ExtendedLocation', module='types')
        key "id": str
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('KubeEnvironmentProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        extended_location: ExtendedLocation
        id: str
        kind: str
        location: str
        name: str
        properties: KubeEnvironmentProperties
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.KubeEnvironmentPatchResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('KubeEnvironmentPatchResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: KubeEnvironmentPatchResourceProperties
        type: str


    class azure.mgmt.web.types.KubeEnvironmentPatchResourceProperties(TypedDict, total=False):
        key "aksResourceID": str
        key "appLogsConfiguration": ForwardRef('AppLogsConfiguration', module='types')
        key "arcConfiguration": ForwardRef('ArcConfiguration', module='types')
        key "containerAppsConfiguration": ForwardRef('ContainerAppsConfiguration', module='types')
        key "defaultDomain": str
        key "deploymentErrors": str
        key "internalLoadBalancerEnabled": bool
        key "provisioningState": Union[str, KubeEnvironmentProvisioningState]
        key "staticIp": str
        aks_resource_id: str
        app_logs_configuration: AppLogsConfiguration
        arc_configuration: ArcConfiguration
        container_apps_configuration: ContainerAppsConfiguration
        default_domain: str
        deployment_errors: str
        internal_load_balancer_enabled: bool
        provisioning_state: Union[str, KubeEnvironmentProvisioningState]
        static_ip: str


    class azure.mgmt.web.types.KubeEnvironmentProfile(TypedDict, total=False):
        key "id": str
        key "name": str
        key "type": str
        id: str
        name: str
        type: str


    class azure.mgmt.web.types.KubeEnvironmentProperties(TypedDict, total=False):
        key "aksResourceID": str
        key "appLogsConfiguration": ForwardRef('AppLogsConfiguration', module='types')
        key "arcConfiguration": ForwardRef('ArcConfiguration', module='types')
        key "containerAppsConfiguration": ForwardRef('ContainerAppsConfiguration', module='types')
        key "defaultDomain": str
        key "deploymentErrors": str
        key "environmentType": str
        key "internalLoadBalancerEnabled": bool
        key "provisioningState": Union[str, KubeEnvironmentProvisioningState]
        key "staticIp": str
        aks_resource_id: str
        app_logs_configuration: AppLogsConfiguration
        arc_configuration: ArcConfiguration
        container_apps_configuration: ContainerAppsConfiguration
        default_domain: str
        deployment_errors: str
        environment_type: str
        internal_load_balancer_enabled: bool
        provisioning_state: Union[str, KubeEnvironmentProvisioningState]
        static_ip: str


    class azure.mgmt.web.types.LegacyMicrosoftAccount(TypedDict, total=False):
        key "enabled": bool
        key "login": ForwardRef('LoginScopes', module='types')
        key "registration": ForwardRef('ClientRegistration', module='types')
        key "validation": ForwardRef('AllowedAudiencesValidation', module='types')
        enabled: bool
        login: LoginScopes
        registration: ClientRegistration
        validation: AllowedAudiencesValidation


    class azure.mgmt.web.types.LogAnalyticsConfiguration(TypedDict, total=False):
        key "customerId": str
        key "sharedKey": str
        customer_id: str
        shared_key: str


    class azure.mgmt.web.types.Login(TypedDict, total=False):
        key "cookieExpiration": ForwardRef('CookieExpiration', module='types')
        key "nonce": ForwardRef('Nonce', module='types')
        key "preserveUrlFragmentsForLogins": bool
        key "routes": ForwardRef('LoginRoutes', module='types')
        key "tokenStore": ForwardRef('TokenStore', module='types')
        allowedExternalRedirectUrls: list[str]
        allowed_external_redirect_urls: list[str]
        cookie_expiration: CookieExpiration
        nonce: Nonce
        preserve_url_fragments_for_logins: bool
        routes: LoginRoutes
        token_store: TokenStore


    class azure.mgmt.web.types.LoginRoutes(TypedDict, total=False):
        key "logoutEndpoint": str
        logout_endpoint: str


    class azure.mgmt.web.types.LoginScopes(TypedDict, total=False):
        scopes: list[str]


    class azure.mgmt.web.types.MSDeploy(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('MSDeployProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: MSDeployProperties
        type: str


    class azure.mgmt.web.types.MSDeployCore(TypedDict, total=False):
        key "appOffline": bool
        key "connectionString": str
        key "dbType": str
        key "packageUri": str
        key "setParametersXmlFileUri": str
        key "skipAppData": bool
        app_offline: bool
        connection_string: str
        db_type: str
        package_uri: str
        setParameters: dict[str, str]
        set_parameters: dict[str, str]
        set_parameters_xml_file_uri: str
        skip_app_data: bool


    class azure.mgmt.web.types.MSDeployProperties(MSDeployCore):
        key "appOffline": bool
        key "connectionString": str
        key "dbType": str
        key "packageUri": str
        key "setParametersXmlFileUri": str
        key "skipAppData": bool
        addOnPackages: list[MSDeployCore]
        add_on_packages: list[MSDeployCore]
        app_offline: bool
        connection_string: str
        db_type: str
        package_uri: str
        setParameters: dict[str, str]
        set_parameters: dict[str, str]
        set_parameters_xml_file_uri: str
        skip_app_data: bool


    class azure.mgmt.web.types.ManagedServiceIdentity(TypedDict, total=False):
        key "principalId": str
        key "tenantId": str
        key "type": Union[str, ManagedServiceIdentityType]
        principal_id: str
        tenant_id: str
        type: Union[str, ManagedServiceIdentityType]
        userAssignedIdentities: dict[str, UserAssignedIdentity]
        user_assigned_identities: dict[str, UserAssignedIdentity]


    class azure.mgmt.web.types.MigrateMySqlRequest(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('MigrateMySqlRequestProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: MigrateMySqlRequestProperties
        type: str


    class azure.mgmt.web.types.MigrateMySqlRequestProperties(TypedDict, total=False):
        key "connectionString": Required[str]
        key "migrationType": Required[Union[str, MySqlMigrationType]]
        connection_string: str
        migration_type: Union[str, MySqlMigrationType]


    class azure.mgmt.web.types.NameIdentifier(TypedDict, total=False):
        key "name": str
        name: str


    class azure.mgmt.web.types.NameValuePair(TypedDict, total=False):
        key "name": str
        key "value": str
        name: str
        value: str


    class azure.mgmt.web.types.Nonce(TypedDict, total=False):
        key "nonceExpirationInterval": str
        key "validateNonce": bool
        nonce_expiration_interval: str
        validate_nonce: bool


    class azure.mgmt.web.types.OpenAuthenticationAccessPolicies(TypedDict, total=False):
        policies: dict[str, OpenAuthenticationAccessPolicy]


    class azure.mgmt.web.types.OpenAuthenticationAccessPolicy(TypedDict, total=False):
        key "type": Union[str, OpenAuthenticationProviderType]
        claims: list[OpenAuthenticationPolicyClaim]
        type: Union[str, OpenAuthenticationProviderType]


    class azure.mgmt.web.types.OpenAuthenticationPolicyClaim(TypedDict, total=False):
        key "name": str
        key "value": str
        name: str
        value: str


    class azure.mgmt.web.types.OpenIdConnectClientCredential(TypedDict, total=False):
        key "clientSecretSettingName": str
        key "method": Literal["ClientSecretPost"]
        client_secret_setting_name: str
        method: Literal[ClientSecretPost]


    class azure.mgmt.web.types.OpenIdConnectConfig(TypedDict, total=False):
        key "authorizationEndpoint": str
        key "certificationUri": str
        key "issuer": str
        key "tokenEndpoint": str
        key "wellKnownOpenIdConfiguration": str
        authorization_endpoint: str
        certification_uri: str
        issuer: str
        token_endpoint: str
        well_known_open_id_configuration: str


    class azure.mgmt.web.types.OpenIdConnectLogin(TypedDict, total=False):
        key "nameClaimType": str
        name_claim_type: str
        scopes: list[str]


    class azure.mgmt.web.types.OpenIdConnectRegistration(TypedDict, total=False):
        key "clientCredential": ForwardRef('OpenIdConnectClientCredential', module='types')
        key "clientId": str
        key "openIdConnectConfiguration": ForwardRef('OpenIdConnectConfig', module='types')
        client_credential: OpenIdConnectClientCredential
        client_id: str
        open_id_connect_configuration: OpenIdConnectConfig


    class azure.mgmt.web.types.OutboundVnetRouting(TypedDict, total=False):
        key "allTraffic": bool
        key "applicationTraffic": bool
        key "backupRestoreTraffic": bool
        key "contentShareTraffic": bool
        key "imagePullTraffic": bool
        all_traffic: bool
        application_traffic: bool
        backup_restore_traffic: bool
        content_share_traffic: bool
        image_pull_traffic: bool


    class azure.mgmt.web.types.PremierAddOn(TrackedResource):
        key "id": str
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('PremierAddOnProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        location: str
        name: str
        properties: PremierAddOnProperties
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.PremierAddOnPatchResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('PremierAddOnPatchResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: PremierAddOnPatchResourceProperties
        type: str


    class azure.mgmt.web.types.PremierAddOnPatchResourceProperties(TypedDict, total=False):
        key "marketplaceOffer": str
        key "marketplacePublisher": str
        key "product": str
        key "sku": str
        key "vendor": str
        marketplace_offer: str
        marketplace_publisher: str
        product: str
        sku: str
        vendor: str


    class azure.mgmt.web.types.PremierAddOnProperties(TypedDict, total=False):
        key "marketplaceOffer": str
        key "marketplacePublisher": str
        key "product": str
        key "sku": str
        key "vendor": str
        marketplace_offer: str
        marketplace_publisher: str
        product: str
        sku: str
        vendor: str


    class azure.mgmt.web.types.PrivateAccess(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('PrivateAccessProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: PrivateAccessProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.PrivateAccessProperties(TypedDict, total=False):
        key "enabled": bool
        enabled: bool
        virtualNetworks: list[PrivateAccessVirtualNetwork]
        virtual_networks: list[PrivateAccessVirtualNetwork]


    class azure.mgmt.web.types.PrivateAccessSubnet(TypedDict, total=False):
        key "key": int
        key "name": str
        key: int
        name: str


    class azure.mgmt.web.types.PrivateAccessVirtualNetwork(TypedDict, total=False):
        key "key": int
        key "name": str
        key "resourceId": str
        key: int
        name: str
        resource_id: str
        subnets: list[PrivateAccessSubnet]


    class azure.mgmt.web.types.PrivateLinkConnectionState(TypedDict, total=False):
        key "actionsRequired": str
        key "description": str
        key "status": str
        actions_required: str
        description: str
        status: str


    class azure.mgmt.web.types.ProxyOnlyResource(TypedDict, total=False):
        key "id": str
        key "kind": str
        key "name": str
        key "type": str
        id: str
        kind: str
        name: str
        type: str


    class azure.mgmt.web.types.ProxyResource(Resource):
        key "id": str
        key "name": str
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        name: str
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.PublicCertificate(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('PublicCertificateProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: PublicCertificateProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.PublicCertificateProperties(TypedDict, total=False):
        key "blob": str
        key "publicCertificateLocation": Union[str, PublicCertificateLocation]
        key "thumbprint": str
        blob: str
        public_certificate_location: Union[str, PublicCertificateLocation]
        thumbprint: str


    class azure.mgmt.web.types.PushSettings(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('PushSettingsProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: PushSettingsProperties
        type: str


    class azure.mgmt.web.types.PushSettingsProperties(TypedDict, total=False):
        key "dynamicTagsJson": str
        key "isPushEnabled": Required[bool]
        key "tagWhitelistJson": str
        key "tagsRequiringAuth": str
        dynamic_tags_json: str
        is_push_enabled: bool
        tag_whitelist_json: str
        tags_requiring_auth: str


    class azure.mgmt.web.types.RampUpRule(TypedDict, total=False):
        key "actionHostName": str
        key "changeDecisionCallbackUrl": str
        key "changeIntervalInMinutes": int
        key "changeStep": float
        key "maxReroutePercentage": float
        key "minReroutePercentage": float
        key "name": str
        key "reroutePercentage": float
        action_host_name: str
        change_decision_callback_url: str
        change_interval_in_minutes: int
        change_step: float
        max_reroute_percentage: float
        min_reroute_percentage: float
        name: str
        reroute_percentage: float


    class azure.mgmt.web.types.RegenerateActionParameter(TypedDict, total=False):
        key "keyType": Union[str, KeyType]
        key_type: Union[str, KeyType]


    class azure.mgmt.web.types.RegistryAdapter(TypedDict, total=False):
        key "keyVaultSecretReference": ForwardRef('KeyVaultReferenceWithStatus', module='types')
        key "registryKey": str
        key "type": Union[str, RegistryAdapterType]
        key_vault_secret_reference: KeyVaultReferenceWithStatus
        registry_key: str
        type: Union[str, RegistryAdapterType]


    class azure.mgmt.web.types.RelayServiceConnectionEntity(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('RelayServiceConnectionEntityProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: RelayServiceConnectionEntityProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.RelayServiceConnectionEntityProperties(TypedDict, total=False):
        key "biztalkUri": str
        key "entityConnectionString": str
        key "entityName": str
        key "hostname": str
        key "port": int
        key "resourceConnectionString": str
        key "resourceType": str
        biztalk_uri: str
        entity_connection_string: str
        entity_name: str
        hostname: str
        port: int
        resource_connection_string: str
        resource_type: str


    class azure.mgmt.web.types.RemotePrivateEndpointConnection(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('RemotePrivateEndpointConnectionProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: RemotePrivateEndpointConnectionProperties
        type: str


    class azure.mgmt.web.types.RemotePrivateEndpointConnectionARMResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('RemotePrivateEndpointConnectionARMResourceProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: RemotePrivateEndpointConnectionARMResourceProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.RemotePrivateEndpointConnectionARMResourceProperties(TypedDict, total=False):
        key "privateEndpoint": ForwardRef('ArmIdWrapper', module='types')
        key "privateLinkServiceConnectionState": ForwardRef('PrivateLinkConnectionState', module='types')
        key "provisioningState": str
        ipAddresses: list[str]
        ip_addresses: list[str]
        private_endpoint: ArmIdWrapper
        private_link_service_connection_state: PrivateLinkConnectionState
        provisioning_state: str


    class azure.mgmt.web.types.RemotePrivateEndpointConnectionProperties(TypedDict, total=False):
        key "privateEndpoint": ForwardRef('ArmIdWrapper', module='types')
        key "privateLinkServiceConnectionState": ForwardRef('PrivateLinkConnectionState', module='types')
        key "provisioningState": str
        ipAddresses: list[str]
        ip_addresses: list[str]
        private_endpoint: ArmIdWrapper
        private_link_service_connection_state: PrivateLinkConnectionState
        provisioning_state: str


    class azure.mgmt.web.types.RequestsBasedTrigger(TypedDict, total=False):
        key "count": int
        key "timeInterval": str
        count: int
        time_interval: str


    class azure.mgmt.web.types.Resource(TypedDict, total=False):
        key "id": str
        key "name": str
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        name: str
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.ResourceConfig(TypedDict, total=False):
        key "cpu": float
        key "memory": str
        cpu: float
        memory: str


    class azure.mgmt.web.types.ResourceNameAvailabilityRequest(TypedDict, total=False):
        key "environmentId": str
        key "isFqdn": bool
        key "name": Required[str]
        key "type": Required[Union[str, CheckNameResourceTypes]]
        environment_id: str
        is_fqdn: bool
        name: str
        type: Union[str, CheckNameResourceTypes]


    class azure.mgmt.web.types.ResourceReference(TypedDict, total=False):
        key "id": str
        key "name": str
        key "type": str
        id: str
        name: str
        type: str


    class azure.mgmt.web.types.ResponseMessageEnvelopeRemotePrivateEndpointConnection(TypedDict, total=False):
        key "error": ForwardRef('ErrorEntity', module='types')
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "location": str
        key "name": str
        key "plan": ForwardRef('ArmPlan', module='types')
        key "properties": ForwardRef('RemotePrivateEndpointConnection', module='types')
        key "sku": ForwardRef('SkuDescription', module='types')
        key "status": str
        key "type": str
        error: ErrorEntity
        id: str
        identity: ManagedServiceIdentity
        location: str
        name: str
        plan: ArmPlan
        properties: RemotePrivateEndpointConnection
        sku: SkuDescription
        status: str
        tags: dict[str, str]
        type: str
        zones: list[str]


    class azure.mgmt.web.types.RestoreRequest(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('RestoreRequestProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: RestoreRequestProperties
        type: str


    class azure.mgmt.web.types.RestoreRequestProperties(TypedDict, total=False):
        key "adjustConnectionStrings": bool
        key "appServicePlan": str
        key "blobName": str
        key "hostingEnvironment": str
        key "ignoreConflictingHostNames": bool
        key "ignoreDatabases": bool
        key "operationType": Union[str, BackupRestoreOperationType]
        key "overwrite": Required[bool]
        key "siteName": str
        key "storageAccountUrl": Required[str]
        adjust_connection_strings: bool
        app_service_plan: str
        blob_name: str
        databases: list[DatabaseBackupSetting]
        hosting_environment: str
        ignore_conflicting_host_names: bool
        ignore_databases: bool
        operation_type: Union[str, BackupRestoreOperationType]
        overwrite: bool
        site_name: str
        storage_account_url: str


    class azure.mgmt.web.types.ServerFarmNetworkSettings(TypedDict, total=False):
        key "virtualNetworkSubnetId": str
        virtual_network_subnet_id: str


    class azure.mgmt.web.types.Site(TrackedResource):
        key "extendedLocation": ForwardRef('ExtendedLocation', module='types')
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('SiteProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        extended_location: ExtendedLocation
        id: str
        identity: ManagedServiceIdentity
        kind: str
        location: str
        name: str
        properties: SiteProperties
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.SiteAuthSettings(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SiteAuthSettingsProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SiteAuthSettingsProperties
        type: str


    class azure.mgmt.web.types.SiteAuthSettingsProperties(TypedDict, total=False):
        key "aadClaimsAuthorization": str
        key "authFilePath": str
        key "clientId": str
        key "clientSecret": str
        key "clientSecretCertificateThumbprint": str
        key "clientSecretSettingName": str
        key "configVersion": str
        key "defaultProvider": Union[str, BuiltInAuthenticationProvider]
        key "enabled": bool
        key "facebookAppId": str
        key "facebookAppSecret": str
        key "facebookAppSecretSettingName": str
        key "gitHubClientId": str
        key "gitHubClientSecret": str
        key "gitHubClientSecretSettingName": str
        key "googleClientId": str
        key "googleClientSecret": str
        key "googleClientSecretSettingName": str
        key "isAuthFromFile": str
        key "issuer": str
        key "microsoftAccountClientId": str
        key "microsoftAccountClientSecret": str
        key "microsoftAccountClientSecretSettingName": str
        key "runtimeVersion": str
        key "tokenRefreshExtensionHours": float
        key "tokenStoreEnabled": bool
        key "twitterConsumerKey": str
        key "twitterConsumerSecret": str
        key "twitterConsumerSecretSettingName": str
        key "unauthenticatedClientAction": Union[str, UnauthenticatedClientAction]
        key "validateIssuer": bool
        aad_claims_authorization: str
        additionalLoginParams: list[str]
        additional_login_params: list[str]
        allowedAudiences: list[str]
        allowedExternalRedirectUrls: list[str]
        allowed_audiences: list[str]
        allowed_external_redirect_urls: list[str]
        auth_file_path: str
        client_id: str
        client_secret: str
        client_secret_certificate_thumbprint: str
        client_secret_setting_name: str
        config_version: str
        default_provider: Union[str, BuiltInAuthenticationProvider]
        enabled: bool
        facebookOAuthScopes: list[str]
        facebook_app_id: str
        facebook_app_secret: str
        facebook_app_secret_setting_name: str
        facebook_o_auth_scopes: list[str]
        gitHubOAuthScopes: list[str]
        git_hub_client_id: str
        git_hub_client_secret: str
        git_hub_client_secret_setting_name: str
        git_hub_o_auth_scopes: list[str]
        googleOAuthScopes: list[str]
        google_client_id: str
        google_client_secret: str
        google_client_secret_setting_name: str
        google_o_auth_scopes: list[str]
        is_auth_from_file: str
        issuer: str
        microsoftAccountOAuthScopes: list[str]
        microsoft_account_client_id: str
        microsoft_account_client_secret: str
        microsoft_account_client_secret_setting_name: str
        microsoft_account_o_auth_scopes: list[str]
        runtime_version: str
        token_refresh_extension_hours: float
        token_store_enabled: bool
        twitter_consumer_key: str
        twitter_consumer_secret: str
        twitter_consumer_secret_setting_name: str
        unauthenticated_client_action: Union[str, UnauthenticatedClientAction]
        validate_issuer: bool


    class azure.mgmt.web.types.SiteAuthSettingsV2(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SiteAuthSettingsV2Properties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SiteAuthSettingsV2Properties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SiteAuthSettingsV2Properties(TypedDict, total=False):
        key "globalValidation": ForwardRef('GlobalValidation', module='types')
        key "httpSettings": ForwardRef('HttpSettings', module='types')
        key "identityProviders": ForwardRef('IdentityProviders', module='types')
        key "login": ForwardRef('Login', module='types')
        key "platform": ForwardRef('AuthPlatform', module='types')
        global_validation: GlobalValidation
        http_settings: HttpSettings
        identity_providers: IdentityProviders
        login: Login
        platform: AuthPlatform


    class azure.mgmt.web.types.SiteConfig(TypedDict, total=False):
        key "acrUseManagedIdentityCreds": bool
        key "acrUserManagedIdentityID": str
        key "alwaysOn": bool
        key "apiDefinition": ForwardRef('ApiDefinitionInfo', module='types')
        key "apiManagementConfig": ForwardRef('ApiManagementConfig', module='types')
        key "appCommandLine": str
        key "autoHealEnabled": bool
        key "autoHealRules": ForwardRef('AutoHealRules', module='types')
        key "autoSwapSlotName": str
        key "cors": ForwardRef('CorsSettings', module='types')
        key "detailedErrorLoggingEnabled": bool
        key "documentRoot": str
        key "elasticWebAppScaleLimit": int
        key "experiments": ForwardRef('Experiments', module='types')
        key "ftpsState": Union[str, FtpsState]
        key "functionAppScaleLimit": int
        key "functionsRuntimeScaleMonitoringEnabled": bool
        key "healthCheckPath": str
        key "http20Enabled": bool
        key "http20ProxyFlag": int
        key "httpLoggingEnabled": bool
        key "ipSecurityRestrictionsDefaultAction": Union[str, DefaultAction]
        key "javaContainer": str
        key "javaContainerVersion": str
        key "javaVersion": str
        key "keyVaultReferenceIdentity": str
        key "limits": ForwardRef('SiteLimits', module='types')
        key "linuxFxVersion": str
        key "loadBalancing": Union[str, SiteLoadBalancing]
        key "localMySqlEnabled": bool
        key "logsDirectorySizeLimit": int
        key "machineKey": ForwardRef('SiteMachineKey', module='types')
        key "managedPipelineMode": Union[str, ManagedPipelineMode]
        key "managedServiceIdentityId": int
        key "minTlsCipherSuite": Union[str, TlsCipherSuites]
        key "minTlsVersion": Union[str, SupportedTlsVersions]
        key "minimumElasticInstanceCount": int
        key "netFrameworkVersion": str
        key "nodeVersion": str
        key "numberOfWorkers": int
        key "phpVersion": str
        key "powerShellVersion": str
        key "preWarmedInstanceCount": int
        key "publicNetworkAccess": str
        key "publishingUsername": str
        key "push": ForwardRef('PushSettings', module='types')
        key "pythonVersion": str
        key "remoteDebuggingEnabled": bool
        key "remoteDebuggingVersion": str
        key "requestTracingEnabled": bool
        key "requestTracingExpirationTime": str
        key "scmIpSecurityRestrictionsDefaultAction": Union[str, DefaultAction]
        key "scmIpSecurityRestrictionsUseMain": bool
        key "scmMinTlsVersion": Union[str, SupportedTlsVersions]
        key "scmType": Union[str, ScmType]
        key "tracingOptions": str
        key "use32BitWorkerProcess": bool
        key "vnetName": str
        key "vnetPrivatePortsCount": int
        key "vnetRouteAllEnabled": bool
        key "webSocketsEnabled": bool
        key "websiteTimeZone": str
        key "windowsFxVersion": str
        key "xManagedServiceIdentityId": int
        acr_use_managed_identity_creds: bool
        acr_user_managed_identity_id: str
        always_on: bool
        api_definition: ApiDefinitionInfo
        api_management_config: ApiManagementConfig
        appSettings: list[NameValuePair]
        app_command_line: str
        app_settings: list[NameValuePair]
        auto_heal_enabled: bool
        auto_heal_rules: AutoHealRules
        auto_swap_slot_name: str
        azureStorageAccounts: dict[str, AzureStorageInfoValue]
        azure_storage_accounts: dict[str, AzureStorageInfoValue]
        connectionStrings: list[ConnStringInfo]
        connection_strings: list[ConnStringInfo]
        cors: CorsSettings
        defaultDocuments: list[str]
        default_documents: list[str]
        detailed_error_logging_enabled: bool
        document_root: str
        elastic_web_app_scale_limit: int
        experiments: Experiments
        ftps_state: Union[str, FtpsState]
        function_app_scale_limit: int
        functions_runtime_scale_monitoring_enabled: bool
        handlerMappings: list[HandlerMapping]
        handler_mappings: list[HandlerMapping]
        health_check_path: str
        http20_enabled: bool
        http20_proxy_flag: int
        http_logging_enabled: bool
        ipSecurityRestrictions: list[IpSecurityRestriction]
        ip_security_restrictions: list[IpSecurityRestriction]
        ip_security_restrictions_default_action: Union[str, DefaultAction]
        java_container: str
        java_container_version: str
        java_version: str
        key_vault_reference_identity: str
        limits: SiteLimits
        linux_fx_version: str
        load_balancing: Union[str, SiteLoadBalancing]
        local_my_sql_enabled: bool
        logs_directory_size_limit: int
        machine_key: SiteMachineKey
        managed_pipeline_mode: Union[str, ManagedPipelineMode]
        managed_service_identity_id: int
        metadata: list[NameValuePair]
        min_tls_cipher_suite: Union[str, TlsCipherSuites]
        min_tls_version: Union[str, SupportedTlsVersions]
        minimum_elastic_instance_count: int
        net_framework_version: str
        node_version: str
        number_of_workers: int
        php_version: str
        power_shell_version: str
        pre_warmed_instance_count: int
        public_network_access: str
        publishing_username: str
        push: PushSettings
        python_version: str
        remote_debugging_enabled: bool
        remote_debugging_version: str
        request_tracing_enabled: bool
        request_tracing_expiration_time: str
        scmIpSecurityRestrictions: list[IpSecurityRestriction]
        scm_ip_security_restrictions: list[IpSecurityRestriction]
        scm_ip_security_restrictions_default_action: Union[str, DefaultAction]
        scm_ip_security_restrictions_use_main: bool
        scm_min_tls_version: Union[str, SupportedTlsVersions]
        scm_type: Union[str, ScmType]
        tracing_options: str
        use32_bit_worker_process: bool
        virtualApplications: list[VirtualApplication]
        virtual_applications: list[VirtualApplication]
        vnet_name: str
        vnet_private_ports_count: int
        vnet_route_all_enabled: bool
        web_sockets_enabled: bool
        website_time_zone: str
        windows_fx_version: str
        x_managed_service_identity_id: int


    class azure.mgmt.web.types.SiteConfigResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SiteConfig', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SiteConfig
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SiteContainer(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SiteContainerProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SiteContainerProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SiteContainerProperties(TypedDict, total=False):
        key "authType": Union[str, AuthType]
        key "createdTime": str
        key "image": Required[str]
        key "inheritAppSettingsAndConnectionStrings": bool
        key "isMain": Required[bool]
        key "lastModifiedTime": str
        key "passwordSecret": str
        key "startUpCommand": str
        key "targetPort": str
        key "userManagedIdentityClientId": str
        key "userName": str
        auth_type: Union[str, AuthType]
        created_time: str
        environmentVariables: list[EnvironmentVariable]
        environment_variables: list[EnvironmentVariable]
        image: str
        inherit_app_settings_and_connection_strings: bool
        is_main: bool
        last_modified_time: str
        password_secret: str
        start_up_command: str
        target_port: str
        user_managed_identity_client_id: str
        user_name: str
        volumeMounts: list[VolumeMount]
        volume_mounts: list[VolumeMount]


    class azure.mgmt.web.types.SiteDnsConfig(TypedDict, total=False):
        key "dnsAltServer": str
        key "dnsLegacySortOrder": bool
        key "dnsMaxCacheTimeout": int
        key "dnsRetryAttemptCount": int
        key "dnsRetryAttemptTimeout": int
        dnsServers: list[str]
        dns_alt_server: str
        dns_legacy_sort_order: bool
        dns_max_cache_timeout: int
        dns_retry_attempt_count: int
        dns_retry_attempt_timeout: int
        dns_servers: list[str]


    class azure.mgmt.web.types.SiteLimits(TypedDict, total=False):
        key "maxDiskSizeInMb": int
        key "maxMemoryInMb": int
        key "maxPercentageCpu": float
        max_disk_size_in_mb: int
        max_memory_in_mb: int
        max_percentage_cpu: float


    class azure.mgmt.web.types.SiteLogsConfig(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SiteLogsConfigProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SiteLogsConfigProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SiteLogsConfigProperties(TypedDict, total=False):
        key "applicationLogs": ForwardRef('ApplicationLogsConfig', module='types')
        key "detailedErrorMessages": ForwardRef('EnabledConfig', module='types')
        key "failedRequestsTracing": ForwardRef('EnabledConfig', module='types')
        key "httpLogs": ForwardRef('HttpLogsConfig', module='types')
        application_logs: ApplicationLogsConfig
        detailed_error_messages: EnabledConfig
        failed_requests_tracing: EnabledConfig
        http_logs: HttpLogsConfig


    class azure.mgmt.web.types.SiteMachineKey(TypedDict, total=False):
        key "decryption": str
        key "decryptionKey": str
        key "validation": str
        key "validationKey": str
        decryption: str
        decryption_key: str
        validation: str
        validation_key: str


    class azure.mgmt.web.types.SitePatchResource(ProxyOnlyResource):
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SitePatchResourceProperties', module='types')
        key "type": str
        id: str
        identity: ManagedServiceIdentity
        kind: str
        name: str
        properties: SitePatchResourceProperties
        type: str


    class azure.mgmt.web.types.SitePatchResourceProperties(TypedDict, total=False):
        key "availabilityState": Union[str, SiteAvailabilityState]
        key "clientAffinityEnabled": bool
        key "clientAffinityProxyEnabled": bool
        key "clientCertEnabled": bool
        key "clientCertExclusionPaths": str
        key "clientCertMode": Union[str, ClientCertMode]
        key "cloningInfo": ForwardRef('CloningInfo', module='types')
        key "containerSize": int
        key "customDomainVerificationId": str
        key "dailyMemoryTimeQuota": int
        key "defaultHostName": str
        key "dnsConfiguration": ForwardRef('SiteDnsConfig', module='types')
        key "enabled": bool
        key "hostNamesDisabled": bool
        key "hostingEnvironmentProfile": ForwardRef('HostingEnvironmentProfile', module='types')
        key "httpsOnly": bool
        key "hyperV": bool
        key "inProgressOperationId": str
        key "isDefaultContainer": bool
        key "isXenon": bool
        key "keyVaultReferenceIdentity": str
        key "lastModifiedTimeUtc": str
        key "maxNumberOfWorkers": int
        key "outboundIpAddresses": str
        key "possibleOutboundIpAddresses": str
        key "publicNetworkAccess": str
        key "redundancyMode": Union[str, RedundancyMode]
        key "repositorySiteName": str
        key "reserved": bool
        key "resourceGroup": str
        key "scmSiteAlsoStopped": bool
        key "serverFarmId": str
        key "siteConfig": ForwardRef('SiteConfig', module='types')
        key "slotSwapStatus": ForwardRef('SlotSwapStatus', module='types')
        key "state": str
        key "storageAccountRequired": bool
        key "suspendedTill": str
        key "targetSwapSlot": str
        key "usageState": Union[str, UsageState]
        key "virtualNetworkSubnetId": str
        availability_state: Union[str, SiteAvailabilityState]
        client_affinity_enabled: bool
        client_affinity_proxy_enabled: bool
        client_cert_enabled: bool
        client_cert_exclusion_paths: str
        client_cert_mode: Union[str, ClientCertMode]
        cloning_info: CloningInfo
        container_size: int
        custom_domain_verification_id: str
        daily_memory_time_quota: int
        default_host_name: str
        dns_configuration: SiteDnsConfig
        enabled: bool
        enabledHostNames: list[str]
        enabled_host_names: list[str]
        hostNameSslStates: list[HostNameSslState]
        hostNames: list[str]
        host_name_ssl_states: list[HostNameSslState]
        host_names: list[str]
        host_names_disabled: bool
        hosting_environment_profile: HostingEnvironmentProfile
        https_only: bool
        hyper_v: bool
        in_progress_operation_id: str
        is_default_container: bool
        is_xenon: bool
        key_vault_reference_identity: str
        last_modified_time_utc: str
        max_number_of_workers: int
        outbound_ip_addresses: str
        possible_outbound_ip_addresses: str
        public_network_access: str
        redundancy_mode: Union[str, RedundancyMode]
        repository_site_name: str
        reserved: bool
        resource_group: str
        scm_site_also_stopped: bool
        server_farm_id: str
        site_config: SiteConfig
        slot_swap_status: SlotSwapStatus
        state: str
        storage_account_required: bool
        suspended_till: str
        target_swap_slot: str
        trafficManagerHostNames: list[str]
        traffic_manager_host_names: list[str]
        usage_state: Union[str, UsageState]
        virtual_network_subnet_id: str


    class azure.mgmt.web.types.SiteProperties(TypedDict, total=False):
        key "autoGeneratedDomainNameLabelScope": Union[str, AutoGeneratedDomainNameLabelScope]
        key "availabilityState": Union[str, SiteAvailabilityState]
        key "clientAffinityEnabled": bool
        key "clientAffinityPartitioningEnabled": bool
        key "clientAffinityProxyEnabled": bool
        key "clientCertEnabled": bool
        key "clientCertExclusionPaths": str
        key "clientCertMode": Union[str, ClientCertMode]
        key "cloningInfo": ForwardRef('CloningInfo', module='types')
        key "containerSize": int
        key "customDomainVerificationId": str
        key "dailyMemoryTimeQuota": int
        key "daprConfig": ForwardRef('DaprConfig', module='types')
        key "defaultHostName": str
        key "dnsConfiguration": ForwardRef('SiteDnsConfig', module='types')
        key "enabled": bool
        key "endToEndEncryptionEnabled": bool
        key "functionAppConfig": ForwardRef('FunctionAppConfig', module='types')
        key "hostNamesDisabled": bool
        key "hostingEnvironmentProfile": ForwardRef('HostingEnvironmentProfile', module='types')
        key "httpsOnly": bool
        key "hyperV": bool
        key "inProgressOperationId": str
        key "ipMode": Union[str, IPMode]
        key "isDefaultContainer": bool
        key "isXenon": bool
        key "keyVaultReferenceIdentity": str
        key "lastModifiedTimeUtc": str
        key "managedEnvironmentId": str
        key "maxNumberOfWorkers": int
        key "outboundIpAddresses": str
        key "outboundVnetRouting": ForwardRef('OutboundVnetRouting', module='types')
        key "possibleOutboundIpAddresses": str
        key "publicNetworkAccess": str
        key "redundancyMode": Union[str, RedundancyMode]
        key "repositorySiteName": str
        key "reserved": bool
        key "resourceConfig": ForwardRef('ResourceConfig', module='types')
        key "resourceGroup": str
        key "scmSiteAlsoStopped": bool
        key "serverFarmId": str
        key "siteConfig": ForwardRef('SiteConfig', module='types')
        key "sku": str
        key "slotSwapStatus": ForwardRef('SlotSwapStatus', module='types')
        key "sshEnabled": bool
        key "state": str
        key "storageAccountRequired": bool
        key "suspendedTill": str
        key "targetSwapSlot": str
        key "usageState": Union[str, UsageState]
        key "virtualNetworkSubnetId": str
        key "workloadProfileName": str
        auto_generated_domain_name_label_scope: Union[str, AutoGeneratedDomainNameLabelScope]
        availability_state: Union[str, SiteAvailabilityState]
        client_affinity_enabled: bool
        client_affinity_partitioning_enabled: bool
        client_affinity_proxy_enabled: bool
        client_cert_enabled: bool
        client_cert_exclusion_paths: str
        client_cert_mode: Union[str, ClientCertMode]
        cloning_info: CloningInfo
        container_size: int
        custom_domain_verification_id: str
        daily_memory_time_quota: int
        dapr_config: DaprConfig
        default_host_name: str
        dns_configuration: SiteDnsConfig
        enabled: bool
        enabledHostNames: list[str]
        enabled_host_names: list[str]
        end_to_end_encryption_enabled: bool
        function_app_config: FunctionAppConfig
        hostNameSslStates: list[HostNameSslState]
        hostNames: list[str]
        host_name_ssl_states: list[HostNameSslState]
        host_names: list[str]
        host_names_disabled: bool
        hosting_environment_profile: HostingEnvironmentProfile
        https_only: bool
        hyper_v: bool
        in_progress_operation_id: str
        ip_mode: Union[str, IPMode]
        is_default_container: bool
        is_xenon: bool
        key_vault_reference_identity: str
        last_modified_time_utc: str
        managed_environment_id: str
        max_number_of_workers: int
        outbound_ip_addresses: str
        outbound_vnet_routing: OutboundVnetRouting
        possible_outbound_ip_addresses: str
        public_network_access: str
        redundancy_mode: Union[str, RedundancyMode]
        repository_site_name: str
        reserved: bool
        resource_config: ResourceConfig
        resource_group: str
        scm_site_also_stopped: bool
        server_farm_id: str
        site_config: SiteConfig
        sku: str
        slot_swap_status: SlotSwapStatus
        ssh_enabled: bool
        state: str
        storage_account_required: bool
        suspended_till: str
        target_swap_slot: str
        trafficManagerHostNames: list[str]
        traffic_manager_host_names: list[str]
        usage_state: Union[str, UsageState]
        virtual_network_subnet_id: str
        workload_profile_name: str


    class azure.mgmt.web.types.SiteSourceControl(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SiteSourceControlProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SiteSourceControlProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SiteSourceControlProperties(TypedDict, total=False):
        key "branch": str
        key "deploymentRollbackEnabled": bool
        key "gitHubActionConfiguration": ForwardRef('GitHubActionConfiguration', module='types')
        key "isGitHubAction": bool
        key "isManualIntegration": bool
        key "isMercurial": bool
        key "repoUrl": str
        branch: str
        deployment_rollback_enabled: bool
        git_hub_action_configuration: GitHubActionConfiguration
        is_git_hub_action: bool
        is_manual_integration: bool
        is_mercurial: bool
        repo_url: str


    class azure.mgmt.web.types.SkuCapacity(TypedDict, total=False):
        key "default": int
        key "elasticMaximum": int
        key "maximum": int
        key "minimum": int
        key "scaleType": str
        default: int
        elastic_maximum: int
        maximum: int
        minimum: int
        scale_type: str


    class azure.mgmt.web.types.SkuDescription(TypedDict, total=False):
        key "capacity": int
        key "family": str
        key "name": str
        key "size": str
        key "skuCapacity": ForwardRef('SkuCapacity', module='types')
        key "tier": str
        capabilities: list[Capability]
        capacity: int
        family: str
        locations: list[str]
        name: str
        size: str
        sku_capacity: SkuCapacity
        tier: str


    class azure.mgmt.web.types.SlotConfigNames(TypedDict, total=False):
        appSettingNames: list[str]
        app_setting_names: list[str]
        azureStorageConfigNames: list[str]
        azure_storage_config_names: list[str]
        connectionStringNames: list[str]
        connection_string_names: list[str]


    class azure.mgmt.web.types.SlotConfigNamesResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SlotConfigNames', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SlotConfigNames
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SlotSwapStatus(TypedDict, total=False):
        key "destinationSlotName": str
        key "sourceSlotName": str
        key "timestampUtc": str
        destination_slot_name: str
        source_slot_name: str
        timestamp_utc: str


    class azure.mgmt.web.types.SlowRequestsBasedTrigger(TypedDict, total=False):
        key "count": int
        key "path": str
        key "timeInterval": str
        key "timeTaken": str
        count: int
        path: str
        time_interval: str
        time_taken: str


    class azure.mgmt.web.types.SnapshotRecoverySource(TypedDict, total=False):
        key "id": str
        key "location": str
        id: str
        location: str


    class azure.mgmt.web.types.SnapshotRestoreRequest(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SnapshotRestoreRequestProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SnapshotRestoreRequestProperties
        type: str


    class azure.mgmt.web.types.SnapshotRestoreRequestProperties(TypedDict, total=False):
        key "ignoreConflictingHostNames": bool
        key "overwrite": Required[bool]
        key "recoverConfiguration": bool
        key "recoverySource": ForwardRef('SnapshotRecoverySource', module='types')
        key "snapshotTime": str
        key "useDRSecondary": bool
        ignore_conflicting_host_names: bool
        overwrite: bool
        recover_configuration: bool
        recovery_source: SnapshotRecoverySource
        snapshot_time: str
        use_dr_secondary: bool


    class azure.mgmt.web.types.SourceControl(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SourceControlProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SourceControlProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SourceControlProperties(TypedDict, total=False):
        key "expirationTime": str
        key "refreshToken": str
        key "token": str
        key "tokenSecret": str
        expiration_time: str
        refresh_token: str
        token: str
        token_secret: str


    class azure.mgmt.web.types.StaticSite(TypedDict, total=False):
        key "allowConfigFileUpdates": bool
        key "branch": str
        key "buildProperties": ForwardRef('StaticSiteBuildProperties', module='types')
        key "contentDistributionEndpoint": str
        key "defaultHostname": str
        key "enterpriseGradeCdnStatus": Union[str, EnterpriseGradeCdnStatus]
        key "keyVaultReferenceIdentity": str
        key "provider": str
        key "publicNetworkAccess": str
        key "repositoryToken": str
        key "repositoryUrl": str
        key "stagingEnvironmentPolicy": Union[str, StagingEnvironmentPolicy]
        key "templateProperties": ForwardRef('StaticSiteTemplateOptions', module='types')
        allow_config_file_updates: bool
        branch: str
        build_properties: StaticSiteBuildProperties
        content_distribution_endpoint: str
        customDomains: list[str]
        custom_domains: list[str]
        databaseConnections: list[DatabaseConnectionOverview]
        database_connections: list[DatabaseConnectionOverview]
        default_hostname: str
        enterprise_grade_cdn_status: Union[str, EnterpriseGradeCdnStatus]
        key_vault_reference_identity: str
        linkedBackends: list[StaticSiteLinkedBackend]
        linked_backends: list[StaticSiteLinkedBackend]
        privateEndpointConnections: list[ResponseMessageEnvelopeRemotePrivateEndpointConnection]
        private_endpoint_connections: list[ResponseMessageEnvelopeRemotePrivateEndpointConnection]
        provider: str
        public_network_access: str
        repository_token: str
        repository_url: str
        staging_environment_policy: Union[str, StagingEnvironmentPolicy]
        template_properties: StaticSiteTemplateOptions
        userProvidedFunctionApps: list[StaticSiteUserProvidedFunctionApp]
        user_provided_function_apps: list[StaticSiteUserProvidedFunctionApp]


    class azure.mgmt.web.types.StaticSiteARMResource(TrackedResource):
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "kind": str
        key "location": Required[str]
        key "name": str
        key "properties": ForwardRef('StaticSite', module='types')
        key "sku": ForwardRef('SkuDescription', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        identity: ManagedServiceIdentity
        kind: str
        location: str
        name: str
        properties: StaticSite
        sku: SkuDescription
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.StaticSiteBasicAuthPropertiesARMResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteBasicAuthPropertiesARMResourceProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteBasicAuthPropertiesARMResourceProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.StaticSiteBasicAuthPropertiesARMResourceProperties(TypedDict, total=False):
        key "applicableEnvironmentsMode": Required[str]
        key "password": str
        key "secretState": str
        key "secretUrl": str
        applicable_environments_mode: str
        environments: list[str]
        password: str
        secret_state: str
        secret_url: str


    class azure.mgmt.web.types.StaticSiteBuildProperties(TypedDict, total=False):
        key "apiBuildCommand": str
        key "apiLocation": str
        key "appArtifactLocation": str
        key "appBuildCommand": str
        key "appLocation": str
        key "githubActionSecretNameOverride": str
        key "outputLocation": str
        key "skipGithubActionWorkflowGeneration": bool
        api_build_command: str
        api_location: str
        app_artifact_location: str
        app_build_command: str
        app_location: str
        github_action_secret_name_override: str
        output_location: str
        skip_github_action_workflow_generation: bool


    class azure.mgmt.web.types.StaticSiteCustomDomainRequestPropertiesARMResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteCustomDomainRequestPropertiesARMResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteCustomDomainRequestPropertiesARMResourceProperties
        type: str


    class azure.mgmt.web.types.StaticSiteCustomDomainRequestPropertiesARMResourceProperties(TypedDict, total=False):
        key "validationMethod": str
        validation_method: str


    class azure.mgmt.web.types.StaticSiteDatabaseConnectionConfigurationFileOverview(TypedDict, total=False):
        key "contents": str
        key "fileName": str
        key "type": str
        contents: str
        file_name: str
        type: str


    class azure.mgmt.web.types.StaticSiteLinkedBackend(TypedDict, total=False):
        key "backendResourceId": str
        key "createdOn": str
        key "provisioningState": str
        key "region": str
        backend_resource_id: str
        created_on: str
        provisioning_state: str
        region: str


    class azure.mgmt.web.types.StaticSiteLinkedBackendARMResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteLinkedBackendARMResourceProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteLinkedBackendARMResourceProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.StaticSiteLinkedBackendARMResourceProperties(TypedDict, total=False):
        key "backendResourceId": str
        key "createdOn": str
        key "provisioningState": str
        key "region": str
        backend_resource_id: str
        created_on: str
        provisioning_state: str
        region: str


    class azure.mgmt.web.types.StaticSitePatchResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSite', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSite
        type: str


    class azure.mgmt.web.types.StaticSiteResetPropertiesARMResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteResetPropertiesARMResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteResetPropertiesARMResourceProperties
        type: str


    class azure.mgmt.web.types.StaticSiteResetPropertiesARMResourceProperties(TypedDict, total=False):
        key "repositoryToken": str
        key "shouldUpdateRepository": bool
        repository_token: str
        should_update_repository: bool


    class azure.mgmt.web.types.StaticSiteTemplateOptions(TypedDict, total=False):
        key "description": str
        key "isPrivate": bool
        key "owner": str
        key "repositoryName": str
        key "templateRepositoryUrl": str
        description: str
        is_private: bool
        owner: str
        repository_name: str
        template_repository_url: str


    class azure.mgmt.web.types.StaticSiteUserARMResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteUserARMResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteUserARMResourceProperties
        type: str


    class azure.mgmt.web.types.StaticSiteUserARMResourceProperties(TypedDict, total=False):
        key "displayName": str
        key "provider": str
        key "roles": str
        key "userId": str
        display_name: str
        provider: str
        roles: str
        user_id: str


    class azure.mgmt.web.types.StaticSiteUserInvitationRequestResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteUserInvitationRequestResourceProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteUserInvitationRequestResourceProperties
        type: str


    class azure.mgmt.web.types.StaticSiteUserInvitationRequestResourceProperties(TypedDict, total=False):
        key "domain": str
        key "numHoursToExpiration": int
        key "provider": str
        key "roles": str
        key "userDetails": str
        domain: str
        num_hours_to_expiration: int
        provider: str
        roles: str
        user_details: str


    class azure.mgmt.web.types.StaticSiteUserProvidedFunctionApp(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteUserProvidedFunctionAppProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteUserProvidedFunctionAppProperties
        type: str


    class azure.mgmt.web.types.StaticSiteUserProvidedFunctionAppARMResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteUserProvidedFunctionAppARMResourceProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteUserProvidedFunctionAppARMResourceProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.StaticSiteUserProvidedFunctionAppARMResourceProperties(TypedDict, total=False):
        key "createdOn": str
        key "functionAppRegion": str
        key "functionAppResourceId": str
        created_on: str
        function_app_region: str
        function_app_resource_id: str


    class azure.mgmt.web.types.StaticSiteUserProvidedFunctionAppProperties(TypedDict, total=False):
        key "createdOn": str
        key "functionAppRegion": str
        key "functionAppResourceId": str
        created_on: str
        function_app_region: str
        function_app_resource_id: str


    class azure.mgmt.web.types.StaticSiteZipDeployment(TypedDict, total=False):
        key "apiZipUrl": str
        key "appZipUrl": str
        key "deploymentTitle": str
        key "functionLanguage": str
        key "provider": str
        api_zip_url: str
        app_zip_url: str
        deployment_title: str
        function_language: str
        provider: str


    class azure.mgmt.web.types.StaticSiteZipDeploymentARMResource(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSiteZipDeployment', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSiteZipDeployment
        type: str


    class azure.mgmt.web.types.StaticSitesWorkflowPreviewRequest(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StaticSitesWorkflowPreviewRequestProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StaticSitesWorkflowPreviewRequestProperties
        type: str


    class azure.mgmt.web.types.StaticSitesWorkflowPreviewRequestProperties(TypedDict, total=False):
        key "branch": str
        key "buildProperties": ForwardRef('StaticSiteBuildProperties', module='types')
        key "repositoryUrl": str
        branch: str
        build_properties: StaticSiteBuildProperties
        repository_url: str


    class azure.mgmt.web.types.StatusCodesBasedTrigger(TypedDict, total=False):
        key "count": int
        key "path": str
        key "status": int
        key "subStatus": int
        key "timeInterval": str
        key "win32Status": int
        count: int
        path: str
        status: int
        sub_status: int
        time_interval: str
        win32_status: int


    class azure.mgmt.web.types.StatusCodesRangeBasedTrigger(TypedDict, total=False):
        key "count": int
        key "path": str
        key "statusCodes": str
        key "timeInterval": str
        count: int
        path: str
        status_codes: str
        time_interval: str


    class azure.mgmt.web.types.StorageMigrationOptions(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('StorageMigrationOptionsProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: StorageMigrationOptionsProperties
        type: str


    class azure.mgmt.web.types.StorageMigrationOptionsProperties(TypedDict, total=False):
        key "azurefilesConnectionString": Required[str]
        key "azurefilesShare": Required[str]
        key "blockWriteAccessToSite": bool
        key "switchSiteAfterMigration": bool
        azurefiles_connection_string: str
        azurefiles_share: str
        block_write_access_to_site: bool
        switch_site_after_migration: bool


    class azure.mgmt.web.types.StorageMount(TypedDict, total=False):
        key "credentialsKeyVaultReference": ForwardRef('KeyVaultReferenceWithStatus', module='types')
        key "destinationPath": str
        key "name": str
        key "source": str
        key "type": Union[str, StorageMountType]
        credentials_key_vault_reference: KeyVaultReferenceWithStatus
        destination_path: str
        name: str
        source: str
        type: Union[str, StorageMountType]


    class azure.mgmt.web.types.StringDictionary(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "type": str
        id: str
        kind: str
        name: str
        properties: dict[str, str]
        type: str


    class azure.mgmt.web.types.SwiftVirtualNetwork(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('SwiftVirtualNetworkProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: SwiftVirtualNetworkProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.SwiftVirtualNetworkProperties(TypedDict, total=False):
        key "subnetResourceId": str
        key "swiftSupported": bool
        subnet_resource_id: str
        swift_supported: bool


    class azure.mgmt.web.types.SystemData(TypedDict, total=False):
        key "createdAt": str
        key "createdBy": str
        key "createdByType": Union[str, CreatedByType]
        key "lastModifiedAt": str
        key "lastModifiedBy": str
        key "lastModifiedByType": Union[str, CreatedByType]
        created_at: str
        created_by: str
        created_by_type: Union[str, CreatedByType]
        last_modified_at: str
        last_modified_by: str
        last_modified_by_type: Union[str, CreatedByType]


    class azure.mgmt.web.types.TokenStore(TypedDict, total=False):
        key "azureBlobStorage": ForwardRef('BlobStorageTokenStore', module='types')
        key "enabled": bool
        key "fileSystem": ForwardRef('FileSystemTokenStore', module='types')
        key "tokenRefreshExtensionHours": float
        azure_blob_storage: BlobStorageTokenStore
        enabled: bool
        file_system: FileSystemTokenStore
        token_refresh_extension_hours: float


    class azure.mgmt.web.types.TrackedResource(Resource):
        key "id": str
        key "location": Required[str]
        key "name": str
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        location: str
        name: str
        system_data: SystemData
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.Twitter(TypedDict, total=False):
        key "enabled": bool
        key "registration": ForwardRef('TwitterRegistration', module='types')
        enabled: bool
        registration: TwitterRegistration


    class azure.mgmt.web.types.TwitterRegistration(TypedDict, total=False):
        key "consumerKey": str
        key "consumerSecretSettingName": str
        consumer_key: str
        consumer_secret_setting_name: str


    class azure.mgmt.web.types.User(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('UserProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: UserProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.UserAssignedIdentity(TypedDict, total=False):
        key "clientId": str
        key "principalId": str
        client_id: str
        principal_id: str


    class azure.mgmt.web.types.UserProperties(TypedDict, total=False):
        key "publishingPassword": str
        key "publishingPasswordHash": str
        key "publishingPasswordHashSalt": str
        key "publishingUserName": Required[str]
        key "scmUri": str
        publishing_password: str
        publishing_password_hash: str
        publishing_password_hash_salt: str
        publishing_user_name: str
        scm_uri: str


    class azure.mgmt.web.types.ValidateProperties(TypedDict, total=False):
        key "appServiceEnvironment": ForwardRef('AppServiceEnvironment', module='types')
        key "capacity": int
        key "containerImagePlatform": str
        key "containerImageRepository": str
        key "containerImageTag": str
        key "containerRegistryBaseUrl": str
        key "containerRegistryPassword": str
        key "containerRegistryUsername": str
        key "hostingEnvironment": str
        key "isSpot": bool
        key "isXenon": bool
        key "needLinuxWorkers": bool
        key "serverFarmId": str
        key "skuName": str
        app_service_environment: AppServiceEnvironment
        capacity: int
        container_image_platform: str
        container_image_repository: str
        container_image_tag: str
        container_registry_base_url: str
        container_registry_password: str
        container_registry_username: str
        hosting_environment: str
        is_spot: bool
        is_xenon: bool
        need_linux_workers: bool
        server_farm_id: str
        sku_name: str


    class azure.mgmt.web.types.ValidateRequest(TypedDict, total=False):
        key "location": Required[str]
        key "name": Required[str]
        key "properties": Required[ValidateProperties]
        key "type": Required[Union[str, ValidateResourceTypes]]
        location: str
        name: str
        properties: ValidateProperties
        type: Union[str, ValidateResourceTypes]


    class azure.mgmt.web.types.VirtualApplication(TypedDict, total=False):
        key "physicalPath": str
        key "preloadEnabled": bool
        key "virtualPath": str
        physical_path: str
        preload_enabled: bool
        virtualDirectories: list[VirtualDirectory]
        virtual_directories: list[VirtualDirectory]
        virtual_path: str


    class azure.mgmt.web.types.VirtualDirectory(TypedDict, total=False):
        key "physicalPath": str
        key "virtualPath": str
        physical_path: str
        virtual_path: str


    class azure.mgmt.web.types.VirtualNetworkProfile(TypedDict, total=False):
        key "id": Required[str]
        key "name": str
        key "subnet": str
        key "type": str
        id: str
        name: str
        subnet: str
        type: str


    class azure.mgmt.web.types.VnetGateway(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('VnetGatewayProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: VnetGatewayProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.VnetGatewayProperties(TypedDict, total=False):
        key "vnetName": str
        key "vpnPackageUri": Required[str]
        vnet_name: str
        vpn_package_uri: str


    class azure.mgmt.web.types.VnetInfo(TypedDict, total=False):
        key "certBlob": str
        key "certThumbprint": str
        key "dnsServers": str
        key "isSwift": bool
        key "resyncRequired": bool
        key "vnetResourceId": str
        cert_blob: str
        cert_thumbprint: str
        dns_servers: str
        is_swift: bool
        resync_required: bool
        routes: list[VnetRoute]
        vnet_resource_id: str


    class azure.mgmt.web.types.VnetInfoResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('VnetInfo', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: VnetInfo
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.VnetParameters(ProxyOnlyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('VnetParametersProperties', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: VnetParametersProperties
        type: str


    class azure.mgmt.web.types.VnetParametersProperties(TypedDict, total=False):
        key "subnetResourceId": str
        key "vnetName": str
        key "vnetResourceGroup": str
        key "vnetSubnetName": str
        subnet_resource_id: str
        vnet_name: str
        vnet_resource_group: str
        vnet_subnet_name: str


    class azure.mgmt.web.types.VnetRoute(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('VnetRouteProperties', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: VnetRouteProperties
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.VnetRouteProperties(TypedDict, total=False):
        key "endAddress": str
        key "routeType": Union[str, RouteType]
        key "startAddress": str
        end_address: str
        route_type: Union[str, RouteType]
        start_address: str


    class azure.mgmt.web.types.VolumeMount(TypedDict, total=False):
        key "containerMountPath": Required[str]
        key "data": str
        key "readOnly": bool
        key "volumeSubPath": Required[str]
        container_mount_path: str
        data: str
        read_only: bool
        volume_sub_path: str


    class azure.mgmt.web.types.WorkerPool(TypedDict, total=False):
        key "computeMode": Union[str, ComputeModeOptions]
        key "workerCount": int
        key "workerSize": str
        key "workerSizeId": int
        compute_mode: Union[str, ComputeModeOptions]
        instanceNames: list[str]
        instance_names: list[str]
        worker_count: int
        worker_size: str
        worker_size_id: int


    class azure.mgmt.web.types.WorkerPoolResource(ProxyResource):
        key "id": str
        key "kind": str
        key "name": str
        key "properties": ForwardRef('WorkerPool', module='types')
        key "sku": ForwardRef('SkuDescription', module='types')
        key "systemData": ForwardRef('SystemData', module='types')
        key "type": str
        id: str
        kind: str
        name: str
        properties: WorkerPool
        sku: SkuDescription
        system_data: SystemData
        type: str


    class azure.mgmt.web.types.Workflow(WorkflowResource):
        key "id": str
        key "identity": ForwardRef('ManagedServiceIdentity', module='types')
        key "location": str
        key "name": str
        key "properties": ForwardRef('WorkflowProperties', module='types')
        key "type": str
        id: str
        identity: ManagedServiceIdentity
        location: str
        name: str
        properties: WorkflowProperties
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.WorkflowArtifacts(TypedDict, total=False):
        key "appSettings": Any
        app_settings: Any
        files: dict[str, Any]
        filesToDelete: list[str]
        files_to_delete: list[str]


    class azure.mgmt.web.types.WorkflowParameter(TypedDict, total=False):
        key "description": str
        key "metadata": Any
        key "type": Union[str, ParameterType]
        key "value": Any
        description: str
        metadata: Any
        type: Union[str, ParameterType]
        value: Any


    class azure.mgmt.web.types.WorkflowProperties(TypedDict, total=False):
        key "accessControl": ForwardRef('FlowAccessControlConfiguration', module='types')
        key "accessEndpoint": str
        key "changedTime": str
        key "createdTime": str
        key "definition": Any
        key "endpointsConfiguration": ForwardRef('FlowEndpointsConfiguration', module='types')
        key "integrationAccount": ForwardRef('ResourceReference', module='types')
        key "integrationServiceEnvironment": ForwardRef('ResourceReference', module='types')
        key "kind": Union[str, Kind]
        key "provisioningState": Union[str, WorkflowProvisioningState]
        key "sku": ForwardRef('WorkflowSku', module='types')
        key "state": Union[str, WorkflowState]
        key "version": str
        access_control: FlowAccessControlConfiguration
        access_endpoint: str
        changed_time: str
        created_time: str
        definition: Any
        endpoints_configuration: FlowEndpointsConfiguration
        integration_account: ResourceReference
        integration_service_environment: ResourceReference
        kind: Union[str, Kind]
        parameters: dict[str, WorkflowParameter]
        provisioning_state: Union[str, WorkflowProvisioningState]
        sku: WorkflowSku
        state: Union[str, WorkflowState]
        version: str


    class azure.mgmt.web.types.WorkflowResource(TypedDict, total=False):
        key "id": str
        key "location": str
        key "name": str
        key "type": str
        id: str
        location: str
        name: str
        tags: dict[str, str]
        type: str


    class azure.mgmt.web.types.WorkflowSku(TypedDict, total=False):
        key "name": Required[Union[str, WorkflowSkuName]]
        key "plan": ForwardRef('ResourceReference', module='types')
        name: Union[str, WorkflowSkuName]
        plan: ResourceReference


```